""" Cisco_IOS_XR_ipv4_bgp_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-bgp package configuration.

This module contains definitions
for the following management objects\:
  bgp\: BGP configuration commands
  bmp\-server\-all\: bmp server all
  bmp\-servers\: bmp servers

This YANG module augments the
  Cisco\-IOS\-XR\-infra\-rsi\-cfg,
  Cisco\-IOS\-XR\-snmp\-agent\-cfg
modules with configuration data.

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class BgpAdvRt(Enum):
    """
    BgpAdvRt

    Bgp adv rt

    .. data:: bgp_regular_rt = 0

    	Regular RT type

    .. data:: bgp_stitching_rt = 1

    	Stitching RT type

    """

    bgp_regular_rt = Enum.YLeaf(0, "bgp-regular-rt")

    bgp_stitching_rt = Enum.YLeaf(1, "bgp-stitching-rt")


class BgpAfEncapsulation(Enum):
    """
    BgpAfEncapsulation

    Bgp af encapsulation

    .. data:: vx_lan = 1

    	VxLAN encapsulation type

    """

    vx_lan = Enum.YLeaf(1, "vx-lan")


class BgpAigpCfg(Enum):
    """
    BgpAigpCfg

    Bgp aigp cfg

    .. data:: enable = 1

    	Enable AIGP

    .. data:: disable = 2

    	Disable AIGP

    """

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")


class BgpAigpCfgPoi(Enum):
    """
    BgpAigpCfgPoi

    Bgp aigp cfg poi

    .. data:: pre_best_path = 1

    	AIGP Pre-bestpath POI

    .. data:: igp_cost = 2

    	AIGP igp-cost POI

    """

    pre_best_path = Enum.YLeaf(1, "pre-best-path")

    igp_cost = Enum.YLeaf(2, "igp-cost")


class BgpBfdEnableMode(Enum):
    """
    BgpBfdEnableMode

    Bgp bfd enable mode

    .. data:: disable = 0

    	Disable Mode - Prevent inheritance

    .. data:: default = 1

    	Default Mode - Default BFD behavior

    .. data:: strict = 2

    	Strict Mode - Hold down adj until BFD session

    	up

    """

    disable = Enum.YLeaf(0, "disable")

    default = Enum.YLeaf(1, "default")

    strict = Enum.YLeaf(2, "strict")


class BgpClusterId(Enum):
    """
    BgpClusterId

    Bgp cluster id

    .. data:: number = 1

    	Number

    .. data:: ipv4_address = 2

    	IPv4 Address

    """

    number = Enum.YLeaf(1, "number")

    ipv4_address = Enum.YLeaf(2, "ipv4-address")


class BgpEbgpSendDmzEnableMode(Enum):
    """
    BgpEbgpSendDmzEnableMode

    Bgp ebgp send dmz enable mode

    .. data:: disable = 0

    	Disable Mode - Prevent inheritance

    .. data:: default = 1

    	Default Mode - Send dmz link bandwidth value to

    	ebgp neighbor

    .. data:: cumulative = 2

    	Strict Mode - Send cumulative dmz link

    	bandwidth value to ebgp neighbor

    """

    disable = Enum.YLeaf(0, "disable")

    default = Enum.YLeaf(1, "default")

    cumulative = Enum.YLeaf(2, "cumulative")


class BgpFlowspecValidationCfg(Enum):
    """
    BgpFlowspecValidationCfg

    Bgp flowspec validation cfg

    .. data:: enable = 1

    	Enable Flowspec validation

    .. data:: disable = 2

    	Disable Flowspec validation

    .. data:: redirect_nexhop_disable = 3

    	Disable Flowspec redirect nexthop validation

    """

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")

    redirect_nexhop_disable = Enum.YLeaf(3, "redirect-nexhop-disable")


class BgpMvpnSfsSelect(Enum):
    """
    BgpMvpnSfsSelect

    Bgp mvpn sfs select

    .. data:: all_paths = 1

    	Select all paths as single forwarder PE

    .. data:: highest_ip_address = 2

    	Select PE with highest address as single

    	forwarder PE

    """

    all_paths = Enum.YLeaf(1, "all-paths")

    highest_ip_address = Enum.YLeaf(2, "highest-ip-address")


class BgpOrf(Enum):
    """
    BgpOrf

    Bgp orf

    .. data:: none = 0

    	No capability to send or receive

    .. data:: receive = 1

    	Receive ORF capability

    .. data:: send = 2

    	Send ORF capability

    .. data:: both = 3

    	Send and receive ORF capability

    """

    none = Enum.YLeaf(0, "none")

    receive = Enum.YLeaf(1, "receive")

    send = Enum.YLeaf(2, "send")

    both = Enum.YLeaf(3, "both")


class BgpReorgOpt(Enum):
    """
    BgpReorgOpt

    Bgp reorg opt

    .. data:: bgp_cfg_adv = 1

    	Advertise translated routes

    .. data:: bgp_cfg_adv_reorg = 2

    	Advertise Reorig routes

    .. data:: bgp_cfg_adv_disable = 3

    	Disable adv of routes

    .. data:: bgp_cfg_adv_local = 4

    	Advertise local routes

    .. data:: bgp_cfg_adv_def_vrf_imp_disable = 5

    	Disable adv of Def VRF Imported routes

    .. data:: bgp_cfg_adv_vrf_re_imp_disable = 6

    	Disable adv of VRF ReImported routes

    """

    bgp_cfg_adv = Enum.YLeaf(1, "bgp-cfg-adv")

    bgp_cfg_adv_reorg = Enum.YLeaf(2, "bgp-cfg-adv-reorg")

    bgp_cfg_adv_disable = Enum.YLeaf(3, "bgp-cfg-adv-disable")

    bgp_cfg_adv_local = Enum.YLeaf(4, "bgp-cfg-adv-local")

    bgp_cfg_adv_def_vrf_imp_disable = Enum.YLeaf(5, "bgp-cfg-adv-def-vrf-imp-disable")

    bgp_cfg_adv_vrf_re_imp_disable = Enum.YLeaf(6, "bgp-cfg-adv-vrf-re-imp-disable")


class BgpRnhInstallFormat(Enum):
    """
    BgpRnhInstallFormat

    Bgp rnh install format

    .. data:: ext_comm = 0

    	Install RNH as opaque and extcomm

    .. data:: ext_comm_only = 1

    	Install RNH as extcomm only

    """

    ext_comm = Enum.YLeaf(0, "ext-comm")

    ext_comm_only = Enum.YLeaf(1, "ext-comm-only")


class BgpRouteDistinguisher(Enum):
    """
    BgpRouteDistinguisher

    Bgp route distinguisher

    .. data:: auto = 1

    	Automatically assigned

    .. data:: as_ = 2

    	AS format RD

    .. data:: four_byte_as = 3

    	4-byte AS format RD

    .. data:: ipv4_address = 4

    	IPv4 address format RD

    """

    auto = Enum.YLeaf(1, "auto")

    as_ = Enum.YLeaf(2, "as")

    four_byte_as = Enum.YLeaf(3, "four-byte-as")

    ipv4_address = Enum.YLeaf(4, "ipv4-address")


class BgpRpkiTransport(Enum):
    """
    BgpRpkiTransport

    Bgp rpki transport

    .. data:: tcp = 0

    	TCP Transport

    .. data:: ssh = 1

    	SSH Transport

    """

    tcp = Enum.YLeaf(0, "tcp")

    ssh = Enum.YLeaf(1, "ssh")


class BgpSendMcastAttrCfg(Enum):
    """
    BgpSendMcastAttrCfg

    Bgp send mcast attr cfg

    .. data:: enable = 1

    	Enable SendMcastAttr

    .. data:: disable = 2

    	Disable SendMcastAttr

    """

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")


class BgpSignal(Enum):
    """
    BgpSignal

    Bgp signal

    .. data:: bgp_disable = 1

    	Signalling BGP disable

    .. data:: ldp_disable = 2

    	Signalling LDP disable

    """

    bgp_disable = Enum.YLeaf(1, "bgp-disable")

    ldp_disable = Enum.YLeaf(2, "ldp-disable")


class BgpSiteOfOrigin(Enum):
    """
    BgpSiteOfOrigin

    Bgp site of origin

    .. data:: as_ = 0

    	AS format SoO

    .. data:: ipv4_address = 1

    	IPv4 address format SoO

    .. data:: four_byte_as = 2

    	4-byte AS format SoO

    """

    as_ = Enum.YLeaf(0, "as")

    ipv4_address = Enum.YLeaf(1, "ipv4-address")

    four_byte_as = Enum.YLeaf(2, "four-byte-as")


class BgpTcpMode(Enum):
    """
    BgpTcpMode

    Bgp tcp mode

    .. data:: either = 0

    	Either active or passive mode

    .. data:: active_only = 1

    	Active mode only

    .. data:: passive_only = 2

    	Passive mode only

    """

    either = Enum.YLeaf(0, "either")

    active_only = Enum.YLeaf(1, "active-only")

    passive_only = Enum.YLeaf(2, "passive-only")


class BgpVrfRouteTarget(Enum):
    """
    BgpVrfRouteTarget

    Bgp vrf route target

    .. data:: as_ = 0

    	AS format RT

    .. data:: ipv4_address = 1

    	IPv4 address format RT

    .. data:: four_byte_as = 2

    	4-byte AS format RT

    """

    as_ = Enum.YLeaf(0, "as")

    ipv4_address = Enum.YLeaf(1, "ipv4-address")

    four_byte_as = Enum.YLeaf(2, "four-byte-as")


class BmpPolicySelect(Enum):
    """
    BmpPolicySelect

    Bmp policy select

    .. data:: post_policy = 2

    	Pickup routes after policy application

    """

    post_policy = Enum.YLeaf(2, "post-policy")


class BmpRouteDirection(Enum):
    """
    BmpRouteDirection

    Bmp route direction

    .. data:: inbound = 1

    	Pickup routes at inbound direction from peer

    """

    inbound = Enum.YLeaf(1, "inbound")



class Bgp(Entity):
    """
    BGP configuration commands
    
    .. attribute:: instance
    
    	BGP instance configuration commands
    	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance>`
    
    

    """

    _prefix = 'ipv4-bgp-cfg'
    _revision = '2015-08-27'

    def __init__(self):
        super(Bgp, self).__init__()
        self._top_entity = None

        self.yang_name = "bgp"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-cfg"

        self.instance = YList(self)

    def __setattr__(self, name, value):
        self._check_monkey_patching_error(name, value)
        with _handle_type_error():
            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                    "Please use list append or extend method."
                                    .format(value))
            if isinstance(value, Enum.YLeaf):
                value = value.name
            if name in () and name in self.__dict__:
                if isinstance(value, YLeaf):
                    self.__dict__[name].set(value.get())
                elif isinstance(value, YLeafList):
                    super(Bgp, self).__setattr__(name, value)
                else:
                    self.__dict__[name].set(value)
            else:
                if hasattr(value, "parent") and name != "parent":
                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                        value.parent = self
                    elif value.parent is None and value.yang_name in self._children_yang_names:
                        value.parent = self
                super(Bgp, self).__setattr__(name, value)


    class Instance(Entity):
        """
        BGP instance configuration commands
        
        .. attribute:: instance_name  <key>
        
        	Instance Name. For Default instance use \- default
        	**type**\:  str
        
        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
        
        .. attribute:: instance_as
        
        	Autonomous system
        	**type**\: list of    :py:class:`InstanceAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs>`
        
        

        """

        _prefix = 'ipv4-bgp-cfg'
        _revision = '2015-08-27'

        def __init__(self):
            super(Bgp.Instance, self).__init__()

            self.yang_name = "instance"
            self.yang_parent_name = "bgp"

            self.instance_name = YLeaf(YType.str, "instance-name")

            self.instance_as = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("instance_name") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Bgp.Instance, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Bgp.Instance, self).__setattr__(name, value)


        class InstanceAs(Entity):
            """
            Autonomous system
            
            .. attribute:: as_  <key>
            
            	Higher 16 bits of 4\-byte Autonomous system number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: four_byte_as
            
            	4\-byte Autonomous system
            	**type**\: list of    :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs>`
            
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2015-08-27'

            def __init__(self):
                super(Bgp.Instance.InstanceAs, self).__init__()

                self.yang_name = "instance-as"
                self.yang_parent_name = "instance"

                self.as_ = YLeaf(YType.uint32, "as")

                self.four_byte_as = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("as_") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Bgp.Instance.InstanceAs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Bgp.Instance.InstanceAs, self).__setattr__(name, value)


            class FourByteAs(Entity):
                """
                4\-byte Autonomous system
                
                .. attribute:: as_  <key>
                
                	2\-byte or 4\-byte Autonomous system number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_running
                
                	Enable BGP. Deletion of this object causes deletion of all the objects under FourByteAS associated with this object
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: default_vrf
                
                	Global default config
                	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf>`
                
                .. attribute:: vrfs
                
                	VRF config
                	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs>`
                
                

                """

                _prefix = 'ipv4-bgp-cfg'
                _revision = '2015-08-27'

                def __init__(self):
                    super(Bgp.Instance.InstanceAs.FourByteAs, self).__init__()

                    self.yang_name = "four-byte-as"
                    self.yang_parent_name = "instance-as"

                    self.as_ = YLeaf(YType.uint32, "as")

                    self.bgp_running = YLeaf(YType.empty, "bgp-running")

                    self.default_vrf = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf()
                    self.default_vrf.parent = self
                    self._children_name_map["default_vrf"] = "default-vrf"
                    self._children_yang_names.add("default-vrf")

                    self.vrfs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                    self._children_yang_names.add("vrfs")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("as_",
                                    "bgp_running") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Bgp.Instance.InstanceAs.FourByteAs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Bgp.Instance.InstanceAs.FourByteAs, self).__setattr__(name, value)


                class Vrfs(Entity):
                    """
                    VRF config
                    
                    .. attribute:: vrf
                    
                    	VRF config
                    	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-cfg'
                    _revision = '2015-08-27'

                    def __init__(self):
                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs, self).__init__()

                        self.yang_name = "vrfs"
                        self.yang_parent_name = "four-byte-as"

                        self.vrf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs, self).__setattr__(name, value)


                    class Vrf(Entity):
                        """
                        VRF config
                        
                        .. attribute:: vrf_name  <key>
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: vrf_global
                        
                        	VRF attribute config
                        	**type**\:   :py:class:`VrfGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal>`
                        
                        .. attribute:: vrf_neighbors
                        
                        	BGP VRF peer
                        	**type**\:   :py:class:`VrfNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-cfg'
                        _revision = '2015-08-27'

                        def __init__(self):
                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrfs"

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.vrf_global = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal()
                            self.vrf_global.parent = self
                            self._children_name_map["vrf_global"] = "vrf-global"
                            self._children_yang_names.add("vrf-global")

                            self.vrf_neighbors = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors()
                            self.vrf_neighbors.parent = self
                            self._children_name_map["vrf_neighbors"] = "vrf-neighbors"
                            self._children_yang_names.add("vrf-neighbors")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf, self).__setattr__(name, value)


                        class VrfGlobal(Entity):
                            """
                            VRF attribute config
                            
                            .. attribute:: best_path_aigp_ignore
                            
                            	Change default route selection criteria to ignore AIGP unless both paths whichare compared have AIGP attribute
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_as_multipath_relax
                            
                            	Change default multi\-route selection criteria to relax as\-path checking \- only require same aspath length
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_as_path_length
                            
                            	Change default route selection criteria to ignore AS path length
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_confederation_paths
                            
                            	Change default route selection criteria and allow the comparing of MED among confederation paths
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_cost_community
                            
                            	Change default route selection criteria to ignore cost community comparison
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_med_always
                            
                            	Change default route selection criteria and allow comparing of MED from different neighbors
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_med_missing
                            
                            	Treat missing MED as the least preferred one
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_router_id
                            
                            	Change default route selection criteria and compare router\-id for identical EBGP paths
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: bfd
                            
                            	BFD configuration
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd>`
                            
                            .. attribute:: default_info_originate
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: default_metric
                            
                            	Default redistributed metric
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: disable_auto_soft_reset
                            
                            	Disable automatic soft peer reset on policy reconfiguration
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_enforce_first_as
                            
                            	Disable enforce the first AS for EBGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_fast_external_fallover
                            
                            	Disable immediate reset session if a link to a directly connected external peer goes down
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_msg_log
                            
                            	Disable inbound and outbound messagelogging for all neighbors under the vrf
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_neighbor_logging
                            
                            	Disable neighbor change logging
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: exists
                            
                            	Create this VRF. Deletion of this object causes deletion of all the objects under VRF associated with this object
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: global_timers
                            
                            	Adjust routing timers
                            	**type**\:   :py:class:`GlobalTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers>`
                            
                            .. attribute:: igp_redist_internal
                            
                            	Allow redistribution of iBGP into IGPs (dangerous)
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: local_preference
                            
                            	Configure default local preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**default value**\: 100
                            
                            .. attribute:: mpls_activated_interfaces
                            
                            	Configure list of MPLS activated interfaces
                            	**type**\:   :py:class:`MplsActivatedInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces>`
                            
                            .. attribute:: multi_path_as_path_ignore_onwards
                            
                            	Change default multi\-route selection criteria to ignore everything onwards as\-path check
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: receive_socket_buffer_sizes
                            
                            	Set socket and BGP receive buffer sizes
                            	**type**\:   :py:class:`ReceiveSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes>`
                            
                            .. attribute:: route_distinguisher
                            
                            	Route distinguisher
                            	**type**\:   :py:class:`RouteDistinguisher <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher>`
                            
                            .. attribute:: router_id
                            
                            	Configure Router\-id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: send_socket_buffer_sizes
                            
                            	set socket parameters
                            	**type**\:   :py:class:`SendSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes>`
                            
                            .. attribute:: vrf_global_afs
                            
                            	Global VRF\-specific configuration
                            	**type**\:   :py:class:`VrfGlobalAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal, self).__init__()

                                self.yang_name = "vrf-global"
                                self.yang_parent_name = "vrf"

                                self.best_path_aigp_ignore = YLeaf(YType.empty, "best-path-aigp-ignore")

                                self.best_path_as_multipath_relax = YLeaf(YType.empty, "best-path-as-multipath-relax")

                                self.best_path_as_path_length = YLeaf(YType.empty, "best-path-as-path-length")

                                self.best_path_confederation_paths = YLeaf(YType.empty, "best-path-confederation-paths")

                                self.best_path_cost_community = YLeaf(YType.empty, "best-path-cost-community")

                                self.best_path_med_always = YLeaf(YType.empty, "best-path-med-always")

                                self.best_path_med_missing = YLeaf(YType.empty, "best-path-med-missing")

                                self.best_path_router_id = YLeaf(YType.empty, "best-path-router-id")

                                self.default_info_originate = YLeaf(YType.empty, "default-info-originate")

                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                self.disable_auto_soft_reset = YLeaf(YType.empty, "disable-auto-soft-reset")

                                self.disable_enforce_first_as = YLeaf(YType.empty, "disable-enforce-first-as")

                                self.disable_fast_external_fallover = YLeaf(YType.empty, "disable-fast-external-fallover")

                                self.disable_msg_log = YLeaf(YType.empty, "disable-msg-log")

                                self.disable_neighbor_logging = YLeaf(YType.empty, "disable-neighbor-logging")

                                self.exists = YLeaf(YType.empty, "exists")

                                self.igp_redist_internal = YLeaf(YType.empty, "igp-redist-internal")

                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                self.multi_path_as_path_ignore_onwards = YLeaf(YType.empty, "multi-path-as-path-ignore-onwards")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.bfd = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                                self._children_yang_names.add("bfd")

                                self.global_timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers()
                                self.global_timers.parent = self
                                self._children_name_map["global_timers"] = "global-timers"
                                self._children_yang_names.add("global-timers")

                                self.mpls_activated_interfaces = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces()
                                self.mpls_activated_interfaces.parent = self
                                self._children_name_map["mpls_activated_interfaces"] = "mpls-activated-interfaces"
                                self._children_yang_names.add("mpls-activated-interfaces")

                                self.receive_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes()
                                self.receive_socket_buffer_sizes.parent = self
                                self._children_name_map["receive_socket_buffer_sizes"] = "receive-socket-buffer-sizes"
                                self._children_yang_names.add("receive-socket-buffer-sizes")

                                self.route_distinguisher = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher()
                                self.route_distinguisher.parent = self
                                self._children_name_map["route_distinguisher"] = "route-distinguisher"
                                self._children_yang_names.add("route-distinguisher")

                                self.send_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes()
                                self.send_socket_buffer_sizes.parent = self
                                self._children_name_map["send_socket_buffer_sizes"] = "send-socket-buffer-sizes"
                                self._children_yang_names.add("send-socket-buffer-sizes")

                                self.vrf_global_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs()
                                self.vrf_global_afs.parent = self
                                self._children_name_map["vrf_global_afs"] = "vrf-global-afs"
                                self._children_yang_names.add("vrf-global-afs")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("best_path_aigp_ignore",
                                                "best_path_as_multipath_relax",
                                                "best_path_as_path_length",
                                                "best_path_confederation_paths",
                                                "best_path_cost_community",
                                                "best_path_med_always",
                                                "best_path_med_missing",
                                                "best_path_router_id",
                                                "default_info_originate",
                                                "default_metric",
                                                "disable_auto_soft_reset",
                                                "disable_enforce_first_as",
                                                "disable_fast_external_fallover",
                                                "disable_msg_log",
                                                "disable_neighbor_logging",
                                                "exists",
                                                "igp_redist_internal",
                                                "local_preference",
                                                "multi_path_as_path_ignore_onwards",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal, self).__setattr__(name, value)


                            class RouteDistinguisher(Entity):
                                """
                                Route distinguisher
                                
                                .. attribute:: address
                                
                                	IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address_index
                                
                                	IP address index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_
                                
                                	AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_index
                                
                                	ASN Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_xx
                                
                                	AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type
                                
                                	Type of RD
                                	**type**\:   :py:class:`BgpRouteDistinguisher <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRouteDistinguisher>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher, self).__init__()

                                    self.yang_name = "route-distinguisher"
                                    self.yang_parent_name = "vrf-global"

                                    self.address = YLeaf(YType.str, "address")

                                    self.address_index = YLeaf(YType.uint32, "address-index")

                                    self.as_ = YLeaf(YType.uint32, "as")

                                    self.as_index = YLeaf(YType.uint32, "as-index")

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "address_index",
                                                    "as_",
                                                    "as_index",
                                                    "as_xx",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.address_index.is_set or
                                        self.as_.is_set or
                                        self.as_index.is_set or
                                        self.as_xx.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.address_index.yfilter != YFilter.not_set or
                                        self.as_.yfilter != YFilter.not_set or
                                        self.as_index.yfilter != YFilter.not_set or
                                        self.as_xx.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-distinguisher" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.address_index.is_set or self.address_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address_index.get_name_leafdata())
                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_.get_name_leafdata())
                                    if (self.as_index.is_set or self.as_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_index.get_name_leafdata())
                                    if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_xx.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "address-index" or name == "as" or name == "as-index" or name == "as-xx" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "address-index"):
                                        self.address_index = value
                                        self.address_index.value_namespace = name_space
                                        self.address_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as"):
                                        self.as_ = value
                                        self.as_.value_namespace = name_space
                                        self.as_.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-index"):
                                        self.as_index = value
                                        self.as_index.value_namespace = name_space
                                        self.as_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-xx"):
                                        self.as_xx = value
                                        self.as_xx.value_namespace = name_space
                                        self.as_xx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class VrfGlobalAfs(Entity):
                                """
                                Global VRF\-specific configuration
                                
                                .. attribute:: vrf_global_af
                                
                                	Global VRF AF\-specific configuration
                                	**type**\: list of    :py:class:`VrfGlobalAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs, self).__init__()

                                    self.yang_name = "vrf-global-afs"
                                    self.yang_parent_name = "vrf-global"

                                    self.vrf_global_af = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs, self).__setattr__(name, value)


                                class VrfGlobalAf(Entity):
                                    """
                                    Global VRF AF\-specific configuration
                                    
                                    .. attribute:: af_name  <key>
                                    
                                    	Address family
                                    	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                    
                                    .. attribute:: additional_paths_receive
                                    
                                    	Advertise additional paths Receive capability
                                    	**type**\:   :py:class:`BgpafAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpafAdditionalPathsCfg>`
                                    
                                    .. attribute:: additional_paths_selection
                                    
                                    	Configure additional paths selection
                                    	**type**\:   :py:class:`AdditionalPathsSelection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection>`
                                    
                                    .. attribute:: additional_paths_send
                                    
                                    	Advertise additional paths Send capability
                                    	**type**\:   :py:class:`BgpafAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpafAdditionalPathsCfg>`
                                    
                                    .. attribute:: advertise_local_labeled_route_safi_unicast
                                    
                                    	Enable/disable advertisement of routes with local\-label via Unicast SAFI
                                    	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                    
                                    .. attribute:: aggregate_addresses
                                    
                                    	Configure BGP aggregate entries
                                    	**type**\:   :py:class:`AggregateAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses>`
                                    
                                    .. attribute:: allocate_label
                                    
                                    	Label allocation policy
                                    	**type**\:   :py:class:`AllocateLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel>`
                                    
                                    .. attribute:: allow_vpn_default_originate
                                    
                                    	TRUE to send default orig route to VPN neighborFALSE to not send default originate route 
                                    	**type**\:  bool
                                    
                                    .. attribute:: application_routes
                                    
                                    	Redistribute information for Application routes
                                    	**type**\:   :py:class:`ApplicationRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes>`
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download configuration
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: best_external
                                    
                                    	TRUE to enable BE FALSE to disable BE inheritance from a parent
                                    	**type**\:  bool
                                    
                                    .. attribute:: connected_routes
                                    
                                    	Redistribute connected routes
                                    	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:   :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: disable_as_path_loop_check
                                    
                                    	Disable outbound AS Path loop check
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: distance
                                    
                                    	Define an administrative distance
                                    	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance>`
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Update generation delay (in minutes) after a MED change
                                    	**type**\:  int
                                    
                                    	**range:** 0..10
                                    
                                    	**units**\: minute
                                    
                                    	**default value**\: 10
                                    
                                    .. attribute:: ebgp
                                    
                                    	Use eBGP multipaths
                                    	**type**\:   :py:class:`Ebgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eibgp
                                    
                                    	Use eiBGP multipaths
                                    	**type**\:   :py:class:`Eibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp_routes
                                    
                                    	Redistribute information for EIGRP routes
                                    	**type**\:   :py:class:`EigrpRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes>`
                                    
                                    .. attribute:: enable
                                    
                                    	Enable the address family. Deletion of this object causes deletion of all the objects under GlobalAF/VRFGlobalAF associated with this object 
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ibgp
                                    
                                    	Use iBGP multipaths
                                    	**type**\:   :py:class:`Ibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: label_mode
                                    
                                    	BGP 6PE/MPLS\-VPN label allocation mode
                                    	**type**\:   :py:class:`LabelMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode>`
                                    
                                    .. attribute:: lisp_routes
                                    
                                    	Redistribute lisp routes
                                    	**type**\:   :py:class:`LispRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: mobile_routes
                                    
                                    	Redistribute mobile routes
                                    	**type**\:   :py:class:`MobileRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: mvpn
                                    
                                    	MVPN configurations
                                    	**type**\:   :py:class:`Mvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn>`
                                    
                                    .. attribute:: next_hop_resolution_prefix_length_minimum
                                    
                                    	Minimum prefix\-length for nexthop resolution
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    	**default value**\: 0
                                    
                                    .. attribute:: ospf_routes
                                    
                                    	Redistribute information for OSPF routes
                                    	**type**\:   :py:class:`OspfRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes>`
                                    
                                    .. attribute:: permanent_network
                                    
                                    	Route policy for permanent networks
                                    	**type**\:  str
                                    
                                    .. attribute:: reset_weight_on_import
                                    
                                    	TRUE to reset weight on import. FALSE to not reset and to prevent inheritance from a parent
                                    	**type**\:  bool
                                    
                                    .. attribute:: rip_routes
                                    
                                    	Redistribute RIP routes
                                    	**type**\:   :py:class:`RipRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: rt_download
                                    
                                    	Route\-Target download configuration
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sourced_networks
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks>`
                                    
                                    .. attribute:: static_routes
                                    
                                    	Redistribute static routes
                                    	**type**\:   :py:class:`StaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: subscriber_routes
                                    
                                    	Redistribute subscriber routes
                                    	**type**\:   :py:class:`SubscriberRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: table_policy
                                    
                                    	Configure policy for installation of routes to RIB
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf, self).__init__()

                                        self.yang_name = "vrf-global-af"
                                        self.yang_parent_name = "vrf-global-afs"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.additional_paths_receive = YLeaf(YType.enumeration, "additional-paths-receive")

                                        self.additional_paths_send = YLeaf(YType.enumeration, "additional-paths-send")

                                        self.advertise_local_labeled_route_safi_unicast = YLeaf(YType.enumeration, "advertise-local-labeled-route-safi-unicast")

                                        self.allow_vpn_default_originate = YLeaf(YType.boolean, "allow-vpn-default-originate")

                                        self.attribute_download = YLeaf(YType.empty, "attribute-download")

                                        self.best_external = YLeaf(YType.boolean, "best-external")

                                        self.disable_as_path_loop_check = YLeaf(YType.empty, "disable-as-path-loop-check")

                                        self.dynamic_med_interval = YLeaf(YType.uint32, "dynamic-med-interval")

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.next_hop_resolution_prefix_length_minimum = YLeaf(YType.uint32, "next-hop-resolution-prefix-length-minimum")

                                        self.permanent_network = YLeaf(YType.str, "permanent-network")

                                        self.reset_weight_on_import = YLeaf(YType.boolean, "reset-weight-on-import")

                                        self.rt_download = YLeaf(YType.empty, "rt-download")

                                        self.table_policy = YLeaf(YType.str, "table-policy")

                                        self.additional_paths_selection = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection()
                                        self.additional_paths_selection.parent = self
                                        self._children_name_map["additional_paths_selection"] = "additional-paths-selection"
                                        self._children_yang_names.add("additional-paths-selection")

                                        self.aggregate_addresses = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses()
                                        self.aggregate_addresses.parent = self
                                        self._children_name_map["aggregate_addresses"] = "aggregate-addresses"
                                        self._children_yang_names.add("aggregate-addresses")

                                        self.allocate_label = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel()
                                        self.allocate_label.parent = self
                                        self._children_name_map["allocate_label"] = "allocate-label"
                                        self._children_yang_names.add("allocate-label")

                                        self.application_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes()
                                        self.application_routes.parent = self
                                        self._children_name_map["application_routes"] = "application-routes"
                                        self._children_yang_names.add("application-routes")

                                        self.connected_routes = None
                                        self._children_name_map["connected_routes"] = "connected-routes"
                                        self._children_yang_names.add("connected-routes")

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"
                                        self._children_yang_names.add("dampening")

                                        self.distance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"
                                        self._children_yang_names.add("distance")

                                        self.ebgp = None
                                        self._children_name_map["ebgp"] = "ebgp"
                                        self._children_yang_names.add("ebgp")

                                        self.eibgp = None
                                        self._children_name_map["eibgp"] = "eibgp"
                                        self._children_yang_names.add("eibgp")

                                        self.eigrp_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes()
                                        self.eigrp_routes.parent = self
                                        self._children_name_map["eigrp_routes"] = "eigrp-routes"
                                        self._children_yang_names.add("eigrp-routes")

                                        self.ibgp = None
                                        self._children_name_map["ibgp"] = "ibgp"
                                        self._children_yang_names.add("ibgp")

                                        self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode()
                                        self.label_mode.parent = self
                                        self._children_name_map["label_mode"] = "label-mode"
                                        self._children_yang_names.add("label-mode")

                                        self.lisp_routes = None
                                        self._children_name_map["lisp_routes"] = "lisp-routes"
                                        self._children_yang_names.add("lisp-routes")

                                        self.mobile_routes = None
                                        self._children_name_map["mobile_routes"] = "mobile-routes"
                                        self._children_yang_names.add("mobile-routes")

                                        self.mvpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn()
                                        self.mvpn.parent = self
                                        self._children_name_map["mvpn"] = "mvpn"
                                        self._children_yang_names.add("mvpn")

                                        self.ospf_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes()
                                        self.ospf_routes.parent = self
                                        self._children_name_map["ospf_routes"] = "ospf-routes"
                                        self._children_yang_names.add("ospf-routes")

                                        self.rip_routes = None
                                        self._children_name_map["rip_routes"] = "rip-routes"
                                        self._children_yang_names.add("rip-routes")

                                        self.sourced_networks = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks()
                                        self.sourced_networks.parent = self
                                        self._children_name_map["sourced_networks"] = "sourced-networks"
                                        self._children_yang_names.add("sourced-networks")

                                        self.static_routes = None
                                        self._children_name_map["static_routes"] = "static-routes"
                                        self._children_yang_names.add("static-routes")

                                        self.subscriber_routes = None
                                        self._children_name_map["subscriber_routes"] = "subscriber-routes"
                                        self._children_yang_names.add("subscriber-routes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "additional_paths_receive",
                                                        "additional_paths_send",
                                                        "advertise_local_labeled_route_safi_unicast",
                                                        "allow_vpn_default_originate",
                                                        "attribute_download",
                                                        "best_external",
                                                        "disable_as_path_loop_check",
                                                        "dynamic_med_interval",
                                                        "enable",
                                                        "next_hop_resolution_prefix_length_minimum",
                                                        "permanent_network",
                                                        "reset_weight_on_import",
                                                        "rt_download",
                                                        "table_policy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf, self).__setattr__(name, value)


                                    class Mvpn(Entity):
                                        """
                                        MVPN configurations
                                        
                                        .. attribute:: single_forwarder_selection
                                        
                                        	Select MVPN single forwarder selection
                                        	**type**\:   :py:class:`BgpMvpnSfsSelect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpMvpnSfsSelect>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn, self).__init__()

                                            self.yang_name = "mvpn"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.single_forwarder_selection = YLeaf(YType.enumeration, "single-forwarder-selection")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("single_forwarder_selection") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.single_forwarder_selection.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.single_forwarder_selection.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mvpn" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.single_forwarder_selection.is_set or self.single_forwarder_selection.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.single_forwarder_selection.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "single-forwarder-selection"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "single-forwarder-selection"):
                                                self.single_forwarder_selection = value
                                                self.single_forwarder_selection.value_namespace = name_space
                                                self.single_forwarder_selection.value_namespace_prefix = name_space_prefix


                                    class Ebgp(Entity):
                                        """
                                        Use eBGP multipaths
                                        
                                        .. attribute:: order_by_igp_metric
                                        
                                        	Order candidate multipaths by IGP metric
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: paths_value
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 2..32
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: selective
                                        
                                        	Allow multipaths only from marked neighbors
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	UNUSED
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp, self).__init__()

                                            self.yang_name = "ebgp"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                            self.paths_value = YLeaf(YType.uint32, "paths-value")

                                            self.selective = YLeaf(YType.boolean, "selective")

                                            self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("order_by_igp_metric",
                                                            "paths_value",
                                                            "selective",
                                                            "unequal_cost") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.order_by_igp_metric.is_set or
                                                self.paths_value.is_set or
                                                self.selective.is_set or
                                                self.unequal_cost.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.order_by_igp_metric.yfilter != YFilter.not_set or
                                                self.paths_value.yfilter != YFilter.not_set or
                                                self.selective.yfilter != YFilter.not_set or
                                                self.unequal_cost.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ebgp" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.order_by_igp_metric.is_set or self.order_by_igp_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.order_by_igp_metric.get_name_leafdata())
                                            if (self.paths_value.is_set or self.paths_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.paths_value.get_name_leafdata())
                                            if (self.selective.is_set or self.selective.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.selective.get_name_leafdata())
                                            if (self.unequal_cost.is_set or self.unequal_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unequal_cost.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "order-by-igp-metric" or name == "paths-value" or name == "selective" or name == "unequal-cost"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "order-by-igp-metric"):
                                                self.order_by_igp_metric = value
                                                self.order_by_igp_metric.value_namespace = name_space
                                                self.order_by_igp_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "paths-value"):
                                                self.paths_value = value
                                                self.paths_value.value_namespace = name_space
                                                self.paths_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "selective"):
                                                self.selective = value
                                                self.selective.value_namespace = name_space
                                                self.selective.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unequal-cost"):
                                                self.unequal_cost = value
                                                self.unequal_cost.value_namespace = name_space
                                                self.unequal_cost.value_namespace_prefix = name_space_prefix


                                    class Eibgp(Entity):
                                        """
                                        Use eiBGP multipaths
                                        
                                        .. attribute:: order_by_igp_metric
                                        
                                        	Order candidate multipaths by IGP metric
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: paths_value
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 2..32
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: selective
                                        
                                        	Allow multipaths only from marked neighbors
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	UNUSED
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp, self).__init__()

                                            self.yang_name = "eibgp"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                            self.paths_value = YLeaf(YType.uint32, "paths-value")

                                            self.selective = YLeaf(YType.boolean, "selective")

                                            self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("order_by_igp_metric",
                                                            "paths_value",
                                                            "selective",
                                                            "unequal_cost") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.order_by_igp_metric.is_set or
                                                self.paths_value.is_set or
                                                self.selective.is_set or
                                                self.unequal_cost.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.order_by_igp_metric.yfilter != YFilter.not_set or
                                                self.paths_value.yfilter != YFilter.not_set or
                                                self.selective.yfilter != YFilter.not_set or
                                                self.unequal_cost.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "eibgp" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.order_by_igp_metric.is_set or self.order_by_igp_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.order_by_igp_metric.get_name_leafdata())
                                            if (self.paths_value.is_set or self.paths_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.paths_value.get_name_leafdata())
                                            if (self.selective.is_set or self.selective.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.selective.get_name_leafdata())
                                            if (self.unequal_cost.is_set or self.unequal_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unequal_cost.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "order-by-igp-metric" or name == "paths-value" or name == "selective" or name == "unequal-cost"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "order-by-igp-metric"):
                                                self.order_by_igp_metric = value
                                                self.order_by_igp_metric.value_namespace = name_space
                                                self.order_by_igp_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "paths-value"):
                                                self.paths_value = value
                                                self.paths_value.value_namespace = name_space
                                                self.paths_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "selective"):
                                                self.selective = value
                                                self.selective.value_namespace = name_space
                                                self.selective.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unequal-cost"):
                                                self.unequal_cost = value
                                                self.unequal_cost.value_namespace = name_space
                                                self.unequal_cost.value_namespace_prefix = name_space_prefix


                                    class Ibgp(Entity):
                                        """
                                        Use iBGP multipaths
                                        
                                        .. attribute:: order_by_igp_metric
                                        
                                        	Order candidate multipaths by IGP metric
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: paths_value
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 2..32
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: selective
                                        
                                        	Allow multipaths only from marked neighbors
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	Allow multipaths to have different IGP metrics
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp, self).__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                            self.paths_value = YLeaf(YType.uint32, "paths-value")

                                            self.selective = YLeaf(YType.boolean, "selective")

                                            self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("order_by_igp_metric",
                                                            "paths_value",
                                                            "selective",
                                                            "unequal_cost") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.order_by_igp_metric.is_set or
                                                self.paths_value.is_set or
                                                self.selective.is_set or
                                                self.unequal_cost.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.order_by_igp_metric.yfilter != YFilter.not_set or
                                                self.paths_value.yfilter != YFilter.not_set or
                                                self.selective.yfilter != YFilter.not_set or
                                                self.unequal_cost.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ibgp" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.order_by_igp_metric.is_set or self.order_by_igp_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.order_by_igp_metric.get_name_leafdata())
                                            if (self.paths_value.is_set or self.paths_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.paths_value.get_name_leafdata())
                                            if (self.selective.is_set or self.selective.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.selective.get_name_leafdata())
                                            if (self.unequal_cost.is_set or self.unequal_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unequal_cost.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "order-by-igp-metric" or name == "paths-value" or name == "selective" or name == "unequal-cost"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "order-by-igp-metric"):
                                                self.order_by_igp_metric = value
                                                self.order_by_igp_metric.value_namespace = name_space
                                                self.order_by_igp_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "paths-value"):
                                                self.paths_value = value
                                                self.paths_value.value_namespace = name_space
                                                self.paths_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "selective"):
                                                self.selective = value
                                                self.selective.value_namespace = name_space
                                                self.selective.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unequal-cost"):
                                                self.unequal_cost = value
                                                self.unequal_cost.value_namespace = name_space
                                                self.unequal_cost.value_namespace_prefix = name_space_prefix


                                    class AggregateAddresses(Entity):
                                        """
                                        Configure BGP aggregate entries
                                        
                                        .. attribute:: aggregate_address
                                        
                                        	Aggregate address configuration
                                        	**type**\: list of    :py:class:`AggregateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses, self).__init__()

                                            self.yang_name = "aggregate-addresses"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.aggregate_address = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses, self).__setattr__(name, value)


                                        class AggregateAddress(Entity):
                                            """
                                            Aggregate address configuration
                                            
                                            .. attribute:: aggregate_addr  <key>
                                            
                                            	Aggregate in prefix/length format (address part)
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: aggregate_prefix  <key>
                                            
                                            	Aggregate in prefix/length format (prefix part)
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: generate_confederation_set_info
                                            
                                            	TRUE to generate AS confederation set path information, FALSE otherwise
                                            	**type**\:  bool
                                            
                                            .. attribute:: generate_set_info
                                            
                                            	TRUE to generate AS set path information, FALSE otherwise
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy on which to condition advertisement, suppression, and attributes
                                            	**type**\:  str
                                            
                                            .. attribute:: summary_only
                                            
                                            	TRUE to filter more specific routes from updates, FALSEotherwise
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress, self).__init__()

                                                self.yang_name = "aggregate-address"
                                                self.yang_parent_name = "aggregate-addresses"

                                                self.aggregate_addr = YLeaf(YType.str, "aggregate-addr")

                                                self.aggregate_prefix = YLeaf(YType.uint16, "aggregate-prefix")

                                                self.generate_confederation_set_info = YLeaf(YType.boolean, "generate-confederation-set-info")

                                                self.generate_set_info = YLeaf(YType.boolean, "generate-set-info")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                                self.summary_only = YLeaf(YType.boolean, "summary-only")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("aggregate_addr",
                                                                "aggregate_prefix",
                                                                "generate_confederation_set_info",
                                                                "generate_set_info",
                                                                "route_policy_name",
                                                                "summary_only") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.aggregate_addr.is_set or
                                                    self.aggregate_prefix.is_set or
                                                    self.generate_confederation_set_info.is_set or
                                                    self.generate_set_info.is_set or
                                                    self.route_policy_name.is_set or
                                                    self.summary_only.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.aggregate_addr.yfilter != YFilter.not_set or
                                                    self.aggregate_prefix.yfilter != YFilter.not_set or
                                                    self.generate_confederation_set_info.yfilter != YFilter.not_set or
                                                    self.generate_set_info.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set or
                                                    self.summary_only.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "aggregate-address" + "[aggregate-addr='" + self.aggregate_addr.get() + "']" + "[aggregate-prefix='" + self.aggregate_prefix.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.aggregate_addr.is_set or self.aggregate_addr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.aggregate_addr.get_name_leafdata())
                                                if (self.aggregate_prefix.is_set or self.aggregate_prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.aggregate_prefix.get_name_leafdata())
                                                if (self.generate_confederation_set_info.is_set or self.generate_confederation_set_info.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.generate_confederation_set_info.get_name_leafdata())
                                                if (self.generate_set_info.is_set or self.generate_set_info.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.generate_set_info.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                                if (self.summary_only.is_set or self.summary_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.summary_only.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "aggregate-addr" or name == "aggregate-prefix" or name == "generate-confederation-set-info" or name == "generate-set-info" or name == "route-policy-name" or name == "summary-only"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "aggregate-addr"):
                                                    self.aggregate_addr = value
                                                    self.aggregate_addr.value_namespace = name_space
                                                    self.aggregate_addr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "aggregate-prefix"):
                                                    self.aggregate_prefix = value
                                                    self.aggregate_prefix.value_namespace = name_space
                                                    self.aggregate_prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "generate-confederation-set-info"):
                                                    self.generate_confederation_set_info = value
                                                    self.generate_confederation_set_info.value_namespace = name_space
                                                    self.generate_confederation_set_info.value_namespace_prefix = name_space_prefix
                                                if(value_path == "generate-set-info"):
                                                    self.generate_set_info = value
                                                    self.generate_set_info.value_namespace = name_space
                                                    self.generate_set_info.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "summary-only"):
                                                    self.summary_only = value
                                                    self.summary_only.value_namespace = name_space
                                                    self.summary_only.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.aggregate_address:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.aggregate_address:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "aggregate-addresses" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "aggregate-address"):
                                                for c in self.aggregate_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.aggregate_address.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "aggregate-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: half_life
                                        
                                        	Half\-life time for the penalty (minutes)
                                        	**type**\:  int
                                        
                                        	**range:** 1..45
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: reuse_threshold
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy to specify criteria for dampening. This cannot be specified if any other parameters are specified
                                        	**type**\:  str
                                        
                                        .. attribute:: suppress_threshold
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	Maximum duration to suppress a stable route (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**units**\: second
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.half_life = YLeaf(YType.uint32, "half-life")

                                            self.reuse_threshold = YLeaf(YType.uint32, "reuse-threshold")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            self.suppress_threshold = YLeaf(YType.uint32, "suppress-threshold")

                                            self.suppress_time = YLeaf(YType.uint32, "suppress-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("half_life",
                                                            "reuse_threshold",
                                                            "route_policy_name",
                                                            "suppress_threshold",
                                                            "suppress_time") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.half_life.is_set or
                                                self.reuse_threshold.is_set or
                                                self.route_policy_name.is_set or
                                                self.suppress_threshold.is_set or
                                                self.suppress_time.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.half_life.yfilter != YFilter.not_set or
                                                self.reuse_threshold.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set or
                                                self.suppress_threshold.yfilter != YFilter.not_set or
                                                self.suppress_time.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dampening" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.half_life.is_set or self.half_life.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.half_life.get_name_leafdata())
                                            if (self.reuse_threshold.is_set or self.reuse_threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reuse_threshold.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                            if (self.suppress_threshold.is_set or self.suppress_threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.suppress_threshold.get_name_leafdata())
                                            if (self.suppress_time.is_set or self.suppress_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.suppress_time.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "half-life" or name == "reuse-threshold" or name == "route-policy-name" or name == "suppress-threshold" or name == "suppress-time"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "half-life"):
                                                self.half_life = value
                                                self.half_life.value_namespace = name_space
                                                self.half_life.value_namespace_prefix = name_space_prefix
                                            if(value_path == "reuse-threshold"):
                                                self.reuse_threshold = value
                                                self.reuse_threshold.value_namespace = name_space
                                                self.reuse_threshold.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "suppress-threshold"):
                                                self.suppress_threshold = value
                                                self.suppress_threshold.value_namespace = name_space
                                                self.suppress_threshold.value_namespace_prefix = name_space_prefix
                                            if(value_path == "suppress-time"):
                                                self.suppress_time = value
                                                self.suppress_time.value_namespace = name_space
                                                self.suppress_time.value_namespace_prefix = name_space_prefix


                                    class RipRoutes(Entity):
                                        """
                                        Redistribute RIP routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes, self).__init__()

                                            self.yang_name = "rip-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("default_metric",
                                                            "not_used",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.default_metric.is_set or
                                                self.not_used.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.not_used.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rip-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.not_used.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "not-used"):
                                                self.not_used = value
                                                self.not_used.value_namespace = name_space
                                                self.not_used.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class LispRoutes(Entity):
                                        """
                                        Redistribute lisp routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes, self).__init__()

                                            self.yang_name = "lisp-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("default_metric",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.default_metric.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lisp-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "default-metric" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class StaticRoutes(Entity):
                                        """
                                        Redistribute static routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes, self).__init__()

                                            self.yang_name = "static-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("default_metric",
                                                            "not_used",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.default_metric.is_set or
                                                self.not_used.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.not_used.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "static-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.not_used.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "not-used"):
                                                self.not_used = value
                                                self.not_used.value_namespace = name_space
                                                self.not_used.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class Distance(Entity):
                                        """
                                        Define an administrative distance
                                        
                                        .. attribute:: external_routes
                                        
                                        	Distance for routes external to the AS
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**default value**\: 20
                                        
                                        .. attribute:: internal_routes
                                        
                                        	Distance for routes internal to the AS
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**default value**\: 200
                                        
                                        .. attribute:: local_routes
                                        
                                        	Distance for local routes
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**default value**\: 200
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.external_routes = YLeaf(YType.uint32, "external-routes")

                                            self.internal_routes = YLeaf(YType.uint32, "internal-routes")

                                            self.local_routes = YLeaf(YType.uint32, "local-routes")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("external_routes",
                                                            "internal_routes",
                                                            "local_routes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.external_routes.is_set or
                                                self.internal_routes.is_set or
                                                self.local_routes.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.external_routes.yfilter != YFilter.not_set or
                                                self.internal_routes.yfilter != YFilter.not_set or
                                                self.local_routes.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "distance" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.external_routes.is_set or self.external_routes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_routes.get_name_leafdata())
                                            if (self.internal_routes.is_set or self.internal_routes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_routes.get_name_leafdata())
                                            if (self.local_routes.is_set or self.local_routes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_routes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "external-routes" or name == "internal-routes" or name == "local-routes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "external-routes"):
                                                self.external_routes = value
                                                self.external_routes.value_namespace = name_space
                                                self.external_routes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "internal-routes"):
                                                self.internal_routes = value
                                                self.internal_routes.value_namespace = name_space
                                                self.internal_routes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-routes"):
                                                self.local_routes = value
                                                self.local_routes.value_namespace = name_space
                                                self.local_routes.value_namespace_prefix = name_space_prefix


                                    class ApplicationRoutes(Entity):
                                        """
                                        Redistribute information for Application routes.
                                        
                                        .. attribute:: application_route
                                        
                                        	Redistribute application routes
                                        	**type**\: list of    :py:class:`ApplicationRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes, self).__init__()

                                            self.yang_name = "application-routes"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.application_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes, self).__setattr__(name, value)


                                        class ApplicationRoute(Entity):
                                            """
                                            Redistribute application routes
                                            
                                            .. attribute:: instance_name  <key>
                                            
                                            	OnePK application name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: default_metric
                                            
                                            	Default metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: not_used
                                            
                                            	Not used
                                            	**type**\:  int
                                            
                                            	**range:** 0..127
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute, self).__init__()

                                                self.yang_name = "application-route"
                                                self.yang_parent_name = "application-routes"

                                                self.instance_name = YLeaf(YType.str, "instance-name")

                                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                                self.not_used = YLeaf(YType.uint32, "not-used")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("instance_name",
                                                                "default_metric",
                                                                "not_used",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.instance_name.is_set or
                                                    self.default_metric.is_set or
                                                    self.not_used.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.instance_name.yfilter != YFilter.not_set or
                                                    self.default_metric.yfilter != YFilter.not_set or
                                                    self.not_used.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "application-route" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance_name.get_name_leafdata())
                                                if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.default_metric.get_name_leafdata())
                                                if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.not_used.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "instance-name" or name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "instance-name"):
                                                    self.instance_name = value
                                                    self.instance_name.value_namespace = name_space
                                                    self.instance_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "default-metric"):
                                                    self.default_metric = value
                                                    self.default_metric.value_namespace = name_space
                                                    self.default_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "not-used"):
                                                    self.not_used = value
                                                    self.not_used.value_namespace = name_space
                                                    self.not_used.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.application_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.application_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "application-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "application-route"):
                                                for c in self.application_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.application_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "application-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class LabelMode(Entity):
                                        """
                                        BGP 6PE/MPLS\-VPN label allocation mode
                                        
                                        .. attribute:: label_allocation_mode
                                        
                                        	Label allocation mode\: per\-ce  Set per CE label mode, per\-vrf Set per VRF label mode, per\-prefix Set per Prefix label mode (for MPLS\-VPN only)
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Label mode route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode, self).__init__()

                                            self.yang_name = "label-mode"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.label_allocation_mode = YLeaf(YType.str, "label-allocation-mode")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("label_allocation_mode",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.label_allocation_mode.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.label_allocation_mode.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "label-mode" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.label_allocation_mode.is_set or self.label_allocation_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.label_allocation_mode.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "label-allocation-mode" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "label-allocation-mode"):
                                                self.label_allocation_mode = value
                                                self.label_allocation_mode.value_namespace = name_space
                                                self.label_allocation_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class EigrpRoutes(Entity):
                                        """
                                        Redistribute information for EIGRP routes.
                                        
                                        .. attribute:: eigrp_route
                                        
                                        	Redistribute EIGRP routes
                                        	**type**\: list of    :py:class:`EigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes, self).__init__()

                                            self.yang_name = "eigrp-routes"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.eigrp_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes, self).__setattr__(name, value)


                                        class EigrpRoute(Entity):
                                            """
                                            Redistribute EIGRP routes
                                            
                                            .. attribute:: instance_name  <key>
                                            
                                            	EIGRP router tag
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: default_metric
                                            
                                            	Default metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: redist_type
                                            
                                            	Redistribution type\: 01 for internal routes, 02 for external routes, Logical combinations permitted
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute, self).__init__()

                                                self.yang_name = "eigrp-route"
                                                self.yang_parent_name = "eigrp-routes"

                                                self.instance_name = YLeaf(YType.str, "instance-name")

                                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                                self.redist_type = YLeaf(YType.str, "redist-type")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("instance_name",
                                                                "default_metric",
                                                                "redist_type",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.instance_name.is_set or
                                                    self.default_metric.is_set or
                                                    self.redist_type.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.instance_name.yfilter != YFilter.not_set or
                                                    self.default_metric.yfilter != YFilter.not_set or
                                                    self.redist_type.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "eigrp-route" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance_name.get_name_leafdata())
                                                if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.default_metric.get_name_leafdata())
                                                if (self.redist_type.is_set or self.redist_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.redist_type.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "instance-name" or name == "default-metric" or name == "redist-type" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "instance-name"):
                                                    self.instance_name = value
                                                    self.instance_name.value_namespace = name_space
                                                    self.instance_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "default-metric"):
                                                    self.default_metric = value
                                                    self.default_metric.value_namespace = name_space
                                                    self.default_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "redist-type"):
                                                    self.redist_type = value
                                                    self.redist_type.value_namespace = name_space
                                                    self.redist_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.eigrp_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.eigrp_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "eigrp-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "eigrp-route"):
                                                for c in self.eigrp_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.eigrp_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "eigrp-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SourcedNetworks(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: sourced_network
                                        
                                        	Sourced network configuration
                                        	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks, self).__init__()

                                            self.yang_name = "sourced-networks"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.sourced_network = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks, self).__setattr__(name, value)


                                        class SourcedNetwork(Entity):
                                            """
                                            Sourced network configuration
                                            
                                            .. attribute:: network_addr  <key>
                                            
                                            	Network in prefix/length format (address part)
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: network_prefix  <key>
                                            
                                            	Network in prefix/length format (prefix part)
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route, default is FALSE
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork, self).__init__()

                                                self.yang_name = "sourced-network"
                                                self.yang_parent_name = "sourced-networks"

                                                self.network_addr = YLeaf(YType.str, "network-addr")

                                                self.network_prefix = YLeaf(YType.uint16, "network-prefix")

                                                self.backdoor = YLeaf(YType.boolean, "backdoor")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("network_addr",
                                                                "network_prefix",
                                                                "backdoor",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.network_addr.is_set or
                                                    self.network_prefix.is_set or
                                                    self.backdoor.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.network_addr.yfilter != YFilter.not_set or
                                                    self.network_prefix.yfilter != YFilter.not_set or
                                                    self.backdoor.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sourced-network" + "[network-addr='" + self.network_addr.get() + "']" + "[network-prefix='" + self.network_prefix.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.network_addr.is_set or self.network_addr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.network_addr.get_name_leafdata())
                                                if (self.network_prefix.is_set or self.network_prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.network_prefix.get_name_leafdata())
                                                if (self.backdoor.is_set or self.backdoor.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backdoor.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "network-addr" or name == "network-prefix" or name == "backdoor" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "network-addr"):
                                                    self.network_addr = value
                                                    self.network_addr.value_namespace = name_space
                                                    self.network_addr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "network-prefix"):
                                                    self.network_prefix = value
                                                    self.network_prefix.value_namespace = name_space
                                                    self.network_prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backdoor"):
                                                    self.backdoor = value
                                                    self.backdoor.value_namespace = name_space
                                                    self.backdoor.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.sourced_network:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.sourced_network:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sourced-networks" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sourced-network"):
                                                for c in self.sourced_network:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.sourced_network.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sourced-network"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class ConnectedRoutes(Entity):
                                        """
                                        Redistribute connected routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes, self).__init__()

                                            self.yang_name = "connected-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("default_metric",
                                                            "not_used",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.default_metric.is_set or
                                                self.not_used.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.not_used.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "connected-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.not_used.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "not-used"):
                                                self.not_used = value
                                                self.not_used.value_namespace = name_space
                                                self.not_used.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class AllocateLabel(Entity):
                                        """
                                        Label allocation policy
                                        
                                        .. attribute:: all
                                        
                                        	Whether all nets should be labeled, default is FALSE
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel, self).__init__()

                                            self.yang_name = "allocate-label"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.all = YLeaf(YType.boolean, "all")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "allocate-label" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all.is_set or self.all.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all"):
                                                self.all = value
                                                self.all.value_namespace = name_space
                                                self.all.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class AdditionalPathsSelection(Entity):
                                        """
                                        Configure additional paths selection
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy for selection
                                        	**type**\:  str
                                        
                                        .. attribute:: selection
                                        
                                        	Enable/disable selection 
                                        	**type**\:   :py:class:`BgpafAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpafAdditionalPathsCfg>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection, self).__init__()

                                            self.yang_name = "additional-paths-selection"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            self.selection = YLeaf(YType.enumeration, "selection")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_policy_name",
                                                            "selection") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.route_policy_name.is_set or
                                                self.selection.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set or
                                                self.selection.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "additional-paths-selection" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                            if (self.selection.is_set or self.selection.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.selection.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-policy-name" or name == "selection"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "selection"):
                                                self.selection = value
                                                self.selection.value_namespace = name_space
                                                self.selection.value_namespace_prefix = name_space_prefix


                                    class OspfRoutes(Entity):
                                        """
                                        Redistribute information for OSPF routes.
                                        
                                        .. attribute:: ospf_route
                                        
                                        	Redistribute OSPF routes
                                        	**type**\: list of    :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes, self).__init__()

                                            self.yang_name = "ospf-routes"
                                            self.yang_parent_name = "vrf-global-af"

                                            self.ospf_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes, self).__setattr__(name, value)


                                        class OspfRoute(Entity):
                                            """
                                            Redistribute OSPF routes
                                            
                                            .. attribute:: instance_name  <key>
                                            
                                            	OSPF router tag
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: default_metric
                                            
                                            	Default metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: redist_type
                                            
                                            	Redistribution type\: 01 for internal routes, 02 for external routes of type 1, 04 for external routes of type 2, 08 for NSSA external routes of type 1, 10 for NSSA external routes of type 2, 20 for external routes, 40 for NSSA external routes.  Logical combinations permitted
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute, self).__init__()

                                                self.yang_name = "ospf-route"
                                                self.yang_parent_name = "ospf-routes"

                                                self.instance_name = YLeaf(YType.str, "instance-name")

                                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                                self.redist_type = YLeaf(YType.str, "redist-type")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("instance_name",
                                                                "default_metric",
                                                                "redist_type",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.instance_name.is_set or
                                                    self.default_metric.is_set or
                                                    self.redist_type.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.instance_name.yfilter != YFilter.not_set or
                                                    self.default_metric.yfilter != YFilter.not_set or
                                                    self.redist_type.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ospf-route" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance_name.get_name_leafdata())
                                                if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.default_metric.get_name_leafdata())
                                                if (self.redist_type.is_set or self.redist_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.redist_type.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "instance-name" or name == "default-metric" or name == "redist-type" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "instance-name"):
                                                    self.instance_name = value
                                                    self.instance_name.value_namespace = name_space
                                                    self.instance_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "default-metric"):
                                                    self.default_metric = value
                                                    self.default_metric.value_namespace = name_space
                                                    self.default_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "redist-type"):
                                                    self.redist_type = value
                                                    self.redist_type.value_namespace = name_space
                                                    self.redist_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ospf_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.ospf_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ospf-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ospf-route"):
                                                for c in self.ospf_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ospf_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ospf-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class MobileRoutes(Entity):
                                        """
                                        Redistribute mobile routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes, self).__init__()

                                            self.yang_name = "mobile-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("default_metric",
                                                            "not_used",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.default_metric.is_set or
                                                self.not_used.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.not_used.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mobile-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.not_used.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "not-used"):
                                                self.not_used = value
                                                self.not_used.value_namespace = name_space
                                                self.not_used.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class SubscriberRoutes(Entity):
                                        """
                                        Redistribute subscriber routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes, self).__init__()

                                            self.yang_name = "subscriber-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("default_metric",
                                                            "not_used",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.default_metric.is_set or
                                                self.not_used.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.not_used.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "subscriber-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.not_used.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "not-used"):
                                                self.not_used = value
                                                self.not_used.value_namespace = name_space
                                                self.not_used.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.additional_paths_receive.is_set or
                                            self.additional_paths_send.is_set or
                                            self.advertise_local_labeled_route_safi_unicast.is_set or
                                            self.allow_vpn_default_originate.is_set or
                                            self.attribute_download.is_set or
                                            self.best_external.is_set or
                                            self.disable_as_path_loop_check.is_set or
                                            self.dynamic_med_interval.is_set or
                                            self.enable.is_set or
                                            self.next_hop_resolution_prefix_length_minimum.is_set or
                                            self.permanent_network.is_set or
                                            self.reset_weight_on_import.is_set or
                                            self.rt_download.is_set or
                                            self.table_policy.is_set or
                                            (self.additional_paths_selection is not None and self.additional_paths_selection.has_data()) or
                                            (self.aggregate_addresses is not None and self.aggregate_addresses.has_data()) or
                                            (self.allocate_label is not None and self.allocate_label.has_data()) or
                                            (self.application_routes is not None and self.application_routes.has_data()) or
                                            (self.distance is not None and self.distance.has_data()) or
                                            (self.eigrp_routes is not None and self.eigrp_routes.has_data()) or
                                            (self.label_mode is not None and self.label_mode.has_data()) or
                                            (self.mvpn is not None and self.mvpn.has_data()) or
                                            (self.ospf_routes is not None and self.ospf_routes.has_data()) or
                                            (self.sourced_networks is not None and self.sourced_networks.has_data()) or
                                            (self.connected_routes is not None) or
                                            (self.dampening is not None) or
                                            (self.ebgp is not None) or
                                            (self.eibgp is not None) or
                                            (self.ibgp is not None) or
                                            (self.lisp_routes is not None) or
                                            (self.mobile_routes is not None) or
                                            (self.rip_routes is not None) or
                                            (self.static_routes is not None) or
                                            (self.subscriber_routes is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.additional_paths_receive.yfilter != YFilter.not_set or
                                            self.additional_paths_send.yfilter != YFilter.not_set or
                                            self.advertise_local_labeled_route_safi_unicast.yfilter != YFilter.not_set or
                                            self.allow_vpn_default_originate.yfilter != YFilter.not_set or
                                            self.attribute_download.yfilter != YFilter.not_set or
                                            self.best_external.yfilter != YFilter.not_set or
                                            self.disable_as_path_loop_check.yfilter != YFilter.not_set or
                                            self.dynamic_med_interval.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.next_hop_resolution_prefix_length_minimum.yfilter != YFilter.not_set or
                                            self.permanent_network.yfilter != YFilter.not_set or
                                            self.reset_weight_on_import.yfilter != YFilter.not_set or
                                            self.rt_download.yfilter != YFilter.not_set or
                                            self.table_policy.yfilter != YFilter.not_set or
                                            (self.additional_paths_selection is not None and self.additional_paths_selection.has_operation()) or
                                            (self.aggregate_addresses is not None and self.aggregate_addresses.has_operation()) or
                                            (self.allocate_label is not None and self.allocate_label.has_operation()) or
                                            (self.application_routes is not None and self.application_routes.has_operation()) or
                                            (self.connected_routes is not None and self.connected_routes.has_operation()) or
                                            (self.dampening is not None and self.dampening.has_operation()) or
                                            (self.distance is not None and self.distance.has_operation()) or
                                            (self.ebgp is not None and self.ebgp.has_operation()) or
                                            (self.eibgp is not None and self.eibgp.has_operation()) or
                                            (self.eigrp_routes is not None and self.eigrp_routes.has_operation()) or
                                            (self.ibgp is not None and self.ibgp.has_operation()) or
                                            (self.label_mode is not None and self.label_mode.has_operation()) or
                                            (self.lisp_routes is not None and self.lisp_routes.has_operation()) or
                                            (self.mobile_routes is not None and self.mobile_routes.has_operation()) or
                                            (self.mvpn is not None and self.mvpn.has_operation()) or
                                            (self.ospf_routes is not None and self.ospf_routes.has_operation()) or
                                            (self.rip_routes is not None and self.rip_routes.has_operation()) or
                                            (self.sourced_networks is not None and self.sourced_networks.has_operation()) or
                                            (self.static_routes is not None and self.static_routes.has_operation()) or
                                            (self.subscriber_routes is not None and self.subscriber_routes.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-global-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.additional_paths_receive.is_set or self.additional_paths_receive.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.additional_paths_receive.get_name_leafdata())
                                        if (self.additional_paths_send.is_set or self.additional_paths_send.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.additional_paths_send.get_name_leafdata())
                                        if (self.advertise_local_labeled_route_safi_unicast.is_set or self.advertise_local_labeled_route_safi_unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.advertise_local_labeled_route_safi_unicast.get_name_leafdata())
                                        if (self.allow_vpn_default_originate.is_set or self.allow_vpn_default_originate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.allow_vpn_default_originate.get_name_leafdata())
                                        if (self.attribute_download.is_set or self.attribute_download.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.attribute_download.get_name_leafdata())
                                        if (self.best_external.is_set or self.best_external.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.best_external.get_name_leafdata())
                                        if (self.disable_as_path_loop_check.is_set or self.disable_as_path_loop_check.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable_as_path_loop_check.get_name_leafdata())
                                        if (self.dynamic_med_interval.is_set or self.dynamic_med_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dynamic_med_interval.get_name_leafdata())
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.next_hop_resolution_prefix_length_minimum.is_set or self.next_hop_resolution_prefix_length_minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_resolution_prefix_length_minimum.get_name_leafdata())
                                        if (self.permanent_network.is_set or self.permanent_network.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.permanent_network.get_name_leafdata())
                                        if (self.reset_weight_on_import.is_set or self.reset_weight_on_import.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reset_weight_on_import.get_name_leafdata())
                                        if (self.rt_download.is_set or self.rt_download.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rt_download.get_name_leafdata())
                                        if (self.table_policy.is_set or self.table_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.table_policy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "additional-paths-selection"):
                                            if (self.additional_paths_selection is None):
                                                self.additional_paths_selection = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection()
                                                self.additional_paths_selection.parent = self
                                                self._children_name_map["additional_paths_selection"] = "additional-paths-selection"
                                            return self.additional_paths_selection

                                        if (child_yang_name == "aggregate-addresses"):
                                            if (self.aggregate_addresses is None):
                                                self.aggregate_addresses = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses()
                                                self.aggregate_addresses.parent = self
                                                self._children_name_map["aggregate_addresses"] = "aggregate-addresses"
                                            return self.aggregate_addresses

                                        if (child_yang_name == "allocate-label"):
                                            if (self.allocate_label is None):
                                                self.allocate_label = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel()
                                                self.allocate_label.parent = self
                                                self._children_name_map["allocate_label"] = "allocate-label"
                                            return self.allocate_label

                                        if (child_yang_name == "application-routes"):
                                            if (self.application_routes is None):
                                                self.application_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes()
                                                self.application_routes.parent = self
                                                self._children_name_map["application_routes"] = "application-routes"
                                            return self.application_routes

                                        if (child_yang_name == "connected-routes"):
                                            if (self.connected_routes is None):
                                                self.connected_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes()
                                                self.connected_routes.parent = self
                                                self._children_name_map["connected_routes"] = "connected-routes"
                                            return self.connected_routes

                                        if (child_yang_name == "dampening"):
                                            if (self.dampening is None):
                                                self.dampening = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening()
                                                self.dampening.parent = self
                                                self._children_name_map["dampening"] = "dampening"
                                            return self.dampening

                                        if (child_yang_name == "distance"):
                                            if (self.distance is None):
                                                self.distance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance()
                                                self.distance.parent = self
                                                self._children_name_map["distance"] = "distance"
                                            return self.distance

                                        if (child_yang_name == "ebgp"):
                                            if (self.ebgp is None):
                                                self.ebgp = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp()
                                                self.ebgp.parent = self
                                                self._children_name_map["ebgp"] = "ebgp"
                                            return self.ebgp

                                        if (child_yang_name == "eibgp"):
                                            if (self.eibgp is None):
                                                self.eibgp = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp()
                                                self.eibgp.parent = self
                                                self._children_name_map["eibgp"] = "eibgp"
                                            return self.eibgp

                                        if (child_yang_name == "eigrp-routes"):
                                            if (self.eigrp_routes is None):
                                                self.eigrp_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes()
                                                self.eigrp_routes.parent = self
                                                self._children_name_map["eigrp_routes"] = "eigrp-routes"
                                            return self.eigrp_routes

                                        if (child_yang_name == "ibgp"):
                                            if (self.ibgp is None):
                                                self.ibgp = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp()
                                                self.ibgp.parent = self
                                                self._children_name_map["ibgp"] = "ibgp"
                                            return self.ibgp

                                        if (child_yang_name == "label-mode"):
                                            if (self.label_mode is None):
                                                self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode()
                                                self.label_mode.parent = self
                                                self._children_name_map["label_mode"] = "label-mode"
                                            return self.label_mode

                                        if (child_yang_name == "lisp-routes"):
                                            if (self.lisp_routes is None):
                                                self.lisp_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes()
                                                self.lisp_routes.parent = self
                                                self._children_name_map["lisp_routes"] = "lisp-routes"
                                            return self.lisp_routes

                                        if (child_yang_name == "mobile-routes"):
                                            if (self.mobile_routes is None):
                                                self.mobile_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes()
                                                self.mobile_routes.parent = self
                                                self._children_name_map["mobile_routes"] = "mobile-routes"
                                            return self.mobile_routes

                                        if (child_yang_name == "mvpn"):
                                            if (self.mvpn is None):
                                                self.mvpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn()
                                                self.mvpn.parent = self
                                                self._children_name_map["mvpn"] = "mvpn"
                                            return self.mvpn

                                        if (child_yang_name == "ospf-routes"):
                                            if (self.ospf_routes is None):
                                                self.ospf_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes()
                                                self.ospf_routes.parent = self
                                                self._children_name_map["ospf_routes"] = "ospf-routes"
                                            return self.ospf_routes

                                        if (child_yang_name == "rip-routes"):
                                            if (self.rip_routes is None):
                                                self.rip_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes()
                                                self.rip_routes.parent = self
                                                self._children_name_map["rip_routes"] = "rip-routes"
                                            return self.rip_routes

                                        if (child_yang_name == "sourced-networks"):
                                            if (self.sourced_networks is None):
                                                self.sourced_networks = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks()
                                                self.sourced_networks.parent = self
                                                self._children_name_map["sourced_networks"] = "sourced-networks"
                                            return self.sourced_networks

                                        if (child_yang_name == "static-routes"):
                                            if (self.static_routes is None):
                                                self.static_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes()
                                                self.static_routes.parent = self
                                                self._children_name_map["static_routes"] = "static-routes"
                                            return self.static_routes

                                        if (child_yang_name == "subscriber-routes"):
                                            if (self.subscriber_routes is None):
                                                self.subscriber_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes()
                                                self.subscriber_routes.parent = self
                                                self._children_name_map["subscriber_routes"] = "subscriber-routes"
                                            return self.subscriber_routes

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "additional-paths-selection" or name == "aggregate-addresses" or name == "allocate-label" or name == "application-routes" or name == "connected-routes" or name == "dampening" or name == "distance" or name == "ebgp" or name == "eibgp" or name == "eigrp-routes" or name == "ibgp" or name == "label-mode" or name == "lisp-routes" or name == "mobile-routes" or name == "mvpn" or name == "ospf-routes" or name == "rip-routes" or name == "sourced-networks" or name == "static-routes" or name == "subscriber-routes" or name == "af-name" or name == "additional-paths-receive" or name == "additional-paths-send" or name == "advertise-local-labeled-route-safi-unicast" or name == "allow-vpn-default-originate" or name == "attribute-download" or name == "best-external" or name == "disable-as-path-loop-check" or name == "dynamic-med-interval" or name == "enable" or name == "next-hop-resolution-prefix-length-minimum" or name == "permanent-network" or name == "reset-weight-on-import" or name == "rt-download" or name == "table-policy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "additional-paths-receive"):
                                            self.additional_paths_receive = value
                                            self.additional_paths_receive.value_namespace = name_space
                                            self.additional_paths_receive.value_namespace_prefix = name_space_prefix
                                        if(value_path == "additional-paths-send"):
                                            self.additional_paths_send = value
                                            self.additional_paths_send.value_namespace = name_space
                                            self.additional_paths_send.value_namespace_prefix = name_space_prefix
                                        if(value_path == "advertise-local-labeled-route-safi-unicast"):
                                            self.advertise_local_labeled_route_safi_unicast = value
                                            self.advertise_local_labeled_route_safi_unicast.value_namespace = name_space
                                            self.advertise_local_labeled_route_safi_unicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "allow-vpn-default-originate"):
                                            self.allow_vpn_default_originate = value
                                            self.allow_vpn_default_originate.value_namespace = name_space
                                            self.allow_vpn_default_originate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "attribute-download"):
                                            self.attribute_download = value
                                            self.attribute_download.value_namespace = name_space
                                            self.attribute_download.value_namespace_prefix = name_space_prefix
                                        if(value_path == "best-external"):
                                            self.best_external = value
                                            self.best_external.value_namespace = name_space
                                            self.best_external.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable-as-path-loop-check"):
                                            self.disable_as_path_loop_check = value
                                            self.disable_as_path_loop_check.value_namespace = name_space
                                            self.disable_as_path_loop_check.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dynamic-med-interval"):
                                            self.dynamic_med_interval = value
                                            self.dynamic_med_interval.value_namespace = name_space
                                            self.dynamic_med_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-resolution-prefix-length-minimum"):
                                            self.next_hop_resolution_prefix_length_minimum = value
                                            self.next_hop_resolution_prefix_length_minimum.value_namespace = name_space
                                            self.next_hop_resolution_prefix_length_minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "permanent-network"):
                                            self.permanent_network = value
                                            self.permanent_network.value_namespace = name_space
                                            self.permanent_network.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reset-weight-on-import"):
                                            self.reset_weight_on_import = value
                                            self.reset_weight_on_import.value_namespace = name_space
                                            self.reset_weight_on_import.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rt-download"):
                                            self.rt_download = value
                                            self.rt_download.value_namespace = name_space
                                            self.rt_download.value_namespace_prefix = name_space_prefix
                                        if(value_path == "table-policy"):
                                            self.table_policy = value
                                            self.table_policy.value_namespace = name_space
                                            self.table_policy.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_global_af:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_global_af:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-global-afs" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-global-af"):
                                        for c in self.vrf_global_af:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_global_af.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-global-af"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class MplsActivatedInterfaces(Entity):
                                """
                                Configure list of MPLS activated interfaces
                                
                                .. attribute:: mpls_activated_interface
                                
                                	Configure a MPLS activated interface
                                	**type**\: list of    :py:class:`MplsActivatedInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces, self).__init__()

                                    self.yang_name = "mpls-activated-interfaces"
                                    self.yang_parent_name = "vrf-global"

                                    self.mpls_activated_interface = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces, self).__setattr__(name, value)


                                class MplsActivatedInterface(Entity):
                                    """
                                    Configure a MPLS activated interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface, self).__init__()

                                        self.yang_name = "mpls-activated-interface"
                                        self.yang_parent_name = "mpls-activated-interfaces"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.interface_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls-activated-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.mpls_activated_interface:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.mpls_activated_interface:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-activated-interfaces" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mpls-activated-interface"):
                                        for c in self.mpls_activated_interface:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mpls_activated_interface.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mpls-activated-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class GlobalTimers(Entity):
                                """
                                Adjust routing timers.
                                
                                .. attribute:: hold_time
                                
                                	Hold time (seconds).  Specify 0 to disable keepalives/hold time
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 180
                                
                                .. attribute:: keepalive
                                
                                	Keepalive interval (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 60
                                
                                .. attribute:: min_accept_hold_time
                                
                                	Minimum acceptable hold time (seconds). Specify 0 to disable keepalives/hold time
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 3
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers, self).__init__()

                                    self.yang_name = "global-timers"
                                    self.yang_parent_name = "vrf-global"

                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                    self.keepalive = YLeaf(YType.uint32, "keepalive")

                                    self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("hold_time",
                                                    "keepalive",
                                                    "min_accept_hold_time") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.hold_time.is_set or
                                        self.keepalive.is_set or
                                        self.min_accept_hold_time.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.hold_time.yfilter != YFilter.not_set or
                                        self.keepalive.yfilter != YFilter.not_set or
                                        self.min_accept_hold_time.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "global-timers" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hold_time.get_name_leafdata())
                                    if (self.keepalive.is_set or self.keepalive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.keepalive.get_name_leafdata())
                                    if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "hold-time" or name == "keepalive" or name == "min-accept-hold-time"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "hold-time"):
                                        self.hold_time = value
                                        self.hold_time.value_namespace = name_space
                                        self.hold_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "keepalive"):
                                        self.keepalive = value
                                        self.keepalive.value_namespace = name_space
                                        self.keepalive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "min-accept-hold-time"):
                                        self.min_accept_hold_time = value
                                        self.min_accept_hold_time.value_namespace = name_space
                                        self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                            class Bfd(Entity):
                                """
                                BFD configuration
                                
                                .. attribute:: detection_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd, self).__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "vrf-global"

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.interval = YLeaf(YType.uint32, "interval")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("detection_multiplier",
                                                    "interval") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.detection_multiplier.is_set or
                                        self.interval.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.detection_multiplier.yfilter != YFilter.not_set or
                                        self.interval.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bfd" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                    if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interval.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "detection-multiplier" or name == "interval"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "detection-multiplier"):
                                        self.detection_multiplier = value
                                        self.detection_multiplier.value_namespace = name_space
                                        self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interval"):
                                        self.interval = value
                                        self.interval.value_namespace = name_space
                                        self.interval.value_namespace_prefix = name_space_prefix


                            class SendSocketBufferSizes(Entity):
                                """
                                set socket parameters
                                
                                .. attribute:: bgp_send_size
                                
                                	BGP Write buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 4096..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 4096
                                
                                .. attribute:: socket_send_size
                                
                                	Send socket buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 4096..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 24576
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes, self).__init__()

                                    self.yang_name = "send-socket-buffer-sizes"
                                    self.yang_parent_name = "vrf-global"

                                    self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                    self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bgp_send_size",
                                                    "socket_send_size") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bgp_send_size.is_set or
                                        self.socket_send_size.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bgp_send_size.yfilter != YFilter.not_set or
                                        self.socket_send_size.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "send-socket-buffer-sizes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                    if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bgp-send-size" or name == "socket-send-size"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bgp-send-size"):
                                        self.bgp_send_size = value
                                        self.bgp_send_size.value_namespace = name_space
                                        self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "socket-send-size"):
                                        self.socket_send_size = value
                                        self.socket_send_size.value_namespace = name_space
                                        self.socket_send_size.value_namespace_prefix = name_space_prefix


                            class ReceiveSocketBufferSizes(Entity):
                                """
                                Set socket and BGP receive buffer sizes
                                
                                .. attribute:: bgp_receive_size
                                
                                	BGP Read buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 512..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 4096
                                
                                .. attribute:: socket_receive_size
                                
                                	Receive socket buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 512..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 32768
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes, self).__init__()

                                    self.yang_name = "receive-socket-buffer-sizes"
                                    self.yang_parent_name = "vrf-global"

                                    self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                    self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bgp_receive_size",
                                                    "socket_receive_size") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bgp_receive_size.is_set or
                                        self.socket_receive_size.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bgp_receive_size.yfilter != YFilter.not_set or
                                        self.socket_receive_size.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "receive-socket-buffer-sizes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                    if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bgp-receive-size"):
                                        self.bgp_receive_size = value
                                        self.bgp_receive_size.value_namespace = name_space
                                        self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "socket-receive-size"):
                                        self.socket_receive_size = value
                                        self.socket_receive_size.value_namespace = name_space
                                        self.socket_receive_size.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.best_path_aigp_ignore.is_set or
                                    self.best_path_as_multipath_relax.is_set or
                                    self.best_path_as_path_length.is_set or
                                    self.best_path_confederation_paths.is_set or
                                    self.best_path_cost_community.is_set or
                                    self.best_path_med_always.is_set or
                                    self.best_path_med_missing.is_set or
                                    self.best_path_router_id.is_set or
                                    self.default_info_originate.is_set or
                                    self.default_metric.is_set or
                                    self.disable_auto_soft_reset.is_set or
                                    self.disable_enforce_first_as.is_set or
                                    self.disable_fast_external_fallover.is_set or
                                    self.disable_msg_log.is_set or
                                    self.disable_neighbor_logging.is_set or
                                    self.exists.is_set or
                                    self.igp_redist_internal.is_set or
                                    self.local_preference.is_set or
                                    self.multi_path_as_path_ignore_onwards.is_set or
                                    self.router_id.is_set or
                                    (self.bfd is not None and self.bfd.has_data()) or
                                    (self.global_timers is not None and self.global_timers.has_data()) or
                                    (self.mpls_activated_interfaces is not None and self.mpls_activated_interfaces.has_data()) or
                                    (self.receive_socket_buffer_sizes is not None and self.receive_socket_buffer_sizes.has_data()) or
                                    (self.route_distinguisher is not None and self.route_distinguisher.has_data()) or
                                    (self.send_socket_buffer_sizes is not None and self.send_socket_buffer_sizes.has_data()) or
                                    (self.vrf_global_afs is not None and self.vrf_global_afs.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.best_path_aigp_ignore.yfilter != YFilter.not_set or
                                    self.best_path_as_multipath_relax.yfilter != YFilter.not_set or
                                    self.best_path_as_path_length.yfilter != YFilter.not_set or
                                    self.best_path_confederation_paths.yfilter != YFilter.not_set or
                                    self.best_path_cost_community.yfilter != YFilter.not_set or
                                    self.best_path_med_always.yfilter != YFilter.not_set or
                                    self.best_path_med_missing.yfilter != YFilter.not_set or
                                    self.best_path_router_id.yfilter != YFilter.not_set or
                                    self.default_info_originate.yfilter != YFilter.not_set or
                                    self.default_metric.yfilter != YFilter.not_set or
                                    self.disable_auto_soft_reset.yfilter != YFilter.not_set or
                                    self.disable_enforce_first_as.yfilter != YFilter.not_set or
                                    self.disable_fast_external_fallover.yfilter != YFilter.not_set or
                                    self.disable_msg_log.yfilter != YFilter.not_set or
                                    self.disable_neighbor_logging.yfilter != YFilter.not_set or
                                    self.exists.yfilter != YFilter.not_set or
                                    self.igp_redist_internal.yfilter != YFilter.not_set or
                                    self.local_preference.yfilter != YFilter.not_set or
                                    self.multi_path_as_path_ignore_onwards.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set or
                                    (self.bfd is not None and self.bfd.has_operation()) or
                                    (self.global_timers is not None and self.global_timers.has_operation()) or
                                    (self.mpls_activated_interfaces is not None and self.mpls_activated_interfaces.has_operation()) or
                                    (self.receive_socket_buffer_sizes is not None and self.receive_socket_buffer_sizes.has_operation()) or
                                    (self.route_distinguisher is not None and self.route_distinguisher.has_operation()) or
                                    (self.send_socket_buffer_sizes is not None and self.send_socket_buffer_sizes.has_operation()) or
                                    (self.vrf_global_afs is not None and self.vrf_global_afs.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-global" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.best_path_aigp_ignore.is_set or self.best_path_aigp_ignore.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_aigp_ignore.get_name_leafdata())
                                if (self.best_path_as_multipath_relax.is_set or self.best_path_as_multipath_relax.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_as_multipath_relax.get_name_leafdata())
                                if (self.best_path_as_path_length.is_set or self.best_path_as_path_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_as_path_length.get_name_leafdata())
                                if (self.best_path_confederation_paths.is_set or self.best_path_confederation_paths.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_confederation_paths.get_name_leafdata())
                                if (self.best_path_cost_community.is_set or self.best_path_cost_community.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_cost_community.get_name_leafdata())
                                if (self.best_path_med_always.is_set or self.best_path_med_always.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_med_always.get_name_leafdata())
                                if (self.best_path_med_missing.is_set or self.best_path_med_missing.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_med_missing.get_name_leafdata())
                                if (self.best_path_router_id.is_set or self.best_path_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.best_path_router_id.get_name_leafdata())
                                if (self.default_info_originate.is_set or self.default_info_originate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_info_originate.get_name_leafdata())
                                if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_metric.get_name_leafdata())
                                if (self.disable_auto_soft_reset.is_set or self.disable_auto_soft_reset.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_auto_soft_reset.get_name_leafdata())
                                if (self.disable_enforce_first_as.is_set or self.disable_enforce_first_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_enforce_first_as.get_name_leafdata())
                                if (self.disable_fast_external_fallover.is_set or self.disable_fast_external_fallover.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_fast_external_fallover.get_name_leafdata())
                                if (self.disable_msg_log.is_set or self.disable_msg_log.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_msg_log.get_name_leafdata())
                                if (self.disable_neighbor_logging.is_set or self.disable_neighbor_logging.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_neighbor_logging.get_name_leafdata())
                                if (self.exists.is_set or self.exists.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.exists.get_name_leafdata())
                                if (self.igp_redist_internal.is_set or self.igp_redist_internal.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igp_redist_internal.get_name_leafdata())
                                if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_preference.get_name_leafdata())
                                if (self.multi_path_as_path_ignore_onwards.is_set or self.multi_path_as_path_ignore_onwards.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multi_path_as_path_ignore_onwards.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bfd"):
                                    if (self.bfd is None):
                                        self.bfd = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd()
                                        self.bfd.parent = self
                                        self._children_name_map["bfd"] = "bfd"
                                    return self.bfd

                                if (child_yang_name == "global-timers"):
                                    if (self.global_timers is None):
                                        self.global_timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers()
                                        self.global_timers.parent = self
                                        self._children_name_map["global_timers"] = "global-timers"
                                    return self.global_timers

                                if (child_yang_name == "mpls-activated-interfaces"):
                                    if (self.mpls_activated_interfaces is None):
                                        self.mpls_activated_interfaces = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces()
                                        self.mpls_activated_interfaces.parent = self
                                        self._children_name_map["mpls_activated_interfaces"] = "mpls-activated-interfaces"
                                    return self.mpls_activated_interfaces

                                if (child_yang_name == "receive-socket-buffer-sizes"):
                                    if (self.receive_socket_buffer_sizes is None):
                                        self.receive_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes()
                                        self.receive_socket_buffer_sizes.parent = self
                                        self._children_name_map["receive_socket_buffer_sizes"] = "receive-socket-buffer-sizes"
                                    return self.receive_socket_buffer_sizes

                                if (child_yang_name == "route-distinguisher"):
                                    if (self.route_distinguisher is None):
                                        self.route_distinguisher = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher()
                                        self.route_distinguisher.parent = self
                                        self._children_name_map["route_distinguisher"] = "route-distinguisher"
                                    return self.route_distinguisher

                                if (child_yang_name == "send-socket-buffer-sizes"):
                                    if (self.send_socket_buffer_sizes is None):
                                        self.send_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes()
                                        self.send_socket_buffer_sizes.parent = self
                                        self._children_name_map["send_socket_buffer_sizes"] = "send-socket-buffer-sizes"
                                    return self.send_socket_buffer_sizes

                                if (child_yang_name == "vrf-global-afs"):
                                    if (self.vrf_global_afs is None):
                                        self.vrf_global_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs()
                                        self.vrf_global_afs.parent = self
                                        self._children_name_map["vrf_global_afs"] = "vrf-global-afs"
                                    return self.vrf_global_afs

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bfd" or name == "global-timers" or name == "mpls-activated-interfaces" or name == "receive-socket-buffer-sizes" or name == "route-distinguisher" or name == "send-socket-buffer-sizes" or name == "vrf-global-afs" or name == "best-path-aigp-ignore" or name == "best-path-as-multipath-relax" or name == "best-path-as-path-length" or name == "best-path-confederation-paths" or name == "best-path-cost-community" or name == "best-path-med-always" or name == "best-path-med-missing" or name == "best-path-router-id" or name == "default-info-originate" or name == "default-metric" or name == "disable-auto-soft-reset" or name == "disable-enforce-first-as" or name == "disable-fast-external-fallover" or name == "disable-msg-log" or name == "disable-neighbor-logging" or name == "exists" or name == "igp-redist-internal" or name == "local-preference" or name == "multi-path-as-path-ignore-onwards" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "best-path-aigp-ignore"):
                                    self.best_path_aigp_ignore = value
                                    self.best_path_aigp_ignore.value_namespace = name_space
                                    self.best_path_aigp_ignore.value_namespace_prefix = name_space_prefix
                                if(value_path == "best-path-as-multipath-relax"):
                                    self.best_path_as_multipath_relax = value
                                    self.best_path_as_multipath_relax.value_namespace = name_space
                                    self.best_path_as_multipath_relax.value_namespace_prefix = name_space_prefix
                                if(value_path == "best-path-as-path-length"):
                                    self.best_path_as_path_length = value
                                    self.best_path_as_path_length.value_namespace = name_space
                                    self.best_path_as_path_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "best-path-confederation-paths"):
                                    self.best_path_confederation_paths = value
                                    self.best_path_confederation_paths.value_namespace = name_space
                                    self.best_path_confederation_paths.value_namespace_prefix = name_space_prefix
                                if(value_path == "best-path-cost-community"):
                                    self.best_path_cost_community = value
                                    self.best_path_cost_community.value_namespace = name_space
                                    self.best_path_cost_community.value_namespace_prefix = name_space_prefix
                                if(value_path == "best-path-med-always"):
                                    self.best_path_med_always = value
                                    self.best_path_med_always.value_namespace = name_space
                                    self.best_path_med_always.value_namespace_prefix = name_space_prefix
                                if(value_path == "best-path-med-missing"):
                                    self.best_path_med_missing = value
                                    self.best_path_med_missing.value_namespace = name_space
                                    self.best_path_med_missing.value_namespace_prefix = name_space_prefix
                                if(value_path == "best-path-router-id"):
                                    self.best_path_router_id = value
                                    self.best_path_router_id.value_namespace = name_space
                                    self.best_path_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-info-originate"):
                                    self.default_info_originate = value
                                    self.default_info_originate.value_namespace = name_space
                                    self.default_info_originate.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-metric"):
                                    self.default_metric = value
                                    self.default_metric.value_namespace = name_space
                                    self.default_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-auto-soft-reset"):
                                    self.disable_auto_soft_reset = value
                                    self.disable_auto_soft_reset.value_namespace = name_space
                                    self.disable_auto_soft_reset.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-enforce-first-as"):
                                    self.disable_enforce_first_as = value
                                    self.disable_enforce_first_as.value_namespace = name_space
                                    self.disable_enforce_first_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-fast-external-fallover"):
                                    self.disable_fast_external_fallover = value
                                    self.disable_fast_external_fallover.value_namespace = name_space
                                    self.disable_fast_external_fallover.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-msg-log"):
                                    self.disable_msg_log = value
                                    self.disable_msg_log.value_namespace = name_space
                                    self.disable_msg_log.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-neighbor-logging"):
                                    self.disable_neighbor_logging = value
                                    self.disable_neighbor_logging.value_namespace = name_space
                                    self.disable_neighbor_logging.value_namespace_prefix = name_space_prefix
                                if(value_path == "exists"):
                                    self.exists = value
                                    self.exists.value_namespace = name_space
                                    self.exists.value_namespace_prefix = name_space_prefix
                                if(value_path == "igp-redist-internal"):
                                    self.igp_redist_internal = value
                                    self.igp_redist_internal.value_namespace = name_space
                                    self.igp_redist_internal.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-preference"):
                                    self.local_preference = value
                                    self.local_preference.value_namespace = name_space
                                    self.local_preference.value_namespace_prefix = name_space_prefix
                                if(value_path == "multi-path-as-path-ignore-onwards"):
                                    self.multi_path_as_path_ignore_onwards = value
                                    self.multi_path_as_path_ignore_onwards.value_namespace = name_space
                                    self.multi_path_as_path_ignore_onwards.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix


                        class VrfNeighbors(Entity):
                            """
                            BGP VRF peer
                            
                            .. attribute:: vrf_neighbor
                            
                            	A particular VRF peer
                            	**type**\: list of    :py:class:`VrfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor>`
                            
                            .. attribute:: vrf_neighbor_prefix_length
                            
                            	A particular VRF peer
                            	**type**\: list of    :py:class:`VrfNeighborPrefixLength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors, self).__init__()

                                self.yang_name = "vrf-neighbors"
                                self.yang_parent_name = "vrf"

                                self.vrf_neighbor = YList(self)
                                self.vrf_neighbor_prefix_length = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors, self).__setattr__(name, value)


                            class VrfNeighbor(Entity):
                                """
                                A particular VRF peer
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgpce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: vrf_neighbor_afs
                                
                                	Address family type of a VRF neighbor
                                	**type**\:   :py:class:`VrfNeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor, self).__init__()

                                    self.yang_name = "vrf-neighbor"
                                    self.yang_parent_name = "vrf-neighbors"

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgpce = YLeaf(YType.boolean, "internal-vpn-client-ibgpce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                    self.vrf_neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs()
                                    self.vrf_neighbor_afs.parent = self
                                    self._children_name_map["vrf_neighbor_afs"] = "vrf-neighbor-afs"
                                    self._children_yang_names.add("vrf-neighbor-afs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("neighbor_address",
                                                    "additional_paths_receive_capability",
                                                    "additional_paths_send_capability",
                                                    "bfd_enable_modes",
                                                    "bfd_minimum_interval",
                                                    "bfd_multiplier",
                                                    "description",
                                                    "ebgp_recv_dmz",
                                                    "ebgp_send_dmz_enable_modes",
                                                    "egress_peer_engineering",
                                                    "enforce_first_as",
                                                    "idle_watch_time",
                                                    "ignore_connected_check_ebgp",
                                                    "internal_vpn_client_ibgpce",
                                                    "max_peers",
                                                    "neighbor_graceful_restart",
                                                    "neighbor_graceful_restart_stalepath_time",
                                                    "neighbor_graceful_restart_time",
                                                    "neighbor_group_add_member",
                                                    "propagate_dmz_link_bandwidth",
                                                    "remote_as_list",
                                                    "session_group_add_member",
                                                    "session_open_mode",
                                                    "shutdown",
                                                    "suppress_all_capabilities",
                                                    "suppress_four_byte_as_capability",
                                                    "ttl_security",
                                                    "update_source_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor, self).__setattr__(name, value)


                                class VrfNeighborAfs(Entity):
                                    """
                                    Address family type of a VRF neighbor
                                    
                                    .. attribute:: vrf_neighbor_af
                                    
                                    	Address family type of a VRF neighbor
                                    	**type**\: list of    :py:class:`VrfNeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs, self).__init__()

                                        self.yang_name = "vrf-neighbor-afs"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.vrf_neighbor_af = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs, self).__setattr__(name, value)


                                    class VrfNeighborAf(Entity):
                                        """
                                        Address family type of a VRF neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpnevpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_l2vpnevpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf, self).__init__()

                                            self.yang_name = "vrf-neighbor-af"
                                            self.yang_parent_name = "vrf-neighbor-afs"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn()
                                            self.advertise_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                            self._children_yang_names.add("advertise-l2vpnevpn")

                                            self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn()
                                            self.advertise_local_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                            self._children_yang_names.add("advertise-local-l2vpnevpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "accept_own",
                                                            "accept_route_legacy_rt",
                                                            "activate",
                                                            "advertise_local_labeled_route",
                                                            "advertise_orf",
                                                            "advertise_permanent_network",
                                                            "af_group",
                                                            "aigp",
                                                            "aigp_send_med",
                                                            "allow_as_in",
                                                            "as_override",
                                                            "default_weight",
                                                            "encapsulation_type",
                                                            "flowspec_validation",
                                                            "multipath",
                                                            "neighbor_af_long_lived_graceful_restart_capable",
                                                            "next_hop_self",
                                                            "next_hop_unchanged",
                                                            "next_hop_unchanged_multipath",
                                                            "prefix_orf_policy",
                                                            "route_policy_in",
                                                            "route_policy_out",
                                                            "route_reflector_client",
                                                            "send_community_ebgp",
                                                            "send_community_ebgp_graceful_shutdown",
                                                            "send_ext_community_ebgp") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf, self).__setattr__(name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cost_community_id",
                                                                "cost_community_poi_type",
                                                                "enable",
                                                                "transitive") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cost_community_id.is_set or
                                                    self.cost_community_poi_type.is_set or
                                                    self.enable.is_set or
                                                    self.transitive.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cost_community_id.yfilter != YFilter.not_set or
                                                    self.cost_community_poi_type.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.transitive.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "aigp-cost-community" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cost_community_id.is_set or self.cost_community_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_id.get_name_leafdata())
                                                if (self.cost_community_poi_type.is_set or self.cost_community_poi_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_poi_type.get_name_leafdata())
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.transitive.is_set or self.transitive.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.transitive.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cost-community-id" or name == "cost-community-poi-type" or name == "enable" or name == "transitive"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cost-community-id"):
                                                    self.cost_community_id = value
                                                    self.cost_community_id.value_namespace = name_space
                                                    self.cost_community_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost-community-poi-type"):
                                                    self.cost_community_poi_type = value
                                                    self.cost_community_poi_type.value_namespace = name_space
                                                    self.cost_community_poi_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "transitive"):
                                                    self.transitive = value
                                                    self.transitive.value_namespace = name_space
                                                    self.transitive.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-disable" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("discard_extra_paths",
                                                                "prefix_limit",
                                                                "restart_time",
                                                                "warning_only",
                                                                "warning_percentage") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.discard_extra_paths.is_set or
                                                    self.prefix_limit.is_set or
                                                    self.restart_time.is_set or
                                                    self.warning_only.is_set or
                                                    self.warning_percentage.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.discard_extra_paths.yfilter != YFilter.not_set or
                                                    self.prefix_limit.yfilter != YFilter.not_set or
                                                    self.restart_time.yfilter != YFilter.not_set or
                                                    self.warning_only.yfilter != YFilter.not_set or
                                                    self.warning_percentage.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-prefixes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.discard_extra_paths.is_set or self.discard_extra_paths.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.discard_extra_paths.get_name_leafdata())
                                                if (self.prefix_limit.is_set or self.prefix_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_limit.get_name_leafdata())
                                                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.restart_time.get_name_leafdata())
                                                if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_only.get_name_leafdata())
                                                if (self.warning_percentage.is_set or self.warning_percentage.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_percentage.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "discard-extra-paths" or name == "prefix-limit" or name == "restart-time" or name == "warning-only" or name == "warning-percentage"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "discard-extra-paths"):
                                                    self.discard_extra_paths = value
                                                    self.discard_extra_paths.value_namespace = name_space
                                                    self.discard_extra_paths.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-limit"):
                                                    self.prefix_limit = value
                                                    self.prefix_limit.value_namespace = name_space
                                                    self.prefix_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "restart-time"):
                                                    self.restart_time = value
                                                    self.restart_time.value_namespace = name_space
                                                    self.restart_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-only"):
                                                    self.warning_only = value
                                                    self.warning_only.value_namespace = name_space
                                                    self.warning_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-percentage"):
                                                    self.warning_percentage = value
                                                    self.warning_percentage.value_namespace = name_space
                                                    self.warning_percentage.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path-inbound" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseL2Vpnevpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-l2vpnevpn"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalL2Vpnevpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpnevpn"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("stale_time_accept",
                                                                "stale_time_send") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.stale_time_accept.is_set or
                                                    self.stale_time_send.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.stale_time_accept.yfilter != YFilter.not_set or
                                                    self.stale_time_send.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-af-long-lived-graceful-restart-stale-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.stale_time_accept.is_set or self.stale_time_accept.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_accept.get_name_leafdata())
                                                if (self.stale_time_send.is_set or self.stale_time_send.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_send.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "stale-time-accept" or name == "stale-time-send"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "stale-time-accept"):
                                                    self.stale_time_accept = value
                                                    self.stale_time_accept.value_namespace = name_space
                                                    self.stale_time_accept.value_namespace_prefix = name_space_prefix
                                                if(value_path == "stale-time-send"):
                                                    self.stale_time_send = value
                                                    self.stale_time_send.value_namespace = name_space
                                                    self.stale_time_send.value_namespace_prefix = name_space_prefix


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("address",
                                                                "address_index",
                                                                "as_",
                                                                "as_index",
                                                                "as_xx",
                                                                "type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.address.is_set or
                                                    self.address_index.is_set or
                                                    self.as_.is_set or
                                                    self.as_index.is_set or
                                                    self.as_xx.is_set or
                                                    self.type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.address_index.yfilter != YFilter.not_set or
                                                    self.as_.yfilter != YFilter.not_set or
                                                    self.as_index.yfilter != YFilter.not_set or
                                                    self.as_xx.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "site-of-origin" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.address_index.is_set or self.address_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address_index.get_name_leafdata())
                                                if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_.get_name_leafdata())
                                                if (self.as_index.is_set or self.as_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_index.get_name_leafdata())
                                                if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_xx.get_name_leafdata())
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "address" or name == "address-index" or name == "as" or name == "as-index" or name == "as-xx" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address-index"):
                                                    self.address_index = value
                                                    self.address_index.value_namespace = name_space
                                                    self.address_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as"):
                                                    self.as_ = value
                                                    self.as_.value_namespace = name_space
                                                    self.as_.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-index"):
                                                    self.as_index = value
                                                    self.as_index.value_namespace = name_space
                                                    self.as_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-xx"):
                                                    self.as_xx = value
                                                    self.as_xx.value_namespace = name_space
                                                    self.as_xx.value_namespace_prefix = name_space_prefix
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("import_reoriginate",
                                                                "import_reoriginate_stitching",
                                                                "import_stitching") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.import_reoriginate.is_set or
                                                    self.import_reoriginate_stitching.is_set or
                                                    self.import_stitching.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.import_reoriginate.yfilter != YFilter.not_set or
                                                    self.import_reoriginate_stitching.yfilter != YFilter.not_set or
                                                    self.import_stitching.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "import" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.import_reoriginate.is_set or self.import_reoriginate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate.get_name_leafdata())
                                                if (self.import_reoriginate_stitching.is_set or self.import_reoriginate_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate_stitching.get_name_leafdata())
                                                if (self.import_stitching.is_set or self.import_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_stitching.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "import-reoriginate" or name == "import-reoriginate-stitching" or name == "import-stitching"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "import-reoriginate"):
                                                    self.import_reoriginate = value
                                                    self.import_reoriginate.value_namespace = name_space
                                                    self.import_reoriginate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-reoriginate-stitching"):
                                                    self.import_reoriginate_stitching = value
                                                    self.import_reoriginate_stitching.value_namespace = name_space
                                                    self.import_reoriginate_stitching.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-stitching"):
                                                    self.import_stitching = value
                                                    self.import_stitching.value_namespace = name_space
                                                    self.import_stitching.value_namespace_prefix = name_space_prefix


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "default-originate" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("inbound_soft",
                                                                "soft_always") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.inbound_soft.is_set or
                                                    self.soft_always.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.inbound_soft.yfilter != YFilter.not_set or
                                                    self.soft_always.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "soft-reconfiguration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.inbound_soft.is_set or self.inbound_soft.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.inbound_soft.get_name_leafdata())
                                                if (self.soft_always.is_set or self.soft_always.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.soft_always.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "inbound-soft" or name == "soft-always"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "inbound-soft"):
                                                    self.inbound_soft = value
                                                    self.inbound_soft.value_namespace = name_space
                                                    self.inbound_soft.value_namespace_prefix = name_space_prefix
                                                if(value_path == "soft-always"):
                                                    self.soft_always = value
                                                    self.soft_always.value_namespace = name_space
                                                    self.soft_always.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.accept_own.is_set or
                                                self.accept_route_legacy_rt.is_set or
                                                self.activate.is_set or
                                                self.advertise_local_labeled_route.is_set or
                                                self.advertise_orf.is_set or
                                                self.advertise_permanent_network.is_set or
                                                self.af_group.is_set or
                                                self.aigp.is_set or
                                                self.aigp_send_med.is_set or
                                                self.allow_as_in.is_set or
                                                self.as_override.is_set or
                                                self.default_weight.is_set or
                                                self.encapsulation_type.is_set or
                                                self.flowspec_validation.is_set or
                                                self.multipath.is_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.is_set or
                                                self.next_hop_self.is_set or
                                                self.next_hop_unchanged.is_set or
                                                self.next_hop_unchanged_multipath.is_set or
                                                self.prefix_orf_policy.is_set or
                                                self.route_policy_in.is_set or
                                                self.route_policy_out.is_set or
                                                self.route_reflector_client.is_set or
                                                self.send_community_ebgp.is_set or
                                                self.send_community_ebgp_graceful_shutdown.is_set or
                                                self.send_ext_community_ebgp.is_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_data()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_data()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_data()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_data()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_data()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_data()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_data()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_data()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_data()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_data()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_data()) or
                                                (self.default_originate is not None and self.default_originate.has_data()) or
                                                (self.import_ is not None and self.import_.has_data()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_data()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_data()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_data()) or
                                                (self.aigp_cost_community is not None) or
                                                (self.maximum_prefixes is not None) or
                                                (self.remove_private_as_entire_as_path is not None) or
                                                (self.remove_private_as_entire_as_path_inbound is not None))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.accept_own.yfilter != YFilter.not_set or
                                                self.accept_route_legacy_rt.yfilter != YFilter.not_set or
                                                self.activate.yfilter != YFilter.not_set or
                                                self.advertise_local_labeled_route.yfilter != YFilter.not_set or
                                                self.advertise_orf.yfilter != YFilter.not_set or
                                                self.advertise_permanent_network.yfilter != YFilter.not_set or
                                                self.af_group.yfilter != YFilter.not_set or
                                                self.aigp.yfilter != YFilter.not_set or
                                                self.aigp_send_med.yfilter != YFilter.not_set or
                                                self.allow_as_in.yfilter != YFilter.not_set or
                                                self.as_override.yfilter != YFilter.not_set or
                                                self.default_weight.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.flowspec_validation.yfilter != YFilter.not_set or
                                                self.multipath.yfilter != YFilter.not_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set or
                                                self.next_hop_self.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged_multipath.yfilter != YFilter.not_set or
                                                self.prefix_orf_policy.yfilter != YFilter.not_set or
                                                self.route_policy_in.yfilter != YFilter.not_set or
                                                self.route_policy_out.yfilter != YFilter.not_set or
                                                self.route_reflector_client.yfilter != YFilter.not_set or
                                                self.send_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set or
                                                self.send_ext_community_ebgp.yfilter != YFilter.not_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_operation()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_operation()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_operation()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_operation()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_operation()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_operation()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_operation()) or
                                                (self.aigp_cost_community is not None and self.aigp_cost_community.has_operation()) or
                                                (self.default_originate is not None and self.default_originate.has_operation()) or
                                                (self.import_ is not None and self.import_.has_operation()) or
                                                (self.maximum_prefixes is not None and self.maximum_prefixes.has_operation()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_operation()) or
                                                (self.remove_private_as_entire_as_path is not None and self.remove_private_as_entire_as_path.has_operation()) or
                                                (self.remove_private_as_entire_as_path_inbound is not None and self.remove_private_as_entire_as_path_inbound.has_operation()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_operation()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-neighbor-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.accept_own.is_set or self.accept_own.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_own.get_name_leafdata())
                                            if (self.accept_route_legacy_rt.is_set or self.accept_route_legacy_rt.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_route_legacy_rt.get_name_leafdata())
                                            if (self.activate.is_set or self.activate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.activate.get_name_leafdata())
                                            if (self.advertise_local_labeled_route.is_set or self.advertise_local_labeled_route.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_local_labeled_route.get_name_leafdata())
                                            if (self.advertise_orf.is_set or self.advertise_orf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_orf.get_name_leafdata())
                                            if (self.advertise_permanent_network.is_set or self.advertise_permanent_network.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_permanent_network.get_name_leafdata())
                                            if (self.af_group.is_set or self.af_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_group.get_name_leafdata())
                                            if (self.aigp.is_set or self.aigp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp.get_name_leafdata())
                                            if (self.aigp_send_med.is_set or self.aigp_send_med.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp_send_med.get_name_leafdata())
                                            if (self.allow_as_in.is_set or self.allow_as_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.allow_as_in.get_name_leafdata())
                                            if (self.as_override.is_set or self.as_override.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_override.get_name_leafdata())
                                            if (self.default_weight.is_set or self.default_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_weight.get_name_leafdata())
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.flowspec_validation.is_set or self.flowspec_validation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flowspec_validation.get_name_leafdata())
                                            if (self.multipath.is_set or self.multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multipath.get_name_leafdata())
                                            if (self.neighbor_af_long_lived_graceful_restart_capable.is_set or self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_af_long_lived_graceful_restart_capable.get_name_leafdata())
                                            if (self.next_hop_self.is_set or self.next_hop_self.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_self.get_name_leafdata())
                                            if (self.next_hop_unchanged.is_set or self.next_hop_unchanged.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged.get_name_leafdata())
                                            if (self.next_hop_unchanged_multipath.is_set or self.next_hop_unchanged_multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged_multipath.get_name_leafdata())
                                            if (self.prefix_orf_policy.is_set or self.prefix_orf_policy.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_orf_policy.get_name_leafdata())
                                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                            if (self.route_reflector_client.is_set or self.route_reflector_client.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_reflector_client.get_name_leafdata())
                                            if (self.send_community_ebgp.is_set or self.send_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp.get_name_leafdata())
                                            if (self.send_community_ebgp_graceful_shutdown.is_set or self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp_graceful_shutdown.get_name_leafdata())
                                            if (self.send_ext_community_ebgp.is_set or self.send_ext_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_ext_community_ebgp.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advertise-def-imp-disable-v4"):
                                                if (self.advertise_def_imp_disable_v4 is None):
                                                    self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4()
                                                    self.advertise_def_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                                return self.advertise_def_imp_disable_v4

                                            if (child_yang_name == "advertise-def-imp-disable-v6"):
                                                if (self.advertise_def_imp_disable_v6 is None):
                                                    self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6()
                                                    self.advertise_def_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                                return self.advertise_def_imp_disable_v6

                                            if (child_yang_name == "advertise-disable"):
                                                if (self.advertise_disable is None):
                                                    self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable()
                                                    self.advertise_disable.parent = self
                                                    self._children_name_map["advertise_disable"] = "advertise-disable"
                                                return self.advertise_disable

                                            if (child_yang_name == "advertise-l2vpnevpn"):
                                                if (self.advertise_l2vpnevpn is None):
                                                    self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn()
                                                    self.advertise_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                                return self.advertise_l2vpnevpn

                                            if (child_yang_name == "advertise-local-l2vpnevpn"):
                                                if (self.advertise_local_l2vpnevpn is None):
                                                    self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn()
                                                    self.advertise_local_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                                return self.advertise_local_l2vpnevpn

                                            if (child_yang_name == "advertise-local-v4"):
                                                if (self.advertise_local_v4 is None):
                                                    self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4()
                                                    self.advertise_local_v4.parent = self
                                                    self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                                return self.advertise_local_v4

                                            if (child_yang_name == "advertise-local-v6"):
                                                if (self.advertise_local_v6 is None):
                                                    self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6()
                                                    self.advertise_local_v6.parent = self
                                                    self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                                return self.advertise_local_v6

                                            if (child_yang_name == "advertise-v4"):
                                                if (self.advertise_v4 is None):
                                                    self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4()
                                                    self.advertise_v4.parent = self
                                                    self._children_name_map["advertise_v4"] = "advertise-v4"
                                                return self.advertise_v4

                                            if (child_yang_name == "advertise-v6"):
                                                if (self.advertise_v6 is None):
                                                    self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6()
                                                    self.advertise_v6.parent = self
                                                    self._children_name_map["advertise_v6"] = "advertise-v6"
                                                return self.advertise_v6

                                            if (child_yang_name == "advertise-vrf-imp-disable-v4"):
                                                if (self.advertise_vrf_imp_disable_v4 is None):
                                                    self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4()
                                                    self.advertise_vrf_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                                return self.advertise_vrf_imp_disable_v4

                                            if (child_yang_name == "advertise-vrf-imp-disable-v6"):
                                                if (self.advertise_vrf_imp_disable_v6 is None):
                                                    self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6()
                                                    self.advertise_vrf_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                                return self.advertise_vrf_imp_disable_v6

                                            if (child_yang_name == "aigp-cost-community"):
                                                if (self.aigp_cost_community is None):
                                                    self.aigp_cost_community = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity()
                                                    self.aigp_cost_community.parent = self
                                                    self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                                return self.aigp_cost_community

                                            if (child_yang_name == "default-originate"):
                                                if (self.default_originate is None):
                                                    self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate()
                                                    self.default_originate.parent = self
                                                    self._children_name_map["default_originate"] = "default-originate"
                                                return self.default_originate

                                            if (child_yang_name == "import"):
                                                if (self.import_ is None):
                                                    self.import_ = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_()
                                                    self.import_.parent = self
                                                    self._children_name_map["import_"] = "import"
                                                return self.import_

                                            if (child_yang_name == "maximum-prefixes"):
                                                if (self.maximum_prefixes is None):
                                                    self.maximum_prefixes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes()
                                                    self.maximum_prefixes.parent = self
                                                    self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                                return self.maximum_prefixes

                                            if (child_yang_name == "neighbor-af-long-lived-graceful-restart-stale-time"):
                                                if (self.neighbor_af_long_lived_graceful_restart_stale_time is None):
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                                    self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                return self.neighbor_af_long_lived_graceful_restart_stale_time

                                            if (child_yang_name == "remove-private-as-entire-as-path"):
                                                if (self.remove_private_as_entire_as_path is None):
                                                    self.remove_private_as_entire_as_path = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath()
                                                    self.remove_private_as_entire_as_path.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                                return self.remove_private_as_entire_as_path

                                            if (child_yang_name == "remove-private-as-entire-as-path-inbound"):
                                                if (self.remove_private_as_entire_as_path_inbound is None):
                                                    self.remove_private_as_entire_as_path_inbound = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound()
                                                    self.remove_private_as_entire_as_path_inbound.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                                return self.remove_private_as_entire_as_path_inbound

                                            if (child_yang_name == "site-of-origin"):
                                                if (self.site_of_origin is None):
                                                    self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin()
                                                    self.site_of_origin.parent = self
                                                    self._children_name_map["site_of_origin"] = "site-of-origin"
                                                return self.site_of_origin

                                            if (child_yang_name == "soft-reconfiguration"):
                                                if (self.soft_reconfiguration is None):
                                                    self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration()
                                                    self.soft_reconfiguration.parent = self
                                                    self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                                return self.soft_reconfiguration

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertise-def-imp-disable-v4" or name == "advertise-def-imp-disable-v6" or name == "advertise-disable" or name == "advertise-l2vpnevpn" or name == "advertise-local-l2vpnevpn" or name == "advertise-local-v4" or name == "advertise-local-v6" or name == "advertise-v4" or name == "advertise-v6" or name == "advertise-vrf-imp-disable-v4" or name == "advertise-vrf-imp-disable-v6" or name == "aigp-cost-community" or name == "default-originate" or name == "import" or name == "maximum-prefixes" or name == "neighbor-af-long-lived-graceful-restart-stale-time" or name == "remove-private-as-entire-as-path" or name == "remove-private-as-entire-as-path-inbound" or name == "site-of-origin" or name == "soft-reconfiguration" or name == "af-name" or name == "accept-own" or name == "accept-route-legacy-rt" or name == "activate" or name == "advertise-local-labeled-route" or name == "advertise-orf" or name == "advertise-permanent-network" or name == "af-group" or name == "aigp" or name == "aigp-send-med" or name == "allow-as-in" or name == "as-override" or name == "default-weight" or name == "encapsulation-type" or name == "flowspec-validation" or name == "multipath" or name == "neighbor-af-long-lived-graceful-restart-capable" or name == "next-hop-self" or name == "next-hop-unchanged" or name == "next-hop-unchanged-multipath" or name == "prefix-orf-policy" or name == "route-policy-in" or name == "route-policy-out" or name == "route-reflector-client" or name == "send-community-ebgp" or name == "send-community-ebgp-graceful-shutdown" or name == "send-ext-community-ebgp"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-own"):
                                                self.accept_own = value
                                                self.accept_own.value_namespace = name_space
                                                self.accept_own.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-route-legacy-rt"):
                                                self.accept_route_legacy_rt = value
                                                self.accept_route_legacy_rt.value_namespace = name_space
                                                self.accept_route_legacy_rt.value_namespace_prefix = name_space_prefix
                                            if(value_path == "activate"):
                                                self.activate = value
                                                self.activate.value_namespace = name_space
                                                self.activate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-local-labeled-route"):
                                                self.advertise_local_labeled_route = value
                                                self.advertise_local_labeled_route.value_namespace = name_space
                                                self.advertise_local_labeled_route.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-orf"):
                                                self.advertise_orf = value
                                                self.advertise_orf.value_namespace = name_space
                                                self.advertise_orf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-permanent-network"):
                                                self.advertise_permanent_network = value
                                                self.advertise_permanent_network.value_namespace = name_space
                                                self.advertise_permanent_network.value_namespace_prefix = name_space_prefix
                                            if(value_path == "af-group"):
                                                self.af_group = value
                                                self.af_group.value_namespace = name_space
                                                self.af_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp"):
                                                self.aigp = value
                                                self.aigp.value_namespace = name_space
                                                self.aigp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp-send-med"):
                                                self.aigp_send_med = value
                                                self.aigp_send_med.value_namespace = name_space
                                                self.aigp_send_med.value_namespace_prefix = name_space_prefix
                                            if(value_path == "allow-as-in"):
                                                self.allow_as_in = value
                                                self.allow_as_in.value_namespace = name_space
                                                self.allow_as_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-override"):
                                                self.as_override = value
                                                self.as_override.value_namespace = name_space
                                                self.as_override.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-weight"):
                                                self.default_weight = value
                                                self.default_weight.value_namespace = name_space
                                                self.default_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flowspec-validation"):
                                                self.flowspec_validation = value
                                                self.flowspec_validation.value_namespace = name_space
                                                self.flowspec_validation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multipath"):
                                                self.multipath = value
                                                self.multipath.value_namespace = name_space
                                                self.multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-af-long-lived-graceful-restart-capable"):
                                                self.neighbor_af_long_lived_graceful_restart_capable = value
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace = name_space
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-self"):
                                                self.next_hop_self = value
                                                self.next_hop_self.value_namespace = name_space
                                                self.next_hop_self.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged"):
                                                self.next_hop_unchanged = value
                                                self.next_hop_unchanged.value_namespace = name_space
                                                self.next_hop_unchanged.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged-multipath"):
                                                self.next_hop_unchanged_multipath = value
                                                self.next_hop_unchanged_multipath.value_namespace = name_space
                                                self.next_hop_unchanged_multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-orf-policy"):
                                                self.prefix_orf_policy = value
                                                self.prefix_orf_policy.value_namespace = name_space
                                                self.prefix_orf_policy.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-in"):
                                                self.route_policy_in = value
                                                self.route_policy_in.value_namespace = name_space
                                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-out"):
                                                self.route_policy_out = value
                                                self.route_policy_out.value_namespace = name_space
                                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-reflector-client"):
                                                self.route_reflector_client = value
                                                self.route_reflector_client.value_namespace = name_space
                                                self.route_reflector_client.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp"):
                                                self.send_community_ebgp = value
                                                self.send_community_ebgp.value_namespace = name_space
                                                self.send_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp-graceful-shutdown"):
                                                self.send_community_ebgp_graceful_shutdown = value
                                                self.send_community_ebgp_graceful_shutdown.value_namespace = name_space
                                                self.send_community_ebgp_graceful_shutdown.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-ext-community-ebgp"):
                                                self.send_ext_community_ebgp = value
                                                self.send_ext_community_ebgp.value_namespace = name_space
                                                self.send_ext_community_ebgp.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_neighbor_af:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_neighbor_af:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-neighbor-afs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-neighbor-af"):
                                            for c in self.vrf_neighbor_af:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_neighbor_af.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-neighbor-af"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address_disable",
                                                        "local_ip_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_address_disable.is_set or
                                            self.local_ip_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address_disable.yfilter != YFilter.not_set or
                                            self.local_ip_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address_disable.is_set or self.local_address_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address_disable.get_name_leafdata())
                                        if (self.local_ip_address.is_set or self.local_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ip_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-address-disable" or name == "local-ip-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address-disable"):
                                            self.local_address_disable = value
                                            self.local_address_disable.value_namespace = name_space
                                            self.local_address_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ip-address"):
                                            self.local_ip_address = value
                                            self.local_ip_address.value_namespace = name_space
                                            self.local_ip_address.value_namespace_prefix = name_space_prefix


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.bmp_activate = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates, self).__setattr__(name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"

                                            self.server_id = YLeaf(YType.uint32, "server-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("server_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.server_id.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.server_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bmp-activate" + "[server-id='" + self.server_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.server_id.is_set or self.server_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.server_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "server-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "server-id"):
                                                self.server_id = value
                                                self.server_id.value_namespace = name_space
                                                self.server_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bmp_activate:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bmp_activate:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmp-activates" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bmp-activate"):
                                            for c in self.bmp_activate:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bmp_activate.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bmp-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("max_hop_count",
                                                        "mpls_deactivation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.max_hop_count.is_set or
                                            self.mpls_deactivation.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.max_hop_count.yfilter != YFilter.not_set or
                                            self.mpls_deactivation.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ebgp-multihop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.max_hop_count.is_set or self.max_hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.max_hop_count.get_name_leafdata())
                                        if (self.mpls_deactivation.is_set or self.mpls_deactivation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_deactivation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "max-hop-count" or name == "mpls-deactivation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "max-hop-count"):
                                            self.max_hop_count = value
                                            self.max_hop_count.value_namespace = name_space
                                            self.max_hop_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-deactivation"):
                                            self.mpls_deactivation = value
                                            self.mpls_deactivation.value_namespace = name_space
                                            self.mpls_deactivation.value_namespace_prefix = name_space_prefix


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy",
                                                        "disable",
                                                        "dual_as",
                                                        "no_prepend",
                                                        "replace_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set or
                                            self.disable.is_set or
                                            self.dual_as.is_set or
                                            self.no_prepend.is_set or
                                            self.replace_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set or
                                            self.disable.yfilter != YFilter.not_set or
                                            self.dual_as.yfilter != YFilter.not_set or
                                            self.no_prepend.yfilter != YFilter.not_set or
                                            self.replace_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())
                                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable.get_name_leafdata())
                                        if (self.dual_as.is_set or self.dual_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dual_as.get_name_leafdata())
                                        if (self.no_prepend.is_set or self.no_prepend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_prepend.get_name_leafdata())
                                        if (self.replace_as.is_set or self.replace_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.replace_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy" or name == "disable" or name == "dual-as" or name == "no-prepend" or name == "replace-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable"):
                                            self.disable = value
                                            self.disable.value_namespace = name_space
                                            self.disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dual-as"):
                                            self.dual_as = value
                                            self.dual_as.value_namespace = name_space
                                            self.dual_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-prepend"):
                                            self.no_prepend = value
                                            self.no_prepend.value_namespace = name_space
                                            self.no_prepend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "replace-as"):
                                            self.replace_as = value
                                            self.replace_as.value_namespace = name_space
                                            self.replace_as.value_namespace_prefix = name_space_prefix


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("password",
                                                        "password_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.password.is_set or
                                            self.password_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.password.yfilter != YFilter.not_set or
                                            self.password_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "password" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password.get_name_leafdata())
                                        if (self.password_disable.is_set or self.password_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "password" or name == "password-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "password"):
                                            self.password = value
                                            self.password.value_namespace = name_space
                                            self.password.value_namespace_prefix = name_space_prefix
                                        if(value_path == "password-disable"):
                                            self.password_disable = value
                                            self.password_disable.value_namespace = name_space
                                            self.password_disable.value_namespace_prefix = name_space_prefix


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("minimum_interval",
                                                        "minimum_interval_msecs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.minimum_interval.is_set or
                                            self.minimum_interval_msecs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.minimum_interval.yfilter != YFilter.not_set or
                                            self.minimum_interval_msecs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "advertisement-interval" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                        if (self.minimum_interval_msecs.is_set or self.minimum_interval_msecs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval_msecs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "minimum-interval" or name == "minimum-interval-msecs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "minimum-interval"):
                                            self.minimum_interval = value
                                            self.minimum_interval.value_namespace = name_space
                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-interval-msecs"):
                                            self.minimum_interval_msecs = value
                                            self.minimum_interval_msecs.value_namespace = name_space
                                            self.minimum_interval_msecs.value_namespace_prefix = name_space_prefix


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cluster_id_address",
                                                        "cluster_id_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cluster_id_address.is_set or
                                            self.cluster_id_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cluster_id_address.yfilter != YFilter.not_set or
                                            self.cluster_id_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-cluster-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_address.get_name_leafdata())
                                        if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cluster-id-address" or name == "cluster-id-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cluster-id-address"):
                                            self.cluster_id_address = value
                                            self.cluster_id_address.value_namespace = name_space
                                            self.cluster_id_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cluster-id-number"):
                                            self.cluster_id_number = value
                                            self.cluster_id_number.value_namespace = name_space
                                            self.cluster_id_number.value_namespace_prefix = name_space_prefix


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mss",
                                                        "tcpmss_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mss.is_set or
                                            self.tcpmss_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mss.yfilter != YFilter.not_set or
                                            self.tcpmss_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tcpmss" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mss.is_set or self.mss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mss.get_name_leafdata())
                                        if (self.tcpmss_disable.is_set or self.tcpmss_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tcpmss_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mss" or name == "tcpmss-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mss"):
                                            self.mss = value
                                            self.mss.value_namespace = name_space
                                            self.mss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tcpmss-disable"):
                                            self.tcpmss_disable = value
                                            self.tcpmss_disable.value_namespace = name_space
                                            self.tcpmss_disable.value_namespace_prefix = name_space_prefix


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type",
                                                        "value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            self.value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            self.value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tos" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())
                                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "type" or name == "value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "value"):
                                            self.value = value
                                            self.value.value_namespace = name_space
                                            self.value.value_namespace_prefix = name_space_prefix


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "update_in_filtering_attribute_filter_group",
                                                        "update_in_filtering_syslog_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering, self).__setattr__(name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("non_circular_buffer",
                                                            "number_of_buffers") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.non_circular_buffer.is_set or
                                                self.number_of_buffers.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.non_circular_buffer.yfilter != YFilter.not_set or
                                                self.number_of_buffers.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "update-in-filtering-message-buffers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.non_circular_buffer.is_set or self.non_circular_buffer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.non_circular_buffer.get_name_leafdata())
                                            if (self.number_of_buffers.is_set or self.number_of_buffers.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_buffers.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "non-circular-buffer" or name == "number-of-buffers"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "non-circular-buffer"):
                                                self.non_circular_buffer = value
                                                self.non_circular_buffer.value_namespace = name_space
                                                self.non_circular_buffer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-buffers"):
                                                self.number_of_buffers = value
                                                self.number_of_buffers.value_namespace = name_space
                                                self.number_of_buffers.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.update_in_filtering_attribute_filter_group.is_set or
                                            self.update_in_filtering_syslog_disable.is_set or
                                            (self.update_in_filtering_message_buffers is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set or
                                            self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set or
                                            (self.update_in_filtering_message_buffers is not None and self.update_in_filtering_message_buffers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "update-in-filtering" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.update_in_filtering_attribute_filter_group.is_set or self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_attribute_filter_group.get_name_leafdata())
                                        if (self.update_in_filtering_syslog_disable.is_set or self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_syslog_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "update-in-filtering-message-buffers"):
                                            if (self.update_in_filtering_message_buffers is None):
                                                self.update_in_filtering_message_buffers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers()
                                                self.update_in_filtering_message_buffers.parent = self
                                                self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                            return self.update_in_filtering_message_buffers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "update-in-filtering-message-buffers" or name == "enable" or name == "update-in-filtering-attribute-filter-group" or name == "update-in-filtering-syslog-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-attribute-filter-group"):
                                            self.update_in_filtering_attribute_filter_group = value
                                            self.update_in_filtering_attribute_filter_group.value_namespace = name_space
                                            self.update_in_filtering_attribute_filter_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-syslog-disable"):
                                            self.update_in_filtering_syslog_disable = value
                                            self.update_in_filtering_syslog_disable.value_namespace = name_space
                                            self.update_in_filtering_syslog_disable.value_namespace_prefix = name_space_prefix


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-out" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_receive_size",
                                                        "socket_receive_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_receive_size.is_set or
                                            self.socket_receive_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_receive_size.yfilter != YFilter.not_set or
                                            self.socket_receive_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "receive-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                        if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-receive-size"):
                                            self.bgp_receive_size = value
                                            self.bgp_receive_size.value_namespace = name_space
                                            self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-receive-size"):
                                            self.socket_receive_size = value
                                            self.socket_receive_size.value_namespace = name_space
                                            self.socket_receive_size.value_namespace_prefix = name_space_prefix


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-in" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_send_size",
                                                        "socket_send_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_send_size.is_set or
                                            self.socket_send_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_send_size.yfilter != YFilter.not_set or
                                            self.socket_send_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "send-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                        if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-send-size" or name == "socket-send-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-send-size"):
                                            self.bgp_send_size = value
                                            self.bgp_send_size.value_namespace = name_space
                                            self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-send-size"):
                                            self.socket_send_size = value
                                            self.socket_send_size.value_namespace = name_space
                                            self.socket_send_size.value_namespace_prefix = name_space_prefix


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("hold_time",
                                                        "keepalive_interval",
                                                        "min_accept_hold_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.hold_time.is_set or
                                            self.keepalive_interval.is_set or
                                            self.min_accept_hold_time.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.hold_time.yfilter != YFilter.not_set or
                                            self.keepalive_interval.yfilter != YFilter.not_set or
                                            self.min_accept_hold_time.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hold_time.get_name_leafdata())
                                        if (self.keepalive_interval.is_set or self.keepalive_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keepalive_interval.get_name_leafdata())
                                        if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "hold-time" or name == "keepalive-interval" or name == "min-accept-hold-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "hold-time"):
                                            self.hold_time = value
                                            self.hold_time.value_namespace = name_space
                                            self.hold_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keepalive-interval"):
                                            self.keepalive_interval = value
                                            self.keepalive_interval.value_namespace = name_space
                                            self.keepalive_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "min-accept-hold-time"):
                                            self.min_accept_hold_time = value
                                            self.min_accept_hold_time.value_namespace = name_space
                                            self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("keychain_disable",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.keychain_disable.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.keychain_disable.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "keychain" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.keychain_disable.is_set or self.keychain_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_disable.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "keychain-disable" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "keychain-disable"):
                                            self.keychain_disable = value
                                            self.keychain_disable.value_namespace = name_space
                                            self.keychain_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "vrf-neighbor"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "graceful_maintenance_activate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance, self).__setattr__(name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("gshut_loc_pref_disable",
                                                            "local_preference") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.gshut_loc_pref_disable.is_set or
                                                self.local_preference.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.gshut_loc_pref_disable.yfilter != YFilter.not_set or
                                                self.local_preference.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-local-preference" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.gshut_loc_pref_disable.is_set or self.gshut_loc_pref_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_loc_pref_disable.get_name_leafdata())
                                            if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_preference.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "gshut-loc-pref-disable" or name == "local-preference"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "gshut-loc-pref-disable"):
                                                self.gshut_loc_pref_disable = value
                                                self.gshut_loc_pref_disable.value_namespace = name_space
                                                self.gshut_loc_pref_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-preference"):
                                                self.local_preference = value
                                                self.local_preference.value_namespace = name_space
                                                self.local_preference.value_namespace_prefix = name_space_prefix


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("as_prepends",
                                                            "gshut_prepends_disable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.as_prepends.is_set or
                                                self.gshut_prepends_disable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.as_prepends.yfilter != YFilter.not_set or
                                                self.gshut_prepends_disable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-as-prepends" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.as_prepends.is_set or self.as_prepends.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_prepends.get_name_leafdata())
                                            if (self.gshut_prepends_disable.is_set or self.gshut_prepends_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_prepends_disable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "as-prepends" or name == "gshut-prepends-disable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "as-prepends"):
                                                self.as_prepends = value
                                                self.as_prepends.value_namespace = name_space
                                                self.as_prepends.value_namespace_prefix = name_space_prefix
                                            if(value_path == "gshut-prepends-disable"):
                                                self.gshut_prepends_disable = value
                                                self.gshut_prepends_disable.value_namespace = name_space
                                                self.gshut_prepends_disable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.graceful_maintenance_activate.is_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_data()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.graceful_maintenance_activate.yfilter != YFilter.not_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_operation()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "graceful-maintenance" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.graceful_maintenance_activate.is_set or self.graceful_maintenance_activate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.graceful_maintenance_activate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "graceful-maintenance-as-prepends"):
                                            if (self.graceful_maintenance_as_prepends is None):
                                                self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                                self.graceful_maintenance_as_prepends.parent = self
                                                self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                            return self.graceful_maintenance_as_prepends

                                        if (child_yang_name == "graceful-maintenance-local-preference"):
                                            if (self.graceful_maintenance_local_preference is None):
                                                self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                                self.graceful_maintenance_local_preference.parent = self
                                                self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                            return self.graceful_maintenance_local_preference

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "graceful-maintenance-as-prepends" or name == "graceful-maintenance-local-preference" or name == "enable" or name == "graceful-maintenance-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "graceful-maintenance-activate"):
                                            self.graceful_maintenance_activate = value
                                            self.graceful_maintenance_activate.value_namespace = name_space
                                            self.graceful_maintenance_activate.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.neighbor_address.is_set or
                                        self.additional_paths_receive_capability.is_set or
                                        self.additional_paths_send_capability.is_set or
                                        self.bfd_enable_modes.is_set or
                                        self.bfd_minimum_interval.is_set or
                                        self.bfd_multiplier.is_set or
                                        self.description.is_set or
                                        self.ebgp_recv_dmz.is_set or
                                        self.ebgp_send_dmz_enable_modes.is_set or
                                        self.egress_peer_engineering.is_set or
                                        self.enforce_first_as.is_set or
                                        self.idle_watch_time.is_set or
                                        self.ignore_connected_check_ebgp.is_set or
                                        self.internal_vpn_client_ibgpce.is_set or
                                        self.max_peers.is_set or
                                        self.neighbor_graceful_restart.is_set or
                                        self.neighbor_graceful_restart_stalepath_time.is_set or
                                        self.neighbor_graceful_restart_time.is_set or
                                        self.neighbor_group_add_member.is_set or
                                        self.propagate_dmz_link_bandwidth.is_set or
                                        self.remote_as_list.is_set or
                                        self.session_group_add_member.is_set or
                                        self.session_open_mode.is_set or
                                        self.shutdown.is_set or
                                        self.suppress_all_capabilities.is_set or
                                        self.suppress_four_byte_as_capability.is_set or
                                        self.ttl_security.is_set or
                                        self.update_source_interface.is_set or
                                        (self.bmp_activates is not None and self.bmp_activates.has_data()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_data()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_data()) or
                                        (self.keychain is not None and self.keychain.has_data()) or
                                        (self.local_address is not None and self.local_address.has_data()) or
                                        (self.local_as is not None and self.local_as.has_data()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_data()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_data()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_data()) or
                                        (self.password is not None and self.password.has_data()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_data()) or
                                        (self.remote_as is not None and self.remote_as.has_data()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_data()) or
                                        (self.tcpmss is not None and self.tcpmss.has_data()) or
                                        (self.timers is not None and self.timers.has_data()) or
                                        (self.tos is not None and self.tos.has_data()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_data()) or
                                        (self.vrf_neighbor_afs is not None and self.vrf_neighbor_afs.has_data()) or
                                        (self.advertisement_interval is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.additional_paths_receive_capability.yfilter != YFilter.not_set or
                                        self.additional_paths_send_capability.yfilter != YFilter.not_set or
                                        self.bfd_enable_modes.yfilter != YFilter.not_set or
                                        self.bfd_minimum_interval.yfilter != YFilter.not_set or
                                        self.bfd_multiplier.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.ebgp_recv_dmz.yfilter != YFilter.not_set or
                                        self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set or
                                        self.egress_peer_engineering.yfilter != YFilter.not_set or
                                        self.enforce_first_as.yfilter != YFilter.not_set or
                                        self.idle_watch_time.yfilter != YFilter.not_set or
                                        self.ignore_connected_check_ebgp.yfilter != YFilter.not_set or
                                        self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set or
                                        self.max_peers.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_time.yfilter != YFilter.not_set or
                                        self.neighbor_group_add_member.yfilter != YFilter.not_set or
                                        self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set or
                                        self.remote_as_list.yfilter != YFilter.not_set or
                                        self.session_group_add_member.yfilter != YFilter.not_set or
                                        self.session_open_mode.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.suppress_all_capabilities.yfilter != YFilter.not_set or
                                        self.suppress_four_byte_as_capability.yfilter != YFilter.not_set or
                                        self.ttl_security.yfilter != YFilter.not_set or
                                        self.update_source_interface.yfilter != YFilter.not_set or
                                        (self.advertisement_interval is not None and self.advertisement_interval.has_operation()) or
                                        (self.bmp_activates is not None and self.bmp_activates.has_operation()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_operation()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_operation()) or
                                        (self.keychain is not None and self.keychain.has_operation()) or
                                        (self.local_address is not None and self.local_address.has_operation()) or
                                        (self.local_as is not None and self.local_as.has_operation()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_operation()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_operation()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_operation()) or
                                        (self.password is not None and self.password.has_operation()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_operation()) or
                                        (self.remote_as is not None and self.remote_as.has_operation()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_operation()) or
                                        (self.tcpmss is not None and self.tcpmss.has_operation()) or
                                        (self.timers is not None and self.timers.has_operation()) or
                                        (self.tos is not None and self.tos.has_operation()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_operation()) or
                                        (self.vrf_neighbor_afs is not None and self.vrf_neighbor_afs.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.additional_paths_receive_capability.is_set or self.additional_paths_receive_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_receive_capability.get_name_leafdata())
                                    if (self.additional_paths_send_capability.is_set or self.additional_paths_send_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_send_capability.get_name_leafdata())
                                    if (self.bfd_enable_modes.is_set or self.bfd_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_enable_modes.get_name_leafdata())
                                    if (self.bfd_minimum_interval.is_set or self.bfd_minimum_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_minimum_interval.get_name_leafdata())
                                    if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.ebgp_recv_dmz.is_set or self.ebgp_recv_dmz.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_recv_dmz.get_name_leafdata())
                                    if (self.ebgp_send_dmz_enable_modes.is_set or self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_send_dmz_enable_modes.get_name_leafdata())
                                    if (self.egress_peer_engineering.is_set or self.egress_peer_engineering.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.egress_peer_engineering.get_name_leafdata())
                                    if (self.enforce_first_as.is_set or self.enforce_first_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enforce_first_as.get_name_leafdata())
                                    if (self.idle_watch_time.is_set or self.idle_watch_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.idle_watch_time.get_name_leafdata())
                                    if (self.ignore_connected_check_ebgp.is_set or self.ignore_connected_check_ebgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ignore_connected_check_ebgp.get_name_leafdata())
                                    if (self.internal_vpn_client_ibgpce.is_set or self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_vpn_client_ibgpce.get_name_leafdata())
                                    if (self.max_peers.is_set or self.max_peers.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_peers.get_name_leafdata())
                                    if (self.neighbor_graceful_restart.is_set or self.neighbor_graceful_restart.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_stalepath_time.is_set or self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_stalepath_time.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_time.is_set or self.neighbor_graceful_restart_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_time.get_name_leafdata())
                                    if (self.neighbor_group_add_member.is_set or self.neighbor_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_group_add_member.get_name_leafdata())
                                    if (self.propagate_dmz_link_bandwidth.is_set or self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.propagate_dmz_link_bandwidth.get_name_leafdata())
                                    if (self.remote_as_list.is_set or self.remote_as_list.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_as_list.get_name_leafdata())
                                    if (self.session_group_add_member.is_set or self.session_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_group_add_member.get_name_leafdata())
                                    if (self.session_open_mode.is_set or self.session_open_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_open_mode.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.suppress_all_capabilities.is_set or self.suppress_all_capabilities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_all_capabilities.get_name_leafdata())
                                    if (self.suppress_four_byte_as_capability.is_set or self.suppress_four_byte_as_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_four_byte_as_capability.get_name_leafdata())
                                    if (self.ttl_security.is_set or self.ttl_security.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security.get_name_leafdata())
                                    if (self.update_source_interface.is_set or self.update_source_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_source_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "advertisement-interval"):
                                        if (self.advertisement_interval is None):
                                            self.advertisement_interval = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval()
                                            self.advertisement_interval.parent = self
                                            self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                        return self.advertisement_interval

                                    if (child_yang_name == "bmp-activates"):
                                        if (self.bmp_activates is None):
                                            self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates()
                                            self.bmp_activates.parent = self
                                            self._children_name_map["bmp_activates"] = "bmp-activates"
                                        return self.bmp_activates

                                    if (child_yang_name == "ebgp-multihop"):
                                        if (self.ebgp_multihop is None):
                                            self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop()
                                            self.ebgp_multihop.parent = self
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                        return self.ebgp_multihop

                                    if (child_yang_name == "graceful-maintenance"):
                                        if (self.graceful_maintenance is None):
                                            self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        return self.graceful_maintenance

                                    if (child_yang_name == "keychain"):
                                        if (self.keychain is None):
                                            self.keychain = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                        return self.keychain

                                    if (child_yang_name == "local-address"):
                                        if (self.local_address is None):
                                            self.local_address = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                        return self.local_address

                                    if (child_yang_name == "local-as"):
                                        if (self.local_as is None):
                                            self.local_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs()
                                            self.local_as.parent = self
                                            self._children_name_map["local_as"] = "local-as"
                                        return self.local_as

                                    if (child_yang_name == "msg-log-in"):
                                        if (self.msg_log_in is None):
                                            self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn()
                                            self.msg_log_in.parent = self
                                            self._children_name_map["msg_log_in"] = "msg-log-in"
                                        return self.msg_log_in

                                    if (child_yang_name == "msg-log-out"):
                                        if (self.msg_log_out is None):
                                            self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut()
                                            self.msg_log_out.parent = self
                                            self._children_name_map["msg_log_out"] = "msg-log-out"
                                        return self.msg_log_out

                                    if (child_yang_name == "neighbor-cluster-id"):
                                        if (self.neighbor_cluster_id is None):
                                            self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId()
                                            self.neighbor_cluster_id.parent = self
                                            self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                        return self.neighbor_cluster_id

                                    if (child_yang_name == "password"):
                                        if (self.password is None):
                                            self.password = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"
                                        return self.password

                                    if (child_yang_name == "receive-buffer-size"):
                                        if (self.receive_buffer_size is None):
                                            self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize()
                                            self.receive_buffer_size.parent = self
                                            self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                        return self.receive_buffer_size

                                    if (child_yang_name == "remote-as"):
                                        if (self.remote_as is None):
                                            self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs()
                                            self.remote_as.parent = self
                                            self._children_name_map["remote_as"] = "remote-as"
                                        return self.remote_as

                                    if (child_yang_name == "send-buffer-size"):
                                        if (self.send_buffer_size is None):
                                            self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize()
                                            self.send_buffer_size.parent = self
                                            self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                        return self.send_buffer_size

                                    if (child_yang_name == "tcpmss"):
                                        if (self.tcpmss is None):
                                            self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss()
                                            self.tcpmss.parent = self
                                            self._children_name_map["tcpmss"] = "tcpmss"
                                        return self.tcpmss

                                    if (child_yang_name == "timers"):
                                        if (self.timers is None):
                                            self.timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"
                                        return self.timers

                                    if (child_yang_name == "tos"):
                                        if (self.tos is None):
                                            self.tos = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos()
                                            self.tos.parent = self
                                            self._children_name_map["tos"] = "tos"
                                        return self.tos

                                    if (child_yang_name == "update-in-filtering"):
                                        if (self.update_in_filtering is None):
                                            self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering()
                                            self.update_in_filtering.parent = self
                                            self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                        return self.update_in_filtering

                                    if (child_yang_name == "vrf-neighbor-afs"):
                                        if (self.vrf_neighbor_afs is None):
                                            self.vrf_neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs()
                                            self.vrf_neighbor_afs.parent = self
                                            self._children_name_map["vrf_neighbor_afs"] = "vrf-neighbor-afs"
                                        return self.vrf_neighbor_afs

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertisement-interval" or name == "bmp-activates" or name == "ebgp-multihop" or name == "graceful-maintenance" or name == "keychain" or name == "local-address" or name == "local-as" or name == "msg-log-in" or name == "msg-log-out" or name == "neighbor-cluster-id" or name == "password" or name == "receive-buffer-size" or name == "remote-as" or name == "send-buffer-size" or name == "tcpmss" or name == "timers" or name == "tos" or name == "update-in-filtering" or name == "vrf-neighbor-afs" or name == "neighbor-address" or name == "additional-paths-receive-capability" or name == "additional-paths-send-capability" or name == "bfd-enable-modes" or name == "bfd-minimum-interval" or name == "bfd-multiplier" or name == "description" or name == "ebgp-recv-dmz" or name == "ebgp-send-dmz-enable-modes" or name == "egress-peer-engineering" or name == "enforce-first-as" or name == "idle-watch-time" or name == "ignore-connected-check-ebgp" or name == "internal-vpn-client-ibgpce" or name == "max-peers" or name == "neighbor-graceful-restart" or name == "neighbor-graceful-restart-stalepath-time" or name == "neighbor-graceful-restart-time" or name == "neighbor-group-add-member" or name == "propagate-dmz-link-bandwidth" or name == "remote-as-list" or name == "session-group-add-member" or name == "session-open-mode" or name == "shutdown" or name == "suppress-all-capabilities" or name == "suppress-four-byte-as-capability" or name == "ttl-security" or name == "update-source-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-receive-capability"):
                                        self.additional_paths_receive_capability = value
                                        self.additional_paths_receive_capability.value_namespace = name_space
                                        self.additional_paths_receive_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-send-capability"):
                                        self.additional_paths_send_capability = value
                                        self.additional_paths_send_capability.value_namespace = name_space
                                        self.additional_paths_send_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-enable-modes"):
                                        self.bfd_enable_modes = value
                                        self.bfd_enable_modes.value_namespace = name_space
                                        self.bfd_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-minimum-interval"):
                                        self.bfd_minimum_interval = value
                                        self.bfd_minimum_interval.value_namespace = name_space
                                        self.bfd_minimum_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-multiplier"):
                                        self.bfd_multiplier = value
                                        self.bfd_multiplier.value_namespace = name_space
                                        self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-recv-dmz"):
                                        self.ebgp_recv_dmz = value
                                        self.ebgp_recv_dmz.value_namespace = name_space
                                        self.ebgp_recv_dmz.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-send-dmz-enable-modes"):
                                        self.ebgp_send_dmz_enable_modes = value
                                        self.ebgp_send_dmz_enable_modes.value_namespace = name_space
                                        self.ebgp_send_dmz_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "egress-peer-engineering"):
                                        self.egress_peer_engineering = value
                                        self.egress_peer_engineering.value_namespace = name_space
                                        self.egress_peer_engineering.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enforce-first-as"):
                                        self.enforce_first_as = value
                                        self.enforce_first_as.value_namespace = name_space
                                        self.enforce_first_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "idle-watch-time"):
                                        self.idle_watch_time = value
                                        self.idle_watch_time.value_namespace = name_space
                                        self.idle_watch_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ignore-connected-check-ebgp"):
                                        self.ignore_connected_check_ebgp = value
                                        self.ignore_connected_check_ebgp.value_namespace = name_space
                                        self.ignore_connected_check_ebgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-vpn-client-ibgpce"):
                                        self.internal_vpn_client_ibgpce = value
                                        self.internal_vpn_client_ibgpce.value_namespace = name_space
                                        self.internal_vpn_client_ibgpce.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-peers"):
                                        self.max_peers = value
                                        self.max_peers.value_namespace = name_space
                                        self.max_peers.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart"):
                                        self.neighbor_graceful_restart = value
                                        self.neighbor_graceful_restart.value_namespace = name_space
                                        self.neighbor_graceful_restart.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-stalepath-time"):
                                        self.neighbor_graceful_restart_stalepath_time = value
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-time"):
                                        self.neighbor_graceful_restart_time = value
                                        self.neighbor_graceful_restart_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-group-add-member"):
                                        self.neighbor_group_add_member = value
                                        self.neighbor_group_add_member.value_namespace = name_space
                                        self.neighbor_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "propagate-dmz-link-bandwidth"):
                                        self.propagate_dmz_link_bandwidth = value
                                        self.propagate_dmz_link_bandwidth.value_namespace = name_space
                                        self.propagate_dmz_link_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-as-list"):
                                        self.remote_as_list = value
                                        self.remote_as_list.value_namespace = name_space
                                        self.remote_as_list.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-group-add-member"):
                                        self.session_group_add_member = value
                                        self.session_group_add_member.value_namespace = name_space
                                        self.session_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-open-mode"):
                                        self.session_open_mode = value
                                        self.session_open_mode.value_namespace = name_space
                                        self.session_open_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-all-capabilities"):
                                        self.suppress_all_capabilities = value
                                        self.suppress_all_capabilities.value_namespace = name_space
                                        self.suppress_all_capabilities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-four-byte-as-capability"):
                                        self.suppress_four_byte_as_capability = value
                                        self.suppress_four_byte_as_capability.value_namespace = name_space
                                        self.suppress_four_byte_as_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security"):
                                        self.ttl_security = value
                                        self.ttl_security.value_namespace = name_space
                                        self.ttl_security.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-source-interface"):
                                        self.update_source_interface = value
                                        self.update_source_interface.value_namespace = name_space
                                        self.update_source_interface.value_namespace_prefix = name_space_prefix


                            class VrfNeighborPrefixLength(Entity):
                                """
                                A particular VRF peer
                                
                                .. attribute:: prefix_length  <key>
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..127
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgpce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: vrf_neighbor_afs
                                
                                	Address family type of a VRF neighbor
                                	**type**\:   :py:class:`VrfNeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength, self).__init__()

                                    self.yang_name = "vrf-neighbor-prefix-length"
                                    self.yang_parent_name = "vrf-neighbors"

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgpce = YLeaf(YType.boolean, "internal-vpn-client-ibgpce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                    self.vrf_neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs()
                                    self.vrf_neighbor_afs.parent = self
                                    self._children_name_map["vrf_neighbor_afs"] = "vrf-neighbor-afs"
                                    self._children_yang_names.add("vrf-neighbor-afs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix_length",
                                                    "neighbor_address",
                                                    "additional_paths_receive_capability",
                                                    "additional_paths_send_capability",
                                                    "bfd_enable_modes",
                                                    "bfd_minimum_interval",
                                                    "bfd_multiplier",
                                                    "description",
                                                    "ebgp_recv_dmz",
                                                    "ebgp_send_dmz_enable_modes",
                                                    "egress_peer_engineering",
                                                    "enforce_first_as",
                                                    "idle_watch_time",
                                                    "ignore_connected_check_ebgp",
                                                    "internal_vpn_client_ibgpce",
                                                    "max_peers",
                                                    "neighbor_graceful_restart",
                                                    "neighbor_graceful_restart_stalepath_time",
                                                    "neighbor_graceful_restart_time",
                                                    "neighbor_group_add_member",
                                                    "propagate_dmz_link_bandwidth",
                                                    "remote_as_list",
                                                    "session_group_add_member",
                                                    "session_open_mode",
                                                    "shutdown",
                                                    "suppress_all_capabilities",
                                                    "suppress_four_byte_as_capability",
                                                    "ttl_security",
                                                    "update_source_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength, self).__setattr__(name, value)


                                class VrfNeighborAfs(Entity):
                                    """
                                    Address family type of a VRF neighbor
                                    
                                    .. attribute:: vrf_neighbor_af
                                    
                                    	Address family type of a VRF neighbor
                                    	**type**\: list of    :py:class:`VrfNeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs, self).__init__()

                                        self.yang_name = "vrf-neighbor-afs"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.vrf_neighbor_af = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs, self).__setattr__(name, value)


                                    class VrfNeighborAf(Entity):
                                        """
                                        Address family type of a VRF neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpnevpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_l2vpnevpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf, self).__init__()

                                            self.yang_name = "vrf-neighbor-af"
                                            self.yang_parent_name = "vrf-neighbor-afs"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn()
                                            self.advertise_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                            self._children_yang_names.add("advertise-l2vpnevpn")

                                            self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn()
                                            self.advertise_local_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                            self._children_yang_names.add("advertise-local-l2vpnevpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "accept_own",
                                                            "accept_route_legacy_rt",
                                                            "activate",
                                                            "advertise_local_labeled_route",
                                                            "advertise_orf",
                                                            "advertise_permanent_network",
                                                            "af_group",
                                                            "aigp",
                                                            "aigp_send_med",
                                                            "allow_as_in",
                                                            "as_override",
                                                            "default_weight",
                                                            "encapsulation_type",
                                                            "flowspec_validation",
                                                            "multipath",
                                                            "neighbor_af_long_lived_graceful_restart_capable",
                                                            "next_hop_self",
                                                            "next_hop_unchanged",
                                                            "next_hop_unchanged_multipath",
                                                            "prefix_orf_policy",
                                                            "route_policy_in",
                                                            "route_policy_out",
                                                            "route_reflector_client",
                                                            "send_community_ebgp",
                                                            "send_community_ebgp_graceful_shutdown",
                                                            "send_ext_community_ebgp") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf, self).__setattr__(name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cost_community_id",
                                                                "cost_community_poi_type",
                                                                "enable",
                                                                "transitive") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cost_community_id.is_set or
                                                    self.cost_community_poi_type.is_set or
                                                    self.enable.is_set or
                                                    self.transitive.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cost_community_id.yfilter != YFilter.not_set or
                                                    self.cost_community_poi_type.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.transitive.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "aigp-cost-community" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cost_community_id.is_set or self.cost_community_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_id.get_name_leafdata())
                                                if (self.cost_community_poi_type.is_set or self.cost_community_poi_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_poi_type.get_name_leafdata())
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.transitive.is_set or self.transitive.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.transitive.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cost-community-id" or name == "cost-community-poi-type" or name == "enable" or name == "transitive"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cost-community-id"):
                                                    self.cost_community_id = value
                                                    self.cost_community_id.value_namespace = name_space
                                                    self.cost_community_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost-community-poi-type"):
                                                    self.cost_community_poi_type = value
                                                    self.cost_community_poi_type.value_namespace = name_space
                                                    self.cost_community_poi_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "transitive"):
                                                    self.transitive = value
                                                    self.transitive.value_namespace = name_space
                                                    self.transitive.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-disable" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("discard_extra_paths",
                                                                "prefix_limit",
                                                                "restart_time",
                                                                "warning_only",
                                                                "warning_percentage") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.discard_extra_paths.is_set or
                                                    self.prefix_limit.is_set or
                                                    self.restart_time.is_set or
                                                    self.warning_only.is_set or
                                                    self.warning_percentage.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.discard_extra_paths.yfilter != YFilter.not_set or
                                                    self.prefix_limit.yfilter != YFilter.not_set or
                                                    self.restart_time.yfilter != YFilter.not_set or
                                                    self.warning_only.yfilter != YFilter.not_set or
                                                    self.warning_percentage.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-prefixes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.discard_extra_paths.is_set or self.discard_extra_paths.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.discard_extra_paths.get_name_leafdata())
                                                if (self.prefix_limit.is_set or self.prefix_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_limit.get_name_leafdata())
                                                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.restart_time.get_name_leafdata())
                                                if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_only.get_name_leafdata())
                                                if (self.warning_percentage.is_set or self.warning_percentage.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_percentage.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "discard-extra-paths" or name == "prefix-limit" or name == "restart-time" or name == "warning-only" or name == "warning-percentage"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "discard-extra-paths"):
                                                    self.discard_extra_paths = value
                                                    self.discard_extra_paths.value_namespace = name_space
                                                    self.discard_extra_paths.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-limit"):
                                                    self.prefix_limit = value
                                                    self.prefix_limit.value_namespace = name_space
                                                    self.prefix_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "restart-time"):
                                                    self.restart_time = value
                                                    self.restart_time.value_namespace = name_space
                                                    self.restart_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-only"):
                                                    self.warning_only = value
                                                    self.warning_only.value_namespace = name_space
                                                    self.warning_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-percentage"):
                                                    self.warning_percentage = value
                                                    self.warning_percentage.value_namespace = name_space
                                                    self.warning_percentage.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path-inbound" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseL2Vpnevpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-l2vpnevpn"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalL2Vpnevpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpnevpn"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("stale_time_accept",
                                                                "stale_time_send") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.stale_time_accept.is_set or
                                                    self.stale_time_send.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.stale_time_accept.yfilter != YFilter.not_set or
                                                    self.stale_time_send.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-af-long-lived-graceful-restart-stale-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.stale_time_accept.is_set or self.stale_time_accept.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_accept.get_name_leafdata())
                                                if (self.stale_time_send.is_set or self.stale_time_send.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_send.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "stale-time-accept" or name == "stale-time-send"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "stale-time-accept"):
                                                    self.stale_time_accept = value
                                                    self.stale_time_accept.value_namespace = name_space
                                                    self.stale_time_accept.value_namespace_prefix = name_space_prefix
                                                if(value_path == "stale-time-send"):
                                                    self.stale_time_send = value
                                                    self.stale_time_send.value_namespace = name_space
                                                    self.stale_time_send.value_namespace_prefix = name_space_prefix


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("address",
                                                                "address_index",
                                                                "as_",
                                                                "as_index",
                                                                "as_xx",
                                                                "type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.address.is_set or
                                                    self.address_index.is_set or
                                                    self.as_.is_set or
                                                    self.as_index.is_set or
                                                    self.as_xx.is_set or
                                                    self.type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.address_index.yfilter != YFilter.not_set or
                                                    self.as_.yfilter != YFilter.not_set or
                                                    self.as_index.yfilter != YFilter.not_set or
                                                    self.as_xx.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "site-of-origin" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.address_index.is_set or self.address_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address_index.get_name_leafdata())
                                                if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_.get_name_leafdata())
                                                if (self.as_index.is_set or self.as_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_index.get_name_leafdata())
                                                if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_xx.get_name_leafdata())
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "address" or name == "address-index" or name == "as" or name == "as-index" or name == "as-xx" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address-index"):
                                                    self.address_index = value
                                                    self.address_index.value_namespace = name_space
                                                    self.address_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as"):
                                                    self.as_ = value
                                                    self.as_.value_namespace = name_space
                                                    self.as_.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-index"):
                                                    self.as_index = value
                                                    self.as_index.value_namespace = name_space
                                                    self.as_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-xx"):
                                                    self.as_xx = value
                                                    self.as_xx.value_namespace = name_space
                                                    self.as_xx.value_namespace_prefix = name_space_prefix
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("import_reoriginate",
                                                                "import_reoriginate_stitching",
                                                                "import_stitching") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.import_reoriginate.is_set or
                                                    self.import_reoriginate_stitching.is_set or
                                                    self.import_stitching.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.import_reoriginate.yfilter != YFilter.not_set or
                                                    self.import_reoriginate_stitching.yfilter != YFilter.not_set or
                                                    self.import_stitching.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "import" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.import_reoriginate.is_set or self.import_reoriginate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate.get_name_leafdata())
                                                if (self.import_reoriginate_stitching.is_set or self.import_reoriginate_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate_stitching.get_name_leafdata())
                                                if (self.import_stitching.is_set or self.import_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_stitching.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "import-reoriginate" or name == "import-reoriginate-stitching" or name == "import-stitching"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "import-reoriginate"):
                                                    self.import_reoriginate = value
                                                    self.import_reoriginate.value_namespace = name_space
                                                    self.import_reoriginate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-reoriginate-stitching"):
                                                    self.import_reoriginate_stitching = value
                                                    self.import_reoriginate_stitching.value_namespace = name_space
                                                    self.import_reoriginate_stitching.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-stitching"):
                                                    self.import_stitching = value
                                                    self.import_stitching.value_namespace = name_space
                                                    self.import_stitching.value_namespace_prefix = name_space_prefix


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "default-originate" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("inbound_soft",
                                                                "soft_always") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.inbound_soft.is_set or
                                                    self.soft_always.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.inbound_soft.yfilter != YFilter.not_set or
                                                    self.soft_always.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "soft-reconfiguration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.inbound_soft.is_set or self.inbound_soft.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.inbound_soft.get_name_leafdata())
                                                if (self.soft_always.is_set or self.soft_always.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.soft_always.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "inbound-soft" or name == "soft-always"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "inbound-soft"):
                                                    self.inbound_soft = value
                                                    self.inbound_soft.value_namespace = name_space
                                                    self.inbound_soft.value_namespace_prefix = name_space_prefix
                                                if(value_path == "soft-always"):
                                                    self.soft_always = value
                                                    self.soft_always.value_namespace = name_space
                                                    self.soft_always.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.accept_own.is_set or
                                                self.accept_route_legacy_rt.is_set or
                                                self.activate.is_set or
                                                self.advertise_local_labeled_route.is_set or
                                                self.advertise_orf.is_set or
                                                self.advertise_permanent_network.is_set or
                                                self.af_group.is_set or
                                                self.aigp.is_set or
                                                self.aigp_send_med.is_set or
                                                self.allow_as_in.is_set or
                                                self.as_override.is_set or
                                                self.default_weight.is_set or
                                                self.encapsulation_type.is_set or
                                                self.flowspec_validation.is_set or
                                                self.multipath.is_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.is_set or
                                                self.next_hop_self.is_set or
                                                self.next_hop_unchanged.is_set or
                                                self.next_hop_unchanged_multipath.is_set or
                                                self.prefix_orf_policy.is_set or
                                                self.route_policy_in.is_set or
                                                self.route_policy_out.is_set or
                                                self.route_reflector_client.is_set or
                                                self.send_community_ebgp.is_set or
                                                self.send_community_ebgp_graceful_shutdown.is_set or
                                                self.send_ext_community_ebgp.is_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_data()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_data()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_data()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_data()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_data()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_data()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_data()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_data()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_data()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_data()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_data()) or
                                                (self.default_originate is not None and self.default_originate.has_data()) or
                                                (self.import_ is not None and self.import_.has_data()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_data()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_data()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_data()) or
                                                (self.aigp_cost_community is not None) or
                                                (self.maximum_prefixes is not None) or
                                                (self.remove_private_as_entire_as_path is not None) or
                                                (self.remove_private_as_entire_as_path_inbound is not None))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.accept_own.yfilter != YFilter.not_set or
                                                self.accept_route_legacy_rt.yfilter != YFilter.not_set or
                                                self.activate.yfilter != YFilter.not_set or
                                                self.advertise_local_labeled_route.yfilter != YFilter.not_set or
                                                self.advertise_orf.yfilter != YFilter.not_set or
                                                self.advertise_permanent_network.yfilter != YFilter.not_set or
                                                self.af_group.yfilter != YFilter.not_set or
                                                self.aigp.yfilter != YFilter.not_set or
                                                self.aigp_send_med.yfilter != YFilter.not_set or
                                                self.allow_as_in.yfilter != YFilter.not_set or
                                                self.as_override.yfilter != YFilter.not_set or
                                                self.default_weight.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.flowspec_validation.yfilter != YFilter.not_set or
                                                self.multipath.yfilter != YFilter.not_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set or
                                                self.next_hop_self.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged_multipath.yfilter != YFilter.not_set or
                                                self.prefix_orf_policy.yfilter != YFilter.not_set or
                                                self.route_policy_in.yfilter != YFilter.not_set or
                                                self.route_policy_out.yfilter != YFilter.not_set or
                                                self.route_reflector_client.yfilter != YFilter.not_set or
                                                self.send_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set or
                                                self.send_ext_community_ebgp.yfilter != YFilter.not_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_operation()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_operation()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_operation()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_operation()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_operation()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_operation()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_operation()) or
                                                (self.aigp_cost_community is not None and self.aigp_cost_community.has_operation()) or
                                                (self.default_originate is not None and self.default_originate.has_operation()) or
                                                (self.import_ is not None and self.import_.has_operation()) or
                                                (self.maximum_prefixes is not None and self.maximum_prefixes.has_operation()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_operation()) or
                                                (self.remove_private_as_entire_as_path is not None and self.remove_private_as_entire_as_path.has_operation()) or
                                                (self.remove_private_as_entire_as_path_inbound is not None and self.remove_private_as_entire_as_path_inbound.has_operation()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_operation()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-neighbor-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.accept_own.is_set or self.accept_own.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_own.get_name_leafdata())
                                            if (self.accept_route_legacy_rt.is_set or self.accept_route_legacy_rt.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_route_legacy_rt.get_name_leafdata())
                                            if (self.activate.is_set or self.activate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.activate.get_name_leafdata())
                                            if (self.advertise_local_labeled_route.is_set or self.advertise_local_labeled_route.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_local_labeled_route.get_name_leafdata())
                                            if (self.advertise_orf.is_set or self.advertise_orf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_orf.get_name_leafdata())
                                            if (self.advertise_permanent_network.is_set or self.advertise_permanent_network.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_permanent_network.get_name_leafdata())
                                            if (self.af_group.is_set or self.af_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_group.get_name_leafdata())
                                            if (self.aigp.is_set or self.aigp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp.get_name_leafdata())
                                            if (self.aigp_send_med.is_set or self.aigp_send_med.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp_send_med.get_name_leafdata())
                                            if (self.allow_as_in.is_set or self.allow_as_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.allow_as_in.get_name_leafdata())
                                            if (self.as_override.is_set or self.as_override.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_override.get_name_leafdata())
                                            if (self.default_weight.is_set or self.default_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_weight.get_name_leafdata())
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.flowspec_validation.is_set or self.flowspec_validation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flowspec_validation.get_name_leafdata())
                                            if (self.multipath.is_set or self.multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multipath.get_name_leafdata())
                                            if (self.neighbor_af_long_lived_graceful_restart_capable.is_set or self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_af_long_lived_graceful_restart_capable.get_name_leafdata())
                                            if (self.next_hop_self.is_set or self.next_hop_self.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_self.get_name_leafdata())
                                            if (self.next_hop_unchanged.is_set or self.next_hop_unchanged.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged.get_name_leafdata())
                                            if (self.next_hop_unchanged_multipath.is_set or self.next_hop_unchanged_multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged_multipath.get_name_leafdata())
                                            if (self.prefix_orf_policy.is_set or self.prefix_orf_policy.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_orf_policy.get_name_leafdata())
                                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                            if (self.route_reflector_client.is_set or self.route_reflector_client.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_reflector_client.get_name_leafdata())
                                            if (self.send_community_ebgp.is_set or self.send_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp.get_name_leafdata())
                                            if (self.send_community_ebgp_graceful_shutdown.is_set or self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp_graceful_shutdown.get_name_leafdata())
                                            if (self.send_ext_community_ebgp.is_set or self.send_ext_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_ext_community_ebgp.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advertise-def-imp-disable-v4"):
                                                if (self.advertise_def_imp_disable_v4 is None):
                                                    self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4()
                                                    self.advertise_def_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                                return self.advertise_def_imp_disable_v4

                                            if (child_yang_name == "advertise-def-imp-disable-v6"):
                                                if (self.advertise_def_imp_disable_v6 is None):
                                                    self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6()
                                                    self.advertise_def_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                                return self.advertise_def_imp_disable_v6

                                            if (child_yang_name == "advertise-disable"):
                                                if (self.advertise_disable is None):
                                                    self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable()
                                                    self.advertise_disable.parent = self
                                                    self._children_name_map["advertise_disable"] = "advertise-disable"
                                                return self.advertise_disable

                                            if (child_yang_name == "advertise-l2vpnevpn"):
                                                if (self.advertise_l2vpnevpn is None):
                                                    self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2Vpnevpn()
                                                    self.advertise_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                                return self.advertise_l2vpnevpn

                                            if (child_yang_name == "advertise-local-l2vpnevpn"):
                                                if (self.advertise_local_l2vpnevpn is None):
                                                    self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2Vpnevpn()
                                                    self.advertise_local_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                                return self.advertise_local_l2vpnevpn

                                            if (child_yang_name == "advertise-local-v4"):
                                                if (self.advertise_local_v4 is None):
                                                    self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4()
                                                    self.advertise_local_v4.parent = self
                                                    self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                                return self.advertise_local_v4

                                            if (child_yang_name == "advertise-local-v6"):
                                                if (self.advertise_local_v6 is None):
                                                    self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6()
                                                    self.advertise_local_v6.parent = self
                                                    self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                                return self.advertise_local_v6

                                            if (child_yang_name == "advertise-v4"):
                                                if (self.advertise_v4 is None):
                                                    self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4()
                                                    self.advertise_v4.parent = self
                                                    self._children_name_map["advertise_v4"] = "advertise-v4"
                                                return self.advertise_v4

                                            if (child_yang_name == "advertise-v6"):
                                                if (self.advertise_v6 is None):
                                                    self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6()
                                                    self.advertise_v6.parent = self
                                                    self._children_name_map["advertise_v6"] = "advertise-v6"
                                                return self.advertise_v6

                                            if (child_yang_name == "advertise-vrf-imp-disable-v4"):
                                                if (self.advertise_vrf_imp_disable_v4 is None):
                                                    self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4()
                                                    self.advertise_vrf_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                                return self.advertise_vrf_imp_disable_v4

                                            if (child_yang_name == "advertise-vrf-imp-disable-v6"):
                                                if (self.advertise_vrf_imp_disable_v6 is None):
                                                    self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6()
                                                    self.advertise_vrf_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                                return self.advertise_vrf_imp_disable_v6

                                            if (child_yang_name == "aigp-cost-community"):
                                                if (self.aigp_cost_community is None):
                                                    self.aigp_cost_community = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity()
                                                    self.aigp_cost_community.parent = self
                                                    self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                                return self.aigp_cost_community

                                            if (child_yang_name == "default-originate"):
                                                if (self.default_originate is None):
                                                    self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate()
                                                    self.default_originate.parent = self
                                                    self._children_name_map["default_originate"] = "default-originate"
                                                return self.default_originate

                                            if (child_yang_name == "import"):
                                                if (self.import_ is None):
                                                    self.import_ = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_()
                                                    self.import_.parent = self
                                                    self._children_name_map["import_"] = "import"
                                                return self.import_

                                            if (child_yang_name == "maximum-prefixes"):
                                                if (self.maximum_prefixes is None):
                                                    self.maximum_prefixes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes()
                                                    self.maximum_prefixes.parent = self
                                                    self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                                return self.maximum_prefixes

                                            if (child_yang_name == "neighbor-af-long-lived-graceful-restart-stale-time"):
                                                if (self.neighbor_af_long_lived_graceful_restart_stale_time is None):
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                                    self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                return self.neighbor_af_long_lived_graceful_restart_stale_time

                                            if (child_yang_name == "remove-private-as-entire-as-path"):
                                                if (self.remove_private_as_entire_as_path is None):
                                                    self.remove_private_as_entire_as_path = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath()
                                                    self.remove_private_as_entire_as_path.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                                return self.remove_private_as_entire_as_path

                                            if (child_yang_name == "remove-private-as-entire-as-path-inbound"):
                                                if (self.remove_private_as_entire_as_path_inbound is None):
                                                    self.remove_private_as_entire_as_path_inbound = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound()
                                                    self.remove_private_as_entire_as_path_inbound.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                                return self.remove_private_as_entire_as_path_inbound

                                            if (child_yang_name == "site-of-origin"):
                                                if (self.site_of_origin is None):
                                                    self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin()
                                                    self.site_of_origin.parent = self
                                                    self._children_name_map["site_of_origin"] = "site-of-origin"
                                                return self.site_of_origin

                                            if (child_yang_name == "soft-reconfiguration"):
                                                if (self.soft_reconfiguration is None):
                                                    self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration()
                                                    self.soft_reconfiguration.parent = self
                                                    self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                                return self.soft_reconfiguration

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertise-def-imp-disable-v4" or name == "advertise-def-imp-disable-v6" or name == "advertise-disable" or name == "advertise-l2vpnevpn" or name == "advertise-local-l2vpnevpn" or name == "advertise-local-v4" or name == "advertise-local-v6" or name == "advertise-v4" or name == "advertise-v6" or name == "advertise-vrf-imp-disable-v4" or name == "advertise-vrf-imp-disable-v6" or name == "aigp-cost-community" or name == "default-originate" or name == "import" or name == "maximum-prefixes" or name == "neighbor-af-long-lived-graceful-restart-stale-time" or name == "remove-private-as-entire-as-path" or name == "remove-private-as-entire-as-path-inbound" or name == "site-of-origin" or name == "soft-reconfiguration" or name == "af-name" or name == "accept-own" or name == "accept-route-legacy-rt" or name == "activate" or name == "advertise-local-labeled-route" or name == "advertise-orf" or name == "advertise-permanent-network" or name == "af-group" or name == "aigp" or name == "aigp-send-med" or name == "allow-as-in" or name == "as-override" or name == "default-weight" or name == "encapsulation-type" or name == "flowspec-validation" or name == "multipath" or name == "neighbor-af-long-lived-graceful-restart-capable" or name == "next-hop-self" or name == "next-hop-unchanged" or name == "next-hop-unchanged-multipath" or name == "prefix-orf-policy" or name == "route-policy-in" or name == "route-policy-out" or name == "route-reflector-client" or name == "send-community-ebgp" or name == "send-community-ebgp-graceful-shutdown" or name == "send-ext-community-ebgp"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-own"):
                                                self.accept_own = value
                                                self.accept_own.value_namespace = name_space
                                                self.accept_own.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-route-legacy-rt"):
                                                self.accept_route_legacy_rt = value
                                                self.accept_route_legacy_rt.value_namespace = name_space
                                                self.accept_route_legacy_rt.value_namespace_prefix = name_space_prefix
                                            if(value_path == "activate"):
                                                self.activate = value
                                                self.activate.value_namespace = name_space
                                                self.activate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-local-labeled-route"):
                                                self.advertise_local_labeled_route = value
                                                self.advertise_local_labeled_route.value_namespace = name_space
                                                self.advertise_local_labeled_route.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-orf"):
                                                self.advertise_orf = value
                                                self.advertise_orf.value_namespace = name_space
                                                self.advertise_orf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-permanent-network"):
                                                self.advertise_permanent_network = value
                                                self.advertise_permanent_network.value_namespace = name_space
                                                self.advertise_permanent_network.value_namespace_prefix = name_space_prefix
                                            if(value_path == "af-group"):
                                                self.af_group = value
                                                self.af_group.value_namespace = name_space
                                                self.af_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp"):
                                                self.aigp = value
                                                self.aigp.value_namespace = name_space
                                                self.aigp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp-send-med"):
                                                self.aigp_send_med = value
                                                self.aigp_send_med.value_namespace = name_space
                                                self.aigp_send_med.value_namespace_prefix = name_space_prefix
                                            if(value_path == "allow-as-in"):
                                                self.allow_as_in = value
                                                self.allow_as_in.value_namespace = name_space
                                                self.allow_as_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-override"):
                                                self.as_override = value
                                                self.as_override.value_namespace = name_space
                                                self.as_override.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-weight"):
                                                self.default_weight = value
                                                self.default_weight.value_namespace = name_space
                                                self.default_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flowspec-validation"):
                                                self.flowspec_validation = value
                                                self.flowspec_validation.value_namespace = name_space
                                                self.flowspec_validation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multipath"):
                                                self.multipath = value
                                                self.multipath.value_namespace = name_space
                                                self.multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-af-long-lived-graceful-restart-capable"):
                                                self.neighbor_af_long_lived_graceful_restart_capable = value
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace = name_space
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-self"):
                                                self.next_hop_self = value
                                                self.next_hop_self.value_namespace = name_space
                                                self.next_hop_self.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged"):
                                                self.next_hop_unchanged = value
                                                self.next_hop_unchanged.value_namespace = name_space
                                                self.next_hop_unchanged.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged-multipath"):
                                                self.next_hop_unchanged_multipath = value
                                                self.next_hop_unchanged_multipath.value_namespace = name_space
                                                self.next_hop_unchanged_multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-orf-policy"):
                                                self.prefix_orf_policy = value
                                                self.prefix_orf_policy.value_namespace = name_space
                                                self.prefix_orf_policy.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-in"):
                                                self.route_policy_in = value
                                                self.route_policy_in.value_namespace = name_space
                                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-out"):
                                                self.route_policy_out = value
                                                self.route_policy_out.value_namespace = name_space
                                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-reflector-client"):
                                                self.route_reflector_client = value
                                                self.route_reflector_client.value_namespace = name_space
                                                self.route_reflector_client.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp"):
                                                self.send_community_ebgp = value
                                                self.send_community_ebgp.value_namespace = name_space
                                                self.send_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp-graceful-shutdown"):
                                                self.send_community_ebgp_graceful_shutdown = value
                                                self.send_community_ebgp_graceful_shutdown.value_namespace = name_space
                                                self.send_community_ebgp_graceful_shutdown.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-ext-community-ebgp"):
                                                self.send_ext_community_ebgp = value
                                                self.send_ext_community_ebgp.value_namespace = name_space
                                                self.send_ext_community_ebgp.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_neighbor_af:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_neighbor_af:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-neighbor-afs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-neighbor-af"):
                                            for c in self.vrf_neighbor_af:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_neighbor_af.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-neighbor-af"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address_disable",
                                                        "local_ip_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_address_disable.is_set or
                                            self.local_ip_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address_disable.yfilter != YFilter.not_set or
                                            self.local_ip_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address_disable.is_set or self.local_address_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address_disable.get_name_leafdata())
                                        if (self.local_ip_address.is_set or self.local_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ip_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-address-disable" or name == "local-ip-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address-disable"):
                                            self.local_address_disable = value
                                            self.local_address_disable.value_namespace = name_space
                                            self.local_address_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ip-address"):
                                            self.local_ip_address = value
                                            self.local_ip_address.value_namespace = name_space
                                            self.local_ip_address.value_namespace_prefix = name_space_prefix


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.bmp_activate = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates, self).__setattr__(name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"

                                            self.server_id = YLeaf(YType.uint32, "server-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("server_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.server_id.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.server_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bmp-activate" + "[server-id='" + self.server_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.server_id.is_set or self.server_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.server_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "server-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "server-id"):
                                                self.server_id = value
                                                self.server_id.value_namespace = name_space
                                                self.server_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bmp_activate:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bmp_activate:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmp-activates" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bmp-activate"):
                                            for c in self.bmp_activate:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bmp_activate.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bmp-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("max_hop_count",
                                                        "mpls_deactivation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.max_hop_count.is_set or
                                            self.mpls_deactivation.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.max_hop_count.yfilter != YFilter.not_set or
                                            self.mpls_deactivation.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ebgp-multihop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.max_hop_count.is_set or self.max_hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.max_hop_count.get_name_leafdata())
                                        if (self.mpls_deactivation.is_set or self.mpls_deactivation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_deactivation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "max-hop-count" or name == "mpls-deactivation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "max-hop-count"):
                                            self.max_hop_count = value
                                            self.max_hop_count.value_namespace = name_space
                                            self.max_hop_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-deactivation"):
                                            self.mpls_deactivation = value
                                            self.mpls_deactivation.value_namespace = name_space
                                            self.mpls_deactivation.value_namespace_prefix = name_space_prefix


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy",
                                                        "disable",
                                                        "dual_as",
                                                        "no_prepend",
                                                        "replace_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set or
                                            self.disable.is_set or
                                            self.dual_as.is_set or
                                            self.no_prepend.is_set or
                                            self.replace_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set or
                                            self.disable.yfilter != YFilter.not_set or
                                            self.dual_as.yfilter != YFilter.not_set or
                                            self.no_prepend.yfilter != YFilter.not_set or
                                            self.replace_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())
                                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable.get_name_leafdata())
                                        if (self.dual_as.is_set or self.dual_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dual_as.get_name_leafdata())
                                        if (self.no_prepend.is_set or self.no_prepend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_prepend.get_name_leafdata())
                                        if (self.replace_as.is_set or self.replace_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.replace_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy" or name == "disable" or name == "dual-as" or name == "no-prepend" or name == "replace-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable"):
                                            self.disable = value
                                            self.disable.value_namespace = name_space
                                            self.disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dual-as"):
                                            self.dual_as = value
                                            self.dual_as.value_namespace = name_space
                                            self.dual_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-prepend"):
                                            self.no_prepend = value
                                            self.no_prepend.value_namespace = name_space
                                            self.no_prepend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "replace-as"):
                                            self.replace_as = value
                                            self.replace_as.value_namespace = name_space
                                            self.replace_as.value_namespace_prefix = name_space_prefix


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("password",
                                                        "password_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.password.is_set or
                                            self.password_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.password.yfilter != YFilter.not_set or
                                            self.password_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "password" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password.get_name_leafdata())
                                        if (self.password_disable.is_set or self.password_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "password" or name == "password-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "password"):
                                            self.password = value
                                            self.password.value_namespace = name_space
                                            self.password.value_namespace_prefix = name_space_prefix
                                        if(value_path == "password-disable"):
                                            self.password_disable = value
                                            self.password_disable.value_namespace = name_space
                                            self.password_disable.value_namespace_prefix = name_space_prefix


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("minimum_interval",
                                                        "minimum_interval_msecs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.minimum_interval.is_set or
                                            self.minimum_interval_msecs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.minimum_interval.yfilter != YFilter.not_set or
                                            self.minimum_interval_msecs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "advertisement-interval" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                        if (self.minimum_interval_msecs.is_set or self.minimum_interval_msecs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval_msecs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "minimum-interval" or name == "minimum-interval-msecs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "minimum-interval"):
                                            self.minimum_interval = value
                                            self.minimum_interval.value_namespace = name_space
                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-interval-msecs"):
                                            self.minimum_interval_msecs = value
                                            self.minimum_interval_msecs.value_namespace = name_space
                                            self.minimum_interval_msecs.value_namespace_prefix = name_space_prefix


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cluster_id_address",
                                                        "cluster_id_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cluster_id_address.is_set or
                                            self.cluster_id_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cluster_id_address.yfilter != YFilter.not_set or
                                            self.cluster_id_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-cluster-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_address.get_name_leafdata())
                                        if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cluster-id-address" or name == "cluster-id-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cluster-id-address"):
                                            self.cluster_id_address = value
                                            self.cluster_id_address.value_namespace = name_space
                                            self.cluster_id_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cluster-id-number"):
                                            self.cluster_id_number = value
                                            self.cluster_id_number.value_namespace = name_space
                                            self.cluster_id_number.value_namespace_prefix = name_space_prefix


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mss",
                                                        "tcpmss_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mss.is_set or
                                            self.tcpmss_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mss.yfilter != YFilter.not_set or
                                            self.tcpmss_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tcpmss" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mss.is_set or self.mss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mss.get_name_leafdata())
                                        if (self.tcpmss_disable.is_set or self.tcpmss_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tcpmss_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mss" or name == "tcpmss-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mss"):
                                            self.mss = value
                                            self.mss.value_namespace = name_space
                                            self.mss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tcpmss-disable"):
                                            self.tcpmss_disable = value
                                            self.tcpmss_disable.value_namespace = name_space
                                            self.tcpmss_disable.value_namespace_prefix = name_space_prefix


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type",
                                                        "value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            self.value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            self.value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tos" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())
                                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "type" or name == "value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "value"):
                                            self.value = value
                                            self.value.value_namespace = name_space
                                            self.value.value_namespace_prefix = name_space_prefix


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "update_in_filtering_attribute_filter_group",
                                                        "update_in_filtering_syslog_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering, self).__setattr__(name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("non_circular_buffer",
                                                            "number_of_buffers") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.non_circular_buffer.is_set or
                                                self.number_of_buffers.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.non_circular_buffer.yfilter != YFilter.not_set or
                                                self.number_of_buffers.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "update-in-filtering-message-buffers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.non_circular_buffer.is_set or self.non_circular_buffer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.non_circular_buffer.get_name_leafdata())
                                            if (self.number_of_buffers.is_set or self.number_of_buffers.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_buffers.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "non-circular-buffer" or name == "number-of-buffers"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "non-circular-buffer"):
                                                self.non_circular_buffer = value
                                                self.non_circular_buffer.value_namespace = name_space
                                                self.non_circular_buffer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-buffers"):
                                                self.number_of_buffers = value
                                                self.number_of_buffers.value_namespace = name_space
                                                self.number_of_buffers.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.update_in_filtering_attribute_filter_group.is_set or
                                            self.update_in_filtering_syslog_disable.is_set or
                                            (self.update_in_filtering_message_buffers is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set or
                                            self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set or
                                            (self.update_in_filtering_message_buffers is not None and self.update_in_filtering_message_buffers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "update-in-filtering" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.update_in_filtering_attribute_filter_group.is_set or self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_attribute_filter_group.get_name_leafdata())
                                        if (self.update_in_filtering_syslog_disable.is_set or self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_syslog_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "update-in-filtering-message-buffers"):
                                            if (self.update_in_filtering_message_buffers is None):
                                                self.update_in_filtering_message_buffers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers()
                                                self.update_in_filtering_message_buffers.parent = self
                                                self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                            return self.update_in_filtering_message_buffers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "update-in-filtering-message-buffers" or name == "enable" or name == "update-in-filtering-attribute-filter-group" or name == "update-in-filtering-syslog-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-attribute-filter-group"):
                                            self.update_in_filtering_attribute_filter_group = value
                                            self.update_in_filtering_attribute_filter_group.value_namespace = name_space
                                            self.update_in_filtering_attribute_filter_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-syslog-disable"):
                                            self.update_in_filtering_syslog_disable = value
                                            self.update_in_filtering_syslog_disable.value_namespace = name_space
                                            self.update_in_filtering_syslog_disable.value_namespace_prefix = name_space_prefix


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-out" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_receive_size",
                                                        "socket_receive_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_receive_size.is_set or
                                            self.socket_receive_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_receive_size.yfilter != YFilter.not_set or
                                            self.socket_receive_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "receive-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                        if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-receive-size"):
                                            self.bgp_receive_size = value
                                            self.bgp_receive_size.value_namespace = name_space
                                            self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-receive-size"):
                                            self.socket_receive_size = value
                                            self.socket_receive_size.value_namespace = name_space
                                            self.socket_receive_size.value_namespace_prefix = name_space_prefix


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-in" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_send_size",
                                                        "socket_send_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_send_size.is_set or
                                            self.socket_send_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_send_size.yfilter != YFilter.not_set or
                                            self.socket_send_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "send-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                        if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-send-size" or name == "socket-send-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-send-size"):
                                            self.bgp_send_size = value
                                            self.bgp_send_size.value_namespace = name_space
                                            self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-send-size"):
                                            self.socket_send_size = value
                                            self.socket_send_size.value_namespace = name_space
                                            self.socket_send_size.value_namespace_prefix = name_space_prefix


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("hold_time",
                                                        "keepalive_interval",
                                                        "min_accept_hold_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.hold_time.is_set or
                                            self.keepalive_interval.is_set or
                                            self.min_accept_hold_time.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.hold_time.yfilter != YFilter.not_set or
                                            self.keepalive_interval.yfilter != YFilter.not_set or
                                            self.min_accept_hold_time.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hold_time.get_name_leafdata())
                                        if (self.keepalive_interval.is_set or self.keepalive_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keepalive_interval.get_name_leafdata())
                                        if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "hold-time" or name == "keepalive-interval" or name == "min-accept-hold-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "hold-time"):
                                            self.hold_time = value
                                            self.hold_time.value_namespace = name_space
                                            self.hold_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keepalive-interval"):
                                            self.keepalive_interval = value
                                            self.keepalive_interval.value_namespace = name_space
                                            self.keepalive_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "min-accept-hold-time"):
                                            self.min_accept_hold_time = value
                                            self.min_accept_hold_time.value_namespace = name_space
                                            self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("keychain_disable",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.keychain_disable.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.keychain_disable.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "keychain" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.keychain_disable.is_set or self.keychain_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_disable.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "keychain-disable" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "keychain-disable"):
                                            self.keychain_disable = value
                                            self.keychain_disable.value_namespace = name_space
                                            self.keychain_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "graceful_maintenance_activate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance, self).__setattr__(name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("gshut_loc_pref_disable",
                                                            "local_preference") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.gshut_loc_pref_disable.is_set or
                                                self.local_preference.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.gshut_loc_pref_disable.yfilter != YFilter.not_set or
                                                self.local_preference.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-local-preference" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.gshut_loc_pref_disable.is_set or self.gshut_loc_pref_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_loc_pref_disable.get_name_leafdata())
                                            if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_preference.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "gshut-loc-pref-disable" or name == "local-preference"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "gshut-loc-pref-disable"):
                                                self.gshut_loc_pref_disable = value
                                                self.gshut_loc_pref_disable.value_namespace = name_space
                                                self.gshut_loc_pref_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-preference"):
                                                self.local_preference = value
                                                self.local_preference.value_namespace = name_space
                                                self.local_preference.value_namespace_prefix = name_space_prefix


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("as_prepends",
                                                            "gshut_prepends_disable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.as_prepends.is_set or
                                                self.gshut_prepends_disable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.as_prepends.yfilter != YFilter.not_set or
                                                self.gshut_prepends_disable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-as-prepends" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.as_prepends.is_set or self.as_prepends.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_prepends.get_name_leafdata())
                                            if (self.gshut_prepends_disable.is_set or self.gshut_prepends_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_prepends_disable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "as-prepends" or name == "gshut-prepends-disable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "as-prepends"):
                                                self.as_prepends = value
                                                self.as_prepends.value_namespace = name_space
                                                self.as_prepends.value_namespace_prefix = name_space_prefix
                                            if(value_path == "gshut-prepends-disable"):
                                                self.gshut_prepends_disable = value
                                                self.gshut_prepends_disable.value_namespace = name_space
                                                self.gshut_prepends_disable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.graceful_maintenance_activate.is_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_data()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.graceful_maintenance_activate.yfilter != YFilter.not_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_operation()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "graceful-maintenance" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.graceful_maintenance_activate.is_set or self.graceful_maintenance_activate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.graceful_maintenance_activate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "graceful-maintenance-as-prepends"):
                                            if (self.graceful_maintenance_as_prepends is None):
                                                self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                                self.graceful_maintenance_as_prepends.parent = self
                                                self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                            return self.graceful_maintenance_as_prepends

                                        if (child_yang_name == "graceful-maintenance-local-preference"):
                                            if (self.graceful_maintenance_local_preference is None):
                                                self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                                self.graceful_maintenance_local_preference.parent = self
                                                self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                            return self.graceful_maintenance_local_preference

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "graceful-maintenance-as-prepends" or name == "graceful-maintenance-local-preference" or name == "enable" or name == "graceful-maintenance-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "graceful-maintenance-activate"):
                                            self.graceful_maintenance_activate = value
                                            self.graceful_maintenance_activate.value_namespace = name_space
                                            self.graceful_maintenance_activate.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.prefix_length.is_set or
                                        self.neighbor_address.is_set or
                                        self.additional_paths_receive_capability.is_set or
                                        self.additional_paths_send_capability.is_set or
                                        self.bfd_enable_modes.is_set or
                                        self.bfd_minimum_interval.is_set or
                                        self.bfd_multiplier.is_set or
                                        self.description.is_set or
                                        self.ebgp_recv_dmz.is_set or
                                        self.ebgp_send_dmz_enable_modes.is_set or
                                        self.egress_peer_engineering.is_set or
                                        self.enforce_first_as.is_set or
                                        self.idle_watch_time.is_set or
                                        self.ignore_connected_check_ebgp.is_set or
                                        self.internal_vpn_client_ibgpce.is_set or
                                        self.max_peers.is_set or
                                        self.neighbor_graceful_restart.is_set or
                                        self.neighbor_graceful_restart_stalepath_time.is_set or
                                        self.neighbor_graceful_restart_time.is_set or
                                        self.neighbor_group_add_member.is_set or
                                        self.propagate_dmz_link_bandwidth.is_set or
                                        self.remote_as_list.is_set or
                                        self.session_group_add_member.is_set or
                                        self.session_open_mode.is_set or
                                        self.shutdown.is_set or
                                        self.suppress_all_capabilities.is_set or
                                        self.suppress_four_byte_as_capability.is_set or
                                        self.ttl_security.is_set or
                                        self.update_source_interface.is_set or
                                        (self.bmp_activates is not None and self.bmp_activates.has_data()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_data()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_data()) or
                                        (self.keychain is not None and self.keychain.has_data()) or
                                        (self.local_address is not None and self.local_address.has_data()) or
                                        (self.local_as is not None and self.local_as.has_data()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_data()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_data()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_data()) or
                                        (self.password is not None and self.password.has_data()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_data()) or
                                        (self.remote_as is not None and self.remote_as.has_data()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_data()) or
                                        (self.tcpmss is not None and self.tcpmss.has_data()) or
                                        (self.timers is not None and self.timers.has_data()) or
                                        (self.tos is not None and self.tos.has_data()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_data()) or
                                        (self.vrf_neighbor_afs is not None and self.vrf_neighbor_afs.has_data()) or
                                        (self.advertisement_interval is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.additional_paths_receive_capability.yfilter != YFilter.not_set or
                                        self.additional_paths_send_capability.yfilter != YFilter.not_set or
                                        self.bfd_enable_modes.yfilter != YFilter.not_set or
                                        self.bfd_minimum_interval.yfilter != YFilter.not_set or
                                        self.bfd_multiplier.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.ebgp_recv_dmz.yfilter != YFilter.not_set or
                                        self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set or
                                        self.egress_peer_engineering.yfilter != YFilter.not_set or
                                        self.enforce_first_as.yfilter != YFilter.not_set or
                                        self.idle_watch_time.yfilter != YFilter.not_set or
                                        self.ignore_connected_check_ebgp.yfilter != YFilter.not_set or
                                        self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set or
                                        self.max_peers.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_time.yfilter != YFilter.not_set or
                                        self.neighbor_group_add_member.yfilter != YFilter.not_set or
                                        self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set or
                                        self.remote_as_list.yfilter != YFilter.not_set or
                                        self.session_group_add_member.yfilter != YFilter.not_set or
                                        self.session_open_mode.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.suppress_all_capabilities.yfilter != YFilter.not_set or
                                        self.suppress_four_byte_as_capability.yfilter != YFilter.not_set or
                                        self.ttl_security.yfilter != YFilter.not_set or
                                        self.update_source_interface.yfilter != YFilter.not_set or
                                        (self.advertisement_interval is not None and self.advertisement_interval.has_operation()) or
                                        (self.bmp_activates is not None and self.bmp_activates.has_operation()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_operation()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_operation()) or
                                        (self.keychain is not None and self.keychain.has_operation()) or
                                        (self.local_address is not None and self.local_address.has_operation()) or
                                        (self.local_as is not None and self.local_as.has_operation()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_operation()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_operation()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_operation()) or
                                        (self.password is not None and self.password.has_operation()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_operation()) or
                                        (self.remote_as is not None and self.remote_as.has_operation()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_operation()) or
                                        (self.tcpmss is not None and self.tcpmss.has_operation()) or
                                        (self.timers is not None and self.timers.has_operation()) or
                                        (self.tos is not None and self.tos.has_operation()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_operation()) or
                                        (self.vrf_neighbor_afs is not None and self.vrf_neighbor_afs.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-neighbor-prefix-length" + "[prefix-length='" + self.prefix_length.get() + "']" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.additional_paths_receive_capability.is_set or self.additional_paths_receive_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_receive_capability.get_name_leafdata())
                                    if (self.additional_paths_send_capability.is_set or self.additional_paths_send_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_send_capability.get_name_leafdata())
                                    if (self.bfd_enable_modes.is_set or self.bfd_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_enable_modes.get_name_leafdata())
                                    if (self.bfd_minimum_interval.is_set or self.bfd_minimum_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_minimum_interval.get_name_leafdata())
                                    if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.ebgp_recv_dmz.is_set or self.ebgp_recv_dmz.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_recv_dmz.get_name_leafdata())
                                    if (self.ebgp_send_dmz_enable_modes.is_set or self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_send_dmz_enable_modes.get_name_leafdata())
                                    if (self.egress_peer_engineering.is_set or self.egress_peer_engineering.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.egress_peer_engineering.get_name_leafdata())
                                    if (self.enforce_first_as.is_set or self.enforce_first_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enforce_first_as.get_name_leafdata())
                                    if (self.idle_watch_time.is_set or self.idle_watch_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.idle_watch_time.get_name_leafdata())
                                    if (self.ignore_connected_check_ebgp.is_set or self.ignore_connected_check_ebgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ignore_connected_check_ebgp.get_name_leafdata())
                                    if (self.internal_vpn_client_ibgpce.is_set or self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_vpn_client_ibgpce.get_name_leafdata())
                                    if (self.max_peers.is_set or self.max_peers.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_peers.get_name_leafdata())
                                    if (self.neighbor_graceful_restart.is_set or self.neighbor_graceful_restart.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_stalepath_time.is_set or self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_stalepath_time.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_time.is_set or self.neighbor_graceful_restart_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_time.get_name_leafdata())
                                    if (self.neighbor_group_add_member.is_set or self.neighbor_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_group_add_member.get_name_leafdata())
                                    if (self.propagate_dmz_link_bandwidth.is_set or self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.propagate_dmz_link_bandwidth.get_name_leafdata())
                                    if (self.remote_as_list.is_set or self.remote_as_list.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_as_list.get_name_leafdata())
                                    if (self.session_group_add_member.is_set or self.session_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_group_add_member.get_name_leafdata())
                                    if (self.session_open_mode.is_set or self.session_open_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_open_mode.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.suppress_all_capabilities.is_set or self.suppress_all_capabilities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_all_capabilities.get_name_leafdata())
                                    if (self.suppress_four_byte_as_capability.is_set or self.suppress_four_byte_as_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_four_byte_as_capability.get_name_leafdata())
                                    if (self.ttl_security.is_set or self.ttl_security.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security.get_name_leafdata())
                                    if (self.update_source_interface.is_set or self.update_source_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_source_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "advertisement-interval"):
                                        if (self.advertisement_interval is None):
                                            self.advertisement_interval = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval()
                                            self.advertisement_interval.parent = self
                                            self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                        return self.advertisement_interval

                                    if (child_yang_name == "bmp-activates"):
                                        if (self.bmp_activates is None):
                                            self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates()
                                            self.bmp_activates.parent = self
                                            self._children_name_map["bmp_activates"] = "bmp-activates"
                                        return self.bmp_activates

                                    if (child_yang_name == "ebgp-multihop"):
                                        if (self.ebgp_multihop is None):
                                            self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop()
                                            self.ebgp_multihop.parent = self
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                        return self.ebgp_multihop

                                    if (child_yang_name == "graceful-maintenance"):
                                        if (self.graceful_maintenance is None):
                                            self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        return self.graceful_maintenance

                                    if (child_yang_name == "keychain"):
                                        if (self.keychain is None):
                                            self.keychain = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                        return self.keychain

                                    if (child_yang_name == "local-address"):
                                        if (self.local_address is None):
                                            self.local_address = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                        return self.local_address

                                    if (child_yang_name == "local-as"):
                                        if (self.local_as is None):
                                            self.local_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs()
                                            self.local_as.parent = self
                                            self._children_name_map["local_as"] = "local-as"
                                        return self.local_as

                                    if (child_yang_name == "msg-log-in"):
                                        if (self.msg_log_in is None):
                                            self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn()
                                            self.msg_log_in.parent = self
                                            self._children_name_map["msg_log_in"] = "msg-log-in"
                                        return self.msg_log_in

                                    if (child_yang_name == "msg-log-out"):
                                        if (self.msg_log_out is None):
                                            self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut()
                                            self.msg_log_out.parent = self
                                            self._children_name_map["msg_log_out"] = "msg-log-out"
                                        return self.msg_log_out

                                    if (child_yang_name == "neighbor-cluster-id"):
                                        if (self.neighbor_cluster_id is None):
                                            self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId()
                                            self.neighbor_cluster_id.parent = self
                                            self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                        return self.neighbor_cluster_id

                                    if (child_yang_name == "password"):
                                        if (self.password is None):
                                            self.password = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"
                                        return self.password

                                    if (child_yang_name == "receive-buffer-size"):
                                        if (self.receive_buffer_size is None):
                                            self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize()
                                            self.receive_buffer_size.parent = self
                                            self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                        return self.receive_buffer_size

                                    if (child_yang_name == "remote-as"):
                                        if (self.remote_as is None):
                                            self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs()
                                            self.remote_as.parent = self
                                            self._children_name_map["remote_as"] = "remote-as"
                                        return self.remote_as

                                    if (child_yang_name == "send-buffer-size"):
                                        if (self.send_buffer_size is None):
                                            self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize()
                                            self.send_buffer_size.parent = self
                                            self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                        return self.send_buffer_size

                                    if (child_yang_name == "tcpmss"):
                                        if (self.tcpmss is None):
                                            self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss()
                                            self.tcpmss.parent = self
                                            self._children_name_map["tcpmss"] = "tcpmss"
                                        return self.tcpmss

                                    if (child_yang_name == "timers"):
                                        if (self.timers is None):
                                            self.timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"
                                        return self.timers

                                    if (child_yang_name == "tos"):
                                        if (self.tos is None):
                                            self.tos = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos()
                                            self.tos.parent = self
                                            self._children_name_map["tos"] = "tos"
                                        return self.tos

                                    if (child_yang_name == "update-in-filtering"):
                                        if (self.update_in_filtering is None):
                                            self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering()
                                            self.update_in_filtering.parent = self
                                            self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                        return self.update_in_filtering

                                    if (child_yang_name == "vrf-neighbor-afs"):
                                        if (self.vrf_neighbor_afs is None):
                                            self.vrf_neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs()
                                            self.vrf_neighbor_afs.parent = self
                                            self._children_name_map["vrf_neighbor_afs"] = "vrf-neighbor-afs"
                                        return self.vrf_neighbor_afs

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertisement-interval" or name == "bmp-activates" or name == "ebgp-multihop" or name == "graceful-maintenance" or name == "keychain" or name == "local-address" or name == "local-as" or name == "msg-log-in" or name == "msg-log-out" or name == "neighbor-cluster-id" or name == "password" or name == "receive-buffer-size" or name == "remote-as" or name == "send-buffer-size" or name == "tcpmss" or name == "timers" or name == "tos" or name == "update-in-filtering" or name == "vrf-neighbor-afs" or name == "prefix-length" or name == "neighbor-address" or name == "additional-paths-receive-capability" or name == "additional-paths-send-capability" or name == "bfd-enable-modes" or name == "bfd-minimum-interval" or name == "bfd-multiplier" or name == "description" or name == "ebgp-recv-dmz" or name == "ebgp-send-dmz-enable-modes" or name == "egress-peer-engineering" or name == "enforce-first-as" or name == "idle-watch-time" or name == "ignore-connected-check-ebgp" or name == "internal-vpn-client-ibgpce" or name == "max-peers" or name == "neighbor-graceful-restart" or name == "neighbor-graceful-restart-stalepath-time" or name == "neighbor-graceful-restart-time" or name == "neighbor-group-add-member" or name == "propagate-dmz-link-bandwidth" or name == "remote-as-list" or name == "session-group-add-member" or name == "session-open-mode" or name == "shutdown" or name == "suppress-all-capabilities" or name == "suppress-four-byte-as-capability" or name == "ttl-security" or name == "update-source-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-receive-capability"):
                                        self.additional_paths_receive_capability = value
                                        self.additional_paths_receive_capability.value_namespace = name_space
                                        self.additional_paths_receive_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-send-capability"):
                                        self.additional_paths_send_capability = value
                                        self.additional_paths_send_capability.value_namespace = name_space
                                        self.additional_paths_send_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-enable-modes"):
                                        self.bfd_enable_modes = value
                                        self.bfd_enable_modes.value_namespace = name_space
                                        self.bfd_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-minimum-interval"):
                                        self.bfd_minimum_interval = value
                                        self.bfd_minimum_interval.value_namespace = name_space
                                        self.bfd_minimum_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-multiplier"):
                                        self.bfd_multiplier = value
                                        self.bfd_multiplier.value_namespace = name_space
                                        self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-recv-dmz"):
                                        self.ebgp_recv_dmz = value
                                        self.ebgp_recv_dmz.value_namespace = name_space
                                        self.ebgp_recv_dmz.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-send-dmz-enable-modes"):
                                        self.ebgp_send_dmz_enable_modes = value
                                        self.ebgp_send_dmz_enable_modes.value_namespace = name_space
                                        self.ebgp_send_dmz_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "egress-peer-engineering"):
                                        self.egress_peer_engineering = value
                                        self.egress_peer_engineering.value_namespace = name_space
                                        self.egress_peer_engineering.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enforce-first-as"):
                                        self.enforce_first_as = value
                                        self.enforce_first_as.value_namespace = name_space
                                        self.enforce_first_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "idle-watch-time"):
                                        self.idle_watch_time = value
                                        self.idle_watch_time.value_namespace = name_space
                                        self.idle_watch_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ignore-connected-check-ebgp"):
                                        self.ignore_connected_check_ebgp = value
                                        self.ignore_connected_check_ebgp.value_namespace = name_space
                                        self.ignore_connected_check_ebgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-vpn-client-ibgpce"):
                                        self.internal_vpn_client_ibgpce = value
                                        self.internal_vpn_client_ibgpce.value_namespace = name_space
                                        self.internal_vpn_client_ibgpce.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-peers"):
                                        self.max_peers = value
                                        self.max_peers.value_namespace = name_space
                                        self.max_peers.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart"):
                                        self.neighbor_graceful_restart = value
                                        self.neighbor_graceful_restart.value_namespace = name_space
                                        self.neighbor_graceful_restart.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-stalepath-time"):
                                        self.neighbor_graceful_restart_stalepath_time = value
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-time"):
                                        self.neighbor_graceful_restart_time = value
                                        self.neighbor_graceful_restart_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-group-add-member"):
                                        self.neighbor_group_add_member = value
                                        self.neighbor_group_add_member.value_namespace = name_space
                                        self.neighbor_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "propagate-dmz-link-bandwidth"):
                                        self.propagate_dmz_link_bandwidth = value
                                        self.propagate_dmz_link_bandwidth.value_namespace = name_space
                                        self.propagate_dmz_link_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-as-list"):
                                        self.remote_as_list = value
                                        self.remote_as_list.value_namespace = name_space
                                        self.remote_as_list.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-group-add-member"):
                                        self.session_group_add_member = value
                                        self.session_group_add_member.value_namespace = name_space
                                        self.session_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-open-mode"):
                                        self.session_open_mode = value
                                        self.session_open_mode.value_namespace = name_space
                                        self.session_open_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-all-capabilities"):
                                        self.suppress_all_capabilities = value
                                        self.suppress_all_capabilities.value_namespace = name_space
                                        self.suppress_all_capabilities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-four-byte-as-capability"):
                                        self.suppress_four_byte_as_capability = value
                                        self.suppress_four_byte_as_capability.value_namespace = name_space
                                        self.suppress_four_byte_as_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security"):
                                        self.ttl_security = value
                                        self.ttl_security.value_namespace = name_space
                                        self.ttl_security.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-source-interface"):
                                        self.update_source_interface = value
                                        self.update_source_interface.value_namespace = name_space
                                        self.update_source_interface.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_neighbor:
                                    if (c.has_data()):
                                        return True
                                for c in self.vrf_neighbor_prefix_length:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_neighbor:
                                    if (c.has_operation()):
                                        return True
                                for c in self.vrf_neighbor_prefix_length:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-neighbors" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-neighbor"):
                                    for c in self.vrf_neighbor:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_neighbor.append(c)
                                    return c

                                if (child_yang_name == "vrf-neighbor-prefix-length"):
                                    for c in self.vrf_neighbor_prefix_length:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_neighbor_prefix_length.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-neighbor" or name == "vrf-neighbor-prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.vrf_name.is_set or
                                (self.vrf_global is not None and self.vrf_global.has_data()) or
                                (self.vrf_neighbors is not None and self.vrf_neighbors.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.vrf_global is not None and self.vrf_global.has_operation()) or
                                (self.vrf_neighbors is not None and self.vrf_neighbors.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-global"):
                                if (self.vrf_global is None):
                                    self.vrf_global = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal()
                                    self.vrf_global.parent = self
                                    self._children_name_map["vrf_global"] = "vrf-global"
                                return self.vrf_global

                            if (child_yang_name == "vrf-neighbors"):
                                if (self.vrf_neighbors is None):
                                    self.vrf_neighbors = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors()
                                    self.vrf_neighbors.parent = self
                                    self._children_name_map["vrf_neighbors"] = "vrf-neighbors"
                                return self.vrf_neighbors

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-global" or name == "vrf-neighbors" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.vrf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.vrf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "vrf"):
                            for c in self.vrf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.vrf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "vrf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class DefaultVrf(Entity):
                    """
                    Global default config
                    
                    .. attribute:: bgp_entity
                    
                    	Neighbor, neighbor\-group, af\-group and session\-group configuration
                    	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity>`
                    
                    .. attribute:: global_
                    
                    	Global default config
                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-cfg'
                    _revision = '2015-08-27'

                    def __init__(self):
                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf, self).__init__()

                        self.yang_name = "default-vrf"
                        self.yang_parent_name = "four-byte-as"

                        self.bgp_entity = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity()
                        self.bgp_entity.parent = self
                        self._children_name_map["bgp_entity"] = "bgp-entity"
                        self._children_yang_names.add("bgp-entity")

                        self.global_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"
                        self._children_yang_names.add("global")


                    class BgpEntity(Entity):
                        """
                        Neighbor, neighbor\-group, af\-group and
                        session\-group configuration
                        
                        .. attribute:: af_groups
                        
                        	AF\-group configuration
                        	**type**\:   :py:class:`AfGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups>`
                        
                        .. attribute:: neighbor_groups
                        
                        	Neighbor\-group configuration
                        	**type**\:   :py:class:`NeighborGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups>`
                        
                        .. attribute:: neighbors
                        
                        	Neighbor configuration
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors>`
                        
                        .. attribute:: session_groups
                        
                        	Session group configuration
                        	**type**\:   :py:class:`SessionGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-cfg'
                        _revision = '2015-08-27'

                        def __init__(self):
                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity, self).__init__()

                            self.yang_name = "bgp-entity"
                            self.yang_parent_name = "default-vrf"

                            self.af_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups()
                            self.af_groups.parent = self
                            self._children_name_map["af_groups"] = "af-groups"
                            self._children_yang_names.add("af-groups")

                            self.neighbor_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups()
                            self.neighbor_groups.parent = self
                            self._children_name_map["neighbor_groups"] = "neighbor-groups"
                            self._children_yang_names.add("neighbor-groups")

                            self.neighbors = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.session_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups()
                            self.session_groups.parent = self
                            self._children_name_map["session_groups"] = "session-groups"
                            self._children_yang_names.add("session-groups")


                        class Neighbors(Entity):
                            """
                            Neighbor configuration
                            
                            .. attribute:: neighbor
                            
                            	A particular BGP peer
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor>`
                            
                            .. attribute:: neighbor_prefix_length
                            
                            	A particular BGP peer
                            	**type**\: list of    :py:class:`NeighborPrefixLength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "bgp-entity"

                                self.neighbor = YList(self)
                                self.neighbor_prefix_length = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors, self).__setattr__(name, value)


                            class Neighbor(Entity):
                                """
                                A particular BGP peer
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgpce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut>`
                                
                                .. attribute:: neighbor_afs
                                
                                	BGP neighbor AF configuration table
                                	**type**\:   :py:class:`NeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgpce = YLeaf(YType.boolean, "internal-vpn-client-ibgpce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs()
                                    self.neighbor_afs.parent = self
                                    self._children_name_map["neighbor_afs"] = "neighbor-afs"
                                    self._children_yang_names.add("neighbor-afs")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("neighbor_address",
                                                    "additional_paths_receive_capability",
                                                    "additional_paths_send_capability",
                                                    "bfd_enable_modes",
                                                    "bfd_minimum_interval",
                                                    "bfd_multiplier",
                                                    "description",
                                                    "ebgp_recv_dmz",
                                                    "ebgp_send_dmz_enable_modes",
                                                    "egress_peer_engineering",
                                                    "enforce_first_as",
                                                    "idle_watch_time",
                                                    "ignore_connected_check_ebgp",
                                                    "internal_vpn_client_ibgpce",
                                                    "max_peers",
                                                    "neighbor_graceful_restart",
                                                    "neighbor_graceful_restart_stalepath_time",
                                                    "neighbor_graceful_restart_time",
                                                    "neighbor_group_add_member",
                                                    "propagate_dmz_link_bandwidth",
                                                    "remote_as_list",
                                                    "rpki_bestpath_origin_as_allow_invalid",
                                                    "rpki_origin_as_validation_disable",
                                                    "session_group_add_member",
                                                    "session_open_mode",
                                                    "shutdown",
                                                    "suppress_all_capabilities",
                                                    "suppress_four_byte_as_capability",
                                                    "ttl_security",
                                                    "update_source_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor, self).__setattr__(name, value)


                                class NeighborAfs(Entity):
                                    """
                                    BGP neighbor AF configuration table
                                    
                                    .. attribute:: neighbor_af
                                    
                                    	Address family type of neighbor
                                    	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs, self).__init__()

                                        self.yang_name = "neighbor-afs"
                                        self.yang_parent_name = "neighbor"

                                        self.neighbor_af = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs, self).__setattr__(name, value)


                                    class NeighborAf(Entity):
                                        """
                                        Address family type of neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpnevpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_l2vpnevpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf, self).__init__()

                                            self.yang_name = "neighbor-af"
                                            self.yang_parent_name = "neighbor-afs"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn()
                                            self.advertise_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                            self._children_yang_names.add("advertise-l2vpnevpn")

                                            self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn()
                                            self.advertise_local_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                            self._children_yang_names.add("advertise-local-l2vpnevpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "accept_own",
                                                            "accept_route_legacy_rt",
                                                            "activate",
                                                            "advertise_local_labeled_route",
                                                            "advertise_orf",
                                                            "advertise_permanent_network",
                                                            "af_group",
                                                            "aigp",
                                                            "aigp_send_med",
                                                            "allow_as_in",
                                                            "as_override",
                                                            "default_weight",
                                                            "encapsulation_type",
                                                            "flowspec_validation",
                                                            "l2vpn_signalling",
                                                            "multipath",
                                                            "neighbor_af_long_lived_graceful_restart_capable",
                                                            "next_hop_self",
                                                            "next_hop_unchanged",
                                                            "next_hop_unchanged_multipath",
                                                            "prefix_orf_policy",
                                                            "route_policy_in",
                                                            "route_policy_out",
                                                            "route_reflector_client",
                                                            "rpki_bestpath_origin_as_allow_invalid",
                                                            "rpki_origin_as_validation_disable",
                                                            "send_community_ebgp",
                                                            "send_community_ebgp_graceful_shutdown",
                                                            "send_ext_community_ebgp",
                                                            "send_multicast_attr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf, self).__setattr__(name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cost_community_id",
                                                                "cost_community_poi_type",
                                                                "enable",
                                                                "transitive") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cost_community_id.is_set or
                                                    self.cost_community_poi_type.is_set or
                                                    self.enable.is_set or
                                                    self.transitive.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cost_community_id.yfilter != YFilter.not_set or
                                                    self.cost_community_poi_type.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.transitive.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "aigp-cost-community" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cost_community_id.is_set or self.cost_community_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_id.get_name_leafdata())
                                                if (self.cost_community_poi_type.is_set or self.cost_community_poi_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_poi_type.get_name_leafdata())
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.transitive.is_set or self.transitive.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.transitive.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cost-community-id" or name == "cost-community-poi-type" or name == "enable" or name == "transitive"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cost-community-id"):
                                                    self.cost_community_id = value
                                                    self.cost_community_id.value_namespace = name_space
                                                    self.cost_community_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost-community-poi-type"):
                                                    self.cost_community_poi_type = value
                                                    self.cost_community_poi_type.value_namespace = name_space
                                                    self.cost_community_poi_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "transitive"):
                                                    self.transitive = value
                                                    self.transitive.value_namespace = name_space
                                                    self.transitive.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-disable" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("discard_extra_paths",
                                                                "prefix_limit",
                                                                "restart_time",
                                                                "warning_only",
                                                                "warning_percentage") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.discard_extra_paths.is_set or
                                                    self.prefix_limit.is_set or
                                                    self.restart_time.is_set or
                                                    self.warning_only.is_set or
                                                    self.warning_percentage.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.discard_extra_paths.yfilter != YFilter.not_set or
                                                    self.prefix_limit.yfilter != YFilter.not_set or
                                                    self.restart_time.yfilter != YFilter.not_set or
                                                    self.warning_only.yfilter != YFilter.not_set or
                                                    self.warning_percentage.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-prefixes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.discard_extra_paths.is_set or self.discard_extra_paths.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.discard_extra_paths.get_name_leafdata())
                                                if (self.prefix_limit.is_set or self.prefix_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_limit.get_name_leafdata())
                                                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.restart_time.get_name_leafdata())
                                                if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_only.get_name_leafdata())
                                                if (self.warning_percentage.is_set or self.warning_percentage.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_percentage.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "discard-extra-paths" or name == "prefix-limit" or name == "restart-time" or name == "warning-only" or name == "warning-percentage"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "discard-extra-paths"):
                                                    self.discard_extra_paths = value
                                                    self.discard_extra_paths.value_namespace = name_space
                                                    self.discard_extra_paths.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-limit"):
                                                    self.prefix_limit = value
                                                    self.prefix_limit.value_namespace = name_space
                                                    self.prefix_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "restart-time"):
                                                    self.restart_time = value
                                                    self.restart_time.value_namespace = name_space
                                                    self.restart_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-only"):
                                                    self.warning_only = value
                                                    self.warning_only.value_namespace = name_space
                                                    self.warning_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-percentage"):
                                                    self.warning_percentage = value
                                                    self.warning_percentage.value_namespace = name_space
                                                    self.warning_percentage.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path-inbound" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseL2Vpnevpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-l2vpnevpn"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalL2Vpnevpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpnevpn"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "neighbor-af"

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("stale_time_accept",
                                                                "stale_time_send") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.stale_time_accept.is_set or
                                                    self.stale_time_send.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.stale_time_accept.yfilter != YFilter.not_set or
                                                    self.stale_time_send.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-af-long-lived-graceful-restart-stale-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.stale_time_accept.is_set or self.stale_time_accept.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_accept.get_name_leafdata())
                                                if (self.stale_time_send.is_set or self.stale_time_send.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_send.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "stale-time-accept" or name == "stale-time-send"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "stale-time-accept"):
                                                    self.stale_time_accept = value
                                                    self.stale_time_accept.value_namespace = name_space
                                                    self.stale_time_accept.value_namespace_prefix = name_space_prefix
                                                if(value_path == "stale-time-send"):
                                                    self.stale_time_send = value
                                                    self.stale_time_send.value_namespace = name_space
                                                    self.stale_time_send.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "neighbor-af"

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("import_reoriginate",
                                                                "import_reoriginate_stitching",
                                                                "import_stitching") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.import_reoriginate.is_set or
                                                    self.import_reoriginate_stitching.is_set or
                                                    self.import_stitching.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.import_reoriginate.yfilter != YFilter.not_set or
                                                    self.import_reoriginate_stitching.yfilter != YFilter.not_set or
                                                    self.import_stitching.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "import" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.import_reoriginate.is_set or self.import_reoriginate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate.get_name_leafdata())
                                                if (self.import_reoriginate_stitching.is_set or self.import_reoriginate_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate_stitching.get_name_leafdata())
                                                if (self.import_stitching.is_set or self.import_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_stitching.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "import-reoriginate" or name == "import-reoriginate-stitching" or name == "import-stitching"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "import-reoriginate"):
                                                    self.import_reoriginate = value
                                                    self.import_reoriginate.value_namespace = name_space
                                                    self.import_reoriginate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-reoriginate-stitching"):
                                                    self.import_reoriginate_stitching = value
                                                    self.import_reoriginate_stitching.value_namespace = name_space
                                                    self.import_reoriginate_stitching.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-stitching"):
                                                    self.import_stitching = value
                                                    self.import_stitching.value_namespace = name_space
                                                    self.import_stitching.value_namespace_prefix = name_space_prefix


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor-af"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "default-originate" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "neighbor-af"

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("inbound_soft",
                                                                "soft_always") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.inbound_soft.is_set or
                                                    self.soft_always.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.inbound_soft.yfilter != YFilter.not_set or
                                                    self.soft_always.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "soft-reconfiguration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.inbound_soft.is_set or self.inbound_soft.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.inbound_soft.get_name_leafdata())
                                                if (self.soft_always.is_set or self.soft_always.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.soft_always.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "inbound-soft" or name == "soft-always"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "inbound-soft"):
                                                    self.inbound_soft = value
                                                    self.inbound_soft.value_namespace = name_space
                                                    self.inbound_soft.value_namespace_prefix = name_space_prefix
                                                if(value_path == "soft-always"):
                                                    self.soft_always = value
                                                    self.soft_always.value_namespace = name_space
                                                    self.soft_always.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.accept_own.is_set or
                                                self.accept_route_legacy_rt.is_set or
                                                self.activate.is_set or
                                                self.advertise_local_labeled_route.is_set or
                                                self.advertise_orf.is_set or
                                                self.advertise_permanent_network.is_set or
                                                self.af_group.is_set or
                                                self.aigp.is_set or
                                                self.aigp_send_med.is_set or
                                                self.allow_as_in.is_set or
                                                self.as_override.is_set or
                                                self.default_weight.is_set or
                                                self.encapsulation_type.is_set or
                                                self.flowspec_validation.is_set or
                                                self.l2vpn_signalling.is_set or
                                                self.multipath.is_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.is_set or
                                                self.next_hop_self.is_set or
                                                self.next_hop_unchanged.is_set or
                                                self.next_hop_unchanged_multipath.is_set or
                                                self.prefix_orf_policy.is_set or
                                                self.route_policy_in.is_set or
                                                self.route_policy_out.is_set or
                                                self.route_reflector_client.is_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                                self.rpki_origin_as_validation_disable.is_set or
                                                self.send_community_ebgp.is_set or
                                                self.send_community_ebgp_graceful_shutdown.is_set or
                                                self.send_ext_community_ebgp.is_set or
                                                self.send_multicast_attr.is_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_data()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_data()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_data()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_data()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_data()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_data()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_data()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_data()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_data()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_data()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_data()) or
                                                (self.default_originate is not None and self.default_originate.has_data()) or
                                                (self.import_ is not None and self.import_.has_data()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_data()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_data()) or
                                                (self.aigp_cost_community is not None) or
                                                (self.maximum_prefixes is not None) or
                                                (self.remove_private_as_entire_as_path is not None) or
                                                (self.remove_private_as_entire_as_path_inbound is not None))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.accept_own.yfilter != YFilter.not_set or
                                                self.accept_route_legacy_rt.yfilter != YFilter.not_set or
                                                self.activate.yfilter != YFilter.not_set or
                                                self.advertise_local_labeled_route.yfilter != YFilter.not_set or
                                                self.advertise_orf.yfilter != YFilter.not_set or
                                                self.advertise_permanent_network.yfilter != YFilter.not_set or
                                                self.af_group.yfilter != YFilter.not_set or
                                                self.aigp.yfilter != YFilter.not_set or
                                                self.aigp_send_med.yfilter != YFilter.not_set or
                                                self.allow_as_in.yfilter != YFilter.not_set or
                                                self.as_override.yfilter != YFilter.not_set or
                                                self.default_weight.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.flowspec_validation.yfilter != YFilter.not_set or
                                                self.l2vpn_signalling.yfilter != YFilter.not_set or
                                                self.multipath.yfilter != YFilter.not_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set or
                                                self.next_hop_self.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged_multipath.yfilter != YFilter.not_set or
                                                self.prefix_orf_policy.yfilter != YFilter.not_set or
                                                self.route_policy_in.yfilter != YFilter.not_set or
                                                self.route_policy_out.yfilter != YFilter.not_set or
                                                self.route_reflector_client.yfilter != YFilter.not_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                                self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                                self.send_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set or
                                                self.send_ext_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_multicast_attr.yfilter != YFilter.not_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_operation()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_operation()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_operation()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_operation()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_operation()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_operation()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_operation()) or
                                                (self.aigp_cost_community is not None and self.aigp_cost_community.has_operation()) or
                                                (self.default_originate is not None and self.default_originate.has_operation()) or
                                                (self.import_ is not None and self.import_.has_operation()) or
                                                (self.maximum_prefixes is not None and self.maximum_prefixes.has_operation()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_operation()) or
                                                (self.remove_private_as_entire_as_path is not None and self.remove_private_as_entire_as_path.has_operation()) or
                                                (self.remove_private_as_entire_as_path_inbound is not None and self.remove_private_as_entire_as_path_inbound.has_operation()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.accept_own.is_set or self.accept_own.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_own.get_name_leafdata())
                                            if (self.accept_route_legacy_rt.is_set or self.accept_route_legacy_rt.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_route_legacy_rt.get_name_leafdata())
                                            if (self.activate.is_set or self.activate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.activate.get_name_leafdata())
                                            if (self.advertise_local_labeled_route.is_set or self.advertise_local_labeled_route.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_local_labeled_route.get_name_leafdata())
                                            if (self.advertise_orf.is_set or self.advertise_orf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_orf.get_name_leafdata())
                                            if (self.advertise_permanent_network.is_set or self.advertise_permanent_network.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_permanent_network.get_name_leafdata())
                                            if (self.af_group.is_set or self.af_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_group.get_name_leafdata())
                                            if (self.aigp.is_set or self.aigp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp.get_name_leafdata())
                                            if (self.aigp_send_med.is_set or self.aigp_send_med.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp_send_med.get_name_leafdata())
                                            if (self.allow_as_in.is_set or self.allow_as_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.allow_as_in.get_name_leafdata())
                                            if (self.as_override.is_set or self.as_override.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_override.get_name_leafdata())
                                            if (self.default_weight.is_set or self.default_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_weight.get_name_leafdata())
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.flowspec_validation.is_set or self.flowspec_validation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flowspec_validation.get_name_leafdata())
                                            if (self.l2vpn_signalling.is_set or self.l2vpn_signalling.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2vpn_signalling.get_name_leafdata())
                                            if (self.multipath.is_set or self.multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multipath.get_name_leafdata())
                                            if (self.neighbor_af_long_lived_graceful_restart_capable.is_set or self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_af_long_lived_graceful_restart_capable.get_name_leafdata())
                                            if (self.next_hop_self.is_set or self.next_hop_self.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_self.get_name_leafdata())
                                            if (self.next_hop_unchanged.is_set or self.next_hop_unchanged.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged.get_name_leafdata())
                                            if (self.next_hop_unchanged_multipath.is_set or self.next_hop_unchanged_multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged_multipath.get_name_leafdata())
                                            if (self.prefix_orf_policy.is_set or self.prefix_orf_policy.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_orf_policy.get_name_leafdata())
                                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                            if (self.route_reflector_client.is_set or self.route_reflector_client.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_reflector_client.get_name_leafdata())
                                            if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                            if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                            if (self.send_community_ebgp.is_set or self.send_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp.get_name_leafdata())
                                            if (self.send_community_ebgp_graceful_shutdown.is_set or self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp_graceful_shutdown.get_name_leafdata())
                                            if (self.send_ext_community_ebgp.is_set or self.send_ext_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_ext_community_ebgp.get_name_leafdata())
                                            if (self.send_multicast_attr.is_set or self.send_multicast_attr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_multicast_attr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advertise-def-imp-disable-v4"):
                                                if (self.advertise_def_imp_disable_v4 is None):
                                                    self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4()
                                                    self.advertise_def_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                                return self.advertise_def_imp_disable_v4

                                            if (child_yang_name == "advertise-def-imp-disable-v6"):
                                                if (self.advertise_def_imp_disable_v6 is None):
                                                    self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6()
                                                    self.advertise_def_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                                return self.advertise_def_imp_disable_v6

                                            if (child_yang_name == "advertise-disable"):
                                                if (self.advertise_disable is None):
                                                    self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable()
                                                    self.advertise_disable.parent = self
                                                    self._children_name_map["advertise_disable"] = "advertise-disable"
                                                return self.advertise_disable

                                            if (child_yang_name == "advertise-l2vpnevpn"):
                                                if (self.advertise_l2vpnevpn is None):
                                                    self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn()
                                                    self.advertise_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                                return self.advertise_l2vpnevpn

                                            if (child_yang_name == "advertise-local-l2vpnevpn"):
                                                if (self.advertise_local_l2vpnevpn is None):
                                                    self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn()
                                                    self.advertise_local_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                                return self.advertise_local_l2vpnevpn

                                            if (child_yang_name == "advertise-local-v4"):
                                                if (self.advertise_local_v4 is None):
                                                    self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4()
                                                    self.advertise_local_v4.parent = self
                                                    self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                                return self.advertise_local_v4

                                            if (child_yang_name == "advertise-local-v6"):
                                                if (self.advertise_local_v6 is None):
                                                    self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6()
                                                    self.advertise_local_v6.parent = self
                                                    self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                                return self.advertise_local_v6

                                            if (child_yang_name == "advertise-v4"):
                                                if (self.advertise_v4 is None):
                                                    self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4()
                                                    self.advertise_v4.parent = self
                                                    self._children_name_map["advertise_v4"] = "advertise-v4"
                                                return self.advertise_v4

                                            if (child_yang_name == "advertise-v6"):
                                                if (self.advertise_v6 is None):
                                                    self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6()
                                                    self.advertise_v6.parent = self
                                                    self._children_name_map["advertise_v6"] = "advertise-v6"
                                                return self.advertise_v6

                                            if (child_yang_name == "advertise-vrf-imp-disable-v4"):
                                                if (self.advertise_vrf_imp_disable_v4 is None):
                                                    self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4()
                                                    self.advertise_vrf_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                                return self.advertise_vrf_imp_disable_v4

                                            if (child_yang_name == "advertise-vrf-imp-disable-v6"):
                                                if (self.advertise_vrf_imp_disable_v6 is None):
                                                    self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6()
                                                    self.advertise_vrf_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                                return self.advertise_vrf_imp_disable_v6

                                            if (child_yang_name == "aigp-cost-community"):
                                                if (self.aigp_cost_community is None):
                                                    self.aigp_cost_community = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity()
                                                    self.aigp_cost_community.parent = self
                                                    self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                                return self.aigp_cost_community

                                            if (child_yang_name == "default-originate"):
                                                if (self.default_originate is None):
                                                    self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate()
                                                    self.default_originate.parent = self
                                                    self._children_name_map["default_originate"] = "default-originate"
                                                return self.default_originate

                                            if (child_yang_name == "import"):
                                                if (self.import_ is None):
                                                    self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_()
                                                    self.import_.parent = self
                                                    self._children_name_map["import_"] = "import"
                                                return self.import_

                                            if (child_yang_name == "maximum-prefixes"):
                                                if (self.maximum_prefixes is None):
                                                    self.maximum_prefixes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes()
                                                    self.maximum_prefixes.parent = self
                                                    self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                                return self.maximum_prefixes

                                            if (child_yang_name == "neighbor-af-long-lived-graceful-restart-stale-time"):
                                                if (self.neighbor_af_long_lived_graceful_restart_stale_time is None):
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                                    self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                return self.neighbor_af_long_lived_graceful_restart_stale_time

                                            if (child_yang_name == "remove-private-as-entire-as-path"):
                                                if (self.remove_private_as_entire_as_path is None):
                                                    self.remove_private_as_entire_as_path = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath()
                                                    self.remove_private_as_entire_as_path.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                                return self.remove_private_as_entire_as_path

                                            if (child_yang_name == "remove-private-as-entire-as-path-inbound"):
                                                if (self.remove_private_as_entire_as_path_inbound is None):
                                                    self.remove_private_as_entire_as_path_inbound = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound()
                                                    self.remove_private_as_entire_as_path_inbound.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                                return self.remove_private_as_entire_as_path_inbound

                                            if (child_yang_name == "soft-reconfiguration"):
                                                if (self.soft_reconfiguration is None):
                                                    self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration()
                                                    self.soft_reconfiguration.parent = self
                                                    self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                                return self.soft_reconfiguration

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertise-def-imp-disable-v4" or name == "advertise-def-imp-disable-v6" or name == "advertise-disable" or name == "advertise-l2vpnevpn" or name == "advertise-local-l2vpnevpn" or name == "advertise-local-v4" or name == "advertise-local-v6" or name == "advertise-v4" or name == "advertise-v6" or name == "advertise-vrf-imp-disable-v4" or name == "advertise-vrf-imp-disable-v6" or name == "aigp-cost-community" or name == "default-originate" or name == "import" or name == "maximum-prefixes" or name == "neighbor-af-long-lived-graceful-restart-stale-time" or name == "remove-private-as-entire-as-path" or name == "remove-private-as-entire-as-path-inbound" or name == "soft-reconfiguration" or name == "af-name" or name == "accept-own" or name == "accept-route-legacy-rt" or name == "activate" or name == "advertise-local-labeled-route" or name == "advertise-orf" or name == "advertise-permanent-network" or name == "af-group" or name == "aigp" or name == "aigp-send-med" or name == "allow-as-in" or name == "as-override" or name == "default-weight" or name == "encapsulation-type" or name == "flowspec-validation" or name == "l2vpn-signalling" or name == "multipath" or name == "neighbor-af-long-lived-graceful-restart-capable" or name == "next-hop-self" or name == "next-hop-unchanged" or name == "next-hop-unchanged-multipath" or name == "prefix-orf-policy" or name == "route-policy-in" or name == "route-policy-out" or name == "route-reflector-client" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "send-community-ebgp" or name == "send-community-ebgp-graceful-shutdown" or name == "send-ext-community-ebgp" or name == "send-multicast-attr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-own"):
                                                self.accept_own = value
                                                self.accept_own.value_namespace = name_space
                                                self.accept_own.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-route-legacy-rt"):
                                                self.accept_route_legacy_rt = value
                                                self.accept_route_legacy_rt.value_namespace = name_space
                                                self.accept_route_legacy_rt.value_namespace_prefix = name_space_prefix
                                            if(value_path == "activate"):
                                                self.activate = value
                                                self.activate.value_namespace = name_space
                                                self.activate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-local-labeled-route"):
                                                self.advertise_local_labeled_route = value
                                                self.advertise_local_labeled_route.value_namespace = name_space
                                                self.advertise_local_labeled_route.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-orf"):
                                                self.advertise_orf = value
                                                self.advertise_orf.value_namespace = name_space
                                                self.advertise_orf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-permanent-network"):
                                                self.advertise_permanent_network = value
                                                self.advertise_permanent_network.value_namespace = name_space
                                                self.advertise_permanent_network.value_namespace_prefix = name_space_prefix
                                            if(value_path == "af-group"):
                                                self.af_group = value
                                                self.af_group.value_namespace = name_space
                                                self.af_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp"):
                                                self.aigp = value
                                                self.aigp.value_namespace = name_space
                                                self.aigp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp-send-med"):
                                                self.aigp_send_med = value
                                                self.aigp_send_med.value_namespace = name_space
                                                self.aigp_send_med.value_namespace_prefix = name_space_prefix
                                            if(value_path == "allow-as-in"):
                                                self.allow_as_in = value
                                                self.allow_as_in.value_namespace = name_space
                                                self.allow_as_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-override"):
                                                self.as_override = value
                                                self.as_override.value_namespace = name_space
                                                self.as_override.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-weight"):
                                                self.default_weight = value
                                                self.default_weight.value_namespace = name_space
                                                self.default_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flowspec-validation"):
                                                self.flowspec_validation = value
                                                self.flowspec_validation.value_namespace = name_space
                                                self.flowspec_validation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2vpn-signalling"):
                                                self.l2vpn_signalling = value
                                                self.l2vpn_signalling.value_namespace = name_space
                                                self.l2vpn_signalling.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multipath"):
                                                self.multipath = value
                                                self.multipath.value_namespace = name_space
                                                self.multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-af-long-lived-graceful-restart-capable"):
                                                self.neighbor_af_long_lived_graceful_restart_capable = value
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace = name_space
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-self"):
                                                self.next_hop_self = value
                                                self.next_hop_self.value_namespace = name_space
                                                self.next_hop_self.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged"):
                                                self.next_hop_unchanged = value
                                                self.next_hop_unchanged.value_namespace = name_space
                                                self.next_hop_unchanged.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged-multipath"):
                                                self.next_hop_unchanged_multipath = value
                                                self.next_hop_unchanged_multipath.value_namespace = name_space
                                                self.next_hop_unchanged_multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-orf-policy"):
                                                self.prefix_orf_policy = value
                                                self.prefix_orf_policy.value_namespace = name_space
                                                self.prefix_orf_policy.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-in"):
                                                self.route_policy_in = value
                                                self.route_policy_in.value_namespace = name_space
                                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-out"):
                                                self.route_policy_out = value
                                                self.route_policy_out.value_namespace = name_space
                                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-reflector-client"):
                                                self.route_reflector_client = value
                                                self.route_reflector_client.value_namespace = name_space
                                                self.route_reflector_client.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                                self.rpki_bestpath_origin_as_allow_invalid = value
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-origin-as-validation-disable"):
                                                self.rpki_origin_as_validation_disable = value
                                                self.rpki_origin_as_validation_disable.value_namespace = name_space
                                                self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp"):
                                                self.send_community_ebgp = value
                                                self.send_community_ebgp.value_namespace = name_space
                                                self.send_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp-graceful-shutdown"):
                                                self.send_community_ebgp_graceful_shutdown = value
                                                self.send_community_ebgp_graceful_shutdown.value_namespace = name_space
                                                self.send_community_ebgp_graceful_shutdown.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-ext-community-ebgp"):
                                                self.send_ext_community_ebgp = value
                                                self.send_ext_community_ebgp.value_namespace = name_space
                                                self.send_ext_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-multicast-attr"):
                                                self.send_multicast_attr = value
                                                self.send_multicast_attr.value_namespace = name_space
                                                self.send_multicast_attr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor_af:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.neighbor_af:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-afs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-af"):
                                            for c in self.neighbor_af:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor_af.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-af"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "neighbor"

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address_disable",
                                                        "local_ip_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_address_disable.is_set or
                                            self.local_ip_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address_disable.yfilter != YFilter.not_set or
                                            self.local_ip_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address_disable.is_set or self.local_address_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address_disable.get_name_leafdata())
                                        if (self.local_ip_address.is_set or self.local_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ip_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-address-disable" or name == "local-ip-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address-disable"):
                                            self.local_address_disable = value
                                            self.local_address_disable.value_namespace = name_space
                                            self.local_address_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ip-address"):
                                            self.local_ip_address = value
                                            self.local_ip_address.value_namespace = name_space
                                            self.local_ip_address.value_namespace_prefix = name_space_prefix


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "neighbor"

                                        self.bmp_activate = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates, self).__setattr__(name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"

                                            self.server_id = YLeaf(YType.uint32, "server-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("server_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.server_id.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.server_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bmp-activate" + "[server-id='" + self.server_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.server_id.is_set or self.server_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.server_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "server-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "server-id"):
                                                self.server_id = value
                                                self.server_id.value_namespace = name_space
                                                self.server_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bmp_activate:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bmp_activate:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmp-activates" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bmp-activate"):
                                            for c in self.bmp_activate:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bmp_activate.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bmp-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "neighbor"

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("max_hop_count",
                                                        "mpls_deactivation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.max_hop_count.is_set or
                                            self.mpls_deactivation.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.max_hop_count.yfilter != YFilter.not_set or
                                            self.mpls_deactivation.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ebgp-multihop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.max_hop_count.is_set or self.max_hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.max_hop_count.get_name_leafdata())
                                        if (self.mpls_deactivation.is_set or self.mpls_deactivation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_deactivation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "max-hop-count" or name == "mpls-deactivation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "max-hop-count"):
                                            self.max_hop_count = value
                                            self.max_hop_count.value_namespace = name_space
                                            self.max_hop_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-deactivation"):
                                            self.mpls_deactivation = value
                                            self.mpls_deactivation.value_namespace = name_space
                                            self.mpls_deactivation.value_namespace_prefix = name_space_prefix


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "neighbor"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "neighbor"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy",
                                                        "disable",
                                                        "dual_as",
                                                        "no_prepend",
                                                        "replace_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set or
                                            self.disable.is_set or
                                            self.dual_as.is_set or
                                            self.no_prepend.is_set or
                                            self.replace_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set or
                                            self.disable.yfilter != YFilter.not_set or
                                            self.dual_as.yfilter != YFilter.not_set or
                                            self.no_prepend.yfilter != YFilter.not_set or
                                            self.replace_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())
                                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable.get_name_leafdata())
                                        if (self.dual_as.is_set or self.dual_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dual_as.get_name_leafdata())
                                        if (self.no_prepend.is_set or self.no_prepend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_prepend.get_name_leafdata())
                                        if (self.replace_as.is_set or self.replace_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.replace_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy" or name == "disable" or name == "dual-as" or name == "no-prepend" or name == "replace-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable"):
                                            self.disable = value
                                            self.disable.value_namespace = name_space
                                            self.disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dual-as"):
                                            self.dual_as = value
                                            self.dual_as.value_namespace = name_space
                                            self.dual_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-prepend"):
                                            self.no_prepend = value
                                            self.no_prepend.value_namespace = name_space
                                            self.no_prepend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "replace-as"):
                                            self.replace_as = value
                                            self.replace_as.value_namespace = name_space
                                            self.replace_as.value_namespace_prefix = name_space_prefix


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "neighbor"

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("password",
                                                        "password_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.password.is_set or
                                            self.password_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.password.yfilter != YFilter.not_set or
                                            self.password_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "password" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password.get_name_leafdata())
                                        if (self.password_disable.is_set or self.password_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "password" or name == "password-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "password"):
                                            self.password = value
                                            self.password.value_namespace = name_space
                                            self.password.value_namespace_prefix = name_space_prefix
                                        if(value_path == "password-disable"):
                                            self.password_disable = value
                                            self.password_disable.value_namespace = name_space
                                            self.password_disable.value_namespace_prefix = name_space_prefix


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "neighbor"
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("minimum_interval",
                                                        "minimum_interval_msecs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.minimum_interval.is_set or
                                            self.minimum_interval_msecs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.minimum_interval.yfilter != YFilter.not_set or
                                            self.minimum_interval_msecs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "advertisement-interval" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                        if (self.minimum_interval_msecs.is_set or self.minimum_interval_msecs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval_msecs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "minimum-interval" or name == "minimum-interval-msecs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "minimum-interval"):
                                            self.minimum_interval = value
                                            self.minimum_interval.value_namespace = name_space
                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-interval-msecs"):
                                            self.minimum_interval_msecs = value
                                            self.minimum_interval_msecs.value_namespace = name_space
                                            self.minimum_interval_msecs.value_namespace_prefix = name_space_prefix


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "neighbor"

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cluster_id_address",
                                                        "cluster_id_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cluster_id_address.is_set or
                                            self.cluster_id_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cluster_id_address.yfilter != YFilter.not_set or
                                            self.cluster_id_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-cluster-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_address.get_name_leafdata())
                                        if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cluster-id-address" or name == "cluster-id-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cluster-id-address"):
                                            self.cluster_id_address = value
                                            self.cluster_id_address.value_namespace = name_space
                                            self.cluster_id_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cluster-id-number"):
                                            self.cluster_id_number = value
                                            self.cluster_id_number.value_namespace = name_space
                                            self.cluster_id_number.value_namespace_prefix = name_space_prefix


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "neighbor"

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mss",
                                                        "tcpmss_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mss.is_set or
                                            self.tcpmss_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mss.yfilter != YFilter.not_set or
                                            self.tcpmss_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tcpmss" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mss.is_set or self.mss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mss.get_name_leafdata())
                                        if (self.tcpmss_disable.is_set or self.tcpmss_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tcpmss_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mss" or name == "tcpmss-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mss"):
                                            self.mss = value
                                            self.mss.value_namespace = name_space
                                            self.mss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tcpmss-disable"):
                                            self.tcpmss_disable = value
                                            self.tcpmss_disable.value_namespace = name_space
                                            self.tcpmss_disable.value_namespace_prefix = name_space_prefix


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "neighbor"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type",
                                                        "value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            self.value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            self.value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tos" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())
                                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "type" or name == "value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "value"):
                                            self.value = value
                                            self.value.value_namespace = name_space
                                            self.value.value_namespace_prefix = name_space_prefix


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "neighbor"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "update_in_filtering_attribute_filter_group",
                                                        "update_in_filtering_syslog_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering, self).__setattr__(name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("non_circular_buffer",
                                                            "number_of_buffers") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.non_circular_buffer.is_set or
                                                self.number_of_buffers.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.non_circular_buffer.yfilter != YFilter.not_set or
                                                self.number_of_buffers.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "update-in-filtering-message-buffers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.non_circular_buffer.is_set or self.non_circular_buffer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.non_circular_buffer.get_name_leafdata())
                                            if (self.number_of_buffers.is_set or self.number_of_buffers.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_buffers.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "non-circular-buffer" or name == "number-of-buffers"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "non-circular-buffer"):
                                                self.non_circular_buffer = value
                                                self.non_circular_buffer.value_namespace = name_space
                                                self.non_circular_buffer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-buffers"):
                                                self.number_of_buffers = value
                                                self.number_of_buffers.value_namespace = name_space
                                                self.number_of_buffers.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.update_in_filtering_attribute_filter_group.is_set or
                                            self.update_in_filtering_syslog_disable.is_set or
                                            (self.update_in_filtering_message_buffers is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set or
                                            self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set or
                                            (self.update_in_filtering_message_buffers is not None and self.update_in_filtering_message_buffers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "update-in-filtering" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.update_in_filtering_attribute_filter_group.is_set or self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_attribute_filter_group.get_name_leafdata())
                                        if (self.update_in_filtering_syslog_disable.is_set or self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_syslog_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "update-in-filtering-message-buffers"):
                                            if (self.update_in_filtering_message_buffers is None):
                                                self.update_in_filtering_message_buffers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers()
                                                self.update_in_filtering_message_buffers.parent = self
                                                self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                            return self.update_in_filtering_message_buffers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "update-in-filtering-message-buffers" or name == "enable" or name == "update-in-filtering-attribute-filter-group" or name == "update-in-filtering-syslog-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-attribute-filter-group"):
                                            self.update_in_filtering_attribute_filter_group = value
                                            self.update_in_filtering_attribute_filter_group.value_namespace = name_space
                                            self.update_in_filtering_attribute_filter_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-syslog-disable"):
                                            self.update_in_filtering_syslog_disable = value
                                            self.update_in_filtering_syslog_disable.value_namespace = name_space
                                            self.update_in_filtering_syslog_disable.value_namespace_prefix = name_space_prefix


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "neighbor"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-out" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "neighbor"

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_receive_size",
                                                        "socket_receive_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_receive_size.is_set or
                                            self.socket_receive_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_receive_size.yfilter != YFilter.not_set or
                                            self.socket_receive_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "receive-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                        if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-receive-size"):
                                            self.bgp_receive_size = value
                                            self.bgp_receive_size.value_namespace = name_space
                                            self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-receive-size"):
                                            self.socket_receive_size = value
                                            self.socket_receive_size.value_namespace = name_space
                                            self.socket_receive_size.value_namespace_prefix = name_space_prefix


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "neighbor"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-in" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "neighbor"

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_send_size",
                                                        "socket_send_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_send_size.is_set or
                                            self.socket_send_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_send_size.yfilter != YFilter.not_set or
                                            self.socket_send_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "send-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                        if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-send-size" or name == "socket-send-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-send-size"):
                                            self.bgp_send_size = value
                                            self.bgp_send_size.value_namespace = name_space
                                            self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-send-size"):
                                            self.socket_send_size = value
                                            self.socket_send_size.value_namespace = name_space
                                            self.socket_send_size.value_namespace_prefix = name_space_prefix


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "neighbor"

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("hold_time",
                                                        "keepalive_interval",
                                                        "min_accept_hold_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.hold_time.is_set or
                                            self.keepalive_interval.is_set or
                                            self.min_accept_hold_time.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.hold_time.yfilter != YFilter.not_set or
                                            self.keepalive_interval.yfilter != YFilter.not_set or
                                            self.min_accept_hold_time.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hold_time.get_name_leafdata())
                                        if (self.keepalive_interval.is_set or self.keepalive_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keepalive_interval.get_name_leafdata())
                                        if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "hold-time" or name == "keepalive-interval" or name == "min-accept-hold-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "hold-time"):
                                            self.hold_time = value
                                            self.hold_time.value_namespace = name_space
                                            self.hold_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keepalive-interval"):
                                            self.keepalive_interval = value
                                            self.keepalive_interval.value_namespace = name_space
                                            self.keepalive_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "min-accept-hold-time"):
                                            self.min_accept_hold_time = value
                                            self.min_accept_hold_time.value_namespace = name_space
                                            self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "neighbor"

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("keychain_disable",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.keychain_disable.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.keychain_disable.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "keychain" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.keychain_disable.is_set or self.keychain_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_disable.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "keychain-disable" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "keychain-disable"):
                                            self.keychain_disable = value
                                            self.keychain_disable.value_namespace = name_space
                                            self.keychain_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "graceful_maintenance_activate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance, self).__setattr__(name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("gshut_loc_pref_disable",
                                                            "local_preference") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.gshut_loc_pref_disable.is_set or
                                                self.local_preference.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.gshut_loc_pref_disable.yfilter != YFilter.not_set or
                                                self.local_preference.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-local-preference" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.gshut_loc_pref_disable.is_set or self.gshut_loc_pref_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_loc_pref_disable.get_name_leafdata())
                                            if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_preference.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "gshut-loc-pref-disable" or name == "local-preference"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "gshut-loc-pref-disable"):
                                                self.gshut_loc_pref_disable = value
                                                self.gshut_loc_pref_disable.value_namespace = name_space
                                                self.gshut_loc_pref_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-preference"):
                                                self.local_preference = value
                                                self.local_preference.value_namespace = name_space
                                                self.local_preference.value_namespace_prefix = name_space_prefix


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("as_prepends",
                                                            "gshut_prepends_disable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.as_prepends.is_set or
                                                self.gshut_prepends_disable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.as_prepends.yfilter != YFilter.not_set or
                                                self.gshut_prepends_disable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-as-prepends" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.as_prepends.is_set or self.as_prepends.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_prepends.get_name_leafdata())
                                            if (self.gshut_prepends_disable.is_set or self.gshut_prepends_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_prepends_disable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "as-prepends" or name == "gshut-prepends-disable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "as-prepends"):
                                                self.as_prepends = value
                                                self.as_prepends.value_namespace = name_space
                                                self.as_prepends.value_namespace_prefix = name_space_prefix
                                            if(value_path == "gshut-prepends-disable"):
                                                self.gshut_prepends_disable = value
                                                self.gshut_prepends_disable.value_namespace = name_space
                                                self.gshut_prepends_disable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.graceful_maintenance_activate.is_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_data()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.graceful_maintenance_activate.yfilter != YFilter.not_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_operation()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "graceful-maintenance" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.graceful_maintenance_activate.is_set or self.graceful_maintenance_activate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.graceful_maintenance_activate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "graceful-maintenance-as-prepends"):
                                            if (self.graceful_maintenance_as_prepends is None):
                                                self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                                self.graceful_maintenance_as_prepends.parent = self
                                                self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                            return self.graceful_maintenance_as_prepends

                                        if (child_yang_name == "graceful-maintenance-local-preference"):
                                            if (self.graceful_maintenance_local_preference is None):
                                                self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                                self.graceful_maintenance_local_preference.parent = self
                                                self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                            return self.graceful_maintenance_local_preference

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "graceful-maintenance-as-prepends" or name == "graceful-maintenance-local-preference" or name == "enable" or name == "graceful-maintenance-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "graceful-maintenance-activate"):
                                            self.graceful_maintenance_activate = value
                                            self.graceful_maintenance_activate.value_namespace = name_space
                                            self.graceful_maintenance_activate.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.neighbor_address.is_set or
                                        self.additional_paths_receive_capability.is_set or
                                        self.additional_paths_send_capability.is_set or
                                        self.bfd_enable_modes.is_set or
                                        self.bfd_minimum_interval.is_set or
                                        self.bfd_multiplier.is_set or
                                        self.description.is_set or
                                        self.ebgp_recv_dmz.is_set or
                                        self.ebgp_send_dmz_enable_modes.is_set or
                                        self.egress_peer_engineering.is_set or
                                        self.enforce_first_as.is_set or
                                        self.idle_watch_time.is_set or
                                        self.ignore_connected_check_ebgp.is_set or
                                        self.internal_vpn_client_ibgpce.is_set or
                                        self.max_peers.is_set or
                                        self.neighbor_graceful_restart.is_set or
                                        self.neighbor_graceful_restart_stalepath_time.is_set or
                                        self.neighbor_graceful_restart_time.is_set or
                                        self.neighbor_group_add_member.is_set or
                                        self.propagate_dmz_link_bandwidth.is_set or
                                        self.remote_as_list.is_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                        self.rpki_origin_as_validation_disable.is_set or
                                        self.session_group_add_member.is_set or
                                        self.session_open_mode.is_set or
                                        self.shutdown.is_set or
                                        self.suppress_all_capabilities.is_set or
                                        self.suppress_four_byte_as_capability.is_set or
                                        self.ttl_security.is_set or
                                        self.update_source_interface.is_set or
                                        (self.bmp_activates is not None and self.bmp_activates.has_data()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_data()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_data()) or
                                        (self.keychain is not None and self.keychain.has_data()) or
                                        (self.local_address is not None and self.local_address.has_data()) or
                                        (self.local_as is not None and self.local_as.has_data()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_data()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_data()) or
                                        (self.neighbor_afs is not None and self.neighbor_afs.has_data()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_data()) or
                                        (self.password is not None and self.password.has_data()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_data()) or
                                        (self.remote_as is not None and self.remote_as.has_data()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_data()) or
                                        (self.tcpmss is not None and self.tcpmss.has_data()) or
                                        (self.timers is not None and self.timers.has_data()) or
                                        (self.tos is not None and self.tos.has_data()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_data()) or
                                        (self.advertisement_interval is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.additional_paths_receive_capability.yfilter != YFilter.not_set or
                                        self.additional_paths_send_capability.yfilter != YFilter.not_set or
                                        self.bfd_enable_modes.yfilter != YFilter.not_set or
                                        self.bfd_minimum_interval.yfilter != YFilter.not_set or
                                        self.bfd_multiplier.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.ebgp_recv_dmz.yfilter != YFilter.not_set or
                                        self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set or
                                        self.egress_peer_engineering.yfilter != YFilter.not_set or
                                        self.enforce_first_as.yfilter != YFilter.not_set or
                                        self.idle_watch_time.yfilter != YFilter.not_set or
                                        self.ignore_connected_check_ebgp.yfilter != YFilter.not_set or
                                        self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set or
                                        self.max_peers.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_time.yfilter != YFilter.not_set or
                                        self.neighbor_group_add_member.yfilter != YFilter.not_set or
                                        self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set or
                                        self.remote_as_list.yfilter != YFilter.not_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                        self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                        self.session_group_add_member.yfilter != YFilter.not_set or
                                        self.session_open_mode.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.suppress_all_capabilities.yfilter != YFilter.not_set or
                                        self.suppress_four_byte_as_capability.yfilter != YFilter.not_set or
                                        self.ttl_security.yfilter != YFilter.not_set or
                                        self.update_source_interface.yfilter != YFilter.not_set or
                                        (self.advertisement_interval is not None and self.advertisement_interval.has_operation()) or
                                        (self.bmp_activates is not None and self.bmp_activates.has_operation()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_operation()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_operation()) or
                                        (self.keychain is not None and self.keychain.has_operation()) or
                                        (self.local_address is not None and self.local_address.has_operation()) or
                                        (self.local_as is not None and self.local_as.has_operation()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_operation()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_operation()) or
                                        (self.neighbor_afs is not None and self.neighbor_afs.has_operation()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_operation()) or
                                        (self.password is not None and self.password.has_operation()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_operation()) or
                                        (self.remote_as is not None and self.remote_as.has_operation()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_operation()) or
                                        (self.tcpmss is not None and self.tcpmss.has_operation()) or
                                        (self.timers is not None and self.timers.has_operation()) or
                                        (self.tos is not None and self.tos.has_operation()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.additional_paths_receive_capability.is_set or self.additional_paths_receive_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_receive_capability.get_name_leafdata())
                                    if (self.additional_paths_send_capability.is_set or self.additional_paths_send_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_send_capability.get_name_leafdata())
                                    if (self.bfd_enable_modes.is_set or self.bfd_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_enable_modes.get_name_leafdata())
                                    if (self.bfd_minimum_interval.is_set or self.bfd_minimum_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_minimum_interval.get_name_leafdata())
                                    if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.ebgp_recv_dmz.is_set or self.ebgp_recv_dmz.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_recv_dmz.get_name_leafdata())
                                    if (self.ebgp_send_dmz_enable_modes.is_set or self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_send_dmz_enable_modes.get_name_leafdata())
                                    if (self.egress_peer_engineering.is_set or self.egress_peer_engineering.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.egress_peer_engineering.get_name_leafdata())
                                    if (self.enforce_first_as.is_set or self.enforce_first_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enforce_first_as.get_name_leafdata())
                                    if (self.idle_watch_time.is_set or self.idle_watch_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.idle_watch_time.get_name_leafdata())
                                    if (self.ignore_connected_check_ebgp.is_set or self.ignore_connected_check_ebgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ignore_connected_check_ebgp.get_name_leafdata())
                                    if (self.internal_vpn_client_ibgpce.is_set or self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_vpn_client_ibgpce.get_name_leafdata())
                                    if (self.max_peers.is_set or self.max_peers.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_peers.get_name_leafdata())
                                    if (self.neighbor_graceful_restart.is_set or self.neighbor_graceful_restart.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_stalepath_time.is_set or self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_stalepath_time.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_time.is_set or self.neighbor_graceful_restart_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_time.get_name_leafdata())
                                    if (self.neighbor_group_add_member.is_set or self.neighbor_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_group_add_member.get_name_leafdata())
                                    if (self.propagate_dmz_link_bandwidth.is_set or self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.propagate_dmz_link_bandwidth.get_name_leafdata())
                                    if (self.remote_as_list.is_set or self.remote_as_list.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_as_list.get_name_leafdata())
                                    if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                    if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                    if (self.session_group_add_member.is_set or self.session_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_group_add_member.get_name_leafdata())
                                    if (self.session_open_mode.is_set or self.session_open_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_open_mode.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.suppress_all_capabilities.is_set or self.suppress_all_capabilities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_all_capabilities.get_name_leafdata())
                                    if (self.suppress_four_byte_as_capability.is_set or self.suppress_four_byte_as_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_four_byte_as_capability.get_name_leafdata())
                                    if (self.ttl_security.is_set or self.ttl_security.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security.get_name_leafdata())
                                    if (self.update_source_interface.is_set or self.update_source_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_source_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "advertisement-interval"):
                                        if (self.advertisement_interval is None):
                                            self.advertisement_interval = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval()
                                            self.advertisement_interval.parent = self
                                            self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                        return self.advertisement_interval

                                    if (child_yang_name == "bmp-activates"):
                                        if (self.bmp_activates is None):
                                            self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates()
                                            self.bmp_activates.parent = self
                                            self._children_name_map["bmp_activates"] = "bmp-activates"
                                        return self.bmp_activates

                                    if (child_yang_name == "ebgp-multihop"):
                                        if (self.ebgp_multihop is None):
                                            self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop()
                                            self.ebgp_multihop.parent = self
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                        return self.ebgp_multihop

                                    if (child_yang_name == "graceful-maintenance"):
                                        if (self.graceful_maintenance is None):
                                            self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        return self.graceful_maintenance

                                    if (child_yang_name == "keychain"):
                                        if (self.keychain is None):
                                            self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                        return self.keychain

                                    if (child_yang_name == "local-address"):
                                        if (self.local_address is None):
                                            self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                        return self.local_address

                                    if (child_yang_name == "local-as"):
                                        if (self.local_as is None):
                                            self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs()
                                            self.local_as.parent = self
                                            self._children_name_map["local_as"] = "local-as"
                                        return self.local_as

                                    if (child_yang_name == "msg-log-in"):
                                        if (self.msg_log_in is None):
                                            self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn()
                                            self.msg_log_in.parent = self
                                            self._children_name_map["msg_log_in"] = "msg-log-in"
                                        return self.msg_log_in

                                    if (child_yang_name == "msg-log-out"):
                                        if (self.msg_log_out is None):
                                            self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut()
                                            self.msg_log_out.parent = self
                                            self._children_name_map["msg_log_out"] = "msg-log-out"
                                        return self.msg_log_out

                                    if (child_yang_name == "neighbor-afs"):
                                        if (self.neighbor_afs is None):
                                            self.neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs()
                                            self.neighbor_afs.parent = self
                                            self._children_name_map["neighbor_afs"] = "neighbor-afs"
                                        return self.neighbor_afs

                                    if (child_yang_name == "neighbor-cluster-id"):
                                        if (self.neighbor_cluster_id is None):
                                            self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId()
                                            self.neighbor_cluster_id.parent = self
                                            self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                        return self.neighbor_cluster_id

                                    if (child_yang_name == "password"):
                                        if (self.password is None):
                                            self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"
                                        return self.password

                                    if (child_yang_name == "receive-buffer-size"):
                                        if (self.receive_buffer_size is None):
                                            self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize()
                                            self.receive_buffer_size.parent = self
                                            self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                        return self.receive_buffer_size

                                    if (child_yang_name == "remote-as"):
                                        if (self.remote_as is None):
                                            self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs()
                                            self.remote_as.parent = self
                                            self._children_name_map["remote_as"] = "remote-as"
                                        return self.remote_as

                                    if (child_yang_name == "send-buffer-size"):
                                        if (self.send_buffer_size is None):
                                            self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize()
                                            self.send_buffer_size.parent = self
                                            self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                        return self.send_buffer_size

                                    if (child_yang_name == "tcpmss"):
                                        if (self.tcpmss is None):
                                            self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss()
                                            self.tcpmss.parent = self
                                            self._children_name_map["tcpmss"] = "tcpmss"
                                        return self.tcpmss

                                    if (child_yang_name == "timers"):
                                        if (self.timers is None):
                                            self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"
                                        return self.timers

                                    if (child_yang_name == "tos"):
                                        if (self.tos is None):
                                            self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos()
                                            self.tos.parent = self
                                            self._children_name_map["tos"] = "tos"
                                        return self.tos

                                    if (child_yang_name == "update-in-filtering"):
                                        if (self.update_in_filtering is None):
                                            self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering()
                                            self.update_in_filtering.parent = self
                                            self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                        return self.update_in_filtering

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertisement-interval" or name == "bmp-activates" or name == "ebgp-multihop" or name == "graceful-maintenance" or name == "keychain" or name == "local-address" or name == "local-as" or name == "msg-log-in" or name == "msg-log-out" or name == "neighbor-afs" or name == "neighbor-cluster-id" or name == "password" or name == "receive-buffer-size" or name == "remote-as" or name == "send-buffer-size" or name == "tcpmss" or name == "timers" or name == "tos" or name == "update-in-filtering" or name == "neighbor-address" or name == "additional-paths-receive-capability" or name == "additional-paths-send-capability" or name == "bfd-enable-modes" or name == "bfd-minimum-interval" or name == "bfd-multiplier" or name == "description" or name == "ebgp-recv-dmz" or name == "ebgp-send-dmz-enable-modes" or name == "egress-peer-engineering" or name == "enforce-first-as" or name == "idle-watch-time" or name == "ignore-connected-check-ebgp" or name == "internal-vpn-client-ibgpce" or name == "max-peers" or name == "neighbor-graceful-restart" or name == "neighbor-graceful-restart-stalepath-time" or name == "neighbor-graceful-restart-time" or name == "neighbor-group-add-member" or name == "propagate-dmz-link-bandwidth" or name == "remote-as-list" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "session-group-add-member" or name == "session-open-mode" or name == "shutdown" or name == "suppress-all-capabilities" or name == "suppress-four-byte-as-capability" or name == "ttl-security" or name == "update-source-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-receive-capability"):
                                        self.additional_paths_receive_capability = value
                                        self.additional_paths_receive_capability.value_namespace = name_space
                                        self.additional_paths_receive_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-send-capability"):
                                        self.additional_paths_send_capability = value
                                        self.additional_paths_send_capability.value_namespace = name_space
                                        self.additional_paths_send_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-enable-modes"):
                                        self.bfd_enable_modes = value
                                        self.bfd_enable_modes.value_namespace = name_space
                                        self.bfd_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-minimum-interval"):
                                        self.bfd_minimum_interval = value
                                        self.bfd_minimum_interval.value_namespace = name_space
                                        self.bfd_minimum_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-multiplier"):
                                        self.bfd_multiplier = value
                                        self.bfd_multiplier.value_namespace = name_space
                                        self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-recv-dmz"):
                                        self.ebgp_recv_dmz = value
                                        self.ebgp_recv_dmz.value_namespace = name_space
                                        self.ebgp_recv_dmz.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-send-dmz-enable-modes"):
                                        self.ebgp_send_dmz_enable_modes = value
                                        self.ebgp_send_dmz_enable_modes.value_namespace = name_space
                                        self.ebgp_send_dmz_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "egress-peer-engineering"):
                                        self.egress_peer_engineering = value
                                        self.egress_peer_engineering.value_namespace = name_space
                                        self.egress_peer_engineering.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enforce-first-as"):
                                        self.enforce_first_as = value
                                        self.enforce_first_as.value_namespace = name_space
                                        self.enforce_first_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "idle-watch-time"):
                                        self.idle_watch_time = value
                                        self.idle_watch_time.value_namespace = name_space
                                        self.idle_watch_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ignore-connected-check-ebgp"):
                                        self.ignore_connected_check_ebgp = value
                                        self.ignore_connected_check_ebgp.value_namespace = name_space
                                        self.ignore_connected_check_ebgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-vpn-client-ibgpce"):
                                        self.internal_vpn_client_ibgpce = value
                                        self.internal_vpn_client_ibgpce.value_namespace = name_space
                                        self.internal_vpn_client_ibgpce.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-peers"):
                                        self.max_peers = value
                                        self.max_peers.value_namespace = name_space
                                        self.max_peers.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart"):
                                        self.neighbor_graceful_restart = value
                                        self.neighbor_graceful_restart.value_namespace = name_space
                                        self.neighbor_graceful_restart.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-stalepath-time"):
                                        self.neighbor_graceful_restart_stalepath_time = value
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-time"):
                                        self.neighbor_graceful_restart_time = value
                                        self.neighbor_graceful_restart_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-group-add-member"):
                                        self.neighbor_group_add_member = value
                                        self.neighbor_group_add_member.value_namespace = name_space
                                        self.neighbor_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "propagate-dmz-link-bandwidth"):
                                        self.propagate_dmz_link_bandwidth = value
                                        self.propagate_dmz_link_bandwidth.value_namespace = name_space
                                        self.propagate_dmz_link_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-as-list"):
                                        self.remote_as_list = value
                                        self.remote_as_list.value_namespace = name_space
                                        self.remote_as_list.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                        self.rpki_bestpath_origin_as_allow_invalid = value
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-origin-as-validation-disable"):
                                        self.rpki_origin_as_validation_disable = value
                                        self.rpki_origin_as_validation_disable.value_namespace = name_space
                                        self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-group-add-member"):
                                        self.session_group_add_member = value
                                        self.session_group_add_member.value_namespace = name_space
                                        self.session_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-open-mode"):
                                        self.session_open_mode = value
                                        self.session_open_mode.value_namespace = name_space
                                        self.session_open_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-all-capabilities"):
                                        self.suppress_all_capabilities = value
                                        self.suppress_all_capabilities.value_namespace = name_space
                                        self.suppress_all_capabilities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-four-byte-as-capability"):
                                        self.suppress_four_byte_as_capability = value
                                        self.suppress_four_byte_as_capability.value_namespace = name_space
                                        self.suppress_four_byte_as_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security"):
                                        self.ttl_security = value
                                        self.ttl_security.value_namespace = name_space
                                        self.ttl_security.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-source-interface"):
                                        self.update_source_interface = value
                                        self.update_source_interface.value_namespace = name_space
                                        self.update_source_interface.value_namespace_prefix = name_space_prefix


                            class NeighborPrefixLength(Entity):
                                """
                                A particular BGP peer
                                
                                .. attribute:: prefix_length  <key>
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..127
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgpce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut>`
                                
                                .. attribute:: neighbor_afs
                                
                                	BGP neighbor AF configuration table
                                	**type**\:   :py:class:`NeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength, self).__init__()

                                    self.yang_name = "neighbor-prefix-length"
                                    self.yang_parent_name = "neighbors"

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgpce = YLeaf(YType.boolean, "internal-vpn-client-ibgpce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs()
                                    self.neighbor_afs.parent = self
                                    self._children_name_map["neighbor_afs"] = "neighbor-afs"
                                    self._children_yang_names.add("neighbor-afs")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix_length",
                                                    "neighbor_address",
                                                    "additional_paths_receive_capability",
                                                    "additional_paths_send_capability",
                                                    "bfd_enable_modes",
                                                    "bfd_minimum_interval",
                                                    "bfd_multiplier",
                                                    "description",
                                                    "ebgp_recv_dmz",
                                                    "ebgp_send_dmz_enable_modes",
                                                    "egress_peer_engineering",
                                                    "enforce_first_as",
                                                    "idle_watch_time",
                                                    "ignore_connected_check_ebgp",
                                                    "internal_vpn_client_ibgpce",
                                                    "max_peers",
                                                    "neighbor_graceful_restart",
                                                    "neighbor_graceful_restart_stalepath_time",
                                                    "neighbor_graceful_restart_time",
                                                    "neighbor_group_add_member",
                                                    "propagate_dmz_link_bandwidth",
                                                    "remote_as_list",
                                                    "rpki_bestpath_origin_as_allow_invalid",
                                                    "rpki_origin_as_validation_disable",
                                                    "session_group_add_member",
                                                    "session_open_mode",
                                                    "shutdown",
                                                    "suppress_all_capabilities",
                                                    "suppress_four_byte_as_capability",
                                                    "ttl_security",
                                                    "update_source_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength, self).__setattr__(name, value)


                                class NeighborAfs(Entity):
                                    """
                                    BGP neighbor AF configuration table
                                    
                                    .. attribute:: neighbor_af
                                    
                                    	Address family type of neighbor
                                    	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs, self).__init__()

                                        self.yang_name = "neighbor-afs"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.neighbor_af = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs, self).__setattr__(name, value)


                                    class NeighborAf(Entity):
                                        """
                                        Address family type of neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpnevpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_l2vpnevpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf, self).__init__()

                                            self.yang_name = "neighbor-af"
                                            self.yang_parent_name = "neighbor-afs"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn()
                                            self.advertise_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                            self._children_yang_names.add("advertise-l2vpnevpn")

                                            self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn()
                                            self.advertise_local_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                            self._children_yang_names.add("advertise-local-l2vpnevpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "accept_own",
                                                            "accept_route_legacy_rt",
                                                            "activate",
                                                            "advertise_local_labeled_route",
                                                            "advertise_orf",
                                                            "advertise_permanent_network",
                                                            "af_group",
                                                            "aigp",
                                                            "aigp_send_med",
                                                            "allow_as_in",
                                                            "as_override",
                                                            "default_weight",
                                                            "encapsulation_type",
                                                            "flowspec_validation",
                                                            "l2vpn_signalling",
                                                            "multipath",
                                                            "neighbor_af_long_lived_graceful_restart_capable",
                                                            "next_hop_self",
                                                            "next_hop_unchanged",
                                                            "next_hop_unchanged_multipath",
                                                            "prefix_orf_policy",
                                                            "route_policy_in",
                                                            "route_policy_out",
                                                            "route_reflector_client",
                                                            "rpki_bestpath_origin_as_allow_invalid",
                                                            "rpki_origin_as_validation_disable",
                                                            "send_community_ebgp",
                                                            "send_community_ebgp_graceful_shutdown",
                                                            "send_ext_community_ebgp",
                                                            "send_multicast_attr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf, self).__setattr__(name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cost_community_id",
                                                                "cost_community_poi_type",
                                                                "enable",
                                                                "transitive") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cost_community_id.is_set or
                                                    self.cost_community_poi_type.is_set or
                                                    self.enable.is_set or
                                                    self.transitive.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cost_community_id.yfilter != YFilter.not_set or
                                                    self.cost_community_poi_type.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.transitive.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "aigp-cost-community" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cost_community_id.is_set or self.cost_community_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_id.get_name_leafdata())
                                                if (self.cost_community_poi_type.is_set or self.cost_community_poi_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_poi_type.get_name_leafdata())
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.transitive.is_set or self.transitive.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.transitive.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cost-community-id" or name == "cost-community-poi-type" or name == "enable" or name == "transitive"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cost-community-id"):
                                                    self.cost_community_id = value
                                                    self.cost_community_id.value_namespace = name_space
                                                    self.cost_community_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost-community-poi-type"):
                                                    self.cost_community_poi_type = value
                                                    self.cost_community_poi_type.value_namespace = name_space
                                                    self.cost_community_poi_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "transitive"):
                                                    self.transitive = value
                                                    self.transitive.value_namespace = name_space
                                                    self.transitive.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-disable" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("discard_extra_paths",
                                                                "prefix_limit",
                                                                "restart_time",
                                                                "warning_only",
                                                                "warning_percentage") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.discard_extra_paths.is_set or
                                                    self.prefix_limit.is_set or
                                                    self.restart_time.is_set or
                                                    self.warning_only.is_set or
                                                    self.warning_percentage.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.discard_extra_paths.yfilter != YFilter.not_set or
                                                    self.prefix_limit.yfilter != YFilter.not_set or
                                                    self.restart_time.yfilter != YFilter.not_set or
                                                    self.warning_only.yfilter != YFilter.not_set or
                                                    self.warning_percentage.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-prefixes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.discard_extra_paths.is_set or self.discard_extra_paths.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.discard_extra_paths.get_name_leafdata())
                                                if (self.prefix_limit.is_set or self.prefix_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_limit.get_name_leafdata())
                                                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.restart_time.get_name_leafdata())
                                                if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_only.get_name_leafdata())
                                                if (self.warning_percentage.is_set or self.warning_percentage.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_percentage.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "discard-extra-paths" or name == "prefix-limit" or name == "restart-time" or name == "warning-only" or name == "warning-percentage"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "discard-extra-paths"):
                                                    self.discard_extra_paths = value
                                                    self.discard_extra_paths.value_namespace = name_space
                                                    self.discard_extra_paths.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-limit"):
                                                    self.prefix_limit = value
                                                    self.prefix_limit.value_namespace = name_space
                                                    self.prefix_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "restart-time"):
                                                    self.restart_time = value
                                                    self.restart_time.value_namespace = name_space
                                                    self.restart_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-only"):
                                                    self.warning_only = value
                                                    self.warning_only.value_namespace = name_space
                                                    self.warning_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-percentage"):
                                                    self.warning_percentage = value
                                                    self.warning_percentage.value_namespace = name_space
                                                    self.warning_percentage.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path-inbound" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseL2Vpnevpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-l2vpnevpn"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalL2Vpnevpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpnevpn"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "neighbor-af"

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("stale_time_accept",
                                                                "stale_time_send") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.stale_time_accept.is_set or
                                                    self.stale_time_send.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.stale_time_accept.yfilter != YFilter.not_set or
                                                    self.stale_time_send.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-af-long-lived-graceful-restart-stale-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.stale_time_accept.is_set or self.stale_time_accept.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_accept.get_name_leafdata())
                                                if (self.stale_time_send.is_set or self.stale_time_send.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_send.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "stale-time-accept" or name == "stale-time-send"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "stale-time-accept"):
                                                    self.stale_time_accept = value
                                                    self.stale_time_accept.value_namespace = name_space
                                                    self.stale_time_accept.value_namespace_prefix = name_space_prefix
                                                if(value_path == "stale-time-send"):
                                                    self.stale_time_send = value
                                                    self.stale_time_send.value_namespace = name_space
                                                    self.stale_time_send.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "neighbor-af"

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("import_reoriginate",
                                                                "import_reoriginate_stitching",
                                                                "import_stitching") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.import_reoriginate.is_set or
                                                    self.import_reoriginate_stitching.is_set or
                                                    self.import_stitching.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.import_reoriginate.yfilter != YFilter.not_set or
                                                    self.import_reoriginate_stitching.yfilter != YFilter.not_set or
                                                    self.import_stitching.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "import" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.import_reoriginate.is_set or self.import_reoriginate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate.get_name_leafdata())
                                                if (self.import_reoriginate_stitching.is_set or self.import_reoriginate_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate_stitching.get_name_leafdata())
                                                if (self.import_stitching.is_set or self.import_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_stitching.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "import-reoriginate" or name == "import-reoriginate-stitching" or name == "import-stitching"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "import-reoriginate"):
                                                    self.import_reoriginate = value
                                                    self.import_reoriginate.value_namespace = name_space
                                                    self.import_reoriginate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-reoriginate-stitching"):
                                                    self.import_reoriginate_stitching = value
                                                    self.import_reoriginate_stitching.value_namespace = name_space
                                                    self.import_reoriginate_stitching.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-stitching"):
                                                    self.import_stitching = value
                                                    self.import_stitching.value_namespace = name_space
                                                    self.import_stitching.value_namespace_prefix = name_space_prefix


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor-af"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "default-originate" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "neighbor-af"

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("inbound_soft",
                                                                "soft_always") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.inbound_soft.is_set or
                                                    self.soft_always.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.inbound_soft.yfilter != YFilter.not_set or
                                                    self.soft_always.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "soft-reconfiguration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.inbound_soft.is_set or self.inbound_soft.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.inbound_soft.get_name_leafdata())
                                                if (self.soft_always.is_set or self.soft_always.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.soft_always.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "inbound-soft" or name == "soft-always"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "inbound-soft"):
                                                    self.inbound_soft = value
                                                    self.inbound_soft.value_namespace = name_space
                                                    self.inbound_soft.value_namespace_prefix = name_space_prefix
                                                if(value_path == "soft-always"):
                                                    self.soft_always = value
                                                    self.soft_always.value_namespace = name_space
                                                    self.soft_always.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.accept_own.is_set or
                                                self.accept_route_legacy_rt.is_set or
                                                self.activate.is_set or
                                                self.advertise_local_labeled_route.is_set or
                                                self.advertise_orf.is_set or
                                                self.advertise_permanent_network.is_set or
                                                self.af_group.is_set or
                                                self.aigp.is_set or
                                                self.aigp_send_med.is_set or
                                                self.allow_as_in.is_set or
                                                self.as_override.is_set or
                                                self.default_weight.is_set or
                                                self.encapsulation_type.is_set or
                                                self.flowspec_validation.is_set or
                                                self.l2vpn_signalling.is_set or
                                                self.multipath.is_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.is_set or
                                                self.next_hop_self.is_set or
                                                self.next_hop_unchanged.is_set or
                                                self.next_hop_unchanged_multipath.is_set or
                                                self.prefix_orf_policy.is_set or
                                                self.route_policy_in.is_set or
                                                self.route_policy_out.is_set or
                                                self.route_reflector_client.is_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                                self.rpki_origin_as_validation_disable.is_set or
                                                self.send_community_ebgp.is_set or
                                                self.send_community_ebgp_graceful_shutdown.is_set or
                                                self.send_ext_community_ebgp.is_set or
                                                self.send_multicast_attr.is_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_data()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_data()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_data()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_data()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_data()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_data()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_data()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_data()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_data()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_data()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_data()) or
                                                (self.default_originate is not None and self.default_originate.has_data()) or
                                                (self.import_ is not None and self.import_.has_data()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_data()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_data()) or
                                                (self.aigp_cost_community is not None) or
                                                (self.maximum_prefixes is not None) or
                                                (self.remove_private_as_entire_as_path is not None) or
                                                (self.remove_private_as_entire_as_path_inbound is not None))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.accept_own.yfilter != YFilter.not_set or
                                                self.accept_route_legacy_rt.yfilter != YFilter.not_set or
                                                self.activate.yfilter != YFilter.not_set or
                                                self.advertise_local_labeled_route.yfilter != YFilter.not_set or
                                                self.advertise_orf.yfilter != YFilter.not_set or
                                                self.advertise_permanent_network.yfilter != YFilter.not_set or
                                                self.af_group.yfilter != YFilter.not_set or
                                                self.aigp.yfilter != YFilter.not_set or
                                                self.aigp_send_med.yfilter != YFilter.not_set or
                                                self.allow_as_in.yfilter != YFilter.not_set or
                                                self.as_override.yfilter != YFilter.not_set or
                                                self.default_weight.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.flowspec_validation.yfilter != YFilter.not_set or
                                                self.l2vpn_signalling.yfilter != YFilter.not_set or
                                                self.multipath.yfilter != YFilter.not_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set or
                                                self.next_hop_self.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged_multipath.yfilter != YFilter.not_set or
                                                self.prefix_orf_policy.yfilter != YFilter.not_set or
                                                self.route_policy_in.yfilter != YFilter.not_set or
                                                self.route_policy_out.yfilter != YFilter.not_set or
                                                self.route_reflector_client.yfilter != YFilter.not_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                                self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                                self.send_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set or
                                                self.send_ext_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_multicast_attr.yfilter != YFilter.not_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_operation()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_operation()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_operation()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_operation()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_operation()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_operation()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_operation()) or
                                                (self.aigp_cost_community is not None and self.aigp_cost_community.has_operation()) or
                                                (self.default_originate is not None and self.default_originate.has_operation()) or
                                                (self.import_ is not None and self.import_.has_operation()) or
                                                (self.maximum_prefixes is not None and self.maximum_prefixes.has_operation()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_operation()) or
                                                (self.remove_private_as_entire_as_path is not None and self.remove_private_as_entire_as_path.has_operation()) or
                                                (self.remove_private_as_entire_as_path_inbound is not None and self.remove_private_as_entire_as_path_inbound.has_operation()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.accept_own.is_set or self.accept_own.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_own.get_name_leafdata())
                                            if (self.accept_route_legacy_rt.is_set or self.accept_route_legacy_rt.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_route_legacy_rt.get_name_leafdata())
                                            if (self.activate.is_set or self.activate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.activate.get_name_leafdata())
                                            if (self.advertise_local_labeled_route.is_set or self.advertise_local_labeled_route.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_local_labeled_route.get_name_leafdata())
                                            if (self.advertise_orf.is_set or self.advertise_orf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_orf.get_name_leafdata())
                                            if (self.advertise_permanent_network.is_set or self.advertise_permanent_network.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_permanent_network.get_name_leafdata())
                                            if (self.af_group.is_set or self.af_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_group.get_name_leafdata())
                                            if (self.aigp.is_set or self.aigp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp.get_name_leafdata())
                                            if (self.aigp_send_med.is_set or self.aigp_send_med.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp_send_med.get_name_leafdata())
                                            if (self.allow_as_in.is_set or self.allow_as_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.allow_as_in.get_name_leafdata())
                                            if (self.as_override.is_set or self.as_override.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_override.get_name_leafdata())
                                            if (self.default_weight.is_set or self.default_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_weight.get_name_leafdata())
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.flowspec_validation.is_set or self.flowspec_validation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flowspec_validation.get_name_leafdata())
                                            if (self.l2vpn_signalling.is_set or self.l2vpn_signalling.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2vpn_signalling.get_name_leafdata())
                                            if (self.multipath.is_set or self.multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multipath.get_name_leafdata())
                                            if (self.neighbor_af_long_lived_graceful_restart_capable.is_set or self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_af_long_lived_graceful_restart_capable.get_name_leafdata())
                                            if (self.next_hop_self.is_set or self.next_hop_self.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_self.get_name_leafdata())
                                            if (self.next_hop_unchanged.is_set or self.next_hop_unchanged.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged.get_name_leafdata())
                                            if (self.next_hop_unchanged_multipath.is_set or self.next_hop_unchanged_multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged_multipath.get_name_leafdata())
                                            if (self.prefix_orf_policy.is_set or self.prefix_orf_policy.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_orf_policy.get_name_leafdata())
                                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                            if (self.route_reflector_client.is_set or self.route_reflector_client.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_reflector_client.get_name_leafdata())
                                            if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                            if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                            if (self.send_community_ebgp.is_set or self.send_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp.get_name_leafdata())
                                            if (self.send_community_ebgp_graceful_shutdown.is_set or self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp_graceful_shutdown.get_name_leafdata())
                                            if (self.send_ext_community_ebgp.is_set or self.send_ext_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_ext_community_ebgp.get_name_leafdata())
                                            if (self.send_multicast_attr.is_set or self.send_multicast_attr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_multicast_attr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advertise-def-imp-disable-v4"):
                                                if (self.advertise_def_imp_disable_v4 is None):
                                                    self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4()
                                                    self.advertise_def_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                                return self.advertise_def_imp_disable_v4

                                            if (child_yang_name == "advertise-def-imp-disable-v6"):
                                                if (self.advertise_def_imp_disable_v6 is None):
                                                    self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6()
                                                    self.advertise_def_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                                return self.advertise_def_imp_disable_v6

                                            if (child_yang_name == "advertise-disable"):
                                                if (self.advertise_disable is None):
                                                    self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable()
                                                    self.advertise_disable.parent = self
                                                    self._children_name_map["advertise_disable"] = "advertise-disable"
                                                return self.advertise_disable

                                            if (child_yang_name == "advertise-l2vpnevpn"):
                                                if (self.advertise_l2vpnevpn is None):
                                                    self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2Vpnevpn()
                                                    self.advertise_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                                return self.advertise_l2vpnevpn

                                            if (child_yang_name == "advertise-local-l2vpnevpn"):
                                                if (self.advertise_local_l2vpnevpn is None):
                                                    self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2Vpnevpn()
                                                    self.advertise_local_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                                return self.advertise_local_l2vpnevpn

                                            if (child_yang_name == "advertise-local-v4"):
                                                if (self.advertise_local_v4 is None):
                                                    self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4()
                                                    self.advertise_local_v4.parent = self
                                                    self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                                return self.advertise_local_v4

                                            if (child_yang_name == "advertise-local-v6"):
                                                if (self.advertise_local_v6 is None):
                                                    self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6()
                                                    self.advertise_local_v6.parent = self
                                                    self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                                return self.advertise_local_v6

                                            if (child_yang_name == "advertise-v4"):
                                                if (self.advertise_v4 is None):
                                                    self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4()
                                                    self.advertise_v4.parent = self
                                                    self._children_name_map["advertise_v4"] = "advertise-v4"
                                                return self.advertise_v4

                                            if (child_yang_name == "advertise-v6"):
                                                if (self.advertise_v6 is None):
                                                    self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6()
                                                    self.advertise_v6.parent = self
                                                    self._children_name_map["advertise_v6"] = "advertise-v6"
                                                return self.advertise_v6

                                            if (child_yang_name == "advertise-vrf-imp-disable-v4"):
                                                if (self.advertise_vrf_imp_disable_v4 is None):
                                                    self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4()
                                                    self.advertise_vrf_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                                return self.advertise_vrf_imp_disable_v4

                                            if (child_yang_name == "advertise-vrf-imp-disable-v6"):
                                                if (self.advertise_vrf_imp_disable_v6 is None):
                                                    self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6()
                                                    self.advertise_vrf_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                                return self.advertise_vrf_imp_disable_v6

                                            if (child_yang_name == "aigp-cost-community"):
                                                if (self.aigp_cost_community is None):
                                                    self.aigp_cost_community = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity()
                                                    self.aigp_cost_community.parent = self
                                                    self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                                return self.aigp_cost_community

                                            if (child_yang_name == "default-originate"):
                                                if (self.default_originate is None):
                                                    self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate()
                                                    self.default_originate.parent = self
                                                    self._children_name_map["default_originate"] = "default-originate"
                                                return self.default_originate

                                            if (child_yang_name == "import"):
                                                if (self.import_ is None):
                                                    self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_()
                                                    self.import_.parent = self
                                                    self._children_name_map["import_"] = "import"
                                                return self.import_

                                            if (child_yang_name == "maximum-prefixes"):
                                                if (self.maximum_prefixes is None):
                                                    self.maximum_prefixes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes()
                                                    self.maximum_prefixes.parent = self
                                                    self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                                return self.maximum_prefixes

                                            if (child_yang_name == "neighbor-af-long-lived-graceful-restart-stale-time"):
                                                if (self.neighbor_af_long_lived_graceful_restart_stale_time is None):
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                                    self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                return self.neighbor_af_long_lived_graceful_restart_stale_time

                                            if (child_yang_name == "remove-private-as-entire-as-path"):
                                                if (self.remove_private_as_entire_as_path is None):
                                                    self.remove_private_as_entire_as_path = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath()
                                                    self.remove_private_as_entire_as_path.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                                return self.remove_private_as_entire_as_path

                                            if (child_yang_name == "remove-private-as-entire-as-path-inbound"):
                                                if (self.remove_private_as_entire_as_path_inbound is None):
                                                    self.remove_private_as_entire_as_path_inbound = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound()
                                                    self.remove_private_as_entire_as_path_inbound.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                                return self.remove_private_as_entire_as_path_inbound

                                            if (child_yang_name == "soft-reconfiguration"):
                                                if (self.soft_reconfiguration is None):
                                                    self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration()
                                                    self.soft_reconfiguration.parent = self
                                                    self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                                return self.soft_reconfiguration

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertise-def-imp-disable-v4" or name == "advertise-def-imp-disable-v6" or name == "advertise-disable" or name == "advertise-l2vpnevpn" or name == "advertise-local-l2vpnevpn" or name == "advertise-local-v4" or name == "advertise-local-v6" or name == "advertise-v4" or name == "advertise-v6" or name == "advertise-vrf-imp-disable-v4" or name == "advertise-vrf-imp-disable-v6" or name == "aigp-cost-community" or name == "default-originate" or name == "import" or name == "maximum-prefixes" or name == "neighbor-af-long-lived-graceful-restart-stale-time" or name == "remove-private-as-entire-as-path" or name == "remove-private-as-entire-as-path-inbound" or name == "soft-reconfiguration" or name == "af-name" or name == "accept-own" or name == "accept-route-legacy-rt" or name == "activate" or name == "advertise-local-labeled-route" or name == "advertise-orf" or name == "advertise-permanent-network" or name == "af-group" or name == "aigp" or name == "aigp-send-med" or name == "allow-as-in" or name == "as-override" or name == "default-weight" or name == "encapsulation-type" or name == "flowspec-validation" or name == "l2vpn-signalling" or name == "multipath" or name == "neighbor-af-long-lived-graceful-restart-capable" or name == "next-hop-self" or name == "next-hop-unchanged" or name == "next-hop-unchanged-multipath" or name == "prefix-orf-policy" or name == "route-policy-in" or name == "route-policy-out" or name == "route-reflector-client" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "send-community-ebgp" or name == "send-community-ebgp-graceful-shutdown" or name == "send-ext-community-ebgp" or name == "send-multicast-attr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-own"):
                                                self.accept_own = value
                                                self.accept_own.value_namespace = name_space
                                                self.accept_own.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-route-legacy-rt"):
                                                self.accept_route_legacy_rt = value
                                                self.accept_route_legacy_rt.value_namespace = name_space
                                                self.accept_route_legacy_rt.value_namespace_prefix = name_space_prefix
                                            if(value_path == "activate"):
                                                self.activate = value
                                                self.activate.value_namespace = name_space
                                                self.activate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-local-labeled-route"):
                                                self.advertise_local_labeled_route = value
                                                self.advertise_local_labeled_route.value_namespace = name_space
                                                self.advertise_local_labeled_route.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-orf"):
                                                self.advertise_orf = value
                                                self.advertise_orf.value_namespace = name_space
                                                self.advertise_orf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-permanent-network"):
                                                self.advertise_permanent_network = value
                                                self.advertise_permanent_network.value_namespace = name_space
                                                self.advertise_permanent_network.value_namespace_prefix = name_space_prefix
                                            if(value_path == "af-group"):
                                                self.af_group = value
                                                self.af_group.value_namespace = name_space
                                                self.af_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp"):
                                                self.aigp = value
                                                self.aigp.value_namespace = name_space
                                                self.aigp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp-send-med"):
                                                self.aigp_send_med = value
                                                self.aigp_send_med.value_namespace = name_space
                                                self.aigp_send_med.value_namespace_prefix = name_space_prefix
                                            if(value_path == "allow-as-in"):
                                                self.allow_as_in = value
                                                self.allow_as_in.value_namespace = name_space
                                                self.allow_as_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-override"):
                                                self.as_override = value
                                                self.as_override.value_namespace = name_space
                                                self.as_override.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-weight"):
                                                self.default_weight = value
                                                self.default_weight.value_namespace = name_space
                                                self.default_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flowspec-validation"):
                                                self.flowspec_validation = value
                                                self.flowspec_validation.value_namespace = name_space
                                                self.flowspec_validation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2vpn-signalling"):
                                                self.l2vpn_signalling = value
                                                self.l2vpn_signalling.value_namespace = name_space
                                                self.l2vpn_signalling.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multipath"):
                                                self.multipath = value
                                                self.multipath.value_namespace = name_space
                                                self.multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-af-long-lived-graceful-restart-capable"):
                                                self.neighbor_af_long_lived_graceful_restart_capable = value
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace = name_space
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-self"):
                                                self.next_hop_self = value
                                                self.next_hop_self.value_namespace = name_space
                                                self.next_hop_self.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged"):
                                                self.next_hop_unchanged = value
                                                self.next_hop_unchanged.value_namespace = name_space
                                                self.next_hop_unchanged.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged-multipath"):
                                                self.next_hop_unchanged_multipath = value
                                                self.next_hop_unchanged_multipath.value_namespace = name_space
                                                self.next_hop_unchanged_multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-orf-policy"):
                                                self.prefix_orf_policy = value
                                                self.prefix_orf_policy.value_namespace = name_space
                                                self.prefix_orf_policy.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-in"):
                                                self.route_policy_in = value
                                                self.route_policy_in.value_namespace = name_space
                                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-out"):
                                                self.route_policy_out = value
                                                self.route_policy_out.value_namespace = name_space
                                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-reflector-client"):
                                                self.route_reflector_client = value
                                                self.route_reflector_client.value_namespace = name_space
                                                self.route_reflector_client.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                                self.rpki_bestpath_origin_as_allow_invalid = value
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-origin-as-validation-disable"):
                                                self.rpki_origin_as_validation_disable = value
                                                self.rpki_origin_as_validation_disable.value_namespace = name_space
                                                self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp"):
                                                self.send_community_ebgp = value
                                                self.send_community_ebgp.value_namespace = name_space
                                                self.send_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp-graceful-shutdown"):
                                                self.send_community_ebgp_graceful_shutdown = value
                                                self.send_community_ebgp_graceful_shutdown.value_namespace = name_space
                                                self.send_community_ebgp_graceful_shutdown.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-ext-community-ebgp"):
                                                self.send_ext_community_ebgp = value
                                                self.send_ext_community_ebgp.value_namespace = name_space
                                                self.send_ext_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-multicast-attr"):
                                                self.send_multicast_attr = value
                                                self.send_multicast_attr.value_namespace = name_space
                                                self.send_multicast_attr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor_af:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.neighbor_af:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-afs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-af"):
                                            for c in self.neighbor_af:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor_af.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-af"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address_disable",
                                                        "local_ip_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_address_disable.is_set or
                                            self.local_ip_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address_disable.yfilter != YFilter.not_set or
                                            self.local_ip_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address_disable.is_set or self.local_address_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address_disable.get_name_leafdata())
                                        if (self.local_ip_address.is_set or self.local_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ip_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-address-disable" or name == "local-ip-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address-disable"):
                                            self.local_address_disable = value
                                            self.local_address_disable.value_namespace = name_space
                                            self.local_address_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ip-address"):
                                            self.local_ip_address = value
                                            self.local_ip_address.value_namespace = name_space
                                            self.local_ip_address.value_namespace_prefix = name_space_prefix


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.bmp_activate = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates, self).__setattr__(name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"

                                            self.server_id = YLeaf(YType.uint32, "server-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("server_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.server_id.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.server_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bmp-activate" + "[server-id='" + self.server_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.server_id.is_set or self.server_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.server_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "server-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "server-id"):
                                                self.server_id = value
                                                self.server_id.value_namespace = name_space
                                                self.server_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bmp_activate:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bmp_activate:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmp-activates" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bmp-activate"):
                                            for c in self.bmp_activate:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bmp_activate.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bmp-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("max_hop_count",
                                                        "mpls_deactivation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.max_hop_count.is_set or
                                            self.mpls_deactivation.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.max_hop_count.yfilter != YFilter.not_set or
                                            self.mpls_deactivation.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ebgp-multihop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.max_hop_count.is_set or self.max_hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.max_hop_count.get_name_leafdata())
                                        if (self.mpls_deactivation.is_set or self.mpls_deactivation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_deactivation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "max-hop-count" or name == "mpls-deactivation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "max-hop-count"):
                                            self.max_hop_count = value
                                            self.max_hop_count.value_namespace = name_space
                                            self.max_hop_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-deactivation"):
                                            self.mpls_deactivation = value
                                            self.mpls_deactivation.value_namespace = name_space
                                            self.mpls_deactivation.value_namespace_prefix = name_space_prefix


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy",
                                                        "disable",
                                                        "dual_as",
                                                        "no_prepend",
                                                        "replace_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set or
                                            self.disable.is_set or
                                            self.dual_as.is_set or
                                            self.no_prepend.is_set or
                                            self.replace_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set or
                                            self.disable.yfilter != YFilter.not_set or
                                            self.dual_as.yfilter != YFilter.not_set or
                                            self.no_prepend.yfilter != YFilter.not_set or
                                            self.replace_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())
                                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable.get_name_leafdata())
                                        if (self.dual_as.is_set or self.dual_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dual_as.get_name_leafdata())
                                        if (self.no_prepend.is_set or self.no_prepend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_prepend.get_name_leafdata())
                                        if (self.replace_as.is_set or self.replace_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.replace_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy" or name == "disable" or name == "dual-as" or name == "no-prepend" or name == "replace-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable"):
                                            self.disable = value
                                            self.disable.value_namespace = name_space
                                            self.disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dual-as"):
                                            self.dual_as = value
                                            self.dual_as.value_namespace = name_space
                                            self.dual_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-prepend"):
                                            self.no_prepend = value
                                            self.no_prepend.value_namespace = name_space
                                            self.no_prepend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "replace-as"):
                                            self.replace_as = value
                                            self.replace_as.value_namespace = name_space
                                            self.replace_as.value_namespace_prefix = name_space_prefix


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("password",
                                                        "password_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.password.is_set or
                                            self.password_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.password.yfilter != YFilter.not_set or
                                            self.password_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "password" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password.get_name_leafdata())
                                        if (self.password_disable.is_set or self.password_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "password" or name == "password-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "password"):
                                            self.password = value
                                            self.password.value_namespace = name_space
                                            self.password.value_namespace_prefix = name_space_prefix
                                        if(value_path == "password-disable"):
                                            self.password_disable = value
                                            self.password_disable.value_namespace = name_space
                                            self.password_disable.value_namespace_prefix = name_space_prefix


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("minimum_interval",
                                                        "minimum_interval_msecs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.minimum_interval.is_set or
                                            self.minimum_interval_msecs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.minimum_interval.yfilter != YFilter.not_set or
                                            self.minimum_interval_msecs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "advertisement-interval" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                        if (self.minimum_interval_msecs.is_set or self.minimum_interval_msecs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval_msecs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "minimum-interval" or name == "minimum-interval-msecs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "minimum-interval"):
                                            self.minimum_interval = value
                                            self.minimum_interval.value_namespace = name_space
                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-interval-msecs"):
                                            self.minimum_interval_msecs = value
                                            self.minimum_interval_msecs.value_namespace = name_space
                                            self.minimum_interval_msecs.value_namespace_prefix = name_space_prefix


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cluster_id_address",
                                                        "cluster_id_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cluster_id_address.is_set or
                                            self.cluster_id_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cluster_id_address.yfilter != YFilter.not_set or
                                            self.cluster_id_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-cluster-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_address.get_name_leafdata())
                                        if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cluster-id-address" or name == "cluster-id-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cluster-id-address"):
                                            self.cluster_id_address = value
                                            self.cluster_id_address.value_namespace = name_space
                                            self.cluster_id_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cluster-id-number"):
                                            self.cluster_id_number = value
                                            self.cluster_id_number.value_namespace = name_space
                                            self.cluster_id_number.value_namespace_prefix = name_space_prefix


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mss",
                                                        "tcpmss_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mss.is_set or
                                            self.tcpmss_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mss.yfilter != YFilter.not_set or
                                            self.tcpmss_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tcpmss" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mss.is_set or self.mss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mss.get_name_leafdata())
                                        if (self.tcpmss_disable.is_set or self.tcpmss_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tcpmss_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mss" or name == "tcpmss-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mss"):
                                            self.mss = value
                                            self.mss.value_namespace = name_space
                                            self.mss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tcpmss-disable"):
                                            self.tcpmss_disable = value
                                            self.tcpmss_disable.value_namespace = name_space
                                            self.tcpmss_disable.value_namespace_prefix = name_space_prefix


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type",
                                                        "value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            self.value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            self.value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tos" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())
                                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "type" or name == "value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "value"):
                                            self.value = value
                                            self.value.value_namespace = name_space
                                            self.value.value_namespace_prefix = name_space_prefix


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "update_in_filtering_attribute_filter_group",
                                                        "update_in_filtering_syslog_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering, self).__setattr__(name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("non_circular_buffer",
                                                            "number_of_buffers") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.non_circular_buffer.is_set or
                                                self.number_of_buffers.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.non_circular_buffer.yfilter != YFilter.not_set or
                                                self.number_of_buffers.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "update-in-filtering-message-buffers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.non_circular_buffer.is_set or self.non_circular_buffer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.non_circular_buffer.get_name_leafdata())
                                            if (self.number_of_buffers.is_set or self.number_of_buffers.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_buffers.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "non-circular-buffer" or name == "number-of-buffers"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "non-circular-buffer"):
                                                self.non_circular_buffer = value
                                                self.non_circular_buffer.value_namespace = name_space
                                                self.non_circular_buffer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-buffers"):
                                                self.number_of_buffers = value
                                                self.number_of_buffers.value_namespace = name_space
                                                self.number_of_buffers.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.update_in_filtering_attribute_filter_group.is_set or
                                            self.update_in_filtering_syslog_disable.is_set or
                                            (self.update_in_filtering_message_buffers is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set or
                                            self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set or
                                            (self.update_in_filtering_message_buffers is not None and self.update_in_filtering_message_buffers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "update-in-filtering" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.update_in_filtering_attribute_filter_group.is_set or self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_attribute_filter_group.get_name_leafdata())
                                        if (self.update_in_filtering_syslog_disable.is_set or self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_syslog_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "update-in-filtering-message-buffers"):
                                            if (self.update_in_filtering_message_buffers is None):
                                                self.update_in_filtering_message_buffers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers()
                                                self.update_in_filtering_message_buffers.parent = self
                                                self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                            return self.update_in_filtering_message_buffers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "update-in-filtering-message-buffers" or name == "enable" or name == "update-in-filtering-attribute-filter-group" or name == "update-in-filtering-syslog-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-attribute-filter-group"):
                                            self.update_in_filtering_attribute_filter_group = value
                                            self.update_in_filtering_attribute_filter_group.value_namespace = name_space
                                            self.update_in_filtering_attribute_filter_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-syslog-disable"):
                                            self.update_in_filtering_syslog_disable = value
                                            self.update_in_filtering_syslog_disable.value_namespace = name_space
                                            self.update_in_filtering_syslog_disable.value_namespace_prefix = name_space_prefix


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-out" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_receive_size",
                                                        "socket_receive_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_receive_size.is_set or
                                            self.socket_receive_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_receive_size.yfilter != YFilter.not_set or
                                            self.socket_receive_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "receive-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                        if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-receive-size"):
                                            self.bgp_receive_size = value
                                            self.bgp_receive_size.value_namespace = name_space
                                            self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-receive-size"):
                                            self.socket_receive_size = value
                                            self.socket_receive_size.value_namespace = name_space
                                            self.socket_receive_size.value_namespace_prefix = name_space_prefix


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-in" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_send_size",
                                                        "socket_send_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_send_size.is_set or
                                            self.socket_send_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_send_size.yfilter != YFilter.not_set or
                                            self.socket_send_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "send-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                        if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-send-size" or name == "socket-send-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-send-size"):
                                            self.bgp_send_size = value
                                            self.bgp_send_size.value_namespace = name_space
                                            self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-send-size"):
                                            self.socket_send_size = value
                                            self.socket_send_size.value_namespace = name_space
                                            self.socket_send_size.value_namespace_prefix = name_space_prefix


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("hold_time",
                                                        "keepalive_interval",
                                                        "min_accept_hold_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.hold_time.is_set or
                                            self.keepalive_interval.is_set or
                                            self.min_accept_hold_time.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.hold_time.yfilter != YFilter.not_set or
                                            self.keepalive_interval.yfilter != YFilter.not_set or
                                            self.min_accept_hold_time.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hold_time.get_name_leafdata())
                                        if (self.keepalive_interval.is_set or self.keepalive_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keepalive_interval.get_name_leafdata())
                                        if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "hold-time" or name == "keepalive-interval" or name == "min-accept-hold-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "hold-time"):
                                            self.hold_time = value
                                            self.hold_time.value_namespace = name_space
                                            self.hold_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keepalive-interval"):
                                            self.keepalive_interval = value
                                            self.keepalive_interval.value_namespace = name_space
                                            self.keepalive_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "min-accept-hold-time"):
                                            self.min_accept_hold_time = value
                                            self.min_accept_hold_time.value_namespace = name_space
                                            self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("keychain_disable",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.keychain_disable.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.keychain_disable.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "keychain" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.keychain_disable.is_set or self.keychain_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_disable.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "keychain-disable" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "keychain-disable"):
                                            self.keychain_disable = value
                                            self.keychain_disable.value_namespace = name_space
                                            self.keychain_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-prefix-length"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "graceful_maintenance_activate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance, self).__setattr__(name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("gshut_loc_pref_disable",
                                                            "local_preference") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.gshut_loc_pref_disable.is_set or
                                                self.local_preference.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.gshut_loc_pref_disable.yfilter != YFilter.not_set or
                                                self.local_preference.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-local-preference" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.gshut_loc_pref_disable.is_set or self.gshut_loc_pref_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_loc_pref_disable.get_name_leafdata())
                                            if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_preference.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "gshut-loc-pref-disable" or name == "local-preference"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "gshut-loc-pref-disable"):
                                                self.gshut_loc_pref_disable = value
                                                self.gshut_loc_pref_disable.value_namespace = name_space
                                                self.gshut_loc_pref_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-preference"):
                                                self.local_preference = value
                                                self.local_preference.value_namespace = name_space
                                                self.local_preference.value_namespace_prefix = name_space_prefix


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("as_prepends",
                                                            "gshut_prepends_disable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.as_prepends.is_set or
                                                self.gshut_prepends_disable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.as_prepends.yfilter != YFilter.not_set or
                                                self.gshut_prepends_disable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-as-prepends" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.as_prepends.is_set or self.as_prepends.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_prepends.get_name_leafdata())
                                            if (self.gshut_prepends_disable.is_set or self.gshut_prepends_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_prepends_disable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "as-prepends" or name == "gshut-prepends-disable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "as-prepends"):
                                                self.as_prepends = value
                                                self.as_prepends.value_namespace = name_space
                                                self.as_prepends.value_namespace_prefix = name_space_prefix
                                            if(value_path == "gshut-prepends-disable"):
                                                self.gshut_prepends_disable = value
                                                self.gshut_prepends_disable.value_namespace = name_space
                                                self.gshut_prepends_disable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.graceful_maintenance_activate.is_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_data()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.graceful_maintenance_activate.yfilter != YFilter.not_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_operation()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "graceful-maintenance" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.graceful_maintenance_activate.is_set or self.graceful_maintenance_activate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.graceful_maintenance_activate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "graceful-maintenance-as-prepends"):
                                            if (self.graceful_maintenance_as_prepends is None):
                                                self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                                self.graceful_maintenance_as_prepends.parent = self
                                                self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                            return self.graceful_maintenance_as_prepends

                                        if (child_yang_name == "graceful-maintenance-local-preference"):
                                            if (self.graceful_maintenance_local_preference is None):
                                                self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                                self.graceful_maintenance_local_preference.parent = self
                                                self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                            return self.graceful_maintenance_local_preference

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "graceful-maintenance-as-prepends" or name == "graceful-maintenance-local-preference" or name == "enable" or name == "graceful-maintenance-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "graceful-maintenance-activate"):
                                            self.graceful_maintenance_activate = value
                                            self.graceful_maintenance_activate.value_namespace = name_space
                                            self.graceful_maintenance_activate.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.prefix_length.is_set or
                                        self.neighbor_address.is_set or
                                        self.additional_paths_receive_capability.is_set or
                                        self.additional_paths_send_capability.is_set or
                                        self.bfd_enable_modes.is_set or
                                        self.bfd_minimum_interval.is_set or
                                        self.bfd_multiplier.is_set or
                                        self.description.is_set or
                                        self.ebgp_recv_dmz.is_set or
                                        self.ebgp_send_dmz_enable_modes.is_set or
                                        self.egress_peer_engineering.is_set or
                                        self.enforce_first_as.is_set or
                                        self.idle_watch_time.is_set or
                                        self.ignore_connected_check_ebgp.is_set or
                                        self.internal_vpn_client_ibgpce.is_set or
                                        self.max_peers.is_set or
                                        self.neighbor_graceful_restart.is_set or
                                        self.neighbor_graceful_restart_stalepath_time.is_set or
                                        self.neighbor_graceful_restart_time.is_set or
                                        self.neighbor_group_add_member.is_set or
                                        self.propagate_dmz_link_bandwidth.is_set or
                                        self.remote_as_list.is_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                        self.rpki_origin_as_validation_disable.is_set or
                                        self.session_group_add_member.is_set or
                                        self.session_open_mode.is_set or
                                        self.shutdown.is_set or
                                        self.suppress_all_capabilities.is_set or
                                        self.suppress_four_byte_as_capability.is_set or
                                        self.ttl_security.is_set or
                                        self.update_source_interface.is_set or
                                        (self.bmp_activates is not None and self.bmp_activates.has_data()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_data()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_data()) or
                                        (self.keychain is not None and self.keychain.has_data()) or
                                        (self.local_address is not None and self.local_address.has_data()) or
                                        (self.local_as is not None and self.local_as.has_data()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_data()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_data()) or
                                        (self.neighbor_afs is not None and self.neighbor_afs.has_data()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_data()) or
                                        (self.password is not None and self.password.has_data()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_data()) or
                                        (self.remote_as is not None and self.remote_as.has_data()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_data()) or
                                        (self.tcpmss is not None and self.tcpmss.has_data()) or
                                        (self.timers is not None and self.timers.has_data()) or
                                        (self.tos is not None and self.tos.has_data()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_data()) or
                                        (self.advertisement_interval is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.additional_paths_receive_capability.yfilter != YFilter.not_set or
                                        self.additional_paths_send_capability.yfilter != YFilter.not_set or
                                        self.bfd_enable_modes.yfilter != YFilter.not_set or
                                        self.bfd_minimum_interval.yfilter != YFilter.not_set or
                                        self.bfd_multiplier.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.ebgp_recv_dmz.yfilter != YFilter.not_set or
                                        self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set or
                                        self.egress_peer_engineering.yfilter != YFilter.not_set or
                                        self.enforce_first_as.yfilter != YFilter.not_set or
                                        self.idle_watch_time.yfilter != YFilter.not_set or
                                        self.ignore_connected_check_ebgp.yfilter != YFilter.not_set or
                                        self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set or
                                        self.max_peers.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_time.yfilter != YFilter.not_set or
                                        self.neighbor_group_add_member.yfilter != YFilter.not_set or
                                        self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set or
                                        self.remote_as_list.yfilter != YFilter.not_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                        self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                        self.session_group_add_member.yfilter != YFilter.not_set or
                                        self.session_open_mode.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.suppress_all_capabilities.yfilter != YFilter.not_set or
                                        self.suppress_four_byte_as_capability.yfilter != YFilter.not_set or
                                        self.ttl_security.yfilter != YFilter.not_set or
                                        self.update_source_interface.yfilter != YFilter.not_set or
                                        (self.advertisement_interval is not None and self.advertisement_interval.has_operation()) or
                                        (self.bmp_activates is not None and self.bmp_activates.has_operation()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_operation()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_operation()) or
                                        (self.keychain is not None and self.keychain.has_operation()) or
                                        (self.local_address is not None and self.local_address.has_operation()) or
                                        (self.local_as is not None and self.local_as.has_operation()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_operation()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_operation()) or
                                        (self.neighbor_afs is not None and self.neighbor_afs.has_operation()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_operation()) or
                                        (self.password is not None and self.password.has_operation()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_operation()) or
                                        (self.remote_as is not None and self.remote_as.has_operation()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_operation()) or
                                        (self.tcpmss is not None and self.tcpmss.has_operation()) or
                                        (self.timers is not None and self.timers.has_operation()) or
                                        (self.tos is not None and self.tos.has_operation()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-prefix-length" + "[prefix-length='" + self.prefix_length.get() + "']" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.additional_paths_receive_capability.is_set or self.additional_paths_receive_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_receive_capability.get_name_leafdata())
                                    if (self.additional_paths_send_capability.is_set or self.additional_paths_send_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_send_capability.get_name_leafdata())
                                    if (self.bfd_enable_modes.is_set or self.bfd_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_enable_modes.get_name_leafdata())
                                    if (self.bfd_minimum_interval.is_set or self.bfd_minimum_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_minimum_interval.get_name_leafdata())
                                    if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.ebgp_recv_dmz.is_set or self.ebgp_recv_dmz.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_recv_dmz.get_name_leafdata())
                                    if (self.ebgp_send_dmz_enable_modes.is_set or self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_send_dmz_enable_modes.get_name_leafdata())
                                    if (self.egress_peer_engineering.is_set or self.egress_peer_engineering.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.egress_peer_engineering.get_name_leafdata())
                                    if (self.enforce_first_as.is_set or self.enforce_first_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enforce_first_as.get_name_leafdata())
                                    if (self.idle_watch_time.is_set or self.idle_watch_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.idle_watch_time.get_name_leafdata())
                                    if (self.ignore_connected_check_ebgp.is_set or self.ignore_connected_check_ebgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ignore_connected_check_ebgp.get_name_leafdata())
                                    if (self.internal_vpn_client_ibgpce.is_set or self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_vpn_client_ibgpce.get_name_leafdata())
                                    if (self.max_peers.is_set or self.max_peers.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_peers.get_name_leafdata())
                                    if (self.neighbor_graceful_restart.is_set or self.neighbor_graceful_restart.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_stalepath_time.is_set or self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_stalepath_time.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_time.is_set or self.neighbor_graceful_restart_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_time.get_name_leafdata())
                                    if (self.neighbor_group_add_member.is_set or self.neighbor_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_group_add_member.get_name_leafdata())
                                    if (self.propagate_dmz_link_bandwidth.is_set or self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.propagate_dmz_link_bandwidth.get_name_leafdata())
                                    if (self.remote_as_list.is_set or self.remote_as_list.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_as_list.get_name_leafdata())
                                    if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                    if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                    if (self.session_group_add_member.is_set or self.session_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_group_add_member.get_name_leafdata())
                                    if (self.session_open_mode.is_set or self.session_open_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_open_mode.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.suppress_all_capabilities.is_set or self.suppress_all_capabilities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_all_capabilities.get_name_leafdata())
                                    if (self.suppress_four_byte_as_capability.is_set or self.suppress_four_byte_as_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_four_byte_as_capability.get_name_leafdata())
                                    if (self.ttl_security.is_set or self.ttl_security.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security.get_name_leafdata())
                                    if (self.update_source_interface.is_set or self.update_source_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_source_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "advertisement-interval"):
                                        if (self.advertisement_interval is None):
                                            self.advertisement_interval = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval()
                                            self.advertisement_interval.parent = self
                                            self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                        return self.advertisement_interval

                                    if (child_yang_name == "bmp-activates"):
                                        if (self.bmp_activates is None):
                                            self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates()
                                            self.bmp_activates.parent = self
                                            self._children_name_map["bmp_activates"] = "bmp-activates"
                                        return self.bmp_activates

                                    if (child_yang_name == "ebgp-multihop"):
                                        if (self.ebgp_multihop is None):
                                            self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop()
                                            self.ebgp_multihop.parent = self
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                        return self.ebgp_multihop

                                    if (child_yang_name == "graceful-maintenance"):
                                        if (self.graceful_maintenance is None):
                                            self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        return self.graceful_maintenance

                                    if (child_yang_name == "keychain"):
                                        if (self.keychain is None):
                                            self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                        return self.keychain

                                    if (child_yang_name == "local-address"):
                                        if (self.local_address is None):
                                            self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                        return self.local_address

                                    if (child_yang_name == "local-as"):
                                        if (self.local_as is None):
                                            self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs()
                                            self.local_as.parent = self
                                            self._children_name_map["local_as"] = "local-as"
                                        return self.local_as

                                    if (child_yang_name == "msg-log-in"):
                                        if (self.msg_log_in is None):
                                            self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn()
                                            self.msg_log_in.parent = self
                                            self._children_name_map["msg_log_in"] = "msg-log-in"
                                        return self.msg_log_in

                                    if (child_yang_name == "msg-log-out"):
                                        if (self.msg_log_out is None):
                                            self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut()
                                            self.msg_log_out.parent = self
                                            self._children_name_map["msg_log_out"] = "msg-log-out"
                                        return self.msg_log_out

                                    if (child_yang_name == "neighbor-afs"):
                                        if (self.neighbor_afs is None):
                                            self.neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs()
                                            self.neighbor_afs.parent = self
                                            self._children_name_map["neighbor_afs"] = "neighbor-afs"
                                        return self.neighbor_afs

                                    if (child_yang_name == "neighbor-cluster-id"):
                                        if (self.neighbor_cluster_id is None):
                                            self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId()
                                            self.neighbor_cluster_id.parent = self
                                            self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                        return self.neighbor_cluster_id

                                    if (child_yang_name == "password"):
                                        if (self.password is None):
                                            self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"
                                        return self.password

                                    if (child_yang_name == "receive-buffer-size"):
                                        if (self.receive_buffer_size is None):
                                            self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize()
                                            self.receive_buffer_size.parent = self
                                            self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                        return self.receive_buffer_size

                                    if (child_yang_name == "remote-as"):
                                        if (self.remote_as is None):
                                            self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs()
                                            self.remote_as.parent = self
                                            self._children_name_map["remote_as"] = "remote-as"
                                        return self.remote_as

                                    if (child_yang_name == "send-buffer-size"):
                                        if (self.send_buffer_size is None):
                                            self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize()
                                            self.send_buffer_size.parent = self
                                            self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                        return self.send_buffer_size

                                    if (child_yang_name == "tcpmss"):
                                        if (self.tcpmss is None):
                                            self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss()
                                            self.tcpmss.parent = self
                                            self._children_name_map["tcpmss"] = "tcpmss"
                                        return self.tcpmss

                                    if (child_yang_name == "timers"):
                                        if (self.timers is None):
                                            self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"
                                        return self.timers

                                    if (child_yang_name == "tos"):
                                        if (self.tos is None):
                                            self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos()
                                            self.tos.parent = self
                                            self._children_name_map["tos"] = "tos"
                                        return self.tos

                                    if (child_yang_name == "update-in-filtering"):
                                        if (self.update_in_filtering is None):
                                            self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering()
                                            self.update_in_filtering.parent = self
                                            self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                        return self.update_in_filtering

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertisement-interval" or name == "bmp-activates" or name == "ebgp-multihop" or name == "graceful-maintenance" or name == "keychain" or name == "local-address" or name == "local-as" or name == "msg-log-in" or name == "msg-log-out" or name == "neighbor-afs" or name == "neighbor-cluster-id" or name == "password" or name == "receive-buffer-size" or name == "remote-as" or name == "send-buffer-size" or name == "tcpmss" or name == "timers" or name == "tos" or name == "update-in-filtering" or name == "prefix-length" or name == "neighbor-address" or name == "additional-paths-receive-capability" or name == "additional-paths-send-capability" or name == "bfd-enable-modes" or name == "bfd-minimum-interval" or name == "bfd-multiplier" or name == "description" or name == "ebgp-recv-dmz" or name == "ebgp-send-dmz-enable-modes" or name == "egress-peer-engineering" or name == "enforce-first-as" or name == "idle-watch-time" or name == "ignore-connected-check-ebgp" or name == "internal-vpn-client-ibgpce" or name == "max-peers" or name == "neighbor-graceful-restart" or name == "neighbor-graceful-restart-stalepath-time" or name == "neighbor-graceful-restart-time" or name == "neighbor-group-add-member" or name == "propagate-dmz-link-bandwidth" or name == "remote-as-list" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "session-group-add-member" or name == "session-open-mode" or name == "shutdown" or name == "suppress-all-capabilities" or name == "suppress-four-byte-as-capability" or name == "ttl-security" or name == "update-source-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-receive-capability"):
                                        self.additional_paths_receive_capability = value
                                        self.additional_paths_receive_capability.value_namespace = name_space
                                        self.additional_paths_receive_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-send-capability"):
                                        self.additional_paths_send_capability = value
                                        self.additional_paths_send_capability.value_namespace = name_space
                                        self.additional_paths_send_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-enable-modes"):
                                        self.bfd_enable_modes = value
                                        self.bfd_enable_modes.value_namespace = name_space
                                        self.bfd_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-minimum-interval"):
                                        self.bfd_minimum_interval = value
                                        self.bfd_minimum_interval.value_namespace = name_space
                                        self.bfd_minimum_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-multiplier"):
                                        self.bfd_multiplier = value
                                        self.bfd_multiplier.value_namespace = name_space
                                        self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-recv-dmz"):
                                        self.ebgp_recv_dmz = value
                                        self.ebgp_recv_dmz.value_namespace = name_space
                                        self.ebgp_recv_dmz.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-send-dmz-enable-modes"):
                                        self.ebgp_send_dmz_enable_modes = value
                                        self.ebgp_send_dmz_enable_modes.value_namespace = name_space
                                        self.ebgp_send_dmz_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "egress-peer-engineering"):
                                        self.egress_peer_engineering = value
                                        self.egress_peer_engineering.value_namespace = name_space
                                        self.egress_peer_engineering.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enforce-first-as"):
                                        self.enforce_first_as = value
                                        self.enforce_first_as.value_namespace = name_space
                                        self.enforce_first_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "idle-watch-time"):
                                        self.idle_watch_time = value
                                        self.idle_watch_time.value_namespace = name_space
                                        self.idle_watch_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ignore-connected-check-ebgp"):
                                        self.ignore_connected_check_ebgp = value
                                        self.ignore_connected_check_ebgp.value_namespace = name_space
                                        self.ignore_connected_check_ebgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-vpn-client-ibgpce"):
                                        self.internal_vpn_client_ibgpce = value
                                        self.internal_vpn_client_ibgpce.value_namespace = name_space
                                        self.internal_vpn_client_ibgpce.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-peers"):
                                        self.max_peers = value
                                        self.max_peers.value_namespace = name_space
                                        self.max_peers.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart"):
                                        self.neighbor_graceful_restart = value
                                        self.neighbor_graceful_restart.value_namespace = name_space
                                        self.neighbor_graceful_restart.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-stalepath-time"):
                                        self.neighbor_graceful_restart_stalepath_time = value
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-time"):
                                        self.neighbor_graceful_restart_time = value
                                        self.neighbor_graceful_restart_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-group-add-member"):
                                        self.neighbor_group_add_member = value
                                        self.neighbor_group_add_member.value_namespace = name_space
                                        self.neighbor_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "propagate-dmz-link-bandwidth"):
                                        self.propagate_dmz_link_bandwidth = value
                                        self.propagate_dmz_link_bandwidth.value_namespace = name_space
                                        self.propagate_dmz_link_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-as-list"):
                                        self.remote_as_list = value
                                        self.remote_as_list.value_namespace = name_space
                                        self.remote_as_list.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                        self.rpki_bestpath_origin_as_allow_invalid = value
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-origin-as-validation-disable"):
                                        self.rpki_origin_as_validation_disable = value
                                        self.rpki_origin_as_validation_disable.value_namespace = name_space
                                        self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-group-add-member"):
                                        self.session_group_add_member = value
                                        self.session_group_add_member.value_namespace = name_space
                                        self.session_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-open-mode"):
                                        self.session_open_mode = value
                                        self.session_open_mode.value_namespace = name_space
                                        self.session_open_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-all-capabilities"):
                                        self.suppress_all_capabilities = value
                                        self.suppress_all_capabilities.value_namespace = name_space
                                        self.suppress_all_capabilities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-four-byte-as-capability"):
                                        self.suppress_four_byte_as_capability = value
                                        self.suppress_four_byte_as_capability.value_namespace = name_space
                                        self.suppress_four_byte_as_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security"):
                                        self.ttl_security = value
                                        self.ttl_security.value_namespace = name_space
                                        self.ttl_security.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-source-interface"):
                                        self.update_source_interface = value
                                        self.update_source_interface.value_namespace = name_space
                                        self.update_source_interface.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.neighbor:
                                    if (c.has_data()):
                                        return True
                                for c in self.neighbor_prefix_length:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.neighbor:
                                    if (c.has_operation()):
                                        return True
                                for c in self.neighbor_prefix_length:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbors" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor"):
                                    for c in self.neighbor:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.neighbor.append(c)
                                    return c

                                if (child_yang_name == "neighbor-prefix-length"):
                                    for c in self.neighbor_prefix_length:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.neighbor_prefix_length.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor" or name == "neighbor-prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class NeighborGroups(Entity):
                            """
                            Neighbor\-group configuration
                            
                            .. attribute:: neighbor_group
                            
                            	A particular BGP neighbor group
                            	**type**\: list of    :py:class:`NeighborGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups, self).__init__()

                                self.yang_name = "neighbor-groups"
                                self.yang_parent_name = "bgp-entity"

                                self.neighbor_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups, self).__setattr__(name, value)


                            class NeighborGroup(Entity):
                                """
                                A particular BGP neighbor group
                                
                                .. attribute:: neighbor_group_name  <key>
                                
                                	BGP neighbor group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates>`
                                
                                .. attribute:: create
                                
                                	Create this group. Deletion of this object causes deletion of all the objects under NeighborGroup/SessionGroup associated with this object
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgpce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: neighbor_group_afs
                                
                                	BGP neighbor\-group AF configuration table
                                	**type**\:   :py:class:`NeighborGroupAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs>`
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup, self).__init__()

                                    self.yang_name = "neighbor-group"
                                    self.yang_parent_name = "neighbor-groups"

                                    self.neighbor_group_name = YLeaf(YType.str, "neighbor-group-name")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.create = YLeaf(YType.empty, "create")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgpce = YLeaf(YType.boolean, "internal-vpn-client-ibgpce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.neighbor_group_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs()
                                    self.neighbor_group_afs.parent = self
                                    self._children_name_map["neighbor_group_afs"] = "neighbor-group-afs"
                                    self._children_yang_names.add("neighbor-group-afs")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("neighbor_group_name",
                                                    "additional_paths_receive_capability",
                                                    "additional_paths_send_capability",
                                                    "bfd_enable_modes",
                                                    "bfd_minimum_interval",
                                                    "bfd_multiplier",
                                                    "create",
                                                    "description",
                                                    "ebgp_recv_dmz",
                                                    "ebgp_send_dmz_enable_modes",
                                                    "egress_peer_engineering",
                                                    "enforce_first_as",
                                                    "idle_watch_time",
                                                    "ignore_connected_check_ebgp",
                                                    "internal_vpn_client_ibgpce",
                                                    "max_peers",
                                                    "neighbor_graceful_restart",
                                                    "neighbor_graceful_restart_stalepath_time",
                                                    "neighbor_graceful_restart_time",
                                                    "neighbor_group_add_member",
                                                    "propagate_dmz_link_bandwidth",
                                                    "remote_as_list",
                                                    "rpki_bestpath_origin_as_allow_invalid",
                                                    "rpki_origin_as_validation_disable",
                                                    "session_group_add_member",
                                                    "session_open_mode",
                                                    "shutdown",
                                                    "suppress_all_capabilities",
                                                    "suppress_four_byte_as_capability",
                                                    "ttl_security",
                                                    "update_source_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup, self).__setattr__(name, value)


                                class NeighborGroupAfs(Entity):
                                    """
                                    BGP neighbor\-group AF configuration table
                                    
                                    .. attribute:: neighbor_group_af
                                    
                                    	Address family type of neighbor group
                                    	**type**\: list of    :py:class:`NeighborGroupAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs, self).__init__()

                                        self.yang_name = "neighbor-group-afs"
                                        self.yang_parent_name = "neighbor-group"

                                        self.neighbor_group_af = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs, self).__setattr__(name, value)


                                    class NeighborGroupAf(Entity):
                                        """
                                        Address family type of neighbor group
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor group address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpnevpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_l2vpnevpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf, self).__init__()

                                            self.yang_name = "neighbor-group-af"
                                            self.yang_parent_name = "neighbor-group-afs"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2Vpnevpn()
                                            self.advertise_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                            self._children_yang_names.add("advertise-l2vpnevpn")

                                            self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2Vpnevpn()
                                            self.advertise_local_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                            self._children_yang_names.add("advertise-local-l2vpnevpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "accept_own",
                                                            "accept_route_legacy_rt",
                                                            "activate",
                                                            "advertise_local_labeled_route",
                                                            "advertise_orf",
                                                            "advertise_permanent_network",
                                                            "af_group",
                                                            "aigp",
                                                            "aigp_send_med",
                                                            "allow_as_in",
                                                            "as_override",
                                                            "default_weight",
                                                            "encapsulation_type",
                                                            "flowspec_validation",
                                                            "l2vpn_signalling",
                                                            "multipath",
                                                            "neighbor_af_long_lived_graceful_restart_capable",
                                                            "next_hop_self",
                                                            "next_hop_unchanged",
                                                            "next_hop_unchanged_multipath",
                                                            "prefix_orf_policy",
                                                            "route_policy_in",
                                                            "route_policy_out",
                                                            "route_reflector_client",
                                                            "rpki_bestpath_origin_as_allow_invalid",
                                                            "rpki_origin_as_validation_disable",
                                                            "send_community_ebgp",
                                                            "send_community_ebgp_graceful_shutdown",
                                                            "send_ext_community_ebgp",
                                                            "send_multicast_attr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf, self).__setattr__(name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cost_community_id",
                                                                "cost_community_poi_type",
                                                                "enable",
                                                                "transitive") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cost_community_id.is_set or
                                                    self.cost_community_poi_type.is_set or
                                                    self.enable.is_set or
                                                    self.transitive.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cost_community_id.yfilter != YFilter.not_set or
                                                    self.cost_community_poi_type.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.transitive.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "aigp-cost-community" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cost_community_id.is_set or self.cost_community_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_id.get_name_leafdata())
                                                if (self.cost_community_poi_type.is_set or self.cost_community_poi_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_poi_type.get_name_leafdata())
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.transitive.is_set or self.transitive.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.transitive.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cost-community-id" or name == "cost-community-poi-type" or name == "enable" or name == "transitive"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cost-community-id"):
                                                    self.cost_community_id = value
                                                    self.cost_community_id.value_namespace = name_space
                                                    self.cost_community_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost-community-poi-type"):
                                                    self.cost_community_poi_type = value
                                                    self.cost_community_poi_type.value_namespace = name_space
                                                    self.cost_community_poi_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "transitive"):
                                                    self.transitive = value
                                                    self.transitive.value_namespace = name_space
                                                    self.transitive.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-disable" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("discard_extra_paths",
                                                                "prefix_limit",
                                                                "restart_time",
                                                                "warning_only",
                                                                "warning_percentage") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.discard_extra_paths.is_set or
                                                    self.prefix_limit.is_set or
                                                    self.restart_time.is_set or
                                                    self.warning_only.is_set or
                                                    self.warning_percentage.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.discard_extra_paths.yfilter != YFilter.not_set or
                                                    self.prefix_limit.yfilter != YFilter.not_set or
                                                    self.restart_time.yfilter != YFilter.not_set or
                                                    self.warning_only.yfilter != YFilter.not_set or
                                                    self.warning_percentage.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-prefixes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.discard_extra_paths.is_set or self.discard_extra_paths.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.discard_extra_paths.get_name_leafdata())
                                                if (self.prefix_limit.is_set or self.prefix_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_limit.get_name_leafdata())
                                                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.restart_time.get_name_leafdata())
                                                if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_only.get_name_leafdata())
                                                if (self.warning_percentage.is_set or self.warning_percentage.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_percentage.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "discard-extra-paths" or name == "prefix-limit" or name == "restart-time" or name == "warning-only" or name == "warning-percentage"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "discard-extra-paths"):
                                                    self.discard_extra_paths = value
                                                    self.discard_extra_paths.value_namespace = name_space
                                                    self.discard_extra_paths.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-limit"):
                                                    self.prefix_limit = value
                                                    self.prefix_limit.value_namespace = name_space
                                                    self.prefix_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "restart-time"):
                                                    self.restart_time = value
                                                    self.restart_time.value_namespace = name_space
                                                    self.restart_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-only"):
                                                    self.warning_only = value
                                                    self.warning_only.value_namespace = name_space
                                                    self.warning_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-percentage"):
                                                    self.warning_percentage = value
                                                    self.warning_percentage.value_namespace = name_space
                                                    self.warning_percentage.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path-inbound" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseL2Vpnevpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-l2vpnevpn"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalL2Vpnevpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpnevpn"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("stale_time_accept",
                                                                "stale_time_send") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.stale_time_accept.is_set or
                                                    self.stale_time_send.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.stale_time_accept.yfilter != YFilter.not_set or
                                                    self.stale_time_send.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-af-long-lived-graceful-restart-stale-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.stale_time_accept.is_set or self.stale_time_accept.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_accept.get_name_leafdata())
                                                if (self.stale_time_send.is_set or self.stale_time_send.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_send.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "stale-time-accept" or name == "stale-time-send"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "stale-time-accept"):
                                                    self.stale_time_accept = value
                                                    self.stale_time_accept.value_namespace = name_space
                                                    self.stale_time_accept.value_namespace_prefix = name_space_prefix
                                                if(value_path == "stale-time-send"):
                                                    self.stale_time_send = value
                                                    self.stale_time_send.value_namespace = name_space
                                                    self.stale_time_send.value_namespace_prefix = name_space_prefix


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("address",
                                                                "address_index",
                                                                "as_",
                                                                "as_index",
                                                                "as_xx",
                                                                "type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.address.is_set or
                                                    self.address_index.is_set or
                                                    self.as_.is_set or
                                                    self.as_index.is_set or
                                                    self.as_xx.is_set or
                                                    self.type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.address_index.yfilter != YFilter.not_set or
                                                    self.as_.yfilter != YFilter.not_set or
                                                    self.as_index.yfilter != YFilter.not_set or
                                                    self.as_xx.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "site-of-origin" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.address_index.is_set or self.address_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address_index.get_name_leafdata())
                                                if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_.get_name_leafdata())
                                                if (self.as_index.is_set or self.as_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_index.get_name_leafdata())
                                                if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_xx.get_name_leafdata())
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "address" or name == "address-index" or name == "as" or name == "as-index" or name == "as-xx" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address-index"):
                                                    self.address_index = value
                                                    self.address_index.value_namespace = name_space
                                                    self.address_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as"):
                                                    self.as_ = value
                                                    self.as_.value_namespace = name_space
                                                    self.as_.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-index"):
                                                    self.as_index = value
                                                    self.as_index.value_namespace = name_space
                                                    self.as_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-xx"):
                                                    self.as_xx = value
                                                    self.as_xx.value_namespace = name_space
                                                    self.as_xx.value_namespace_prefix = name_space_prefix
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("import_reoriginate",
                                                                "import_reoriginate_stitching",
                                                                "import_stitching") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.import_reoriginate.is_set or
                                                    self.import_reoriginate_stitching.is_set or
                                                    self.import_stitching.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.import_reoriginate.yfilter != YFilter.not_set or
                                                    self.import_reoriginate_stitching.yfilter != YFilter.not_set or
                                                    self.import_stitching.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "import" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.import_reoriginate.is_set or self.import_reoriginate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate.get_name_leafdata())
                                                if (self.import_reoriginate_stitching.is_set or self.import_reoriginate_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate_stitching.get_name_leafdata())
                                                if (self.import_stitching.is_set or self.import_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_stitching.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "import-reoriginate" or name == "import-reoriginate-stitching" or name == "import-stitching"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "import-reoriginate"):
                                                    self.import_reoriginate = value
                                                    self.import_reoriginate.value_namespace = name_space
                                                    self.import_reoriginate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-reoriginate-stitching"):
                                                    self.import_reoriginate_stitching = value
                                                    self.import_reoriginate_stitching.value_namespace = name_space
                                                    self.import_reoriginate_stitching.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-stitching"):
                                                    self.import_stitching = value
                                                    self.import_stitching.value_namespace = name_space
                                                    self.import_stitching.value_namespace_prefix = name_space_prefix


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "default-originate" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("inbound_soft",
                                                                "soft_always") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.inbound_soft.is_set or
                                                    self.soft_always.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.inbound_soft.yfilter != YFilter.not_set or
                                                    self.soft_always.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "soft-reconfiguration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.inbound_soft.is_set or self.inbound_soft.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.inbound_soft.get_name_leafdata())
                                                if (self.soft_always.is_set or self.soft_always.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.soft_always.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "inbound-soft" or name == "soft-always"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "inbound-soft"):
                                                    self.inbound_soft = value
                                                    self.inbound_soft.value_namespace = name_space
                                                    self.inbound_soft.value_namespace_prefix = name_space_prefix
                                                if(value_path == "soft-always"):
                                                    self.soft_always = value
                                                    self.soft_always.value_namespace = name_space
                                                    self.soft_always.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.accept_own.is_set or
                                                self.accept_route_legacy_rt.is_set or
                                                self.activate.is_set or
                                                self.advertise_local_labeled_route.is_set or
                                                self.advertise_orf.is_set or
                                                self.advertise_permanent_network.is_set or
                                                self.af_group.is_set or
                                                self.aigp.is_set or
                                                self.aigp_send_med.is_set or
                                                self.allow_as_in.is_set or
                                                self.as_override.is_set or
                                                self.default_weight.is_set or
                                                self.encapsulation_type.is_set or
                                                self.flowspec_validation.is_set or
                                                self.l2vpn_signalling.is_set or
                                                self.multipath.is_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.is_set or
                                                self.next_hop_self.is_set or
                                                self.next_hop_unchanged.is_set or
                                                self.next_hop_unchanged_multipath.is_set or
                                                self.prefix_orf_policy.is_set or
                                                self.route_policy_in.is_set or
                                                self.route_policy_out.is_set or
                                                self.route_reflector_client.is_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                                self.rpki_origin_as_validation_disable.is_set or
                                                self.send_community_ebgp.is_set or
                                                self.send_community_ebgp_graceful_shutdown.is_set or
                                                self.send_ext_community_ebgp.is_set or
                                                self.send_multicast_attr.is_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_data()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_data()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_data()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_data()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_data()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_data()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_data()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_data()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_data()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_data()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_data()) or
                                                (self.default_originate is not None and self.default_originate.has_data()) or
                                                (self.import_ is not None and self.import_.has_data()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_data()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_data()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_data()) or
                                                (self.aigp_cost_community is not None) or
                                                (self.maximum_prefixes is not None) or
                                                (self.remove_private_as_entire_as_path is not None) or
                                                (self.remove_private_as_entire_as_path_inbound is not None))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.accept_own.yfilter != YFilter.not_set or
                                                self.accept_route_legacy_rt.yfilter != YFilter.not_set or
                                                self.activate.yfilter != YFilter.not_set or
                                                self.advertise_local_labeled_route.yfilter != YFilter.not_set or
                                                self.advertise_orf.yfilter != YFilter.not_set or
                                                self.advertise_permanent_network.yfilter != YFilter.not_set or
                                                self.af_group.yfilter != YFilter.not_set or
                                                self.aigp.yfilter != YFilter.not_set or
                                                self.aigp_send_med.yfilter != YFilter.not_set or
                                                self.allow_as_in.yfilter != YFilter.not_set or
                                                self.as_override.yfilter != YFilter.not_set or
                                                self.default_weight.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.flowspec_validation.yfilter != YFilter.not_set or
                                                self.l2vpn_signalling.yfilter != YFilter.not_set or
                                                self.multipath.yfilter != YFilter.not_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set or
                                                self.next_hop_self.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged_multipath.yfilter != YFilter.not_set or
                                                self.prefix_orf_policy.yfilter != YFilter.not_set or
                                                self.route_policy_in.yfilter != YFilter.not_set or
                                                self.route_policy_out.yfilter != YFilter.not_set or
                                                self.route_reflector_client.yfilter != YFilter.not_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                                self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                                self.send_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set or
                                                self.send_ext_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_multicast_attr.yfilter != YFilter.not_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_operation()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_operation()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_operation()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_operation()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_operation()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_operation()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_operation()) or
                                                (self.aigp_cost_community is not None and self.aigp_cost_community.has_operation()) or
                                                (self.default_originate is not None and self.default_originate.has_operation()) or
                                                (self.import_ is not None and self.import_.has_operation()) or
                                                (self.maximum_prefixes is not None and self.maximum_prefixes.has_operation()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_operation()) or
                                                (self.remove_private_as_entire_as_path is not None and self.remove_private_as_entire_as_path.has_operation()) or
                                                (self.remove_private_as_entire_as_path_inbound is not None and self.remove_private_as_entire_as_path_inbound.has_operation()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_operation()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-group-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.accept_own.is_set or self.accept_own.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_own.get_name_leafdata())
                                            if (self.accept_route_legacy_rt.is_set or self.accept_route_legacy_rt.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_route_legacy_rt.get_name_leafdata())
                                            if (self.activate.is_set or self.activate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.activate.get_name_leafdata())
                                            if (self.advertise_local_labeled_route.is_set or self.advertise_local_labeled_route.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_local_labeled_route.get_name_leafdata())
                                            if (self.advertise_orf.is_set or self.advertise_orf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_orf.get_name_leafdata())
                                            if (self.advertise_permanent_network.is_set or self.advertise_permanent_network.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_permanent_network.get_name_leafdata())
                                            if (self.af_group.is_set or self.af_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_group.get_name_leafdata())
                                            if (self.aigp.is_set or self.aigp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp.get_name_leafdata())
                                            if (self.aigp_send_med.is_set or self.aigp_send_med.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp_send_med.get_name_leafdata())
                                            if (self.allow_as_in.is_set or self.allow_as_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.allow_as_in.get_name_leafdata())
                                            if (self.as_override.is_set or self.as_override.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_override.get_name_leafdata())
                                            if (self.default_weight.is_set or self.default_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_weight.get_name_leafdata())
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.flowspec_validation.is_set or self.flowspec_validation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flowspec_validation.get_name_leafdata())
                                            if (self.l2vpn_signalling.is_set or self.l2vpn_signalling.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2vpn_signalling.get_name_leafdata())
                                            if (self.multipath.is_set or self.multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multipath.get_name_leafdata())
                                            if (self.neighbor_af_long_lived_graceful_restart_capable.is_set or self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_af_long_lived_graceful_restart_capable.get_name_leafdata())
                                            if (self.next_hop_self.is_set or self.next_hop_self.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_self.get_name_leafdata())
                                            if (self.next_hop_unchanged.is_set or self.next_hop_unchanged.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged.get_name_leafdata())
                                            if (self.next_hop_unchanged_multipath.is_set or self.next_hop_unchanged_multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged_multipath.get_name_leafdata())
                                            if (self.prefix_orf_policy.is_set or self.prefix_orf_policy.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_orf_policy.get_name_leafdata())
                                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                            if (self.route_reflector_client.is_set or self.route_reflector_client.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_reflector_client.get_name_leafdata())
                                            if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                            if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                            if (self.send_community_ebgp.is_set or self.send_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp.get_name_leafdata())
                                            if (self.send_community_ebgp_graceful_shutdown.is_set or self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp_graceful_shutdown.get_name_leafdata())
                                            if (self.send_ext_community_ebgp.is_set or self.send_ext_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_ext_community_ebgp.get_name_leafdata())
                                            if (self.send_multicast_attr.is_set or self.send_multicast_attr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_multicast_attr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advertise-def-imp-disable-v4"):
                                                if (self.advertise_def_imp_disable_v4 is None):
                                                    self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4()
                                                    self.advertise_def_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                                return self.advertise_def_imp_disable_v4

                                            if (child_yang_name == "advertise-def-imp-disable-v6"):
                                                if (self.advertise_def_imp_disable_v6 is None):
                                                    self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6()
                                                    self.advertise_def_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                                return self.advertise_def_imp_disable_v6

                                            if (child_yang_name == "advertise-disable"):
                                                if (self.advertise_disable is None):
                                                    self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable()
                                                    self.advertise_disable.parent = self
                                                    self._children_name_map["advertise_disable"] = "advertise-disable"
                                                return self.advertise_disable

                                            if (child_yang_name == "advertise-l2vpnevpn"):
                                                if (self.advertise_l2vpnevpn is None):
                                                    self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2Vpnevpn()
                                                    self.advertise_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                                return self.advertise_l2vpnevpn

                                            if (child_yang_name == "advertise-local-l2vpnevpn"):
                                                if (self.advertise_local_l2vpnevpn is None):
                                                    self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2Vpnevpn()
                                                    self.advertise_local_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                                return self.advertise_local_l2vpnevpn

                                            if (child_yang_name == "advertise-local-v4"):
                                                if (self.advertise_local_v4 is None):
                                                    self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4()
                                                    self.advertise_local_v4.parent = self
                                                    self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                                return self.advertise_local_v4

                                            if (child_yang_name == "advertise-local-v6"):
                                                if (self.advertise_local_v6 is None):
                                                    self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6()
                                                    self.advertise_local_v6.parent = self
                                                    self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                                return self.advertise_local_v6

                                            if (child_yang_name == "advertise-v4"):
                                                if (self.advertise_v4 is None):
                                                    self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4()
                                                    self.advertise_v4.parent = self
                                                    self._children_name_map["advertise_v4"] = "advertise-v4"
                                                return self.advertise_v4

                                            if (child_yang_name == "advertise-v6"):
                                                if (self.advertise_v6 is None):
                                                    self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6()
                                                    self.advertise_v6.parent = self
                                                    self._children_name_map["advertise_v6"] = "advertise-v6"
                                                return self.advertise_v6

                                            if (child_yang_name == "advertise-vrf-imp-disable-v4"):
                                                if (self.advertise_vrf_imp_disable_v4 is None):
                                                    self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4()
                                                    self.advertise_vrf_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                                return self.advertise_vrf_imp_disable_v4

                                            if (child_yang_name == "advertise-vrf-imp-disable-v6"):
                                                if (self.advertise_vrf_imp_disable_v6 is None):
                                                    self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6()
                                                    self.advertise_vrf_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                                return self.advertise_vrf_imp_disable_v6

                                            if (child_yang_name == "aigp-cost-community"):
                                                if (self.aigp_cost_community is None):
                                                    self.aigp_cost_community = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity()
                                                    self.aigp_cost_community.parent = self
                                                    self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                                return self.aigp_cost_community

                                            if (child_yang_name == "default-originate"):
                                                if (self.default_originate is None):
                                                    self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate()
                                                    self.default_originate.parent = self
                                                    self._children_name_map["default_originate"] = "default-originate"
                                                return self.default_originate

                                            if (child_yang_name == "import"):
                                                if (self.import_ is None):
                                                    self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_()
                                                    self.import_.parent = self
                                                    self._children_name_map["import_"] = "import"
                                                return self.import_

                                            if (child_yang_name == "maximum-prefixes"):
                                                if (self.maximum_prefixes is None):
                                                    self.maximum_prefixes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes()
                                                    self.maximum_prefixes.parent = self
                                                    self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                                return self.maximum_prefixes

                                            if (child_yang_name == "neighbor-af-long-lived-graceful-restart-stale-time"):
                                                if (self.neighbor_af_long_lived_graceful_restart_stale_time is None):
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                                    self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                return self.neighbor_af_long_lived_graceful_restart_stale_time

                                            if (child_yang_name == "remove-private-as-entire-as-path"):
                                                if (self.remove_private_as_entire_as_path is None):
                                                    self.remove_private_as_entire_as_path = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath()
                                                    self.remove_private_as_entire_as_path.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                                return self.remove_private_as_entire_as_path

                                            if (child_yang_name == "remove-private-as-entire-as-path-inbound"):
                                                if (self.remove_private_as_entire_as_path_inbound is None):
                                                    self.remove_private_as_entire_as_path_inbound = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound()
                                                    self.remove_private_as_entire_as_path_inbound.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                                return self.remove_private_as_entire_as_path_inbound

                                            if (child_yang_name == "site-of-origin"):
                                                if (self.site_of_origin is None):
                                                    self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin()
                                                    self.site_of_origin.parent = self
                                                    self._children_name_map["site_of_origin"] = "site-of-origin"
                                                return self.site_of_origin

                                            if (child_yang_name == "soft-reconfiguration"):
                                                if (self.soft_reconfiguration is None):
                                                    self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration()
                                                    self.soft_reconfiguration.parent = self
                                                    self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                                return self.soft_reconfiguration

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertise-def-imp-disable-v4" or name == "advertise-def-imp-disable-v6" or name == "advertise-disable" or name == "advertise-l2vpnevpn" or name == "advertise-local-l2vpnevpn" or name == "advertise-local-v4" or name == "advertise-local-v6" or name == "advertise-v4" or name == "advertise-v6" or name == "advertise-vrf-imp-disable-v4" or name == "advertise-vrf-imp-disable-v6" or name == "aigp-cost-community" or name == "default-originate" or name == "import" or name == "maximum-prefixes" or name == "neighbor-af-long-lived-graceful-restart-stale-time" or name == "remove-private-as-entire-as-path" or name == "remove-private-as-entire-as-path-inbound" or name == "site-of-origin" or name == "soft-reconfiguration" or name == "af-name" or name == "accept-own" or name == "accept-route-legacy-rt" or name == "activate" or name == "advertise-local-labeled-route" or name == "advertise-orf" or name == "advertise-permanent-network" or name == "af-group" or name == "aigp" or name == "aigp-send-med" or name == "allow-as-in" or name == "as-override" or name == "default-weight" or name == "encapsulation-type" or name == "flowspec-validation" or name == "l2vpn-signalling" or name == "multipath" or name == "neighbor-af-long-lived-graceful-restart-capable" or name == "next-hop-self" or name == "next-hop-unchanged" or name == "next-hop-unchanged-multipath" or name == "prefix-orf-policy" or name == "route-policy-in" or name == "route-policy-out" or name == "route-reflector-client" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "send-community-ebgp" or name == "send-community-ebgp-graceful-shutdown" or name == "send-ext-community-ebgp" or name == "send-multicast-attr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-own"):
                                                self.accept_own = value
                                                self.accept_own.value_namespace = name_space
                                                self.accept_own.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-route-legacy-rt"):
                                                self.accept_route_legacy_rt = value
                                                self.accept_route_legacy_rt.value_namespace = name_space
                                                self.accept_route_legacy_rt.value_namespace_prefix = name_space_prefix
                                            if(value_path == "activate"):
                                                self.activate = value
                                                self.activate.value_namespace = name_space
                                                self.activate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-local-labeled-route"):
                                                self.advertise_local_labeled_route = value
                                                self.advertise_local_labeled_route.value_namespace = name_space
                                                self.advertise_local_labeled_route.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-orf"):
                                                self.advertise_orf = value
                                                self.advertise_orf.value_namespace = name_space
                                                self.advertise_orf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-permanent-network"):
                                                self.advertise_permanent_network = value
                                                self.advertise_permanent_network.value_namespace = name_space
                                                self.advertise_permanent_network.value_namespace_prefix = name_space_prefix
                                            if(value_path == "af-group"):
                                                self.af_group = value
                                                self.af_group.value_namespace = name_space
                                                self.af_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp"):
                                                self.aigp = value
                                                self.aigp.value_namespace = name_space
                                                self.aigp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp-send-med"):
                                                self.aigp_send_med = value
                                                self.aigp_send_med.value_namespace = name_space
                                                self.aigp_send_med.value_namespace_prefix = name_space_prefix
                                            if(value_path == "allow-as-in"):
                                                self.allow_as_in = value
                                                self.allow_as_in.value_namespace = name_space
                                                self.allow_as_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-override"):
                                                self.as_override = value
                                                self.as_override.value_namespace = name_space
                                                self.as_override.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-weight"):
                                                self.default_weight = value
                                                self.default_weight.value_namespace = name_space
                                                self.default_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flowspec-validation"):
                                                self.flowspec_validation = value
                                                self.flowspec_validation.value_namespace = name_space
                                                self.flowspec_validation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2vpn-signalling"):
                                                self.l2vpn_signalling = value
                                                self.l2vpn_signalling.value_namespace = name_space
                                                self.l2vpn_signalling.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multipath"):
                                                self.multipath = value
                                                self.multipath.value_namespace = name_space
                                                self.multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-af-long-lived-graceful-restart-capable"):
                                                self.neighbor_af_long_lived_graceful_restart_capable = value
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace = name_space
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-self"):
                                                self.next_hop_self = value
                                                self.next_hop_self.value_namespace = name_space
                                                self.next_hop_self.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged"):
                                                self.next_hop_unchanged = value
                                                self.next_hop_unchanged.value_namespace = name_space
                                                self.next_hop_unchanged.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged-multipath"):
                                                self.next_hop_unchanged_multipath = value
                                                self.next_hop_unchanged_multipath.value_namespace = name_space
                                                self.next_hop_unchanged_multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-orf-policy"):
                                                self.prefix_orf_policy = value
                                                self.prefix_orf_policy.value_namespace = name_space
                                                self.prefix_orf_policy.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-in"):
                                                self.route_policy_in = value
                                                self.route_policy_in.value_namespace = name_space
                                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-out"):
                                                self.route_policy_out = value
                                                self.route_policy_out.value_namespace = name_space
                                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-reflector-client"):
                                                self.route_reflector_client = value
                                                self.route_reflector_client.value_namespace = name_space
                                                self.route_reflector_client.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                                self.rpki_bestpath_origin_as_allow_invalid = value
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-origin-as-validation-disable"):
                                                self.rpki_origin_as_validation_disable = value
                                                self.rpki_origin_as_validation_disable.value_namespace = name_space
                                                self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp"):
                                                self.send_community_ebgp = value
                                                self.send_community_ebgp.value_namespace = name_space
                                                self.send_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp-graceful-shutdown"):
                                                self.send_community_ebgp_graceful_shutdown = value
                                                self.send_community_ebgp_graceful_shutdown.value_namespace = name_space
                                                self.send_community_ebgp_graceful_shutdown.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-ext-community-ebgp"):
                                                self.send_ext_community_ebgp = value
                                                self.send_ext_community_ebgp.value_namespace = name_space
                                                self.send_ext_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-multicast-attr"):
                                                self.send_multicast_attr = value
                                                self.send_multicast_attr.value_namespace = name_space
                                                self.send_multicast_attr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor_group_af:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.neighbor_group_af:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-group-afs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-group-af"):
                                            for c in self.neighbor_group_af:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor_group_af.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-group-af"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "neighbor-group"

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address_disable",
                                                        "local_ip_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_address_disable.is_set or
                                            self.local_ip_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address_disable.yfilter != YFilter.not_set or
                                            self.local_ip_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address_disable.is_set or self.local_address_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address_disable.get_name_leafdata())
                                        if (self.local_ip_address.is_set or self.local_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ip_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-address-disable" or name == "local-ip-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address-disable"):
                                            self.local_address_disable = value
                                            self.local_address_disable.value_namespace = name_space
                                            self.local_address_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ip-address"):
                                            self.local_ip_address = value
                                            self.local_ip_address.value_namespace = name_space
                                            self.local_ip_address.value_namespace_prefix = name_space_prefix


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "neighbor-group"

                                        self.bmp_activate = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates, self).__setattr__(name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"

                                            self.server_id = YLeaf(YType.uint32, "server-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("server_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.server_id.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.server_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bmp-activate" + "[server-id='" + self.server_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.server_id.is_set or self.server_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.server_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "server-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "server-id"):
                                                self.server_id = value
                                                self.server_id.value_namespace = name_space
                                                self.server_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bmp_activate:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bmp_activate:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmp-activates" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bmp-activate"):
                                            for c in self.bmp_activate:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bmp_activate.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bmp-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "neighbor-group"

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("max_hop_count",
                                                        "mpls_deactivation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.max_hop_count.is_set or
                                            self.mpls_deactivation.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.max_hop_count.yfilter != YFilter.not_set or
                                            self.mpls_deactivation.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ebgp-multihop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.max_hop_count.is_set or self.max_hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.max_hop_count.get_name_leafdata())
                                        if (self.mpls_deactivation.is_set or self.mpls_deactivation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_deactivation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "max-hop-count" or name == "mpls-deactivation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "max-hop-count"):
                                            self.max_hop_count = value
                                            self.max_hop_count.value_namespace = name_space
                                            self.max_hop_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-deactivation"):
                                            self.mpls_deactivation = value
                                            self.mpls_deactivation.value_namespace = name_space
                                            self.mpls_deactivation.value_namespace_prefix = name_space_prefix


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "neighbor-group"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "neighbor-group"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy",
                                                        "disable",
                                                        "dual_as",
                                                        "no_prepend",
                                                        "replace_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set or
                                            self.disable.is_set or
                                            self.dual_as.is_set or
                                            self.no_prepend.is_set or
                                            self.replace_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set or
                                            self.disable.yfilter != YFilter.not_set or
                                            self.dual_as.yfilter != YFilter.not_set or
                                            self.no_prepend.yfilter != YFilter.not_set or
                                            self.replace_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())
                                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable.get_name_leafdata())
                                        if (self.dual_as.is_set or self.dual_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dual_as.get_name_leafdata())
                                        if (self.no_prepend.is_set or self.no_prepend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_prepend.get_name_leafdata())
                                        if (self.replace_as.is_set or self.replace_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.replace_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy" or name == "disable" or name == "dual-as" or name == "no-prepend" or name == "replace-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable"):
                                            self.disable = value
                                            self.disable.value_namespace = name_space
                                            self.disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dual-as"):
                                            self.dual_as = value
                                            self.dual_as.value_namespace = name_space
                                            self.dual_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-prepend"):
                                            self.no_prepend = value
                                            self.no_prepend.value_namespace = name_space
                                            self.no_prepend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "replace-as"):
                                            self.replace_as = value
                                            self.replace_as.value_namespace = name_space
                                            self.replace_as.value_namespace_prefix = name_space_prefix


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "neighbor-group"

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("password",
                                                        "password_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.password.is_set or
                                            self.password_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.password.yfilter != YFilter.not_set or
                                            self.password_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "password" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password.get_name_leafdata())
                                        if (self.password_disable.is_set or self.password_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "password" or name == "password-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "password"):
                                            self.password = value
                                            self.password.value_namespace = name_space
                                            self.password.value_namespace_prefix = name_space_prefix
                                        if(value_path == "password-disable"):
                                            self.password_disable = value
                                            self.password_disable.value_namespace = name_space
                                            self.password_disable.value_namespace_prefix = name_space_prefix


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("minimum_interval",
                                                        "minimum_interval_msecs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.minimum_interval.is_set or
                                            self.minimum_interval_msecs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.minimum_interval.yfilter != YFilter.not_set or
                                            self.minimum_interval_msecs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "advertisement-interval" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                        if (self.minimum_interval_msecs.is_set or self.minimum_interval_msecs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval_msecs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "minimum-interval" or name == "minimum-interval-msecs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "minimum-interval"):
                                            self.minimum_interval = value
                                            self.minimum_interval.value_namespace = name_space
                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-interval-msecs"):
                                            self.minimum_interval_msecs = value
                                            self.minimum_interval_msecs.value_namespace = name_space
                                            self.minimum_interval_msecs.value_namespace_prefix = name_space_prefix


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "neighbor-group"

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cluster_id_address",
                                                        "cluster_id_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cluster_id_address.is_set or
                                            self.cluster_id_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cluster_id_address.yfilter != YFilter.not_set or
                                            self.cluster_id_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-cluster-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_address.get_name_leafdata())
                                        if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cluster-id-address" or name == "cluster-id-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cluster-id-address"):
                                            self.cluster_id_address = value
                                            self.cluster_id_address.value_namespace = name_space
                                            self.cluster_id_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cluster-id-number"):
                                            self.cluster_id_number = value
                                            self.cluster_id_number.value_namespace = name_space
                                            self.cluster_id_number.value_namespace_prefix = name_space_prefix


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "neighbor-group"

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mss",
                                                        "tcpmss_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mss.is_set or
                                            self.tcpmss_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mss.yfilter != YFilter.not_set or
                                            self.tcpmss_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tcpmss" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mss.is_set or self.mss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mss.get_name_leafdata())
                                        if (self.tcpmss_disable.is_set or self.tcpmss_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tcpmss_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mss" or name == "tcpmss-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mss"):
                                            self.mss = value
                                            self.mss.value_namespace = name_space
                                            self.mss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tcpmss-disable"):
                                            self.tcpmss_disable = value
                                            self.tcpmss_disable.value_namespace = name_space
                                            self.tcpmss_disable.value_namespace_prefix = name_space_prefix


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "neighbor-group"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type",
                                                        "value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            self.value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            self.value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tos" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())
                                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "type" or name == "value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "value"):
                                            self.value = value
                                            self.value.value_namespace = name_space
                                            self.value.value_namespace_prefix = name_space_prefix


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "neighbor-group"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "update_in_filtering_attribute_filter_group",
                                                        "update_in_filtering_syslog_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering, self).__setattr__(name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("non_circular_buffer",
                                                            "number_of_buffers") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.non_circular_buffer.is_set or
                                                self.number_of_buffers.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.non_circular_buffer.yfilter != YFilter.not_set or
                                                self.number_of_buffers.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "update-in-filtering-message-buffers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.non_circular_buffer.is_set or self.non_circular_buffer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.non_circular_buffer.get_name_leafdata())
                                            if (self.number_of_buffers.is_set or self.number_of_buffers.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_buffers.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "non-circular-buffer" or name == "number-of-buffers"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "non-circular-buffer"):
                                                self.non_circular_buffer = value
                                                self.non_circular_buffer.value_namespace = name_space
                                                self.non_circular_buffer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-buffers"):
                                                self.number_of_buffers = value
                                                self.number_of_buffers.value_namespace = name_space
                                                self.number_of_buffers.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.update_in_filtering_attribute_filter_group.is_set or
                                            self.update_in_filtering_syslog_disable.is_set or
                                            (self.update_in_filtering_message_buffers is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set or
                                            self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set or
                                            (self.update_in_filtering_message_buffers is not None and self.update_in_filtering_message_buffers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "update-in-filtering" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.update_in_filtering_attribute_filter_group.is_set or self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_attribute_filter_group.get_name_leafdata())
                                        if (self.update_in_filtering_syslog_disable.is_set or self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_syslog_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "update-in-filtering-message-buffers"):
                                            if (self.update_in_filtering_message_buffers is None):
                                                self.update_in_filtering_message_buffers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers()
                                                self.update_in_filtering_message_buffers.parent = self
                                                self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                            return self.update_in_filtering_message_buffers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "update-in-filtering-message-buffers" or name == "enable" or name == "update-in-filtering-attribute-filter-group" or name == "update-in-filtering-syslog-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-attribute-filter-group"):
                                            self.update_in_filtering_attribute_filter_group = value
                                            self.update_in_filtering_attribute_filter_group.value_namespace = name_space
                                            self.update_in_filtering_attribute_filter_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-syslog-disable"):
                                            self.update_in_filtering_syslog_disable = value
                                            self.update_in_filtering_syslog_disable.value_namespace = name_space
                                            self.update_in_filtering_syslog_disable.value_namespace_prefix = name_space_prefix


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "neighbor-group"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-out" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "neighbor-group"

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_receive_size",
                                                        "socket_receive_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_receive_size.is_set or
                                            self.socket_receive_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_receive_size.yfilter != YFilter.not_set or
                                            self.socket_receive_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "receive-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                        if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-receive-size"):
                                            self.bgp_receive_size = value
                                            self.bgp_receive_size.value_namespace = name_space
                                            self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-receive-size"):
                                            self.socket_receive_size = value
                                            self.socket_receive_size.value_namespace = name_space
                                            self.socket_receive_size.value_namespace_prefix = name_space_prefix


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "neighbor-group"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-in" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "neighbor-group"

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_send_size",
                                                        "socket_send_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_send_size.is_set or
                                            self.socket_send_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_send_size.yfilter != YFilter.not_set or
                                            self.socket_send_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "send-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                        if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-send-size" or name == "socket-send-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-send-size"):
                                            self.bgp_send_size = value
                                            self.bgp_send_size.value_namespace = name_space
                                            self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-send-size"):
                                            self.socket_send_size = value
                                            self.socket_send_size.value_namespace = name_space
                                            self.socket_send_size.value_namespace_prefix = name_space_prefix


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "neighbor-group"

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("hold_time",
                                                        "keepalive_interval",
                                                        "min_accept_hold_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.hold_time.is_set or
                                            self.keepalive_interval.is_set or
                                            self.min_accept_hold_time.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.hold_time.yfilter != YFilter.not_set or
                                            self.keepalive_interval.yfilter != YFilter.not_set or
                                            self.min_accept_hold_time.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hold_time.get_name_leafdata())
                                        if (self.keepalive_interval.is_set or self.keepalive_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keepalive_interval.get_name_leafdata())
                                        if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "hold-time" or name == "keepalive-interval" or name == "min-accept-hold-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "hold-time"):
                                            self.hold_time = value
                                            self.hold_time.value_namespace = name_space
                                            self.hold_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keepalive-interval"):
                                            self.keepalive_interval = value
                                            self.keepalive_interval.value_namespace = name_space
                                            self.keepalive_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "min-accept-hold-time"):
                                            self.min_accept_hold_time = value
                                            self.min_accept_hold_time.value_namespace = name_space
                                            self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "neighbor-group"

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("keychain_disable",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.keychain_disable.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.keychain_disable.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "keychain" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.keychain_disable.is_set or self.keychain_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_disable.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "keychain-disable" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "keychain-disable"):
                                            self.keychain_disable = value
                                            self.keychain_disable.value_namespace = name_space
                                            self.keychain_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-group"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "graceful_maintenance_activate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance, self).__setattr__(name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("gshut_loc_pref_disable",
                                                            "local_preference") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.gshut_loc_pref_disable.is_set or
                                                self.local_preference.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.gshut_loc_pref_disable.yfilter != YFilter.not_set or
                                                self.local_preference.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-local-preference" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.gshut_loc_pref_disable.is_set or self.gshut_loc_pref_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_loc_pref_disable.get_name_leafdata())
                                            if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_preference.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "gshut-loc-pref-disable" or name == "local-preference"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "gshut-loc-pref-disable"):
                                                self.gshut_loc_pref_disable = value
                                                self.gshut_loc_pref_disable.value_namespace = name_space
                                                self.gshut_loc_pref_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-preference"):
                                                self.local_preference = value
                                                self.local_preference.value_namespace = name_space
                                                self.local_preference.value_namespace_prefix = name_space_prefix


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("as_prepends",
                                                            "gshut_prepends_disable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.as_prepends.is_set or
                                                self.gshut_prepends_disable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.as_prepends.yfilter != YFilter.not_set or
                                                self.gshut_prepends_disable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-as-prepends" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.as_prepends.is_set or self.as_prepends.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_prepends.get_name_leafdata())
                                            if (self.gshut_prepends_disable.is_set or self.gshut_prepends_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_prepends_disable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "as-prepends" or name == "gshut-prepends-disable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "as-prepends"):
                                                self.as_prepends = value
                                                self.as_prepends.value_namespace = name_space
                                                self.as_prepends.value_namespace_prefix = name_space_prefix
                                            if(value_path == "gshut-prepends-disable"):
                                                self.gshut_prepends_disable = value
                                                self.gshut_prepends_disable.value_namespace = name_space
                                                self.gshut_prepends_disable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.graceful_maintenance_activate.is_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_data()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.graceful_maintenance_activate.yfilter != YFilter.not_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_operation()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "graceful-maintenance" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.graceful_maintenance_activate.is_set or self.graceful_maintenance_activate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.graceful_maintenance_activate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "graceful-maintenance-as-prepends"):
                                            if (self.graceful_maintenance_as_prepends is None):
                                                self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                                self.graceful_maintenance_as_prepends.parent = self
                                                self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                            return self.graceful_maintenance_as_prepends

                                        if (child_yang_name == "graceful-maintenance-local-preference"):
                                            if (self.graceful_maintenance_local_preference is None):
                                                self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                                self.graceful_maintenance_local_preference.parent = self
                                                self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                            return self.graceful_maintenance_local_preference

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "graceful-maintenance-as-prepends" or name == "graceful-maintenance-local-preference" or name == "enable" or name == "graceful-maintenance-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "graceful-maintenance-activate"):
                                            self.graceful_maintenance_activate = value
                                            self.graceful_maintenance_activate.value_namespace = name_space
                                            self.graceful_maintenance_activate.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.neighbor_group_name.is_set or
                                        self.additional_paths_receive_capability.is_set or
                                        self.additional_paths_send_capability.is_set or
                                        self.bfd_enable_modes.is_set or
                                        self.bfd_minimum_interval.is_set or
                                        self.bfd_multiplier.is_set or
                                        self.create.is_set or
                                        self.description.is_set or
                                        self.ebgp_recv_dmz.is_set or
                                        self.ebgp_send_dmz_enable_modes.is_set or
                                        self.egress_peer_engineering.is_set or
                                        self.enforce_first_as.is_set or
                                        self.idle_watch_time.is_set or
                                        self.ignore_connected_check_ebgp.is_set or
                                        self.internal_vpn_client_ibgpce.is_set or
                                        self.max_peers.is_set or
                                        self.neighbor_graceful_restart.is_set or
                                        self.neighbor_graceful_restart_stalepath_time.is_set or
                                        self.neighbor_graceful_restart_time.is_set or
                                        self.neighbor_group_add_member.is_set or
                                        self.propagate_dmz_link_bandwidth.is_set or
                                        self.remote_as_list.is_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                        self.rpki_origin_as_validation_disable.is_set or
                                        self.session_group_add_member.is_set or
                                        self.session_open_mode.is_set or
                                        self.shutdown.is_set or
                                        self.suppress_all_capabilities.is_set or
                                        self.suppress_four_byte_as_capability.is_set or
                                        self.ttl_security.is_set or
                                        self.update_source_interface.is_set or
                                        (self.bmp_activates is not None and self.bmp_activates.has_data()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_data()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_data()) or
                                        (self.keychain is not None and self.keychain.has_data()) or
                                        (self.local_address is not None and self.local_address.has_data()) or
                                        (self.local_as is not None and self.local_as.has_data()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_data()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_data()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_data()) or
                                        (self.neighbor_group_afs is not None and self.neighbor_group_afs.has_data()) or
                                        (self.password is not None and self.password.has_data()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_data()) or
                                        (self.remote_as is not None and self.remote_as.has_data()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_data()) or
                                        (self.tcpmss is not None and self.tcpmss.has_data()) or
                                        (self.timers is not None and self.timers.has_data()) or
                                        (self.tos is not None and self.tos.has_data()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_data()) or
                                        (self.advertisement_interval is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.neighbor_group_name.yfilter != YFilter.not_set or
                                        self.additional_paths_receive_capability.yfilter != YFilter.not_set or
                                        self.additional_paths_send_capability.yfilter != YFilter.not_set or
                                        self.bfd_enable_modes.yfilter != YFilter.not_set or
                                        self.bfd_minimum_interval.yfilter != YFilter.not_set or
                                        self.bfd_multiplier.yfilter != YFilter.not_set or
                                        self.create.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.ebgp_recv_dmz.yfilter != YFilter.not_set or
                                        self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set or
                                        self.egress_peer_engineering.yfilter != YFilter.not_set or
                                        self.enforce_first_as.yfilter != YFilter.not_set or
                                        self.idle_watch_time.yfilter != YFilter.not_set or
                                        self.ignore_connected_check_ebgp.yfilter != YFilter.not_set or
                                        self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set or
                                        self.max_peers.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_time.yfilter != YFilter.not_set or
                                        self.neighbor_group_add_member.yfilter != YFilter.not_set or
                                        self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set or
                                        self.remote_as_list.yfilter != YFilter.not_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                        self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                        self.session_group_add_member.yfilter != YFilter.not_set or
                                        self.session_open_mode.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.suppress_all_capabilities.yfilter != YFilter.not_set or
                                        self.suppress_four_byte_as_capability.yfilter != YFilter.not_set or
                                        self.ttl_security.yfilter != YFilter.not_set or
                                        self.update_source_interface.yfilter != YFilter.not_set or
                                        (self.advertisement_interval is not None and self.advertisement_interval.has_operation()) or
                                        (self.bmp_activates is not None and self.bmp_activates.has_operation()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_operation()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_operation()) or
                                        (self.keychain is not None and self.keychain.has_operation()) or
                                        (self.local_address is not None and self.local_address.has_operation()) or
                                        (self.local_as is not None and self.local_as.has_operation()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_operation()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_operation()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_operation()) or
                                        (self.neighbor_group_afs is not None and self.neighbor_group_afs.has_operation()) or
                                        (self.password is not None and self.password.has_operation()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_operation()) or
                                        (self.remote_as is not None and self.remote_as.has_operation()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_operation()) or
                                        (self.tcpmss is not None and self.tcpmss.has_operation()) or
                                        (self.timers is not None and self.timers.has_operation()) or
                                        (self.tos is not None and self.tos.has_operation()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-group" + "[neighbor-group-name='" + self.neighbor_group_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.neighbor_group_name.is_set or self.neighbor_group_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_group_name.get_name_leafdata())
                                    if (self.additional_paths_receive_capability.is_set or self.additional_paths_receive_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_receive_capability.get_name_leafdata())
                                    if (self.additional_paths_send_capability.is_set or self.additional_paths_send_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_send_capability.get_name_leafdata())
                                    if (self.bfd_enable_modes.is_set or self.bfd_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_enable_modes.get_name_leafdata())
                                    if (self.bfd_minimum_interval.is_set or self.bfd_minimum_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_minimum_interval.get_name_leafdata())
                                    if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                                    if (self.create.is_set or self.create.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.create.get_name_leafdata())
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.ebgp_recv_dmz.is_set or self.ebgp_recv_dmz.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_recv_dmz.get_name_leafdata())
                                    if (self.ebgp_send_dmz_enable_modes.is_set or self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_send_dmz_enable_modes.get_name_leafdata())
                                    if (self.egress_peer_engineering.is_set or self.egress_peer_engineering.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.egress_peer_engineering.get_name_leafdata())
                                    if (self.enforce_first_as.is_set or self.enforce_first_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enforce_first_as.get_name_leafdata())
                                    if (self.idle_watch_time.is_set or self.idle_watch_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.idle_watch_time.get_name_leafdata())
                                    if (self.ignore_connected_check_ebgp.is_set or self.ignore_connected_check_ebgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ignore_connected_check_ebgp.get_name_leafdata())
                                    if (self.internal_vpn_client_ibgpce.is_set or self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_vpn_client_ibgpce.get_name_leafdata())
                                    if (self.max_peers.is_set or self.max_peers.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_peers.get_name_leafdata())
                                    if (self.neighbor_graceful_restart.is_set or self.neighbor_graceful_restart.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_stalepath_time.is_set or self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_stalepath_time.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_time.is_set or self.neighbor_graceful_restart_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_time.get_name_leafdata())
                                    if (self.neighbor_group_add_member.is_set or self.neighbor_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_group_add_member.get_name_leafdata())
                                    if (self.propagate_dmz_link_bandwidth.is_set or self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.propagate_dmz_link_bandwidth.get_name_leafdata())
                                    if (self.remote_as_list.is_set or self.remote_as_list.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_as_list.get_name_leafdata())
                                    if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                    if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                    if (self.session_group_add_member.is_set or self.session_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_group_add_member.get_name_leafdata())
                                    if (self.session_open_mode.is_set or self.session_open_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_open_mode.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.suppress_all_capabilities.is_set or self.suppress_all_capabilities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_all_capabilities.get_name_leafdata())
                                    if (self.suppress_four_byte_as_capability.is_set or self.suppress_four_byte_as_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_four_byte_as_capability.get_name_leafdata())
                                    if (self.ttl_security.is_set or self.ttl_security.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security.get_name_leafdata())
                                    if (self.update_source_interface.is_set or self.update_source_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_source_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "advertisement-interval"):
                                        if (self.advertisement_interval is None):
                                            self.advertisement_interval = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval()
                                            self.advertisement_interval.parent = self
                                            self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                        return self.advertisement_interval

                                    if (child_yang_name == "bmp-activates"):
                                        if (self.bmp_activates is None):
                                            self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates()
                                            self.bmp_activates.parent = self
                                            self._children_name_map["bmp_activates"] = "bmp-activates"
                                        return self.bmp_activates

                                    if (child_yang_name == "ebgp-multihop"):
                                        if (self.ebgp_multihop is None):
                                            self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop()
                                            self.ebgp_multihop.parent = self
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                        return self.ebgp_multihop

                                    if (child_yang_name == "graceful-maintenance"):
                                        if (self.graceful_maintenance is None):
                                            self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        return self.graceful_maintenance

                                    if (child_yang_name == "keychain"):
                                        if (self.keychain is None):
                                            self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                        return self.keychain

                                    if (child_yang_name == "local-address"):
                                        if (self.local_address is None):
                                            self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                        return self.local_address

                                    if (child_yang_name == "local-as"):
                                        if (self.local_as is None):
                                            self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs()
                                            self.local_as.parent = self
                                            self._children_name_map["local_as"] = "local-as"
                                        return self.local_as

                                    if (child_yang_name == "msg-log-in"):
                                        if (self.msg_log_in is None):
                                            self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn()
                                            self.msg_log_in.parent = self
                                            self._children_name_map["msg_log_in"] = "msg-log-in"
                                        return self.msg_log_in

                                    if (child_yang_name == "msg-log-out"):
                                        if (self.msg_log_out is None):
                                            self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut()
                                            self.msg_log_out.parent = self
                                            self._children_name_map["msg_log_out"] = "msg-log-out"
                                        return self.msg_log_out

                                    if (child_yang_name == "neighbor-cluster-id"):
                                        if (self.neighbor_cluster_id is None):
                                            self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId()
                                            self.neighbor_cluster_id.parent = self
                                            self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                        return self.neighbor_cluster_id

                                    if (child_yang_name == "neighbor-group-afs"):
                                        if (self.neighbor_group_afs is None):
                                            self.neighbor_group_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs()
                                            self.neighbor_group_afs.parent = self
                                            self._children_name_map["neighbor_group_afs"] = "neighbor-group-afs"
                                        return self.neighbor_group_afs

                                    if (child_yang_name == "password"):
                                        if (self.password is None):
                                            self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"
                                        return self.password

                                    if (child_yang_name == "receive-buffer-size"):
                                        if (self.receive_buffer_size is None):
                                            self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize()
                                            self.receive_buffer_size.parent = self
                                            self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                        return self.receive_buffer_size

                                    if (child_yang_name == "remote-as"):
                                        if (self.remote_as is None):
                                            self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs()
                                            self.remote_as.parent = self
                                            self._children_name_map["remote_as"] = "remote-as"
                                        return self.remote_as

                                    if (child_yang_name == "send-buffer-size"):
                                        if (self.send_buffer_size is None):
                                            self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize()
                                            self.send_buffer_size.parent = self
                                            self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                        return self.send_buffer_size

                                    if (child_yang_name == "tcpmss"):
                                        if (self.tcpmss is None):
                                            self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss()
                                            self.tcpmss.parent = self
                                            self._children_name_map["tcpmss"] = "tcpmss"
                                        return self.tcpmss

                                    if (child_yang_name == "timers"):
                                        if (self.timers is None):
                                            self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"
                                        return self.timers

                                    if (child_yang_name == "tos"):
                                        if (self.tos is None):
                                            self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos()
                                            self.tos.parent = self
                                            self._children_name_map["tos"] = "tos"
                                        return self.tos

                                    if (child_yang_name == "update-in-filtering"):
                                        if (self.update_in_filtering is None):
                                            self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering()
                                            self.update_in_filtering.parent = self
                                            self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                        return self.update_in_filtering

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertisement-interval" or name == "bmp-activates" or name == "ebgp-multihop" or name == "graceful-maintenance" or name == "keychain" or name == "local-address" or name == "local-as" or name == "msg-log-in" or name == "msg-log-out" or name == "neighbor-cluster-id" or name == "neighbor-group-afs" or name == "password" or name == "receive-buffer-size" or name == "remote-as" or name == "send-buffer-size" or name == "tcpmss" or name == "timers" or name == "tos" or name == "update-in-filtering" or name == "neighbor-group-name" or name == "additional-paths-receive-capability" or name == "additional-paths-send-capability" or name == "bfd-enable-modes" or name == "bfd-minimum-interval" or name == "bfd-multiplier" or name == "create" or name == "description" or name == "ebgp-recv-dmz" or name == "ebgp-send-dmz-enable-modes" or name == "egress-peer-engineering" or name == "enforce-first-as" or name == "idle-watch-time" or name == "ignore-connected-check-ebgp" or name == "internal-vpn-client-ibgpce" or name == "max-peers" or name == "neighbor-graceful-restart" or name == "neighbor-graceful-restart-stalepath-time" or name == "neighbor-graceful-restart-time" or name == "neighbor-group-add-member" or name == "propagate-dmz-link-bandwidth" or name == "remote-as-list" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "session-group-add-member" or name == "session-open-mode" or name == "shutdown" or name == "suppress-all-capabilities" or name == "suppress-four-byte-as-capability" or name == "ttl-security" or name == "update-source-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "neighbor-group-name"):
                                        self.neighbor_group_name = value
                                        self.neighbor_group_name.value_namespace = name_space
                                        self.neighbor_group_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-receive-capability"):
                                        self.additional_paths_receive_capability = value
                                        self.additional_paths_receive_capability.value_namespace = name_space
                                        self.additional_paths_receive_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-send-capability"):
                                        self.additional_paths_send_capability = value
                                        self.additional_paths_send_capability.value_namespace = name_space
                                        self.additional_paths_send_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-enable-modes"):
                                        self.bfd_enable_modes = value
                                        self.bfd_enable_modes.value_namespace = name_space
                                        self.bfd_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-minimum-interval"):
                                        self.bfd_minimum_interval = value
                                        self.bfd_minimum_interval.value_namespace = name_space
                                        self.bfd_minimum_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-multiplier"):
                                        self.bfd_multiplier = value
                                        self.bfd_multiplier.value_namespace = name_space
                                        self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "create"):
                                        self.create = value
                                        self.create.value_namespace = name_space
                                        self.create.value_namespace_prefix = name_space_prefix
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-recv-dmz"):
                                        self.ebgp_recv_dmz = value
                                        self.ebgp_recv_dmz.value_namespace = name_space
                                        self.ebgp_recv_dmz.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-send-dmz-enable-modes"):
                                        self.ebgp_send_dmz_enable_modes = value
                                        self.ebgp_send_dmz_enable_modes.value_namespace = name_space
                                        self.ebgp_send_dmz_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "egress-peer-engineering"):
                                        self.egress_peer_engineering = value
                                        self.egress_peer_engineering.value_namespace = name_space
                                        self.egress_peer_engineering.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enforce-first-as"):
                                        self.enforce_first_as = value
                                        self.enforce_first_as.value_namespace = name_space
                                        self.enforce_first_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "idle-watch-time"):
                                        self.idle_watch_time = value
                                        self.idle_watch_time.value_namespace = name_space
                                        self.idle_watch_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ignore-connected-check-ebgp"):
                                        self.ignore_connected_check_ebgp = value
                                        self.ignore_connected_check_ebgp.value_namespace = name_space
                                        self.ignore_connected_check_ebgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-vpn-client-ibgpce"):
                                        self.internal_vpn_client_ibgpce = value
                                        self.internal_vpn_client_ibgpce.value_namespace = name_space
                                        self.internal_vpn_client_ibgpce.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-peers"):
                                        self.max_peers = value
                                        self.max_peers.value_namespace = name_space
                                        self.max_peers.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart"):
                                        self.neighbor_graceful_restart = value
                                        self.neighbor_graceful_restart.value_namespace = name_space
                                        self.neighbor_graceful_restart.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-stalepath-time"):
                                        self.neighbor_graceful_restart_stalepath_time = value
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-time"):
                                        self.neighbor_graceful_restart_time = value
                                        self.neighbor_graceful_restart_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-group-add-member"):
                                        self.neighbor_group_add_member = value
                                        self.neighbor_group_add_member.value_namespace = name_space
                                        self.neighbor_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "propagate-dmz-link-bandwidth"):
                                        self.propagate_dmz_link_bandwidth = value
                                        self.propagate_dmz_link_bandwidth.value_namespace = name_space
                                        self.propagate_dmz_link_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-as-list"):
                                        self.remote_as_list = value
                                        self.remote_as_list.value_namespace = name_space
                                        self.remote_as_list.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                        self.rpki_bestpath_origin_as_allow_invalid = value
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-origin-as-validation-disable"):
                                        self.rpki_origin_as_validation_disable = value
                                        self.rpki_origin_as_validation_disable.value_namespace = name_space
                                        self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-group-add-member"):
                                        self.session_group_add_member = value
                                        self.session_group_add_member.value_namespace = name_space
                                        self.session_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-open-mode"):
                                        self.session_open_mode = value
                                        self.session_open_mode.value_namespace = name_space
                                        self.session_open_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-all-capabilities"):
                                        self.suppress_all_capabilities = value
                                        self.suppress_all_capabilities.value_namespace = name_space
                                        self.suppress_all_capabilities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-four-byte-as-capability"):
                                        self.suppress_four_byte_as_capability = value
                                        self.suppress_four_byte_as_capability.value_namespace = name_space
                                        self.suppress_four_byte_as_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security"):
                                        self.ttl_security = value
                                        self.ttl_security.value_namespace = name_space
                                        self.ttl_security.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-source-interface"):
                                        self.update_source_interface = value
                                        self.update_source_interface.value_namespace = name_space
                                        self.update_source_interface.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.neighbor_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.neighbor_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor-group"):
                                    for c in self.neighbor_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.neighbor_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AfGroups(Entity):
                            """
                            AF\-group configuration
                            
                            .. attribute:: af_group
                            
                            	A particular BGP AF group
                            	**type**\: list of    :py:class:`AfGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups, self).__init__()

                                self.yang_name = "af-groups"
                                self.yang_parent_name = "bgp-entity"

                                self.af_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups, self).__setattr__(name, value)


                            class AfGroup(Entity):
                                """
                                A particular BGP AF group
                                
                                .. attribute:: af_group_name  <key>
                                
                                	BGP AF group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: af_group_afs
                                
                                	AF group configuration table
                                	**type**\:   :py:class:`AfGroupAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup, self).__init__()

                                    self.yang_name = "af-group"
                                    self.yang_parent_name = "af-groups"

                                    self.af_group_name = YLeaf(YType.str, "af-group-name")

                                    self.af_group_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs()
                                    self.af_group_afs.parent = self
                                    self._children_name_map["af_group_afs"] = "af-group-afs"
                                    self._children_yang_names.add("af-group-afs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_group_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup, self).__setattr__(name, value)


                                class AfGroupAfs(Entity):
                                    """
                                    AF group configuration table
                                    
                                    .. attribute:: af_group_af
                                    
                                    	Address family type of an AF group
                                    	**type**\: list of    :py:class:`AfGroupAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs, self).__init__()

                                        self.yang_name = "af-group-afs"
                                        self.yang_parent_name = "af-group"

                                        self.af_group_af = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs, self).__setattr__(name, value)


                                    class AfGroupAf(Entity):
                                        """
                                        Address family type of an AF group
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP AF group address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpnevpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_l2vpnevpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2Vpnevpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2Vpnevpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: create
                                        
                                        	Create this address family group. Deletion of this object causes deletion of all the objects under AFGroup associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf, self).__init__()

                                            self.yang_name = "af-group-af"
                                            self.yang_parent_name = "af-group-afs"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.create = YLeaf(YType.empty, "create")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2Vpnevpn()
                                            self.advertise_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                            self._children_yang_names.add("advertise-l2vpnevpn")

                                            self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2Vpnevpn()
                                            self.advertise_local_l2vpnevpn.parent = self
                                            self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                            self._children_yang_names.add("advertise-local-l2vpnevpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "accept_own",
                                                            "accept_route_legacy_rt",
                                                            "advertise_local_labeled_route",
                                                            "advertise_orf",
                                                            "advertise_permanent_network",
                                                            "af_group",
                                                            "aigp",
                                                            "aigp_send_med",
                                                            "allow_as_in",
                                                            "as_override",
                                                            "create",
                                                            "default_weight",
                                                            "encapsulation_type",
                                                            "flowspec_validation",
                                                            "l2vpn_signalling",
                                                            "multipath",
                                                            "neighbor_af_long_lived_graceful_restart_capable",
                                                            "next_hop_self",
                                                            "next_hop_unchanged",
                                                            "next_hop_unchanged_multipath",
                                                            "prefix_orf_policy",
                                                            "route_policy_in",
                                                            "route_policy_out",
                                                            "route_reflector_client",
                                                            "rpki_bestpath_origin_as_allow_invalid",
                                                            "rpki_origin_as_validation_disable",
                                                            "send_community_ebgp",
                                                            "send_community_ebgp_graceful_shutdown",
                                                            "send_ext_community_ebgp",
                                                            "send_multicast_attr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf, self).__setattr__(name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cost_community_id",
                                                                "cost_community_poi_type",
                                                                "enable",
                                                                "transitive") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cost_community_id.is_set or
                                                    self.cost_community_poi_type.is_set or
                                                    self.enable.is_set or
                                                    self.transitive.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cost_community_id.yfilter != YFilter.not_set or
                                                    self.cost_community_poi_type.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.transitive.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "aigp-cost-community" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cost_community_id.is_set or self.cost_community_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_id.get_name_leafdata())
                                                if (self.cost_community_poi_type.is_set or self.cost_community_poi_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost_community_poi_type.get_name_leafdata())
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.transitive.is_set or self.transitive.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.transitive.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cost-community-id" or name == "cost-community-poi-type" or name == "enable" or name == "transitive"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cost-community-id"):
                                                    self.cost_community_id = value
                                                    self.cost_community_id.value_namespace = name_space
                                                    self.cost_community_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost-community-poi-type"):
                                                    self.cost_community_poi_type = value
                                                    self.cost_community_poi_type.value_namespace = name_space
                                                    self.cost_community_poi_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "transitive"):
                                                    self.transitive = value
                                                    self.transitive.value_namespace = name_space
                                                    self.transitive.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "af-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "af-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-disable" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("discard_extra_paths",
                                                                "prefix_limit",
                                                                "restart_time",
                                                                "warning_only",
                                                                "warning_percentage") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.discard_extra_paths.is_set or
                                                    self.prefix_limit.is_set or
                                                    self.restart_time.is_set or
                                                    self.warning_only.is_set or
                                                    self.warning_percentage.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.discard_extra_paths.yfilter != YFilter.not_set or
                                                    self.prefix_limit.yfilter != YFilter.not_set or
                                                    self.restart_time.yfilter != YFilter.not_set or
                                                    self.warning_only.yfilter != YFilter.not_set or
                                                    self.warning_percentage.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-prefixes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.discard_extra_paths.is_set or self.discard_extra_paths.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.discard_extra_paths.get_name_leafdata())
                                                if (self.prefix_limit.is_set or self.prefix_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_limit.get_name_leafdata())
                                                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.restart_time.get_name_leafdata())
                                                if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_only.get_name_leafdata())
                                                if (self.warning_percentage.is_set or self.warning_percentage.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.warning_percentage.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "discard-extra-paths" or name == "prefix-limit" or name == "restart-time" or name == "warning-only" or name == "warning-percentage"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "discard-extra-paths"):
                                                    self.discard_extra_paths = value
                                                    self.discard_extra_paths.value_namespace = name_space
                                                    self.discard_extra_paths.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-limit"):
                                                    self.prefix_limit = value
                                                    self.prefix_limit.value_namespace = name_space
                                                    self.prefix_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "restart-time"):
                                                    self.restart_time = value
                                                    self.restart_time.value_namespace = name_space
                                                    self.restart_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-only"):
                                                    self.warning_only = value
                                                    self.warning_only.value_namespace = name_space
                                                    self.warning_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "warning-percentage"):
                                                    self.warning_percentage = value
                                                    self.warning_percentage.value_namespace = name_space
                                                    self.warning_percentage.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path-inbound" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "af-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-def-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseL2Vpnevpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-l2vpnevpn"
                                                self.yang_parent_name = "af-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalL2Vpnevpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2Vpnevpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpnevpn"
                                                self.yang_parent_name = "af-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2Vpnevpn, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-l2vpnevpn" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "af-group-af"

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("stale_time_accept",
                                                                "stale_time_send") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.stale_time_accept.is_set or
                                                    self.stale_time_send.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.stale_time_accept.yfilter != YFilter.not_set or
                                                    self.stale_time_send.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-af-long-lived-graceful-restart-stale-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.stale_time_accept.is_set or self.stale_time_accept.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_accept.get_name_leafdata())
                                                if (self.stale_time_send.is_set or self.stale_time_send.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stale_time_send.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "stale-time-accept" or name == "stale-time-send"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "stale-time-accept"):
                                                    self.stale_time_accept = value
                                                    self.stale_time_accept.value_namespace = name_space
                                                    self.stale_time_accept.value_namespace_prefix = name_space_prefix
                                                if(value_path == "stale-time-send"):
                                                    self.stale_time_send = value
                                                    self.stale_time_send.value_namespace = name_space
                                                    self.stale_time_send.value_namespace_prefix = name_space_prefix


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "af-group-af"

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("address",
                                                                "address_index",
                                                                "as_",
                                                                "as_index",
                                                                "as_xx",
                                                                "type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.address.is_set or
                                                    self.address_index.is_set or
                                                    self.as_.is_set or
                                                    self.as_index.is_set or
                                                    self.as_xx.is_set or
                                                    self.type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.address_index.yfilter != YFilter.not_set or
                                                    self.as_.yfilter != YFilter.not_set or
                                                    self.as_index.yfilter != YFilter.not_set or
                                                    self.as_xx.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "site-of-origin" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.address_index.is_set or self.address_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address_index.get_name_leafdata())
                                                if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_.get_name_leafdata())
                                                if (self.as_index.is_set or self.as_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_index.get_name_leafdata())
                                                if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.as_xx.get_name_leafdata())
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "address" or name == "address-index" or name == "as" or name == "as-index" or name == "as-xx" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address-index"):
                                                    self.address_index = value
                                                    self.address_index.value_namespace = name_space
                                                    self.address_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as"):
                                                    self.as_ = value
                                                    self.as_.value_namespace = name_space
                                                    self.as_.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-index"):
                                                    self.as_index = value
                                                    self.as_index.value_namespace = name_space
                                                    self.as_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "as-xx"):
                                                    self.as_xx = value
                                                    self.as_xx.value_namespace = name_space
                                                    self.as_xx.value_namespace_prefix = name_space_prefix
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "af-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "af-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "af-group-af"

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("import_reoriginate",
                                                                "import_reoriginate_stitching",
                                                                "import_stitching") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.import_reoriginate.is_set or
                                                    self.import_reoriginate_stitching.is_set or
                                                    self.import_stitching.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.import_reoriginate.yfilter != YFilter.not_set or
                                                    self.import_reoriginate_stitching.yfilter != YFilter.not_set or
                                                    self.import_stitching.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "import" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.import_reoriginate.is_set or self.import_reoriginate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate.get_name_leafdata())
                                                if (self.import_reoriginate_stitching.is_set or self.import_reoriginate_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_reoriginate_stitching.get_name_leafdata())
                                                if (self.import_stitching.is_set or self.import_stitching.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.import_stitching.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "import-reoriginate" or name == "import-reoriginate-stitching" or name == "import-stitching"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "import-reoriginate"):
                                                    self.import_reoriginate = value
                                                    self.import_reoriginate.value_namespace = name_space
                                                    self.import_reoriginate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-reoriginate-stitching"):
                                                    self.import_reoriginate_stitching = value
                                                    self.import_reoriginate_stitching.value_namespace = name_space
                                                    self.import_reoriginate_stitching.value_namespace_prefix = name_space_prefix
                                                if(value_path == "import-stitching"):
                                                    self.import_stitching = value
                                                    self.import_stitching.value_namespace = name_space
                                                    self.import_stitching.value_namespace_prefix = name_space_prefix


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "af-group-af"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "route_policy_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.route_policy_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.route_policy_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "default-originate" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "route-policy-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-policy-name"):
                                                    self.route_policy_name = value
                                                    self.route_policy_name.value_namespace = name_space
                                                    self.route_policy_name.value_namespace_prefix = name_space_prefix


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "af-group-af"

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("inbound_soft",
                                                                "soft_always") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.inbound_soft.is_set or
                                                    self.soft_always.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.inbound_soft.yfilter != YFilter.not_set or
                                                    self.soft_always.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "soft-reconfiguration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.inbound_soft.is_set or self.inbound_soft.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.inbound_soft.get_name_leafdata())
                                                if (self.soft_always.is_set or self.soft_always.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.soft_always.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "inbound-soft" or name == "soft-always"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "inbound-soft"):
                                                    self.inbound_soft = value
                                                    self.inbound_soft.value_namespace = name_space
                                                    self.inbound_soft.value_namespace_prefix = name_space_prefix
                                                if(value_path == "soft-always"):
                                                    self.soft_always = value
                                                    self.soft_always.value_namespace = name_space
                                                    self.soft_always.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "af-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v6" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "af-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "af-group-af"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name",
                                                                "reorg_option",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    self.reorg_option.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.reorg_option.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-local-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.reorg_option.is_set or self.reorg_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reorg_option.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "af-name" or name == "reorg-option" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reorg-option"):
                                                    self.reorg_option = value
                                                    self.reorg_option.value_namespace = name_space
                                                    self.reorg_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "entire") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.entire.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.entire.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remove-private-as-entire-as-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.entire.is_set or self.entire.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entire.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "entire"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "entire"):
                                                    self.entire = value
                                                    self.entire.value_namespace = name_space
                                                    self.entire.value_namespace_prefix = name_space_prefix


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "af-group-af"

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("adv_option",
                                                                "af_name",
                                                                "rt_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.adv_option.is_set or
                                                    self.af_name.is_set or
                                                    self.rt_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.adv_option.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    self.rt_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advertise-vrf-imp-disable-v4" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.adv_option.is_set or self.adv_option.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.adv_option.get_name_leafdata())
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                                if (self.rt_type.is_set or self.rt_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rt_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "adv-option" or name == "af-name" or name == "rt-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "adv-option"):
                                                    self.adv_option = value
                                                    self.adv_option.value_namespace = name_space
                                                    self.adv_option.value_namespace_prefix = name_space_prefix
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rt-type"):
                                                    self.rt_type = value
                                                    self.rt_type.value_namespace = name_space
                                                    self.rt_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.accept_own.is_set or
                                                self.accept_route_legacy_rt.is_set or
                                                self.advertise_local_labeled_route.is_set or
                                                self.advertise_orf.is_set or
                                                self.advertise_permanent_network.is_set or
                                                self.af_group.is_set or
                                                self.aigp.is_set or
                                                self.aigp_send_med.is_set or
                                                self.allow_as_in.is_set or
                                                self.as_override.is_set or
                                                self.create.is_set or
                                                self.default_weight.is_set or
                                                self.encapsulation_type.is_set or
                                                self.flowspec_validation.is_set or
                                                self.l2vpn_signalling.is_set or
                                                self.multipath.is_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.is_set or
                                                self.next_hop_self.is_set or
                                                self.next_hop_unchanged.is_set or
                                                self.next_hop_unchanged_multipath.is_set or
                                                self.prefix_orf_policy.is_set or
                                                self.route_policy_in.is_set or
                                                self.route_policy_out.is_set or
                                                self.route_reflector_client.is_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                                self.rpki_origin_as_validation_disable.is_set or
                                                self.send_community_ebgp.is_set or
                                                self.send_community_ebgp_graceful_shutdown.is_set or
                                                self.send_ext_community_ebgp.is_set or
                                                self.send_multicast_attr.is_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_data()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_data()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_data()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_data()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_data()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_data()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_data()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_data()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_data()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_data()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_data()) or
                                                (self.default_originate is not None and self.default_originate.has_data()) or
                                                (self.import_ is not None and self.import_.has_data()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_data()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_data()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_data()) or
                                                (self.aigp_cost_community is not None) or
                                                (self.maximum_prefixes is not None) or
                                                (self.remove_private_as_entire_as_path is not None) or
                                                (self.remove_private_as_entire_as_path_inbound is not None))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.accept_own.yfilter != YFilter.not_set or
                                                self.accept_route_legacy_rt.yfilter != YFilter.not_set or
                                                self.advertise_local_labeled_route.yfilter != YFilter.not_set or
                                                self.advertise_orf.yfilter != YFilter.not_set or
                                                self.advertise_permanent_network.yfilter != YFilter.not_set or
                                                self.af_group.yfilter != YFilter.not_set or
                                                self.aigp.yfilter != YFilter.not_set or
                                                self.aigp_send_med.yfilter != YFilter.not_set or
                                                self.allow_as_in.yfilter != YFilter.not_set or
                                                self.as_override.yfilter != YFilter.not_set or
                                                self.create.yfilter != YFilter.not_set or
                                                self.default_weight.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.flowspec_validation.yfilter != YFilter.not_set or
                                                self.l2vpn_signalling.yfilter != YFilter.not_set or
                                                self.multipath.yfilter != YFilter.not_set or
                                                self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set or
                                                self.next_hop_self.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged.yfilter != YFilter.not_set or
                                                self.next_hop_unchanged_multipath.yfilter != YFilter.not_set or
                                                self.prefix_orf_policy.yfilter != YFilter.not_set or
                                                self.route_policy_in.yfilter != YFilter.not_set or
                                                self.route_policy_out.yfilter != YFilter.not_set or
                                                self.route_reflector_client.yfilter != YFilter.not_set or
                                                self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                                self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                                self.send_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set or
                                                self.send_ext_community_ebgp.yfilter != YFilter.not_set or
                                                self.send_multicast_attr.yfilter != YFilter.not_set or
                                                (self.advertise_def_imp_disable_v4 is not None and self.advertise_def_imp_disable_v4.has_operation()) or
                                                (self.advertise_def_imp_disable_v6 is not None and self.advertise_def_imp_disable_v6.has_operation()) or
                                                (self.advertise_disable is not None and self.advertise_disable.has_operation()) or
                                                (self.advertise_l2vpnevpn is not None and self.advertise_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_l2vpnevpn is not None and self.advertise_local_l2vpnevpn.has_operation()) or
                                                (self.advertise_local_v4 is not None and self.advertise_local_v4.has_operation()) or
                                                (self.advertise_local_v6 is not None and self.advertise_local_v6.has_operation()) or
                                                (self.advertise_v4 is not None and self.advertise_v4.has_operation()) or
                                                (self.advertise_v6 is not None and self.advertise_v6.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v4 is not None and self.advertise_vrf_imp_disable_v4.has_operation()) or
                                                (self.advertise_vrf_imp_disable_v6 is not None and self.advertise_vrf_imp_disable_v6.has_operation()) or
                                                (self.aigp_cost_community is not None and self.aigp_cost_community.has_operation()) or
                                                (self.default_originate is not None and self.default_originate.has_operation()) or
                                                (self.import_ is not None and self.import_.has_operation()) or
                                                (self.maximum_prefixes is not None and self.maximum_prefixes.has_operation()) or
                                                (self.neighbor_af_long_lived_graceful_restart_stale_time is not None and self.neighbor_af_long_lived_graceful_restart_stale_time.has_operation()) or
                                                (self.remove_private_as_entire_as_path is not None and self.remove_private_as_entire_as_path.has_operation()) or
                                                (self.remove_private_as_entire_as_path_inbound is not None and self.remove_private_as_entire_as_path_inbound.has_operation()) or
                                                (self.site_of_origin is not None and self.site_of_origin.has_operation()) or
                                                (self.soft_reconfiguration is not None and self.soft_reconfiguration.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "af-group-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.accept_own.is_set or self.accept_own.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_own.get_name_leafdata())
                                            if (self.accept_route_legacy_rt.is_set or self.accept_route_legacy_rt.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.accept_route_legacy_rt.get_name_leafdata())
                                            if (self.advertise_local_labeled_route.is_set or self.advertise_local_labeled_route.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_local_labeled_route.get_name_leafdata())
                                            if (self.advertise_orf.is_set or self.advertise_orf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_orf.get_name_leafdata())
                                            if (self.advertise_permanent_network.is_set or self.advertise_permanent_network.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertise_permanent_network.get_name_leafdata())
                                            if (self.af_group.is_set or self.af_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_group.get_name_leafdata())
                                            if (self.aigp.is_set or self.aigp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp.get_name_leafdata())
                                            if (self.aigp_send_med.is_set or self.aigp_send_med.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aigp_send_med.get_name_leafdata())
                                            if (self.allow_as_in.is_set or self.allow_as_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.allow_as_in.get_name_leafdata())
                                            if (self.as_override.is_set or self.as_override.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_override.get_name_leafdata())
                                            if (self.create.is_set or self.create.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.create.get_name_leafdata())
                                            if (self.default_weight.is_set or self.default_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_weight.get_name_leafdata())
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.flowspec_validation.is_set or self.flowspec_validation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flowspec_validation.get_name_leafdata())
                                            if (self.l2vpn_signalling.is_set or self.l2vpn_signalling.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2vpn_signalling.get_name_leafdata())
                                            if (self.multipath.is_set or self.multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multipath.get_name_leafdata())
                                            if (self.neighbor_af_long_lived_graceful_restart_capable.is_set or self.neighbor_af_long_lived_graceful_restart_capable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_af_long_lived_graceful_restart_capable.get_name_leafdata())
                                            if (self.next_hop_self.is_set or self.next_hop_self.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_self.get_name_leafdata())
                                            if (self.next_hop_unchanged.is_set or self.next_hop_unchanged.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged.get_name_leafdata())
                                            if (self.next_hop_unchanged_multipath.is_set or self.next_hop_unchanged_multipath.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_unchanged_multipath.get_name_leafdata())
                                            if (self.prefix_orf_policy.is_set or self.prefix_orf_policy.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_orf_policy.get_name_leafdata())
                                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                            if (self.route_reflector_client.is_set or self.route_reflector_client.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_reflector_client.get_name_leafdata())
                                            if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                            if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                            if (self.send_community_ebgp.is_set or self.send_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp.get_name_leafdata())
                                            if (self.send_community_ebgp_graceful_shutdown.is_set or self.send_community_ebgp_graceful_shutdown.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_community_ebgp_graceful_shutdown.get_name_leafdata())
                                            if (self.send_ext_community_ebgp.is_set or self.send_ext_community_ebgp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_ext_community_ebgp.get_name_leafdata())
                                            if (self.send_multicast_attr.is_set or self.send_multicast_attr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.send_multicast_attr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advertise-def-imp-disable-v4"):
                                                if (self.advertise_def_imp_disable_v4 is None):
                                                    self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4()
                                                    self.advertise_def_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                                return self.advertise_def_imp_disable_v4

                                            if (child_yang_name == "advertise-def-imp-disable-v6"):
                                                if (self.advertise_def_imp_disable_v6 is None):
                                                    self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6()
                                                    self.advertise_def_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                                return self.advertise_def_imp_disable_v6

                                            if (child_yang_name == "advertise-disable"):
                                                if (self.advertise_disable is None):
                                                    self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable()
                                                    self.advertise_disable.parent = self
                                                    self._children_name_map["advertise_disable"] = "advertise-disable"
                                                return self.advertise_disable

                                            if (child_yang_name == "advertise-l2vpnevpn"):
                                                if (self.advertise_l2vpnevpn is None):
                                                    self.advertise_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2Vpnevpn()
                                                    self.advertise_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_l2vpnevpn"] = "advertise-l2vpnevpn"
                                                return self.advertise_l2vpnevpn

                                            if (child_yang_name == "advertise-local-l2vpnevpn"):
                                                if (self.advertise_local_l2vpnevpn is None):
                                                    self.advertise_local_l2vpnevpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2Vpnevpn()
                                                    self.advertise_local_l2vpnevpn.parent = self
                                                    self._children_name_map["advertise_local_l2vpnevpn"] = "advertise-local-l2vpnevpn"
                                                return self.advertise_local_l2vpnevpn

                                            if (child_yang_name == "advertise-local-v4"):
                                                if (self.advertise_local_v4 is None):
                                                    self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4()
                                                    self.advertise_local_v4.parent = self
                                                    self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                                return self.advertise_local_v4

                                            if (child_yang_name == "advertise-local-v6"):
                                                if (self.advertise_local_v6 is None):
                                                    self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6()
                                                    self.advertise_local_v6.parent = self
                                                    self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                                return self.advertise_local_v6

                                            if (child_yang_name == "advertise-v4"):
                                                if (self.advertise_v4 is None):
                                                    self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4()
                                                    self.advertise_v4.parent = self
                                                    self._children_name_map["advertise_v4"] = "advertise-v4"
                                                return self.advertise_v4

                                            if (child_yang_name == "advertise-v6"):
                                                if (self.advertise_v6 is None):
                                                    self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6()
                                                    self.advertise_v6.parent = self
                                                    self._children_name_map["advertise_v6"] = "advertise-v6"
                                                return self.advertise_v6

                                            if (child_yang_name == "advertise-vrf-imp-disable-v4"):
                                                if (self.advertise_vrf_imp_disable_v4 is None):
                                                    self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4()
                                                    self.advertise_vrf_imp_disable_v4.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                                return self.advertise_vrf_imp_disable_v4

                                            if (child_yang_name == "advertise-vrf-imp-disable-v6"):
                                                if (self.advertise_vrf_imp_disable_v6 is None):
                                                    self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6()
                                                    self.advertise_vrf_imp_disable_v6.parent = self
                                                    self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                                return self.advertise_vrf_imp_disable_v6

                                            if (child_yang_name == "aigp-cost-community"):
                                                if (self.aigp_cost_community is None):
                                                    self.aigp_cost_community = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity()
                                                    self.aigp_cost_community.parent = self
                                                    self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                                return self.aigp_cost_community

                                            if (child_yang_name == "default-originate"):
                                                if (self.default_originate is None):
                                                    self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate()
                                                    self.default_originate.parent = self
                                                    self._children_name_map["default_originate"] = "default-originate"
                                                return self.default_originate

                                            if (child_yang_name == "import"):
                                                if (self.import_ is None):
                                                    self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_()
                                                    self.import_.parent = self
                                                    self._children_name_map["import_"] = "import"
                                                return self.import_

                                            if (child_yang_name == "maximum-prefixes"):
                                                if (self.maximum_prefixes is None):
                                                    self.maximum_prefixes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes()
                                                    self.maximum_prefixes.parent = self
                                                    self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                                return self.maximum_prefixes

                                            if (child_yang_name == "neighbor-af-long-lived-graceful-restart-stale-time"):
                                                if (self.neighbor_af_long_lived_graceful_restart_stale_time is None):
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                                    self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                                    self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                return self.neighbor_af_long_lived_graceful_restart_stale_time

                                            if (child_yang_name == "remove-private-as-entire-as-path"):
                                                if (self.remove_private_as_entire_as_path is None):
                                                    self.remove_private_as_entire_as_path = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath()
                                                    self.remove_private_as_entire_as_path.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                                return self.remove_private_as_entire_as_path

                                            if (child_yang_name == "remove-private-as-entire-as-path-inbound"):
                                                if (self.remove_private_as_entire_as_path_inbound is None):
                                                    self.remove_private_as_entire_as_path_inbound = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound()
                                                    self.remove_private_as_entire_as_path_inbound.parent = self
                                                    self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                                return self.remove_private_as_entire_as_path_inbound

                                            if (child_yang_name == "site-of-origin"):
                                                if (self.site_of_origin is None):
                                                    self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin()
                                                    self.site_of_origin.parent = self
                                                    self._children_name_map["site_of_origin"] = "site-of-origin"
                                                return self.site_of_origin

                                            if (child_yang_name == "soft-reconfiguration"):
                                                if (self.soft_reconfiguration is None):
                                                    self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration()
                                                    self.soft_reconfiguration.parent = self
                                                    self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                                return self.soft_reconfiguration

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertise-def-imp-disable-v4" or name == "advertise-def-imp-disable-v6" or name == "advertise-disable" or name == "advertise-l2vpnevpn" or name == "advertise-local-l2vpnevpn" or name == "advertise-local-v4" or name == "advertise-local-v6" or name == "advertise-v4" or name == "advertise-v6" or name == "advertise-vrf-imp-disable-v4" or name == "advertise-vrf-imp-disable-v6" or name == "aigp-cost-community" or name == "default-originate" or name == "import" or name == "maximum-prefixes" or name == "neighbor-af-long-lived-graceful-restart-stale-time" or name == "remove-private-as-entire-as-path" or name == "remove-private-as-entire-as-path-inbound" or name == "site-of-origin" or name == "soft-reconfiguration" or name == "af-name" or name == "accept-own" or name == "accept-route-legacy-rt" or name == "advertise-local-labeled-route" or name == "advertise-orf" or name == "advertise-permanent-network" or name == "af-group" or name == "aigp" or name == "aigp-send-med" or name == "allow-as-in" or name == "as-override" or name == "create" or name == "default-weight" or name == "encapsulation-type" or name == "flowspec-validation" or name == "l2vpn-signalling" or name == "multipath" or name == "neighbor-af-long-lived-graceful-restart-capable" or name == "next-hop-self" or name == "next-hop-unchanged" or name == "next-hop-unchanged-multipath" or name == "prefix-orf-policy" or name == "route-policy-in" or name == "route-policy-out" or name == "route-reflector-client" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "send-community-ebgp" or name == "send-community-ebgp-graceful-shutdown" or name == "send-ext-community-ebgp" or name == "send-multicast-attr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-own"):
                                                self.accept_own = value
                                                self.accept_own.value_namespace = name_space
                                                self.accept_own.value_namespace_prefix = name_space_prefix
                                            if(value_path == "accept-route-legacy-rt"):
                                                self.accept_route_legacy_rt = value
                                                self.accept_route_legacy_rt.value_namespace = name_space
                                                self.accept_route_legacy_rt.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-local-labeled-route"):
                                                self.advertise_local_labeled_route = value
                                                self.advertise_local_labeled_route.value_namespace = name_space
                                                self.advertise_local_labeled_route.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-orf"):
                                                self.advertise_orf = value
                                                self.advertise_orf.value_namespace = name_space
                                                self.advertise_orf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "advertise-permanent-network"):
                                                self.advertise_permanent_network = value
                                                self.advertise_permanent_network.value_namespace = name_space
                                                self.advertise_permanent_network.value_namespace_prefix = name_space_prefix
                                            if(value_path == "af-group"):
                                                self.af_group = value
                                                self.af_group.value_namespace = name_space
                                                self.af_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp"):
                                                self.aigp = value
                                                self.aigp.value_namespace = name_space
                                                self.aigp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aigp-send-med"):
                                                self.aigp_send_med = value
                                                self.aigp_send_med.value_namespace = name_space
                                                self.aigp_send_med.value_namespace_prefix = name_space_prefix
                                            if(value_path == "allow-as-in"):
                                                self.allow_as_in = value
                                                self.allow_as_in.value_namespace = name_space
                                                self.allow_as_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-override"):
                                                self.as_override = value
                                                self.as_override.value_namespace = name_space
                                                self.as_override.value_namespace_prefix = name_space_prefix
                                            if(value_path == "create"):
                                                self.create = value
                                                self.create.value_namespace = name_space
                                                self.create.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-weight"):
                                                self.default_weight = value
                                                self.default_weight.value_namespace = name_space
                                                self.default_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flowspec-validation"):
                                                self.flowspec_validation = value
                                                self.flowspec_validation.value_namespace = name_space
                                                self.flowspec_validation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2vpn-signalling"):
                                                self.l2vpn_signalling = value
                                                self.l2vpn_signalling.value_namespace = name_space
                                                self.l2vpn_signalling.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multipath"):
                                                self.multipath = value
                                                self.multipath.value_namespace = name_space
                                                self.multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-af-long-lived-graceful-restart-capable"):
                                                self.neighbor_af_long_lived_graceful_restart_capable = value
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace = name_space
                                                self.neighbor_af_long_lived_graceful_restart_capable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-self"):
                                                self.next_hop_self = value
                                                self.next_hop_self.value_namespace = name_space
                                                self.next_hop_self.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged"):
                                                self.next_hop_unchanged = value
                                                self.next_hop_unchanged.value_namespace = name_space
                                                self.next_hop_unchanged.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-unchanged-multipath"):
                                                self.next_hop_unchanged_multipath = value
                                                self.next_hop_unchanged_multipath.value_namespace = name_space
                                                self.next_hop_unchanged_multipath.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-orf-policy"):
                                                self.prefix_orf_policy = value
                                                self.prefix_orf_policy.value_namespace = name_space
                                                self.prefix_orf_policy.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-in"):
                                                self.route_policy_in = value
                                                self.route_policy_in.value_namespace = name_space
                                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-out"):
                                                self.route_policy_out = value
                                                self.route_policy_out.value_namespace = name_space
                                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-reflector-client"):
                                                self.route_reflector_client = value
                                                self.route_reflector_client.value_namespace = name_space
                                                self.route_reflector_client.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                                self.rpki_bestpath_origin_as_allow_invalid = value
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rpki-origin-as-validation-disable"):
                                                self.rpki_origin_as_validation_disable = value
                                                self.rpki_origin_as_validation_disable.value_namespace = name_space
                                                self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp"):
                                                self.send_community_ebgp = value
                                                self.send_community_ebgp.value_namespace = name_space
                                                self.send_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-community-ebgp-graceful-shutdown"):
                                                self.send_community_ebgp_graceful_shutdown = value
                                                self.send_community_ebgp_graceful_shutdown.value_namespace = name_space
                                                self.send_community_ebgp_graceful_shutdown.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-ext-community-ebgp"):
                                                self.send_ext_community_ebgp = value
                                                self.send_ext_community_ebgp.value_namespace = name_space
                                                self.send_ext_community_ebgp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "send-multicast-attr"):
                                                self.send_multicast_attr = value
                                                self.send_multicast_attr.value_namespace = name_space
                                                self.send_multicast_attr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.af_group_af:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.af_group_af:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "af-group-afs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "af-group-af"):
                                            for c in self.af_group_af:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.af_group_af.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-group-af"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.af_group_name.is_set or
                                        (self.af_group_afs is not None and self.af_group_afs.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_group_name.yfilter != YFilter.not_set or
                                        (self.af_group_afs is not None and self.af_group_afs.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "af-group" + "[af-group-name='" + self.af_group_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_group_name.is_set or self.af_group_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_group_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "af-group-afs"):
                                        if (self.af_group_afs is None):
                                            self.af_group_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs()
                                            self.af_group_afs.parent = self
                                            self._children_name_map["af_group_afs"] = "af-group-afs"
                                        return self.af_group_afs

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-group-afs" or name == "af-group-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-group-name"):
                                        self.af_group_name = value
                                        self.af_group_name.value_namespace = name_space
                                        self.af_group_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.af_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.af_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "af-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "af-group"):
                                    for c in self.af_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.af_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SessionGroups(Entity):
                            """
                            Session group configuration
                            
                            .. attribute:: session_group
                            
                            	A particular BGP session group
                            	**type**\: list of    :py:class:`SessionGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups, self).__init__()

                                self.yang_name = "session-groups"
                                self.yang_parent_name = "bgp-entity"

                                self.session_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups, self).__setattr__(name, value)


                            class SessionGroup(Entity):
                                """
                                A particular BGP session group
                                
                                .. attribute:: session_group_name  <key>
                                
                                	BGP session group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates>`
                                
                                .. attribute:: create
                                
                                	Create this group. Deletion of this object causes deletion of all the objects under NeighborGroup/SessionGroup associated with this object
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgpce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup, self).__init__()

                                    self.yang_name = "session-group"
                                    self.yang_parent_name = "session-groups"

                                    self.session_group_name = YLeaf(YType.str, "session-group-name")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.create = YLeaf(YType.empty, "create")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgpce = YLeaf(YType.boolean, "internal-vpn-client-ibgpce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("session_group_name",
                                                    "additional_paths_receive_capability",
                                                    "additional_paths_send_capability",
                                                    "bfd_enable_modes",
                                                    "bfd_minimum_interval",
                                                    "bfd_multiplier",
                                                    "create",
                                                    "description",
                                                    "ebgp_recv_dmz",
                                                    "ebgp_send_dmz_enable_modes",
                                                    "egress_peer_engineering",
                                                    "enforce_first_as",
                                                    "idle_watch_time",
                                                    "ignore_connected_check_ebgp",
                                                    "internal_vpn_client_ibgpce",
                                                    "max_peers",
                                                    "neighbor_graceful_restart",
                                                    "neighbor_graceful_restart_stalepath_time",
                                                    "neighbor_graceful_restart_time",
                                                    "propagate_dmz_link_bandwidth",
                                                    "remote_as_list",
                                                    "rpki_bestpath_origin_as_allow_invalid",
                                                    "rpki_origin_as_validation_disable",
                                                    "session_group_add_member",
                                                    "session_open_mode",
                                                    "shutdown",
                                                    "suppress_all_capabilities",
                                                    "suppress_four_byte_as_capability",
                                                    "ttl_security",
                                                    "update_source_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup, self).__setattr__(name, value)


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "session-group"

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address_disable",
                                                        "local_ip_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_address_disable.is_set or
                                            self.local_ip_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address_disable.yfilter != YFilter.not_set or
                                            self.local_ip_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address_disable.is_set or self.local_address_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address_disable.get_name_leafdata())
                                        if (self.local_ip_address.is_set or self.local_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ip_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-address-disable" or name == "local-ip-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address-disable"):
                                            self.local_address_disable = value
                                            self.local_address_disable.value_namespace = name_space
                                            self.local_address_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ip-address"):
                                            self.local_ip_address = value
                                            self.local_ip_address.value_namespace = name_space
                                            self.local_ip_address.value_namespace_prefix = name_space_prefix


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "session-group"

                                        self.bmp_activate = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates, self).__setattr__(name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"

                                            self.server_id = YLeaf(YType.uint32, "server-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("server_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.server_id.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.server_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bmp-activate" + "[server-id='" + self.server_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.server_id.is_set or self.server_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.server_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "server-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "server-id"):
                                                self.server_id = value
                                                self.server_id.value_namespace = name_space
                                                self.server_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bmp_activate:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bmp_activate:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmp-activates" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bmp-activate"):
                                            for c in self.bmp_activate:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bmp_activate.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bmp-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "session-group"

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("max_hop_count",
                                                        "mpls_deactivation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.max_hop_count.is_set or
                                            self.mpls_deactivation.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.max_hop_count.yfilter != YFilter.not_set or
                                            self.mpls_deactivation.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ebgp-multihop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.max_hop_count.is_set or self.max_hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.max_hop_count.get_name_leafdata())
                                        if (self.mpls_deactivation.is_set or self.mpls_deactivation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_deactivation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "max-hop-count" or name == "mpls-deactivation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "max-hop-count"):
                                            self.max_hop_count = value
                                            self.max_hop_count.value_namespace = name_space
                                            self.max_hop_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-deactivation"):
                                            self.mpls_deactivation = value
                                            self.mpls_deactivation.value_namespace = name_space
                                            self.mpls_deactivation.value_namespace_prefix = name_space_prefix


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "session-group"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "session-group"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy",
                                                        "disable",
                                                        "dual_as",
                                                        "no_prepend",
                                                        "replace_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set or
                                            self.disable.is_set or
                                            self.dual_as.is_set or
                                            self.no_prepend.is_set or
                                            self.replace_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set or
                                            self.disable.yfilter != YFilter.not_set or
                                            self.dual_as.yfilter != YFilter.not_set or
                                            self.no_prepend.yfilter != YFilter.not_set or
                                            self.replace_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())
                                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable.get_name_leafdata())
                                        if (self.dual_as.is_set or self.dual_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dual_as.get_name_leafdata())
                                        if (self.no_prepend.is_set or self.no_prepend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_prepend.get_name_leafdata())
                                        if (self.replace_as.is_set or self.replace_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.replace_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy" or name == "disable" or name == "dual-as" or name == "no-prepend" or name == "replace-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable"):
                                            self.disable = value
                                            self.disable.value_namespace = name_space
                                            self.disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dual-as"):
                                            self.dual_as = value
                                            self.dual_as.value_namespace = name_space
                                            self.dual_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-prepend"):
                                            self.no_prepend = value
                                            self.no_prepend.value_namespace = name_space
                                            self.no_prepend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "replace-as"):
                                            self.replace_as = value
                                            self.replace_as.value_namespace = name_space
                                            self.replace_as.value_namespace_prefix = name_space_prefix


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "session-group"

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("password",
                                                        "password_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.password.is_set or
                                            self.password_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.password.yfilter != YFilter.not_set or
                                            self.password_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "password" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password.get_name_leafdata())
                                        if (self.password_disable.is_set or self.password_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "password" or name == "password-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "password"):
                                            self.password = value
                                            self.password.value_namespace = name_space
                                            self.password.value_namespace_prefix = name_space_prefix
                                        if(value_path == "password-disable"):
                                            self.password_disable = value
                                            self.password_disable.value_namespace = name_space
                                            self.password_disable.value_namespace_prefix = name_space_prefix


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "session-group"
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("minimum_interval",
                                                        "minimum_interval_msecs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.minimum_interval.is_set or
                                            self.minimum_interval_msecs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.minimum_interval.yfilter != YFilter.not_set or
                                            self.minimum_interval_msecs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "advertisement-interval" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                        if (self.minimum_interval_msecs.is_set or self.minimum_interval_msecs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_interval_msecs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "minimum-interval" or name == "minimum-interval-msecs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "minimum-interval"):
                                            self.minimum_interval = value
                                            self.minimum_interval.value_namespace = name_space
                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-interval-msecs"):
                                            self.minimum_interval_msecs = value
                                            self.minimum_interval_msecs.value_namespace = name_space
                                            self.minimum_interval_msecs.value_namespace_prefix = name_space_prefix


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "session-group"

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cluster_id_address",
                                                        "cluster_id_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cluster_id_address.is_set or
                                            self.cluster_id_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cluster_id_address.yfilter != YFilter.not_set or
                                            self.cluster_id_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-cluster-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_address.get_name_leafdata())
                                        if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cluster-id-address" or name == "cluster-id-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cluster-id-address"):
                                            self.cluster_id_address = value
                                            self.cluster_id_address.value_namespace = name_space
                                            self.cluster_id_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cluster-id-number"):
                                            self.cluster_id_number = value
                                            self.cluster_id_number.value_namespace = name_space
                                            self.cluster_id_number.value_namespace_prefix = name_space_prefix


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "session-group"

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mss",
                                                        "tcpmss_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mss.is_set or
                                            self.tcpmss_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mss.yfilter != YFilter.not_set or
                                            self.tcpmss_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tcpmss" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mss.is_set or self.mss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mss.get_name_leafdata())
                                        if (self.tcpmss_disable.is_set or self.tcpmss_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tcpmss_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mss" or name == "tcpmss-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mss"):
                                            self.mss = value
                                            self.mss.value_namespace = name_space
                                            self.mss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tcpmss-disable"):
                                            self.tcpmss_disable = value
                                            self.tcpmss_disable.value_namespace = name_space
                                            self.tcpmss_disable.value_namespace_prefix = name_space_prefix


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "session-group"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type",
                                                        "value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            self.value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            self.value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tos" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())
                                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "type" or name == "value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "value"):
                                            self.value = value
                                            self.value.value_namespace = name_space
                                            self.value.value_namespace_prefix = name_space_prefix


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "session-group"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "update_in_filtering_attribute_filter_group",
                                                        "update_in_filtering_syslog_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering, self).__setattr__(name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("non_circular_buffer",
                                                            "number_of_buffers") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.non_circular_buffer.is_set or
                                                self.number_of_buffers.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.non_circular_buffer.yfilter != YFilter.not_set or
                                                self.number_of_buffers.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "update-in-filtering-message-buffers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.non_circular_buffer.is_set or self.non_circular_buffer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.non_circular_buffer.get_name_leafdata())
                                            if (self.number_of_buffers.is_set or self.number_of_buffers.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_buffers.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "non-circular-buffer" or name == "number-of-buffers"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "non-circular-buffer"):
                                                self.non_circular_buffer = value
                                                self.non_circular_buffer.value_namespace = name_space
                                                self.non_circular_buffer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-buffers"):
                                                self.number_of_buffers = value
                                                self.number_of_buffers.value_namespace = name_space
                                                self.number_of_buffers.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.update_in_filtering_attribute_filter_group.is_set or
                                            self.update_in_filtering_syslog_disable.is_set or
                                            (self.update_in_filtering_message_buffers is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set or
                                            self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set or
                                            (self.update_in_filtering_message_buffers is not None and self.update_in_filtering_message_buffers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "update-in-filtering" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.update_in_filtering_attribute_filter_group.is_set or self.update_in_filtering_attribute_filter_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_attribute_filter_group.get_name_leafdata())
                                        if (self.update_in_filtering_syslog_disable.is_set or self.update_in_filtering_syslog_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.update_in_filtering_syslog_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "update-in-filtering-message-buffers"):
                                            if (self.update_in_filtering_message_buffers is None):
                                                self.update_in_filtering_message_buffers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers()
                                                self.update_in_filtering_message_buffers.parent = self
                                                self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                            return self.update_in_filtering_message_buffers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "update-in-filtering-message-buffers" or name == "enable" or name == "update-in-filtering-attribute-filter-group" or name == "update-in-filtering-syslog-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-attribute-filter-group"):
                                            self.update_in_filtering_attribute_filter_group = value
                                            self.update_in_filtering_attribute_filter_group.value_namespace = name_space
                                            self.update_in_filtering_attribute_filter_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "update-in-filtering-syslog-disable"):
                                            self.update_in_filtering_syslog_disable = value
                                            self.update_in_filtering_syslog_disable.value_namespace = name_space
                                            self.update_in_filtering_syslog_disable.value_namespace_prefix = name_space_prefix


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "session-group"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-out" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "session-group"

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_receive_size",
                                                        "socket_receive_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_receive_size.is_set or
                                            self.socket_receive_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_receive_size.yfilter != YFilter.not_set or
                                            self.socket_receive_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "receive-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                        if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-receive-size"):
                                            self.bgp_receive_size = value
                                            self.bgp_receive_size.value_namespace = name_space
                                            self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-receive-size"):
                                            self.socket_receive_size = value
                                            self.socket_receive_size.value_namespace = name_space
                                            self.socket_receive_size.value_namespace_prefix = name_space_prefix


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "session-group"

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("msg_buf_count",
                                                        "msg_log_disable",
                                                        "msg_log_inherit_disable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.msg_buf_count.is_set or
                                            self.msg_log_disable.is_set or
                                            self.msg_log_inherit_disable.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.msg_buf_count.yfilter != YFilter.not_set or
                                            self.msg_log_disable.yfilter != YFilter.not_set or
                                            self.msg_log_inherit_disable.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "msg-log-in" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.msg_buf_count.is_set or self.msg_buf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_buf_count.get_name_leafdata())
                                        if (self.msg_log_disable.is_set or self.msg_log_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_disable.get_name_leafdata())
                                        if (self.msg_log_inherit_disable.is_set or self.msg_log_inherit_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msg_log_inherit_disable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "msg-buf-count" or name == "msg-log-disable" or name == "msg-log-inherit-disable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "msg-buf-count"):
                                            self.msg_buf_count = value
                                            self.msg_buf_count.value_namespace = name_space
                                            self.msg_buf_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-disable"):
                                            self.msg_log_disable = value
                                            self.msg_log_disable.value_namespace = name_space
                                            self.msg_log_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msg-log-inherit-disable"):
                                            self.msg_log_inherit_disable = value
                                            self.msg_log_inherit_disable.value_namespace = name_space
                                            self.msg_log_inherit_disable.value_namespace_prefix = name_space_prefix


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "session-group"

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_send_size",
                                                        "socket_send_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_send_size.is_set or
                                            self.socket_send_size.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_send_size.yfilter != YFilter.not_set or
                                            self.socket_send_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "send-buffer-size" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                        if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-send-size" or name == "socket-send-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-send-size"):
                                            self.bgp_send_size = value
                                            self.bgp_send_size.value_namespace = name_space
                                            self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "socket-send-size"):
                                            self.socket_send_size = value
                                            self.socket_send_size.value_namespace = name_space
                                            self.socket_send_size.value_namespace_prefix = name_space_prefix


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "session-group"

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("hold_time",
                                                        "keepalive_interval",
                                                        "min_accept_hold_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.hold_time.is_set or
                                            self.keepalive_interval.is_set or
                                            self.min_accept_hold_time.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.hold_time.yfilter != YFilter.not_set or
                                            self.keepalive_interval.yfilter != YFilter.not_set or
                                            self.min_accept_hold_time.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hold_time.get_name_leafdata())
                                        if (self.keepalive_interval.is_set or self.keepalive_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keepalive_interval.get_name_leafdata())
                                        if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "hold-time" or name == "keepalive-interval" or name == "min-accept-hold-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "hold-time"):
                                            self.hold_time = value
                                            self.hold_time.value_namespace = name_space
                                            self.hold_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keepalive-interval"):
                                            self.keepalive_interval = value
                                            self.keepalive_interval.value_namespace = name_space
                                            self.keepalive_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "min-accept-hold-time"):
                                            self.min_accept_hold_time = value
                                            self.min_accept_hold_time.value_namespace = name_space
                                            self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "session-group"

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("keychain_disable",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.keychain_disable.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.keychain_disable.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "keychain" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.keychain_disable.is_set or self.keychain_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_disable.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "keychain-disable" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "keychain-disable"):
                                            self.keychain_disable = value
                                            self.keychain_disable.value_namespace = name_space
                                            self.keychain_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "session-group"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "graceful_maintenance_activate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance, self).__setattr__(name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("gshut_loc_pref_disable",
                                                            "local_preference") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.gshut_loc_pref_disable.is_set or
                                                self.local_preference.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.gshut_loc_pref_disable.yfilter != YFilter.not_set or
                                                self.local_preference.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-local-preference" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.gshut_loc_pref_disable.is_set or self.gshut_loc_pref_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_loc_pref_disable.get_name_leafdata())
                                            if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_preference.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "gshut-loc-pref-disable" or name == "local-preference"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "gshut-loc-pref-disable"):
                                                self.gshut_loc_pref_disable = value
                                                self.gshut_loc_pref_disable.value_namespace = name_space
                                                self.gshut_loc_pref_disable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-preference"):
                                                self.local_preference = value
                                                self.local_preference.value_namespace = name_space
                                                self.local_preference.value_namespace_prefix = name_space_prefix


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("as_prepends",
                                                            "gshut_prepends_disable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.as_prepends.is_set or
                                                self.gshut_prepends_disable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.as_prepends.yfilter != YFilter.not_set or
                                                self.gshut_prepends_disable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "graceful-maintenance-as-prepends" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.as_prepends.is_set or self.as_prepends.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_prepends.get_name_leafdata())
                                            if (self.gshut_prepends_disable.is_set or self.gshut_prepends_disable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.gshut_prepends_disable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "as-prepends" or name == "gshut-prepends-disable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "as-prepends"):
                                                self.as_prepends = value
                                                self.as_prepends.value_namespace = name_space
                                                self.as_prepends.value_namespace_prefix = name_space_prefix
                                            if(value_path == "gshut-prepends-disable"):
                                                self.gshut_prepends_disable = value
                                                self.gshut_prepends_disable.value_namespace = name_space
                                                self.gshut_prepends_disable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.graceful_maintenance_activate.is_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_data()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.graceful_maintenance_activate.yfilter != YFilter.not_set or
                                            (self.graceful_maintenance_as_prepends is not None and self.graceful_maintenance_as_prepends.has_operation()) or
                                            (self.graceful_maintenance_local_preference is not None and self.graceful_maintenance_local_preference.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "graceful-maintenance" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.graceful_maintenance_activate.is_set or self.graceful_maintenance_activate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.graceful_maintenance_activate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "graceful-maintenance-as-prepends"):
                                            if (self.graceful_maintenance_as_prepends is None):
                                                self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                                self.graceful_maintenance_as_prepends.parent = self
                                                self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                            return self.graceful_maintenance_as_prepends

                                        if (child_yang_name == "graceful-maintenance-local-preference"):
                                            if (self.graceful_maintenance_local_preference is None):
                                                self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                                self.graceful_maintenance_local_preference.parent = self
                                                self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                            return self.graceful_maintenance_local_preference

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "graceful-maintenance-as-prepends" or name == "graceful-maintenance-local-preference" or name == "enable" or name == "graceful-maintenance-activate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "graceful-maintenance-activate"):
                                            self.graceful_maintenance_activate = value
                                            self.graceful_maintenance_activate.value_namespace = name_space
                                            self.graceful_maintenance_activate.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.session_group_name.is_set or
                                        self.additional_paths_receive_capability.is_set or
                                        self.additional_paths_send_capability.is_set or
                                        self.bfd_enable_modes.is_set or
                                        self.bfd_minimum_interval.is_set or
                                        self.bfd_multiplier.is_set or
                                        self.create.is_set or
                                        self.description.is_set or
                                        self.ebgp_recv_dmz.is_set or
                                        self.ebgp_send_dmz_enable_modes.is_set or
                                        self.egress_peer_engineering.is_set or
                                        self.enforce_first_as.is_set or
                                        self.idle_watch_time.is_set or
                                        self.ignore_connected_check_ebgp.is_set or
                                        self.internal_vpn_client_ibgpce.is_set or
                                        self.max_peers.is_set or
                                        self.neighbor_graceful_restart.is_set or
                                        self.neighbor_graceful_restart_stalepath_time.is_set or
                                        self.neighbor_graceful_restart_time.is_set or
                                        self.propagate_dmz_link_bandwidth.is_set or
                                        self.remote_as_list.is_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                        self.rpki_origin_as_validation_disable.is_set or
                                        self.session_group_add_member.is_set or
                                        self.session_open_mode.is_set or
                                        self.shutdown.is_set or
                                        self.suppress_all_capabilities.is_set or
                                        self.suppress_four_byte_as_capability.is_set or
                                        self.ttl_security.is_set or
                                        self.update_source_interface.is_set or
                                        (self.bmp_activates is not None and self.bmp_activates.has_data()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_data()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_data()) or
                                        (self.keychain is not None and self.keychain.has_data()) or
                                        (self.local_address is not None and self.local_address.has_data()) or
                                        (self.local_as is not None and self.local_as.has_data()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_data()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_data()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_data()) or
                                        (self.password is not None and self.password.has_data()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_data()) or
                                        (self.remote_as is not None and self.remote_as.has_data()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_data()) or
                                        (self.tcpmss is not None and self.tcpmss.has_data()) or
                                        (self.timers is not None and self.timers.has_data()) or
                                        (self.tos is not None and self.tos.has_data()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_data()) or
                                        (self.advertisement_interval is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.session_group_name.yfilter != YFilter.not_set or
                                        self.additional_paths_receive_capability.yfilter != YFilter.not_set or
                                        self.additional_paths_send_capability.yfilter != YFilter.not_set or
                                        self.bfd_enable_modes.yfilter != YFilter.not_set or
                                        self.bfd_minimum_interval.yfilter != YFilter.not_set or
                                        self.bfd_multiplier.yfilter != YFilter.not_set or
                                        self.create.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.ebgp_recv_dmz.yfilter != YFilter.not_set or
                                        self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set or
                                        self.egress_peer_engineering.yfilter != YFilter.not_set or
                                        self.enforce_first_as.yfilter != YFilter.not_set or
                                        self.idle_watch_time.yfilter != YFilter.not_set or
                                        self.ignore_connected_check_ebgp.yfilter != YFilter.not_set or
                                        self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set or
                                        self.max_peers.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set or
                                        self.neighbor_graceful_restart_time.yfilter != YFilter.not_set or
                                        self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set or
                                        self.remote_as_list.yfilter != YFilter.not_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                        self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                        self.session_group_add_member.yfilter != YFilter.not_set or
                                        self.session_open_mode.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.suppress_all_capabilities.yfilter != YFilter.not_set or
                                        self.suppress_four_byte_as_capability.yfilter != YFilter.not_set or
                                        self.ttl_security.yfilter != YFilter.not_set or
                                        self.update_source_interface.yfilter != YFilter.not_set or
                                        (self.advertisement_interval is not None and self.advertisement_interval.has_operation()) or
                                        (self.bmp_activates is not None and self.bmp_activates.has_operation()) or
                                        (self.ebgp_multihop is not None and self.ebgp_multihop.has_operation()) or
                                        (self.graceful_maintenance is not None and self.graceful_maintenance.has_operation()) or
                                        (self.keychain is not None and self.keychain.has_operation()) or
                                        (self.local_address is not None and self.local_address.has_operation()) or
                                        (self.local_as is not None and self.local_as.has_operation()) or
                                        (self.msg_log_in is not None and self.msg_log_in.has_operation()) or
                                        (self.msg_log_out is not None and self.msg_log_out.has_operation()) or
                                        (self.neighbor_cluster_id is not None and self.neighbor_cluster_id.has_operation()) or
                                        (self.password is not None and self.password.has_operation()) or
                                        (self.receive_buffer_size is not None and self.receive_buffer_size.has_operation()) or
                                        (self.remote_as is not None and self.remote_as.has_operation()) or
                                        (self.send_buffer_size is not None and self.send_buffer_size.has_operation()) or
                                        (self.tcpmss is not None and self.tcpmss.has_operation()) or
                                        (self.timers is not None and self.timers.has_operation()) or
                                        (self.tos is not None and self.tos.has_operation()) or
                                        (self.update_in_filtering is not None and self.update_in_filtering.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "session-group" + "[session-group-name='" + self.session_group_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.session_group_name.is_set or self.session_group_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_group_name.get_name_leafdata())
                                    if (self.additional_paths_receive_capability.is_set or self.additional_paths_receive_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_receive_capability.get_name_leafdata())
                                    if (self.additional_paths_send_capability.is_set or self.additional_paths_send_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_send_capability.get_name_leafdata())
                                    if (self.bfd_enable_modes.is_set or self.bfd_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_enable_modes.get_name_leafdata())
                                    if (self.bfd_minimum_interval.is_set or self.bfd_minimum_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_minimum_interval.get_name_leafdata())
                                    if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                                    if (self.create.is_set or self.create.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.create.get_name_leafdata())
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.ebgp_recv_dmz.is_set or self.ebgp_recv_dmz.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_recv_dmz.get_name_leafdata())
                                    if (self.ebgp_send_dmz_enable_modes.is_set or self.ebgp_send_dmz_enable_modes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebgp_send_dmz_enable_modes.get_name_leafdata())
                                    if (self.egress_peer_engineering.is_set or self.egress_peer_engineering.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.egress_peer_engineering.get_name_leafdata())
                                    if (self.enforce_first_as.is_set or self.enforce_first_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enforce_first_as.get_name_leafdata())
                                    if (self.idle_watch_time.is_set or self.idle_watch_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.idle_watch_time.get_name_leafdata())
                                    if (self.ignore_connected_check_ebgp.is_set or self.ignore_connected_check_ebgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ignore_connected_check_ebgp.get_name_leafdata())
                                    if (self.internal_vpn_client_ibgpce.is_set or self.internal_vpn_client_ibgpce.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_vpn_client_ibgpce.get_name_leafdata())
                                    if (self.max_peers.is_set or self.max_peers.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_peers.get_name_leafdata())
                                    if (self.neighbor_graceful_restart.is_set or self.neighbor_graceful_restart.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_stalepath_time.is_set or self.neighbor_graceful_restart_stalepath_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_stalepath_time.get_name_leafdata())
                                    if (self.neighbor_graceful_restart_time.is_set or self.neighbor_graceful_restart_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_graceful_restart_time.get_name_leafdata())
                                    if (self.propagate_dmz_link_bandwidth.is_set or self.propagate_dmz_link_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.propagate_dmz_link_bandwidth.get_name_leafdata())
                                    if (self.remote_as_list.is_set or self.remote_as_list.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_as_list.get_name_leafdata())
                                    if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                    if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                    if (self.session_group_add_member.is_set or self.session_group_add_member.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_group_add_member.get_name_leafdata())
                                    if (self.session_open_mode.is_set or self.session_open_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.session_open_mode.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.suppress_all_capabilities.is_set or self.suppress_all_capabilities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_all_capabilities.get_name_leafdata())
                                    if (self.suppress_four_byte_as_capability.is_set or self.suppress_four_byte_as_capability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_four_byte_as_capability.get_name_leafdata())
                                    if (self.ttl_security.is_set or self.ttl_security.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security.get_name_leafdata())
                                    if (self.update_source_interface.is_set or self.update_source_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_source_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "advertisement-interval"):
                                        if (self.advertisement_interval is None):
                                            self.advertisement_interval = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval()
                                            self.advertisement_interval.parent = self
                                            self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                        return self.advertisement_interval

                                    if (child_yang_name == "bmp-activates"):
                                        if (self.bmp_activates is None):
                                            self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates()
                                            self.bmp_activates.parent = self
                                            self._children_name_map["bmp_activates"] = "bmp-activates"
                                        return self.bmp_activates

                                    if (child_yang_name == "ebgp-multihop"):
                                        if (self.ebgp_multihop is None):
                                            self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop()
                                            self.ebgp_multihop.parent = self
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                        return self.ebgp_multihop

                                    if (child_yang_name == "graceful-maintenance"):
                                        if (self.graceful_maintenance is None):
                                            self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        return self.graceful_maintenance

                                    if (child_yang_name == "keychain"):
                                        if (self.keychain is None):
                                            self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                        return self.keychain

                                    if (child_yang_name == "local-address"):
                                        if (self.local_address is None):
                                            self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                        return self.local_address

                                    if (child_yang_name == "local-as"):
                                        if (self.local_as is None):
                                            self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs()
                                            self.local_as.parent = self
                                            self._children_name_map["local_as"] = "local-as"
                                        return self.local_as

                                    if (child_yang_name == "msg-log-in"):
                                        if (self.msg_log_in is None):
                                            self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn()
                                            self.msg_log_in.parent = self
                                            self._children_name_map["msg_log_in"] = "msg-log-in"
                                        return self.msg_log_in

                                    if (child_yang_name == "msg-log-out"):
                                        if (self.msg_log_out is None):
                                            self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut()
                                            self.msg_log_out.parent = self
                                            self._children_name_map["msg_log_out"] = "msg-log-out"
                                        return self.msg_log_out

                                    if (child_yang_name == "neighbor-cluster-id"):
                                        if (self.neighbor_cluster_id is None):
                                            self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId()
                                            self.neighbor_cluster_id.parent = self
                                            self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                        return self.neighbor_cluster_id

                                    if (child_yang_name == "password"):
                                        if (self.password is None):
                                            self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"
                                        return self.password

                                    if (child_yang_name == "receive-buffer-size"):
                                        if (self.receive_buffer_size is None):
                                            self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize()
                                            self.receive_buffer_size.parent = self
                                            self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                        return self.receive_buffer_size

                                    if (child_yang_name == "remote-as"):
                                        if (self.remote_as is None):
                                            self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs()
                                            self.remote_as.parent = self
                                            self._children_name_map["remote_as"] = "remote-as"
                                        return self.remote_as

                                    if (child_yang_name == "send-buffer-size"):
                                        if (self.send_buffer_size is None):
                                            self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize()
                                            self.send_buffer_size.parent = self
                                            self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                        return self.send_buffer_size

                                    if (child_yang_name == "tcpmss"):
                                        if (self.tcpmss is None):
                                            self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss()
                                            self.tcpmss.parent = self
                                            self._children_name_map["tcpmss"] = "tcpmss"
                                        return self.tcpmss

                                    if (child_yang_name == "timers"):
                                        if (self.timers is None):
                                            self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"
                                        return self.timers

                                    if (child_yang_name == "tos"):
                                        if (self.tos is None):
                                            self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos()
                                            self.tos.parent = self
                                            self._children_name_map["tos"] = "tos"
                                        return self.tos

                                    if (child_yang_name == "update-in-filtering"):
                                        if (self.update_in_filtering is None):
                                            self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering()
                                            self.update_in_filtering.parent = self
                                            self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                        return self.update_in_filtering

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertisement-interval" or name == "bmp-activates" or name == "ebgp-multihop" or name == "graceful-maintenance" or name == "keychain" or name == "local-address" or name == "local-as" or name == "msg-log-in" or name == "msg-log-out" or name == "neighbor-cluster-id" or name == "password" or name == "receive-buffer-size" or name == "remote-as" or name == "send-buffer-size" or name == "tcpmss" or name == "timers" or name == "tos" or name == "update-in-filtering" or name == "session-group-name" or name == "additional-paths-receive-capability" or name == "additional-paths-send-capability" or name == "bfd-enable-modes" or name == "bfd-minimum-interval" or name == "bfd-multiplier" or name == "create" or name == "description" or name == "ebgp-recv-dmz" or name == "ebgp-send-dmz-enable-modes" or name == "egress-peer-engineering" or name == "enforce-first-as" or name == "idle-watch-time" or name == "ignore-connected-check-ebgp" or name == "internal-vpn-client-ibgpce" or name == "max-peers" or name == "neighbor-graceful-restart" or name == "neighbor-graceful-restart-stalepath-time" or name == "neighbor-graceful-restart-time" or name == "propagate-dmz-link-bandwidth" or name == "remote-as-list" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-origin-as-validation-disable" or name == "session-group-add-member" or name == "session-open-mode" or name == "shutdown" or name == "suppress-all-capabilities" or name == "suppress-four-byte-as-capability" or name == "ttl-security" or name == "update-source-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "session-group-name"):
                                        self.session_group_name = value
                                        self.session_group_name.value_namespace = name_space
                                        self.session_group_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-receive-capability"):
                                        self.additional_paths_receive_capability = value
                                        self.additional_paths_receive_capability.value_namespace = name_space
                                        self.additional_paths_receive_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-send-capability"):
                                        self.additional_paths_send_capability = value
                                        self.additional_paths_send_capability.value_namespace = name_space
                                        self.additional_paths_send_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-enable-modes"):
                                        self.bfd_enable_modes = value
                                        self.bfd_enable_modes.value_namespace = name_space
                                        self.bfd_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-minimum-interval"):
                                        self.bfd_minimum_interval = value
                                        self.bfd_minimum_interval.value_namespace = name_space
                                        self.bfd_minimum_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-multiplier"):
                                        self.bfd_multiplier = value
                                        self.bfd_multiplier.value_namespace = name_space
                                        self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "create"):
                                        self.create = value
                                        self.create.value_namespace = name_space
                                        self.create.value_namespace_prefix = name_space_prefix
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-recv-dmz"):
                                        self.ebgp_recv_dmz = value
                                        self.ebgp_recv_dmz.value_namespace = name_space
                                        self.ebgp_recv_dmz.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebgp-send-dmz-enable-modes"):
                                        self.ebgp_send_dmz_enable_modes = value
                                        self.ebgp_send_dmz_enable_modes.value_namespace = name_space
                                        self.ebgp_send_dmz_enable_modes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "egress-peer-engineering"):
                                        self.egress_peer_engineering = value
                                        self.egress_peer_engineering.value_namespace = name_space
                                        self.egress_peer_engineering.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enforce-first-as"):
                                        self.enforce_first_as = value
                                        self.enforce_first_as.value_namespace = name_space
                                        self.enforce_first_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "idle-watch-time"):
                                        self.idle_watch_time = value
                                        self.idle_watch_time.value_namespace = name_space
                                        self.idle_watch_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ignore-connected-check-ebgp"):
                                        self.ignore_connected_check_ebgp = value
                                        self.ignore_connected_check_ebgp.value_namespace = name_space
                                        self.ignore_connected_check_ebgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-vpn-client-ibgpce"):
                                        self.internal_vpn_client_ibgpce = value
                                        self.internal_vpn_client_ibgpce.value_namespace = name_space
                                        self.internal_vpn_client_ibgpce.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-peers"):
                                        self.max_peers = value
                                        self.max_peers.value_namespace = name_space
                                        self.max_peers.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart"):
                                        self.neighbor_graceful_restart = value
                                        self.neighbor_graceful_restart.value_namespace = name_space
                                        self.neighbor_graceful_restart.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-stalepath-time"):
                                        self.neighbor_graceful_restart_stalepath_time = value
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_stalepath_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-graceful-restart-time"):
                                        self.neighbor_graceful_restart_time = value
                                        self.neighbor_graceful_restart_time.value_namespace = name_space
                                        self.neighbor_graceful_restart_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "propagate-dmz-link-bandwidth"):
                                        self.propagate_dmz_link_bandwidth = value
                                        self.propagate_dmz_link_bandwidth.value_namespace = name_space
                                        self.propagate_dmz_link_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-as-list"):
                                        self.remote_as_list = value
                                        self.remote_as_list.value_namespace = name_space
                                        self.remote_as_list.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                        self.rpki_bestpath_origin_as_allow_invalid = value
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-origin-as-validation-disable"):
                                        self.rpki_origin_as_validation_disable = value
                                        self.rpki_origin_as_validation_disable.value_namespace = name_space
                                        self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-group-add-member"):
                                        self.session_group_add_member = value
                                        self.session_group_add_member.value_namespace = name_space
                                        self.session_group_add_member.value_namespace_prefix = name_space_prefix
                                    if(value_path == "session-open-mode"):
                                        self.session_open_mode = value
                                        self.session_open_mode.value_namespace = name_space
                                        self.session_open_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-all-capabilities"):
                                        self.suppress_all_capabilities = value
                                        self.suppress_all_capabilities.value_namespace = name_space
                                        self.suppress_all_capabilities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-four-byte-as-capability"):
                                        self.suppress_four_byte_as_capability = value
                                        self.suppress_four_byte_as_capability.value_namespace = name_space
                                        self.suppress_four_byte_as_capability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security"):
                                        self.ttl_security = value
                                        self.ttl_security.value_namespace = name_space
                                        self.ttl_security.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-source-interface"):
                                        self.update_source_interface = value
                                        self.update_source_interface.value_namespace = name_space
                                        self.update_source_interface.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.session_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.session_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "session-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "session-group"):
                                    for c in self.session_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.session_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "session-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.af_groups is not None and self.af_groups.has_data()) or
                                (self.neighbor_groups is not None and self.neighbor_groups.has_data()) or
                                (self.neighbors is not None and self.neighbors.has_data()) or
                                (self.session_groups is not None and self.session_groups.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.af_groups is not None and self.af_groups.has_operation()) or
                                (self.neighbor_groups is not None and self.neighbor_groups.has_operation()) or
                                (self.neighbors is not None and self.neighbors.has_operation()) or
                                (self.session_groups is not None and self.session_groups.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bgp-entity" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "af-groups"):
                                if (self.af_groups is None):
                                    self.af_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups()
                                    self.af_groups.parent = self
                                    self._children_name_map["af_groups"] = "af-groups"
                                return self.af_groups

                            if (child_yang_name == "neighbor-groups"):
                                if (self.neighbor_groups is None):
                                    self.neighbor_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups()
                                    self.neighbor_groups.parent = self
                                    self._children_name_map["neighbor_groups"] = "neighbor-groups"
                                return self.neighbor_groups

                            if (child_yang_name == "neighbors"):
                                if (self.neighbors is None):
                                    self.neighbors = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                return self.neighbors

                            if (child_yang_name == "session-groups"):
                                if (self.session_groups is None):
                                    self.session_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups()
                                    self.session_groups.parent = self
                                    self._children_name_map["session_groups"] = "session-groups"
                                return self.session_groups

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-groups" or name == "neighbor-groups" or name == "neighbors" or name == "session-groups"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Global_(Entity):
                        """
                        Global default config
                        
                        .. attribute:: as_league
                        
                        	AS League
                        	**type**\:   :py:class:`AsLeague <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague>`
                        
                        .. attribute:: as_list_groups
                        
                        	AS\-list group lists
                        	**type**\:   :py:class:`AsListGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups>`
                        
                        .. attribute:: attribute_filter_groups
                        
                        	Attribute\-filter groups list
                        	**type**\:   :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups>`
                        
                        .. attribute:: best_path_aigp_ignore
                        
                        	Change default route selection criteria to ignore AIGP unless both paths whichare compared have AIGP attribute
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_as_multipath_relax
                        
                        	Change default multi\-route selection criteria to relax as\-path checking \- only require same aspath length
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_as_path_length
                        
                        	Change default route selection criteria to ignore AS path length
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_confederation_paths
                        
                        	Change default route selection criteria and allow the comparing of MED among confederation paths
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_cost_community
                        
                        	Change default route selection criteria to ignore cost community comparison
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_med_always
                        
                        	Change default route selection criteria and allow comparing of MED from different neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_med_missing
                        
                        	Treat missing MED as the least preferred one
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_router_id
                        
                        	Change default route selection criteria and compare router\-id for identical EBGP paths
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: bfd
                        
                        	BFD configuration
                        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd>`
                        
                        .. attribute:: cluster_id
                        
                        	Configure Route\-Reflector Cluster\-id
                        	**type**\:   :py:class:`ClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId>`
                        
                        .. attribute:: confederation_domain
                        
                        	Set routing domain confederation AS
                        	**type**\:   :py:class:`ConfederationDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain>`
                        
                        .. attribute:: confederation_peer_ases
                        
                        	Define peer ASes in BGP confederation
                        	**type**\:   :py:class:`ConfederationPeerAses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses>`
                        
                        .. attribute:: default_info_originate
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: default_metric
                        
                        	Default redistributed metric
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: disable_auto_soft_reset
                        
                        	Disable automatic soft peer reset on policy reconfiguration
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_enforce_first_as
                        
                        	Disable enforce the first AS for EBGP routes
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_fast_external_fallover
                        
                        	Disable immediate reset session if a link to a directly connected external peer goes down
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_msg_log
                        
                        	Disable inbound and outbound messagelogging for all neighbors under the vrf
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_neighbor_logging
                        
                        	Disable neighbor change logging
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: enforce_ibgp_out_policy
                        
                        	Allow all attributes to be modified by outbound policy for iBGP peers
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: global_afs
                        
                        	Global AF\-specific configuration
                        	**type**\:   :py:class:`GlobalAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs>`
                        
                        .. attribute:: global_graceful_maintenance_activate
                        
                        	Activate Graceful Maintenance Mode for all neighbors with graceful maintenance config
                        	**type**\:   :py:class:`GlobalGracefulMaintenanceActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate>`
                        
                        .. attribute:: global_scan_time
                        
                        	Configure background scanner interval for generic scanner
                        	**type**\:  int
                        
                        	**range:** 5..3600
                        
                        	**units**\: second
                        
                        	**default value**\: 60
                        
                        .. attribute:: global_timers
                        
                        	Adjust routing timers
                        	**type**\:   :py:class:`GlobalTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers>`
                        
                        .. attribute:: graceful_reset
                        
                        	Reset gracefully if configuration change forces a peer reset
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: graceful_restart
                        
                        	Enable graceful restart support
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: graceful_restart_purge_time
                        
                        	Time before stale routes are purged
                        	**type**\:  int
                        
                        	**range:** 1..6000
                        
                        	**units**\: second
                        
                        	**default value**\: 600
                        
                        .. attribute:: graceful_restart_stalepath_time
                        
                        	Maximum time to wait for restart of GR capable peers
                        	**type**\:  int
                        
                        	**range:** 1..4095
                        
                        	**units**\: second
                        
                        	**default value**\: 360
                        
                        .. attribute:: graceful_restart_time
                        
                        	Restart time advertised to neighbors
                        	**type**\:  int
                        
                        	**range:** 1..4095
                        
                        	**units**\: second
                        
                        	**default value**\: 120
                        
                        .. attribute:: igp_loop_check
                        
                        	Enable AS\-path loop checking for iBGP peers
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: igp_redist_internal
                        
                        	Allow redistribution of iBGP into IGPs (dangerous)
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: install_diversion
                        
                        	Install diversion path to RIB/CEF
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: limits
                        
                        	Maximum number that can be configured
                        	**type**\:   :py:class:`Limits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits>`
                        
                        .. attribute:: local_preference
                        
                        	Configure default local preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**default value**\: 100
                        
                        .. attribute:: mpls_activated_interfaces
                        
                        	Configure list of MPLS activated interfaces
                        	**type**\:   :py:class:`MplsActivatedInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces>`
                        
                        .. attribute:: multi_path_as_path_ignore_onwards
                        
                        	Change default multi\-route selection criteria to ignore everything onwards as\-path check
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mvpn
                        
                        	Connect to PIM/PIM6
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: neighbor_logging_detail
                        
                        	Include extra detail in neighbor change messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: next_hop_trigger_delay
                        
                        	Set the delay for triggering nexthop recalculations
                        	**type**\:  int
                        
                        	**range:** 0..300
                        
                        	**units**\: second
                        
                        	**default value**\: 5
                        
                        .. attribute:: nsr
                        
                        	TRUE to Enable non\-stop routing supportFALSE to Disable non\-stop routing support
                        	**type**\:  bool
                        
                        .. attribute:: read_only
                        
                        	Allow duplicate table config and disable update generation
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_socket_buffer_sizes
                        
                        	Set socket and BGP receive buffer sizes
                        	**type**\:   :py:class:`ReceiveSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes>`
                        
                        .. attribute:: router_id
                        
                        	Configure Router\-id
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**default value**\: 0.0.0.0
                        
                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                        
                        	RPKI bestpath origin\-AS allow invalid
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_bestpath_use_origin_as_validity
                        
                        	RPKI bestpath use origin\-AS validity
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_origin_as_validation_disable
                        
                        	RPKI origin\-AS validation disable
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_origin_as_validation_time
                        
                        	Prefix validation time (in seconds). Range  \: 5 \- 60. Specify 0 to disable the timer
                        	**type**\:  int
                        
                        	**range:** 0..60
                        
                        	**units**\: second
                        
                        .. attribute:: rpki_origin_as_validity_signal_ibgp
                        
                        	RPKI origin\-AS validity signal ibgp
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_servers
                        
                        	RPKI server configuration
                        	**type**\:   :py:class:`RpkiServers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers>`
                        
                        .. attribute:: rpki_static_routes
                        
                        	RPKI static route configuration
                        	**type**\:   :py:class:`RpkiStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes>`
                        
                        .. attribute:: send_socket_buffer_sizes
                        
                        	set socket parameters
                        	**type**\:   :py:class:`SendSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes>`
                        
                        .. attribute:: update_delay
                        
                        	Set the max initial delay for sending updates
                        	**type**\:   :py:class:`UpdateDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay>`
                        
                        .. attribute:: update_error_handling_basic_ebgp_disable
                        
                        	Inbound update basic error\-handling for EBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_error_handling_basic_ibgp_disable
                        
                        	Inbound update basic error\-handling for IBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_error_handling_extended_ebgp
                        
                        	Inbound update extended error\-handling for EBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_error_handling_extended_ibgp
                        
                        	Inbound update extended error\-handling for IBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_limit_process
                        
                        	Upper bound on update generation transient memory usage for the process
                        	**type**\:  int
                        
                        	**range:** 16..2048
                        
                        	**units**\: megabyte
                        
                        	**default value**\: 512
                        
                        .. attribute:: update_out_logging
                        
                        	Enables logging of update generation events
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: write_limit
                        
                        	Set write\-queue limit for each update group
                        	**type**\:   :py:class:`WriteLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-cfg'
                        _revision = '2015-08-27'

                        def __init__(self):
                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "default-vrf"

                            self.best_path_aigp_ignore = YLeaf(YType.empty, "best-path-aigp-ignore")

                            self.best_path_as_multipath_relax = YLeaf(YType.empty, "best-path-as-multipath-relax")

                            self.best_path_as_path_length = YLeaf(YType.empty, "best-path-as-path-length")

                            self.best_path_confederation_paths = YLeaf(YType.empty, "best-path-confederation-paths")

                            self.best_path_cost_community = YLeaf(YType.empty, "best-path-cost-community")

                            self.best_path_med_always = YLeaf(YType.empty, "best-path-med-always")

                            self.best_path_med_missing = YLeaf(YType.empty, "best-path-med-missing")

                            self.best_path_router_id = YLeaf(YType.empty, "best-path-router-id")

                            self.default_info_originate = YLeaf(YType.empty, "default-info-originate")

                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                            self.disable_auto_soft_reset = YLeaf(YType.empty, "disable-auto-soft-reset")

                            self.disable_enforce_first_as = YLeaf(YType.empty, "disable-enforce-first-as")

                            self.disable_fast_external_fallover = YLeaf(YType.empty, "disable-fast-external-fallover")

                            self.disable_msg_log = YLeaf(YType.empty, "disable-msg-log")

                            self.disable_neighbor_logging = YLeaf(YType.empty, "disable-neighbor-logging")

                            self.enforce_ibgp_out_policy = YLeaf(YType.empty, "enforce-ibgp-out-policy")

                            self.global_scan_time = YLeaf(YType.uint32, "global-scan-time")

                            self.graceful_reset = YLeaf(YType.empty, "graceful-reset")

                            self.graceful_restart = YLeaf(YType.empty, "graceful-restart")

                            self.graceful_restart_purge_time = YLeaf(YType.uint32, "graceful-restart-purge-time")

                            self.graceful_restart_stalepath_time = YLeaf(YType.uint32, "graceful-restart-stalepath-time")

                            self.graceful_restart_time = YLeaf(YType.uint32, "graceful-restart-time")

                            self.igp_loop_check = YLeaf(YType.empty, "igp-loop-check")

                            self.igp_redist_internal = YLeaf(YType.empty, "igp-redist-internal")

                            self.install_diversion = YLeaf(YType.empty, "install-diversion")

                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                            self.multi_path_as_path_ignore_onwards = YLeaf(YType.empty, "multi-path-as-path-ignore-onwards")

                            self.mvpn = YLeaf(YType.empty, "mvpn")

                            self.neighbor_logging_detail = YLeaf(YType.empty, "neighbor-logging-detail")

                            self.next_hop_trigger_delay = YLeaf(YType.uint32, "next-hop-trigger-delay")

                            self.nsr = YLeaf(YType.boolean, "nsr")

                            self.read_only = YLeaf(YType.empty, "read-only")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                            self.rpki_bestpath_use_origin_as_validity = YLeaf(YType.empty, "rpki-bestpath-use-origin-as-validity")

                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                            self.rpki_origin_as_validation_time = YLeaf(YType.uint32, "rpki-origin-as-validation-time")

                            self.rpki_origin_as_validity_signal_ibgp = YLeaf(YType.empty, "rpki-origin-as-validity-signal-ibgp")

                            self.update_error_handling_basic_ebgp_disable = YLeaf(YType.empty, "update-error-handling-basic-ebgp-disable")

                            self.update_error_handling_basic_ibgp_disable = YLeaf(YType.empty, "update-error-handling-basic-ibgp-disable")

                            self.update_error_handling_extended_ebgp = YLeaf(YType.empty, "update-error-handling-extended-ebgp")

                            self.update_error_handling_extended_ibgp = YLeaf(YType.empty, "update-error-handling-extended-ibgp")

                            self.update_limit_process = YLeaf(YType.uint32, "update-limit-process")

                            self.update_out_logging = YLeaf(YType.empty, "update-out-logging")

                            self.as_league = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague()
                            self.as_league.parent = self
                            self._children_name_map["as_league"] = "as-league"
                            self._children_yang_names.add("as-league")

                            self.as_list_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups()
                            self.as_list_groups.parent = self
                            self._children_name_map["as_list_groups"] = "as-list-groups"
                            self._children_yang_names.add("as-list-groups")

                            self.attribute_filter_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups()
                            self.attribute_filter_groups.parent = self
                            self._children_name_map["attribute_filter_groups"] = "attribute-filter-groups"
                            self._children_yang_names.add("attribute-filter-groups")

                            self.bfd = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"
                            self._children_yang_names.add("bfd")

                            self.cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId()
                            self.cluster_id.parent = self
                            self._children_name_map["cluster_id"] = "cluster-id"
                            self._children_yang_names.add("cluster-id")

                            self.confederation_domain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain()
                            self.confederation_domain.parent = self
                            self._children_name_map["confederation_domain"] = "confederation-domain"
                            self._children_yang_names.add("confederation-domain")

                            self.confederation_peer_ases = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses()
                            self.confederation_peer_ases.parent = self
                            self._children_name_map["confederation_peer_ases"] = "confederation-peer-ases"
                            self._children_yang_names.add("confederation-peer-ases")

                            self.global_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs()
                            self.global_afs.parent = self
                            self._children_name_map["global_afs"] = "global-afs"
                            self._children_yang_names.add("global-afs")

                            self.global_graceful_maintenance_activate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate()
                            self.global_graceful_maintenance_activate.parent = self
                            self._children_name_map["global_graceful_maintenance_activate"] = "global-graceful-maintenance-activate"
                            self._children_yang_names.add("global-graceful-maintenance-activate")

                            self.global_timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers()
                            self.global_timers.parent = self
                            self._children_name_map["global_timers"] = "global-timers"
                            self._children_yang_names.add("global-timers")

                            self.limits = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits()
                            self.limits.parent = self
                            self._children_name_map["limits"] = "limits"
                            self._children_yang_names.add("limits")

                            self.mpls_activated_interfaces = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces()
                            self.mpls_activated_interfaces.parent = self
                            self._children_name_map["mpls_activated_interfaces"] = "mpls-activated-interfaces"
                            self._children_yang_names.add("mpls-activated-interfaces")

                            self.receive_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes()
                            self.receive_socket_buffer_sizes.parent = self
                            self._children_name_map["receive_socket_buffer_sizes"] = "receive-socket-buffer-sizes"
                            self._children_yang_names.add("receive-socket-buffer-sizes")

                            self.rpki_servers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers()
                            self.rpki_servers.parent = self
                            self._children_name_map["rpki_servers"] = "rpki-servers"
                            self._children_yang_names.add("rpki-servers")

                            self.rpki_static_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes()
                            self.rpki_static_routes.parent = self
                            self._children_name_map["rpki_static_routes"] = "rpki-static-routes"
                            self._children_yang_names.add("rpki-static-routes")

                            self.send_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes()
                            self.send_socket_buffer_sizes.parent = self
                            self._children_name_map["send_socket_buffer_sizes"] = "send-socket-buffer-sizes"
                            self._children_yang_names.add("send-socket-buffer-sizes")

                            self.update_delay = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay()
                            self.update_delay.parent = self
                            self._children_name_map["update_delay"] = "update-delay"
                            self._children_yang_names.add("update-delay")

                            self.write_limit = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit()
                            self.write_limit.parent = self
                            self._children_name_map["write_limit"] = "write-limit"
                            self._children_yang_names.add("write-limit")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("best_path_aigp_ignore",
                                            "best_path_as_multipath_relax",
                                            "best_path_as_path_length",
                                            "best_path_confederation_paths",
                                            "best_path_cost_community",
                                            "best_path_med_always",
                                            "best_path_med_missing",
                                            "best_path_router_id",
                                            "default_info_originate",
                                            "default_metric",
                                            "disable_auto_soft_reset",
                                            "disable_enforce_first_as",
                                            "disable_fast_external_fallover",
                                            "disable_msg_log",
                                            "disable_neighbor_logging",
                                            "enforce_ibgp_out_policy",
                                            "global_scan_time",
                                            "graceful_reset",
                                            "graceful_restart",
                                            "graceful_restart_purge_time",
                                            "graceful_restart_stalepath_time",
                                            "graceful_restart_time",
                                            "igp_loop_check",
                                            "igp_redist_internal",
                                            "install_diversion",
                                            "local_preference",
                                            "multi_path_as_path_ignore_onwards",
                                            "mvpn",
                                            "neighbor_logging_detail",
                                            "next_hop_trigger_delay",
                                            "nsr",
                                            "read_only",
                                            "router_id",
                                            "rpki_bestpath_origin_as_allow_invalid",
                                            "rpki_bestpath_use_origin_as_validity",
                                            "rpki_origin_as_validation_disable",
                                            "rpki_origin_as_validation_time",
                                            "rpki_origin_as_validity_signal_ibgp",
                                            "update_error_handling_basic_ebgp_disable",
                                            "update_error_handling_basic_ibgp_disable",
                                            "update_error_handling_extended_ebgp",
                                            "update_error_handling_extended_ibgp",
                                            "update_limit_process",
                                            "update_out_logging") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_, self).__setattr__(name, value)


                        class ClusterId(Entity):
                            """
                            Configure Route\-Reflector Cluster\-id
                            
                            .. attribute:: cluster_id_address
                            
                            	Route\-Reflector Cluster ID in IPV4 address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cluster_id_number
                            
                            	Route\-Reflector Cluster ID as 32 bit quantity
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId, self).__init__()

                                self.yang_name = "cluster-id"
                                self.yang_parent_name = "global"

                                self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("cluster_id_address",
                                                "cluster_id_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.cluster_id_address.is_set or
                                    self.cluster_id_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.cluster_id_address.yfilter != YFilter.not_set or
                                    self.cluster_id_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "cluster-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cluster_id_address.get_name_leafdata())
                                if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "cluster-id-address" or name == "cluster-id-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "cluster-id-address"):
                                    self.cluster_id_address = value
                                    self.cluster_id_address.value_namespace = name_space
                                    self.cluster_id_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "cluster-id-number"):
                                    self.cluster_id_number = value
                                    self.cluster_id_number.value_namespace = name_space
                                    self.cluster_id_number.value_namespace_prefix = name_space_prefix


                        class WriteLimit(Entity):
                            """
                            Set write\-queue limit for each update group
                            
                            .. attribute:: desynchronize
                            
                            	TRUE to enable desynchronization, FALSE otherwise
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: enqueued_messages
                            
                            	Number of messages that can be enqueued in total
                            	**type**\:  int
                            
                            	**range:** 500..100000000
                            
                            	**default value**\: 250000
                            
                            .. attribute:: formatted_messages
                            
                            	Number of messages to be formatted per update group
                            	**type**\:  int
                            
                            	**range:** 500..100000000
                            
                            	**default value**\: 50000
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit, self).__init__()

                                self.yang_name = "write-limit"
                                self.yang_parent_name = "global"

                                self.desynchronize = YLeaf(YType.boolean, "desynchronize")

                                self.enqueued_messages = YLeaf(YType.uint32, "enqueued-messages")

                                self.formatted_messages = YLeaf(YType.uint32, "formatted-messages")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("desynchronize",
                                                "enqueued_messages",
                                                "formatted_messages") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.desynchronize.is_set or
                                    self.enqueued_messages.is_set or
                                    self.formatted_messages.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.desynchronize.yfilter != YFilter.not_set or
                                    self.enqueued_messages.yfilter != YFilter.not_set or
                                    self.formatted_messages.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "write-limit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.desynchronize.is_set or self.desynchronize.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.desynchronize.get_name_leafdata())
                                if (self.enqueued_messages.is_set or self.enqueued_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enqueued_messages.get_name_leafdata())
                                if (self.formatted_messages.is_set or self.formatted_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.formatted_messages.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "desynchronize" or name == "enqueued-messages" or name == "formatted-messages"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "desynchronize"):
                                    self.desynchronize = value
                                    self.desynchronize.value_namespace = name_space
                                    self.desynchronize.value_namespace_prefix = name_space_prefix
                                if(value_path == "enqueued-messages"):
                                    self.enqueued_messages = value
                                    self.enqueued_messages.value_namespace = name_space
                                    self.enqueued_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "formatted-messages"):
                                    self.formatted_messages = value
                                    self.formatted_messages.value_namespace = name_space
                                    self.formatted_messages.value_namespace_prefix = name_space_prefix


                        class UpdateDelay(Entity):
                            """
                            Set the max initial delay for sending
                            updates
                            
                            .. attribute:: always
                            
                            	Set to TRUE to disable keepalive trigger bestpath and delay is enforced
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: delay
                            
                            	Delay value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..3600
                            
                            	**units**\: second
                            
                            	**default value**\: 120
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay, self).__init__()

                                self.yang_name = "update-delay"
                                self.yang_parent_name = "global"

                                self.always = YLeaf(YType.boolean, "always")

                                self.delay = YLeaf(YType.uint32, "delay")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("always",
                                                "delay") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.always.is_set or
                                    self.delay.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.always.yfilter != YFilter.not_set or
                                    self.delay.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "update-delay" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.always.is_set or self.always.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.always.get_name_leafdata())
                                if (self.delay.is_set or self.delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.delay.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "always" or name == "delay"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "always"):
                                    self.always = value
                                    self.always.value_namespace = name_space
                                    self.always.value_namespace_prefix = name_space_prefix
                                if(value_path == "delay"):
                                    self.delay = value
                                    self.delay.value_namespace = name_space
                                    self.delay.value_namespace_prefix = name_space_prefix


                        class AsLeague(Entity):
                            """
                            AS League
                            
                            .. attribute:: enable
                            
                            	AS League creation
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: peers
                            
                            	AS League Peers
                            	**type**\:   :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague, self).__init__()

                                self.yang_name = "as-league"
                                self.yang_parent_name = "global"

                                self.enable = YLeaf(YType.empty, "enable")

                                self.peers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers()
                                self.peers.parent = self
                                self._children_name_map["peers"] = "peers"
                                self._children_yang_names.add("peers")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague, self).__setattr__(name, value)


                            class Peers(Entity):
                                """
                                AS League Peers
                                
                                .. attribute:: peer
                                
                                	AS League Peer AS
                                	**type**\: list of    :py:class:`Peer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers, self).__init__()

                                    self.yang_name = "peers"
                                    self.yang_parent_name = "as-league"

                                    self.peer = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers, self).__setattr__(name, value)


                                class Peer(Entity):
                                    """
                                    AS League Peer AS
                                    
                                    .. attribute:: as_xx  <key>
                                    
                                    	xx of peer AS xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy  <key>
                                    
                                    	yy of peer AS xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "peers"

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_xx",
                                                        "as_yy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_xx.is_set or
                                            self.as_yy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "peer" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as-xx" or name == "as-yy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.peer:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.peer:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peers" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "peer"):
                                        for c in self.peer:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.peer.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "peer"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.enable.is_set or
                                    (self.peers is not None and self.peers.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set or
                                    (self.peers is not None and self.peers.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "as-league" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "peers"):
                                    if (self.peers is None):
                                        self.peers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers()
                                        self.peers.parent = self
                                        self._children_name_map["peers"] = "peers"
                                    return self.peers

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "peers" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix


                        class RpkiServers(Entity):
                            """
                            RPKI server configuration
                            
                            .. attribute:: rpki_server
                            
                            	RPKI server configuration
                            	**type**\: list of    :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers, self).__init__()

                                self.yang_name = "rpki-servers"
                                self.yang_parent_name = "global"

                                self.rpki_server = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers, self).__setattr__(name, value)


                            class RpkiServer(Entity):
                                """
                                RPKI server configuration
                                
                                .. attribute:: server  <key>
                                
                                	Server address (opaque string)
                                	**type**\:  str
                                
                                .. attribute:: enable
                                
                                	RPKI server configuration
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: password
                                
                                	RPKI server password
                                	**type**\:  str
                                
                                .. attribute:: purge_time
                                
                                	RPKI server purge\-time (seconds)
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                .. attribute:: refresh_time
                                
                                	RPKI server refresh\-time (seconds)
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                .. attribute:: response_time
                                
                                	RPKI server response\-time (seconds)
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                .. attribute:: shutdown
                                
                                	RPKI server shutdown
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transport
                                
                                	RPKI server transport
                                	**type**\:   :py:class:`Transport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport>`
                                
                                .. attribute:: username
                                
                                	RPKI server username
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer, self).__init__()

                                    self.yang_name = "rpki-server"
                                    self.yang_parent_name = "rpki-servers"

                                    self.server = YLeaf(YType.str, "server")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.password = YLeaf(YType.str, "password")

                                    self.purge_time = YLeaf(YType.int32, "purge-time")

                                    self.refresh_time = YLeaf(YType.int32, "refresh-time")

                                    self.response_time = YLeaf(YType.int32, "response-time")

                                    self.shutdown = YLeaf(YType.empty, "shutdown")

                                    self.username = YLeaf(YType.str, "username")

                                    self.transport = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport()
                                    self.transport.parent = self
                                    self._children_name_map["transport"] = "transport"
                                    self._children_yang_names.add("transport")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("server",
                                                    "enable",
                                                    "password",
                                                    "purge_time",
                                                    "refresh_time",
                                                    "response_time",
                                                    "shutdown",
                                                    "username") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer, self).__setattr__(name, value)


                                class Transport(Entity):
                                    """
                                    RPKI server transport
                                    
                                    .. attribute:: port
                                    
                                    	port
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**default value**\: 22
                                    
                                    .. attribute:: transport
                                    
                                    	RPKI server transport
                                    	**type**\:   :py:class:`BgpRpkiTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRpkiTransport>`
                                    
                                    	**default value**\: ssh
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport, self).__init__()

                                        self.yang_name = "transport"
                                        self.yang_parent_name = "rpki-server"

                                        self.port = YLeaf(YType.uint16, "port")

                                        self.transport = YLeaf(YType.enumeration, "transport")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("port",
                                                        "transport") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.port.is_set or
                                            self.transport.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.port.yfilter != YFilter.not_set or
                                            self.transport.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "transport" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.port.is_set or self.port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port.get_name_leafdata())
                                        if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transport.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "port" or name == "transport"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "port"):
                                            self.port = value
                                            self.port.value_namespace = name_space
                                            self.port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transport"):
                                            self.transport = value
                                            self.transport.value_namespace = name_space
                                            self.transport.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.server.is_set or
                                        self.enable.is_set or
                                        self.password.is_set or
                                        self.purge_time.is_set or
                                        self.refresh_time.is_set or
                                        self.response_time.is_set or
                                        self.shutdown.is_set or
                                        self.username.is_set or
                                        (self.transport is not None and self.transport.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.server.yfilter != YFilter.not_set or
                                        self.enable.yfilter != YFilter.not_set or
                                        self.password.yfilter != YFilter.not_set or
                                        self.purge_time.yfilter != YFilter.not_set or
                                        self.refresh_time.yfilter != YFilter.not_set or
                                        self.response_time.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.username.yfilter != YFilter.not_set or
                                        (self.transport is not None and self.transport.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpki-server" + "[server='" + self.server.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.server.is_set or self.server.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.server.get_name_leafdata())
                                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enable.get_name_leafdata())
                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.password.get_name_leafdata())
                                    if (self.purge_time.is_set or self.purge_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.purge_time.get_name_leafdata())
                                    if (self.refresh_time.is_set or self.refresh_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.refresh_time.get_name_leafdata())
                                    if (self.response_time.is_set or self.response_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.response_time.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.username.is_set or self.username.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.username.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "transport"):
                                        if (self.transport is None):
                                            self.transport = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport()
                                            self.transport.parent = self
                                            self._children_name_map["transport"] = "transport"
                                        return self.transport

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "transport" or name == "server" or name == "enable" or name == "password" or name == "purge-time" or name == "refresh-time" or name == "response-time" or name == "shutdown" or name == "username"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "server"):
                                        self.server = value
                                        self.server.value_namespace = name_space
                                        self.server.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enable"):
                                        self.enable = value
                                        self.enable.value_namespace = name_space
                                        self.enable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "password"):
                                        self.password = value
                                        self.password.value_namespace = name_space
                                        self.password.value_namespace_prefix = name_space_prefix
                                    if(value_path == "purge-time"):
                                        self.purge_time = value
                                        self.purge_time.value_namespace = name_space
                                        self.purge_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "refresh-time"):
                                        self.refresh_time = value
                                        self.refresh_time.value_namespace = name_space
                                        self.refresh_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "response-time"):
                                        self.response_time = value
                                        self.response_time.value_namespace = name_space
                                        self.response_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "username"):
                                        self.username = value
                                        self.username.value_namespace = name_space
                                        self.username.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpki_server:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpki_server:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpki-servers" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpki-server"):
                                    for c in self.rpki_server:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpki_server.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpki-server"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AsListGroups(Entity):
                            """
                            AS\-list group lists
                            
                            .. attribute:: as_list_group
                            
                            	AS\-List group
                            	**type**\: list of    :py:class:`AsListGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups, self).__init__()

                                self.yang_name = "as-list-groups"
                                self.yang_parent_name = "global"

                                self.as_list_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups, self).__setattr__(name, value)


                            class AsListGroup(Entity):
                                """
                                AS\-List group
                                
                                .. attribute:: as_list_group_name  <key>
                                
                                	Group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: ases
                                
                                	AS list
                                	**type**\:   :py:class:`Ases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases>`
                                
                                .. attribute:: enable
                                
                                	AS\-List group creation
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup, self).__init__()

                                    self.yang_name = "as-list-group"
                                    self.yang_parent_name = "as-list-groups"

                                    self.as_list_group_name = YLeaf(YType.str, "as-list-group-name")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.ases = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases()
                                    self.ases.parent = self
                                    self._children_name_map["ases"] = "ases"
                                    self._children_yang_names.add("ases")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("as_list_group_name",
                                                    "enable") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup, self).__setattr__(name, value)


                                class Ases(Entity):
                                    """
                                    AS list
                                    
                                    .. attribute:: as_
                                    
                                    	AS\-List group
                                    	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases, self).__init__()

                                        self.yang_name = "ases"
                                        self.yang_parent_name = "as-list-group"

                                        self.as_ = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases, self).__setattr__(name, value)


                                    class As_(Entity):
                                        """
                                        AS\-List group
                                        
                                        .. attribute:: as_xx  <key>
                                        
                                        	xx of AS number/confed peer xx.yy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_yy  <key>
                                        
                                        	yy of AS number/confed peer xx.yy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_, self).__init__()

                                            self.yang_name = "as"
                                            self.yang_parent_name = "ases"

                                            self.as_xx = YLeaf(YType.uint32, "as-xx")

                                            self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("as_xx",
                                                            "as_yy") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.as_xx.is_set or
                                                self.as_yy.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.as_xx.yfilter != YFilter.not_set or
                                                self.as_yy.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "as" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_xx.get_name_leafdata())
                                            if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_yy.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "as-xx" or name == "as-yy"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "as-xx"):
                                                self.as_xx = value
                                                self.as_xx.value_namespace = name_space
                                                self.as_xx.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-yy"):
                                                self.as_yy = value
                                                self.as_yy.value_namespace = name_space
                                                self.as_yy.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.as_:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.as_:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ases" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "as"):
                                            for c in self.as_:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.as_.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.as_list_group_name.is_set or
                                        self.enable.is_set or
                                        (self.ases is not None and self.ases.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.as_list_group_name.yfilter != YFilter.not_set or
                                        self.enable.yfilter != YFilter.not_set or
                                        (self.ases is not None and self.ases.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "as-list-group" + "[as-list-group-name='" + self.as_list_group_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.as_list_group_name.is_set or self.as_list_group_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_list_group_name.get_name_leafdata())
                                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enable.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ases"):
                                        if (self.ases is None):
                                            self.ases = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases()
                                            self.ases.parent = self
                                            self._children_name_map["ases"] = "ases"
                                        return self.ases

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ases" or name == "as-list-group-name" or name == "enable"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "as-list-group-name"):
                                        self.as_list_group_name = value
                                        self.as_list_group_name.value_namespace = name_space
                                        self.as_list_group_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enable"):
                                        self.enable = value
                                        self.enable.value_namespace = name_space
                                        self.enable.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.as_list_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.as_list_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "as-list-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "as-list-group"):
                                    for c in self.as_list_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.as_list_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "as-list-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Limits(Entity):
                            """
                            Maximum number that can be configured
                            
                            .. attribute:: maximum_neighbors
                            
                            	Maximum number of neighbors that can be configured
                            	**type**\:  int
                            
                            	**range:** 1..15000
                            
                            	**default value**\: 10000
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits, self).__init__()

                                self.yang_name = "limits"
                                self.yang_parent_name = "global"

                                self.maximum_neighbors = YLeaf(YType.uint32, "maximum-neighbors")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("maximum_neighbors") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits, self).__setattr__(name, value)

                            def has_data(self):
                                return self.maximum_neighbors.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.maximum_neighbors.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "limits" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.maximum_neighbors.is_set or self.maximum_neighbors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_neighbors.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "maximum-neighbors"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "maximum-neighbors"):
                                    self.maximum_neighbors = value
                                    self.maximum_neighbors.value_namespace = name_space
                                    self.maximum_neighbors.value_namespace_prefix = name_space_prefix


                        class ConfederationDomain(Entity):
                            """
                            Set routing domain confederation AS
                            
                            .. attribute:: as_xx
                            
                            	xx of AS number xx.yy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_yy
                            
                            	yy of AS number xx.yy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain, self).__init__()

                                self.yang_name = "confederation-domain"
                                self.yang_parent_name = "global"

                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                self.as_yy = YLeaf(YType.uint32, "as-yy")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("as_xx",
                                                "as_yy") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.as_xx.is_set or
                                    self.as_yy.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.as_xx.yfilter != YFilter.not_set or
                                    self.as_yy.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "confederation-domain" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_xx.get_name_leafdata())
                                if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_yy.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "as-xx" or name == "as-yy"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "as-xx"):
                                    self.as_xx = value
                                    self.as_xx.value_namespace = name_space
                                    self.as_xx.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-yy"):
                                    self.as_yy = value
                                    self.as_yy.value_namespace = name_space
                                    self.as_yy.value_namespace_prefix = name_space_prefix


                        class ConfederationPeerAses(Entity):
                            """
                            Define peer ASes in BGP confederation
                            
                            .. attribute:: confederation_peer_as
                            
                            	Confederation peer AS
                            	**type**\: list of    :py:class:`ConfederationPeerAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses, self).__init__()

                                self.yang_name = "confederation-peer-ases"
                                self.yang_parent_name = "global"

                                self.confederation_peer_as = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses, self).__setattr__(name, value)


                            class ConfederationPeerAs(Entity):
                                """
                                Confederation peer AS
                                
                                .. attribute:: as_xx  <key>
                                
                                	xx of AS number/confed peer xx.yy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_yy  <key>
                                
                                	yy of AS number/confed peer xx.yy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs, self).__init__()

                                    self.yang_name = "confederation-peer-as"
                                    self.yang_parent_name = "confederation-peer-ases"

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.as_yy = YLeaf(YType.uint32, "as-yy")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("as_xx",
                                                    "as_yy") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.as_xx.is_set or
                                        self.as_yy.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.as_xx.yfilter != YFilter.not_set or
                                        self.as_yy.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "confederation-peer-as" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_xx.get_name_leafdata())
                                    if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_yy.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "as-xx" or name == "as-yy"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "as-xx"):
                                        self.as_xx = value
                                        self.as_xx.value_namespace = name_space
                                        self.as_xx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-yy"):
                                        self.as_yy = value
                                        self.as_yy.value_namespace = name_space
                                        self.as_yy.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.confederation_peer_as:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.confederation_peer_as:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "confederation-peer-ases" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "confederation-peer-as"):
                                    for c in self.confederation_peer_as:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.confederation_peer_as.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "confederation-peer-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AttributeFilterGroups(Entity):
                            """
                            Attribute\-filter groups list
                            
                            .. attribute:: attribute_filter_group
                            
                            	Attribute\-filter group
                            	**type**\: list of    :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups, self).__init__()

                                self.yang_name = "attribute-filter-groups"
                                self.yang_parent_name = "global"

                                self.attribute_filter_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups, self).__setattr__(name, value)


                            class AttributeFilterGroup(Entity):
                                """
                                Attribute\-filter group
                                
                                .. attribute:: attribute_filter_group_name  <key>
                                
                                	Group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: attribute_filters
                                
                                	Attribute\-filter group attributes list
                                	**type**\:   :py:class:`AttributeFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters>`
                                
                                .. attribute:: enable
                                
                                	Attribute\-filter group creation
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup, self).__init__()

                                    self.yang_name = "attribute-filter-group"
                                    self.yang_parent_name = "attribute-filter-groups"

                                    self.attribute_filter_group_name = YLeaf(YType.str, "attribute-filter-group-name")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.attribute_filters = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters()
                                    self.attribute_filters.parent = self
                                    self._children_name_map["attribute_filters"] = "attribute-filters"
                                    self._children_yang_names.add("attribute-filters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("attribute_filter_group_name",
                                                    "enable") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup, self).__setattr__(name, value)


                                class AttributeFilters(Entity):
                                    """
                                    Attribute\-filter group attributes list
                                    
                                    .. attribute:: attribute_filter
                                    
                                    	Attribute\-filter group attribute
                                    	**type**\: list of    :py:class:`AttributeFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters, self).__init__()

                                        self.yang_name = "attribute-filters"
                                        self.yang_parent_name = "attribute-filter-group"

                                        self.attribute_filter = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters, self).__setattr__(name, value)


                                    class AttributeFilter(Entity):
                                        """
                                        Attribute\-filter group attribute
                                        
                                        .. attribute:: attribute_start  <key>
                                        
                                        	Start of attribute range
                                        	**type**\:  int
                                        
                                        	**range:** 0..256
                                        
                                        .. attribute:: attribute_end  <key>
                                        
                                        	End of attribute range
                                        	**type**\:  int
                                        
                                        	**range:** 0..256
                                        
                                        .. attribute:: filter_action
                                        
                                        	Filtering action
                                        	**type**\:   :py:class:`BgpUpdateFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpUpdateFilterAction>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter, self).__init__()

                                            self.yang_name = "attribute-filter"
                                            self.yang_parent_name = "attribute-filters"

                                            self.attribute_start = YLeaf(YType.uint32, "attribute-start")

                                            self.attribute_end = YLeaf(YType.uint32, "attribute-end")

                                            self.filter_action = YLeaf(YType.enumeration, "filter-action")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("attribute_start",
                                                            "attribute_end",
                                                            "filter_action") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.attribute_start.is_set or
                                                self.attribute_end.is_set or
                                                self.filter_action.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.attribute_start.yfilter != YFilter.not_set or
                                                self.attribute_end.yfilter != YFilter.not_set or
                                                self.filter_action.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "attribute-filter" + "[attribute-start='" + self.attribute_start.get() + "']" + "[attribute-end='" + self.attribute_end.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.attribute_start.is_set or self.attribute_start.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.attribute_start.get_name_leafdata())
                                            if (self.attribute_end.is_set or self.attribute_end.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.attribute_end.get_name_leafdata())
                                            if (self.filter_action.is_set or self.filter_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.filter_action.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "attribute-start" or name == "attribute-end" or name == "filter-action"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "attribute-start"):
                                                self.attribute_start = value
                                                self.attribute_start.value_namespace = name_space
                                                self.attribute_start.value_namespace_prefix = name_space_prefix
                                            if(value_path == "attribute-end"):
                                                self.attribute_end = value
                                                self.attribute_end.value_namespace = name_space
                                                self.attribute_end.value_namespace_prefix = name_space_prefix
                                            if(value_path == "filter-action"):
                                                self.filter_action = value
                                                self.filter_action.value_namespace = name_space
                                                self.filter_action.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.attribute_filter:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.attribute_filter:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "attribute-filters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "attribute-filter"):
                                            for c in self.attribute_filter:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.attribute_filter.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "attribute-filter"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.attribute_filter_group_name.is_set or
                                        self.enable.is_set or
                                        (self.attribute_filters is not None and self.attribute_filters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.attribute_filter_group_name.yfilter != YFilter.not_set or
                                        self.enable.yfilter != YFilter.not_set or
                                        (self.attribute_filters is not None and self.attribute_filters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "attribute-filter-group" + "[attribute-filter-group-name='" + self.attribute_filter_group_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.attribute_filter_group_name.is_set or self.attribute_filter_group_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.attribute_filter_group_name.get_name_leafdata())
                                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enable.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "attribute-filters"):
                                        if (self.attribute_filters is None):
                                            self.attribute_filters = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters()
                                            self.attribute_filters.parent = self
                                            self._children_name_map["attribute_filters"] = "attribute-filters"
                                        return self.attribute_filters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "attribute-filters" or name == "attribute-filter-group-name" or name == "enable"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "attribute-filter-group-name"):
                                        self.attribute_filter_group_name = value
                                        self.attribute_filter_group_name.value_namespace = name_space
                                        self.attribute_filter_group_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enable"):
                                        self.enable = value
                                        self.enable.value_namespace = name_space
                                        self.enable.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.attribute_filter_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.attribute_filter_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attribute-filter-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "attribute-filter-group"):
                                    for c in self.attribute_filter_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.attribute_filter_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "attribute-filter-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class GlobalGracefulMaintenanceActivate(Entity):
                            """
                            Activate Graceful Maintenance Mode for all
                            neighbors with graceful maintenance config
                            
                            .. attribute:: all_neighbors
                            
                            	Also for neighbors without graceful maintenance config
                            	**type**\:  bool
                            
                            .. attribute:: retain_routes
                            
                            	Keep routes in RIB once BGP stops
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate, self).__init__()

                                self.yang_name = "global-graceful-maintenance-activate"
                                self.yang_parent_name = "global"

                                self.all_neighbors = YLeaf(YType.boolean, "all-neighbors")

                                self.retain_routes = YLeaf(YType.boolean, "retain-routes")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("all_neighbors",
                                                "retain_routes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.all_neighbors.is_set or
                                    self.retain_routes.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.all_neighbors.yfilter != YFilter.not_set or
                                    self.retain_routes.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "global-graceful-maintenance-activate" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.all_neighbors.is_set or self.all_neighbors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.all_neighbors.get_name_leafdata())
                                if (self.retain_routes.is_set or self.retain_routes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retain_routes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "all-neighbors" or name == "retain-routes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "all-neighbors"):
                                    self.all_neighbors = value
                                    self.all_neighbors.value_namespace = name_space
                                    self.all_neighbors.value_namespace_prefix = name_space_prefix
                                if(value_path == "retain-routes"):
                                    self.retain_routes = value
                                    self.retain_routes.value_namespace = name_space
                                    self.retain_routes.value_namespace_prefix = name_space_prefix


                        class GlobalAfs(Entity):
                            """
                            Global AF\-specific configuration
                            
                            .. attribute:: global_af
                            
                            	Global AF\-specific configuration
                            	**type**\: list of    :py:class:`GlobalAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs, self).__init__()

                                self.yang_name = "global-afs"
                                self.yang_parent_name = "global"

                                self.global_af = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs, self).__setattr__(name, value)


                            class GlobalAf(Entity):
                                """
                                Global AF\-specific configuration
                                
                                .. attribute:: af_name  <key>
                                
                                	Address family
                                	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                
                                .. attribute:: additional_paths_receive
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpafAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpafAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_selection
                                
                                	Configure additional paths selection
                                	**type**\:   :py:class:`AdditionalPathsSelection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection>`
                                
                                .. attribute:: additional_paths_send
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpafAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpafAdditionalPathsCfg>`
                                
                                .. attribute:: advertise_local_labeled_route_safi_unicast
                                
                                	Enable/disable advertisement of routes with local\-label via Unicast SAFI
                                	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                
                                .. attribute:: aggregate_addresses
                                
                                	Configure BGP aggregate entries
                                	**type**\:   :py:class:`AggregateAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses>`
                                
                                .. attribute:: allocate_label
                                
                                	Label allocation policy
                                	**type**\:   :py:class:`AllocateLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel>`
                                
                                .. attribute:: application_routes
                                
                                	Redistribute information for Application routes
                                	**type**\:   :py:class:`ApplicationRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes>`
                                
                                .. attribute:: attribute_download
                                
                                	Attribute download configuration
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: best_external
                                
                                	TRUE to enable BE FALSE to disable BE inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: connected_routes
                                
                                	Redistribute connected routes
                                	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:   :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: disable_as_path_loop_check
                                
                                	Disable outbound AS Path loop check
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: disable_client_to_client_rr
                                
                                	Disable client\-to\-client reflection
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: disable_cluster_client_to_client_rrs
                                
                                	Disable client\-to\-client reflection for a cluster
                                	**type**\:   :py:class:`DisableClusterClientToClientRrs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs>`
                                
                                .. attribute:: disable_default_martian_check
                                
                                	Disable default Martian Check
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: distance
                                
                                	Define an administrative distance
                                	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance>`
                                
                                .. attribute:: domain_distinguisher
                                
                                	<ASN, router\-id> tuple to use to identify the link\-state domain
                                	**type**\:   :py:class:`DomainDistinguisher <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dynamic_med_interval
                                
                                	Update generation delay (in minutes) after a MED change
                                	**type**\:  int
                                
                                	**range:** 0..10
                                
                                	**units**\: minute
                                
                                	**default value**\: 10
                                
                                .. attribute:: ebgp
                                
                                	Use eBGP multipaths
                                	**type**\:   :py:class:`Ebgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eibgp
                                
                                	Use eiBGP multipaths
                                	**type**\:   :py:class:`Eibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp_routes
                                
                                	Redistribute information for EIGRP routes
                                	**type**\:   :py:class:`EigrpRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes>`
                                
                                .. attribute:: enable
                                
                                	Enable the address family. Deletion of this object causes deletion of all the objects under GlobalAF/VRFGlobalAF associated with this object 
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: global_table_mcast
                                
                                	Enable global table multicast
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ibgp
                                
                                	Use iBGP multipaths
                                	**type**\:   :py:class:`Ibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: import_delay
                                
                                	Delay timer to batch import processing
                                	**type**\:   :py:class:`ImportDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: inter_as_install
                                
                                	Enable install remote MVPN routes to PIM in default VRF
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: isis_routes
                                
                                	Redistribute information for IS\-IS routes 
                                	**type**\:   :py:class:`IsisRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes>`
                                
                                .. attribute:: label_delay
                                
                                	Delay timer to batch label processing
                                	**type**\:   :py:class:`LabelDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: label_mode
                                
                                	BGP 6PE/MPLS\-VPN label allocation mode
                                	**type**\:   :py:class:`LabelMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode>`
                                
                                .. attribute:: label_retain
                                
                                	Label retention time in minutes
                                	**type**\:  int
                                
                                	**range:** 3..60
                                
                                	**units**\: minute
                                
                                .. attribute:: label_security_rpf
                                
                                	Calculate label\-security RPF lists and install to RIB/LSD
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: lisp_routes
                                
                                	Redistribute lisp routes
                                	**type**\:   :py:class:`LispRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: mobile_routes
                                
                                	Redistribute mobile routes
                                	**type**\:   :py:class:`MobileRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_critical_trigger_delay
                                
                                	Next hop Critical Trigger Delay
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                	**default value**\: 3000
                                
                                .. attribute:: next_hop_non_critical_trigger_delay
                                
                                	Next hop Non\-critical Trigger Delay
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                	**default value**\: 10000
                                
                                .. attribute:: next_hop_resolution_prefix_length_minimum
                                
                                	Minimum prefix\-length for nexthop resolution
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                	**default value**\: 0
                                
                                .. attribute:: next_hop_route_policy
                                
                                	Next hop policy to filter out nexthop notification
                                	**type**\:  str
                                
                                .. attribute:: ospf_routes
                                
                                	Redistribute information for OSPF routes
                                	**type**\:   :py:class:`OspfRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes>`
                                
                                .. attribute:: permanent_network
                                
                                	Route policy for permanent networks
                                	**type**\:  str
                                
                                .. attribute:: reset_weight_on_import
                                
                                	TRUE to reset weight on import. FALSE to not reset and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: retain_rt
                                
                                	Accept received updates with the specified attributes
                                	**type**\:   :py:class:`RetainRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt>`
                                
                                .. attribute:: rip_routes
                                
                                	Redistribute RIP routes
                                	**type**\:   :py:class:`RipRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: rnh_install_format
                                
                                	RNH install format type\: extcomm \- install rnh as opaque and extcomms, extcomm\-only \- install rnh as extcomms only
                                	**type**\:   :py:class:`BgpRnhInstallFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRnhInstallFormat>`
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_bestpath_use_origin_as_validity
                                
                                	RPKI bestpath use origin\-AS validity
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validity_signal_ibgp
                                
                                	RPKI origin\-AS validity signal ibgp
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval for this address family
                                	**type**\:  int
                                
                                	**range:** 5..3600
                                
                                	**units**\: second
                                
                                	**default value**\: 60
                                
                                .. attribute:: segmented_mcast
                                
                                	Enable segmented multicast
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sourced_networks
                                
                                	Specify a network to announce via BGP
                                	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks>`
                                
                                .. attribute:: static_routes
                                
                                	Redistribute static routes
                                	**type**\:   :py:class:`StaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: subscriber_routes
                                
                                	Redistribute subscriber routes
                                	**type**\:   :py:class:`SubscriberRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: table_policy
                                
                                	Configure policy for installation of routes to RIB
                                	**type**\:  str
                                
                                .. attribute:: update_limit_address_family
                                
                                	Upper bound on update generation transient memory usage for the address\-family
                                	**type**\:  int
                                
                                	**range:** 4..2048
                                
                                	**units**\: megabyte
                                
                                	**default value**\: 256
                                
                                .. attribute:: update_limit_sub_group_ebgp
                                
                                	Upper bound on update generation transient memory usage for every EBGP Sub\-group
                                	**type**\:  int
                                
                                	**range:** 1..512
                                
                                	**units**\: megabyte
                                
                                	**default value**\: 32
                                
                                .. attribute:: update_limit_sub_group_ibgp
                                
                                	Upper bound on update generation transient memory usage for every IBGP Sub\-group
                                	**type**\:  int
                                
                                	**range:** 1..512
                                
                                	**units**\: megabyte
                                
                                	**default value**\: 32
                                
                                .. attribute:: use_igpsr_label
                                
                                	Use IGP SR label for resolution configuration
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf_all
                                
                                	Configurations to be inherited to all vrfs
                                	**type**\:   :py:class:`VrfAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll>`
                                
                                .. attribute:: wait_rib_install
                                
                                	Wait for route install before sending updates to neighbors
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf, self).__init__()

                                    self.yang_name = "global-af"
                                    self.yang_parent_name = "global-afs"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.additional_paths_receive = YLeaf(YType.enumeration, "additional-paths-receive")

                                    self.additional_paths_send = YLeaf(YType.enumeration, "additional-paths-send")

                                    self.advertise_local_labeled_route_safi_unicast = YLeaf(YType.enumeration, "advertise-local-labeled-route-safi-unicast")

                                    self.attribute_download = YLeaf(YType.empty, "attribute-download")

                                    self.best_external = YLeaf(YType.boolean, "best-external")

                                    self.disable_as_path_loop_check = YLeaf(YType.empty, "disable-as-path-loop-check")

                                    self.disable_client_to_client_rr = YLeaf(YType.empty, "disable-client-to-client-rr")

                                    self.disable_default_martian_check = YLeaf(YType.empty, "disable-default-martian-check")

                                    self.dynamic_med_interval = YLeaf(YType.uint32, "dynamic-med-interval")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.global_table_mcast = YLeaf(YType.empty, "global-table-mcast")

                                    self.inter_as_install = YLeaf(YType.empty, "inter-as-install")

                                    self.label_retain = YLeaf(YType.uint32, "label-retain")

                                    self.label_security_rpf = YLeaf(YType.empty, "label-security-rpf")

                                    self.next_hop_critical_trigger_delay = YLeaf(YType.uint32, "next-hop-critical-trigger-delay")

                                    self.next_hop_non_critical_trigger_delay = YLeaf(YType.uint32, "next-hop-non-critical-trigger-delay")

                                    self.next_hop_resolution_prefix_length_minimum = YLeaf(YType.uint32, "next-hop-resolution-prefix-length-minimum")

                                    self.next_hop_route_policy = YLeaf(YType.str, "next-hop-route-policy")

                                    self.permanent_network = YLeaf(YType.str, "permanent-network")

                                    self.reset_weight_on_import = YLeaf(YType.boolean, "reset-weight-on-import")

                                    self.rnh_install_format = YLeaf(YType.enumeration, "rnh-install-format")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_bestpath_use_origin_as_validity = YLeaf(YType.empty, "rpki-bestpath-use-origin-as-validity")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.rpki_origin_as_validity_signal_ibgp = YLeaf(YType.empty, "rpki-origin-as-validity-signal-ibgp")

                                    self.scan_time = YLeaf(YType.uint32, "scan-time")

                                    self.segmented_mcast = YLeaf(YType.empty, "segmented-mcast")

                                    self.table_policy = YLeaf(YType.str, "table-policy")

                                    self.update_limit_address_family = YLeaf(YType.uint32, "update-limit-address-family")

                                    self.update_limit_sub_group_ebgp = YLeaf(YType.uint32, "update-limit-sub-group-ebgp")

                                    self.update_limit_sub_group_ibgp = YLeaf(YType.uint32, "update-limit-sub-group-ibgp")

                                    self.use_igpsr_label = YLeaf(YType.empty, "use-igpsr-label")

                                    self.wait_rib_install = YLeaf(YType.empty, "wait-rib-install")

                                    self.additional_paths_selection = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection()
                                    self.additional_paths_selection.parent = self
                                    self._children_name_map["additional_paths_selection"] = "additional-paths-selection"
                                    self._children_yang_names.add("additional-paths-selection")

                                    self.aggregate_addresses = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses()
                                    self.aggregate_addresses.parent = self
                                    self._children_name_map["aggregate_addresses"] = "aggregate-addresses"
                                    self._children_yang_names.add("aggregate-addresses")

                                    self.allocate_label = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel()
                                    self.allocate_label.parent = self
                                    self._children_name_map["allocate_label"] = "allocate-label"
                                    self._children_yang_names.add("allocate-label")

                                    self.application_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes()
                                    self.application_routes.parent = self
                                    self._children_name_map["application_routes"] = "application-routes"
                                    self._children_yang_names.add("application-routes")

                                    self.connected_routes = None
                                    self._children_name_map["connected_routes"] = "connected-routes"
                                    self._children_yang_names.add("connected-routes")

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"
                                    self._children_yang_names.add("dampening")

                                    self.disable_cluster_client_to_client_rrs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs()
                                    self.disable_cluster_client_to_client_rrs.parent = self
                                    self._children_name_map["disable_cluster_client_to_client_rrs"] = "disable-cluster-client-to-client-rrs"
                                    self._children_yang_names.add("disable-cluster-client-to-client-rrs")

                                    self.distance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"
                                    self._children_yang_names.add("distance")

                                    self.domain_distinguisher = None
                                    self._children_name_map["domain_distinguisher"] = "domain-distinguisher"
                                    self._children_yang_names.add("domain-distinguisher")

                                    self.ebgp = None
                                    self._children_name_map["ebgp"] = "ebgp"
                                    self._children_yang_names.add("ebgp")

                                    self.eibgp = None
                                    self._children_name_map["eibgp"] = "eibgp"
                                    self._children_yang_names.add("eibgp")

                                    self.eigrp_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes()
                                    self.eigrp_routes.parent = self
                                    self._children_name_map["eigrp_routes"] = "eigrp-routes"
                                    self._children_yang_names.add("eigrp-routes")

                                    self.ibgp = None
                                    self._children_name_map["ibgp"] = "ibgp"
                                    self._children_yang_names.add("ibgp")

                                    self.import_delay = None
                                    self._children_name_map["import_delay"] = "import-delay"
                                    self._children_yang_names.add("import-delay")

                                    self.isis_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes()
                                    self.isis_routes.parent = self
                                    self._children_name_map["isis_routes"] = "isis-routes"
                                    self._children_yang_names.add("isis-routes")

                                    self.label_delay = None
                                    self._children_name_map["label_delay"] = "label-delay"
                                    self._children_yang_names.add("label-delay")

                                    self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode()
                                    self.label_mode.parent = self
                                    self._children_name_map["label_mode"] = "label-mode"
                                    self._children_yang_names.add("label-mode")

                                    self.lisp_routes = None
                                    self._children_name_map["lisp_routes"] = "lisp-routes"
                                    self._children_yang_names.add("lisp-routes")

                                    self.mobile_routes = None
                                    self._children_name_map["mobile_routes"] = "mobile-routes"
                                    self._children_yang_names.add("mobile-routes")

                                    self.ospf_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes()
                                    self.ospf_routes.parent = self
                                    self._children_name_map["ospf_routes"] = "ospf-routes"
                                    self._children_yang_names.add("ospf-routes")

                                    self.retain_rt = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt()
                                    self.retain_rt.parent = self
                                    self._children_name_map["retain_rt"] = "retain-rt"
                                    self._children_yang_names.add("retain-rt")

                                    self.rip_routes = None
                                    self._children_name_map["rip_routes"] = "rip-routes"
                                    self._children_yang_names.add("rip-routes")

                                    self.sourced_networks = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self._children_name_map["sourced_networks"] = "sourced-networks"
                                    self._children_yang_names.add("sourced-networks")

                                    self.static_routes = None
                                    self._children_name_map["static_routes"] = "static-routes"
                                    self._children_yang_names.add("static-routes")

                                    self.subscriber_routes = None
                                    self._children_name_map["subscriber_routes"] = "subscriber-routes"
                                    self._children_yang_names.add("subscriber-routes")

                                    self.vrf_all = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll()
                                    self.vrf_all.parent = self
                                    self._children_name_map["vrf_all"] = "vrf-all"
                                    self._children_yang_names.add("vrf-all")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "additional_paths_receive",
                                                    "additional_paths_send",
                                                    "advertise_local_labeled_route_safi_unicast",
                                                    "attribute_download",
                                                    "best_external",
                                                    "disable_as_path_loop_check",
                                                    "disable_client_to_client_rr",
                                                    "disable_default_martian_check",
                                                    "dynamic_med_interval",
                                                    "enable",
                                                    "global_table_mcast",
                                                    "inter_as_install",
                                                    "label_retain",
                                                    "label_security_rpf",
                                                    "next_hop_critical_trigger_delay",
                                                    "next_hop_non_critical_trigger_delay",
                                                    "next_hop_resolution_prefix_length_minimum",
                                                    "next_hop_route_policy",
                                                    "permanent_network",
                                                    "reset_weight_on_import",
                                                    "rnh_install_format",
                                                    "rpki_bestpath_origin_as_allow_invalid",
                                                    "rpki_bestpath_use_origin_as_validity",
                                                    "rpki_origin_as_validation_disable",
                                                    "rpki_origin_as_validity_signal_ibgp",
                                                    "scan_time",
                                                    "segmented_mcast",
                                                    "table_policy",
                                                    "update_limit_address_family",
                                                    "update_limit_sub_group_ebgp",
                                                    "update_limit_sub_group_ibgp",
                                                    "use_igpsr_label",
                                                    "wait_rib_install") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf, self).__setattr__(name, value)


                                class IsisRoutes(Entity):
                                    """
                                    Redistribute information for IS\-IS routes
                                    .
                                    
                                    .. attribute:: isis_route
                                    
                                    	Redistribute IS\-IS routes
                                    	**type**\: list of    :py:class:`IsisRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes, self).__init__()

                                        self.yang_name = "isis-routes"
                                        self.yang_parent_name = "global-af"

                                        self.isis_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes, self).__setattr__(name, value)


                                    class IsisRoute(Entity):
                                        """
                                        Redistribute IS\-IS routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	IS\-IS instance name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: redist_type
                                        
                                        	Redistribution type\: 01 for level 1 routes, 02 for level 2 routes, 04 for level 1 inter\-area routes. Logical combinations permitted
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute, self).__init__()

                                            self.yang_name = "isis-route"
                                            self.yang_parent_name = "isis-routes"

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.redist_type = YLeaf(YType.str, "redist-type")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("instance_name",
                                                            "default_metric",
                                                            "redist_type",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.instance_name.is_set or
                                                self.default_metric.is_set or
                                                self.redist_type.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.instance_name.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.redist_type.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "isis-route" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.instance_name.get_name_leafdata())
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.redist_type.is_set or self.redist_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.redist_type.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "instance-name" or name == "default-metric" or name == "redist-type" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "instance-name"):
                                                self.instance_name = value
                                                self.instance_name.value_namespace = name_space
                                                self.instance_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "redist-type"):
                                                self.redist_type = value
                                                self.redist_type.value_namespace = name_space
                                                self.redist_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.isis_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.isis_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "isis-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "isis-route"):
                                            for c in self.isis_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.isis_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "isis-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DomainDistinguisher(Entity):
                                    """
                                    <ASN, router\-id> tuple to use to identify
                                    the link\-state domain
                                    
                                    .. attribute:: as_
                                    
                                    	AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher, self).__init__()

                                        self.yang_name = "domain-distinguisher"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.as_ = YLeaf(YType.uint32, "as")

                                        self.router_id = YLeaf(YType.str, "router-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("as_",
                                                        "router_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.as_.is_set or
                                            self.router_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.as_.yfilter != YFilter.not_set or
                                            self.router_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "domain-distinguisher" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_.get_name_leafdata())
                                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.router_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "as" or name == "router-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "as"):
                                            self.as_ = value
                                            self.as_.value_namespace = name_space
                                            self.as_.value_namespace_prefix = name_space_prefix
                                        if(value_path == "router-id"):
                                            self.router_id = value
                                            self.router_id.value_namespace = name_space
                                            self.router_id.value_namespace_prefix = name_space_prefix


                                class VrfAll(Entity):
                                    """
                                    Configurations to be inherited to all
                                    vrfs
                                    
                                    .. attribute:: enable
                                    
                                    	Enable vrf all configuration submode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: label_mode
                                    
                                    	MPLS\-VPN label allocation mode
                                    	**type**\:   :py:class:`LabelMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode>`
                                    
                                    .. attribute:: rnh_install_format
                                    
                                    	RNH install format type\: extcomm \- install rnh as opaque and extcomms, extcomm\-only \- install rnh as extcomms only
                                    	**type**\:   :py:class:`BgpRnhInstallFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRnhInstallFormat>`
                                    
                                    .. attribute:: source_rt_import_policy
                                    
                                    	Enable sourcing of import route\-targets  from import\-policy
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: table_policy
                                    
                                    	Configure policy for installation of routes to RIB
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll, self).__init__()

                                        self.yang_name = "vrf-all"
                                        self.yang_parent_name = "global-af"

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.rnh_install_format = YLeaf(YType.enumeration, "rnh-install-format")

                                        self.source_rt_import_policy = YLeaf(YType.empty, "source-rt-import-policy")

                                        self.table_policy = YLeaf(YType.str, "table-policy")

                                        self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode()
                                        self.label_mode.parent = self
                                        self._children_name_map["label_mode"] = "label-mode"
                                        self._children_yang_names.add("label-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "rnh_install_format",
                                                        "source_rt_import_policy",
                                                        "table_policy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll, self).__setattr__(name, value)


                                    class LabelMode(Entity):
                                        """
                                        MPLS\-VPN label allocation mode
                                        
                                        .. attribute:: label_allocation_mode
                                        
                                        	Label allocation mode\: per\-ce  Set per CE label mode, per\-vrf Set per VRF label mode
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Label mode route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode, self).__init__()

                                            self.yang_name = "label-mode"
                                            self.yang_parent_name = "vrf-all"

                                            self.label_allocation_mode = YLeaf(YType.str, "label-allocation-mode")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("label_allocation_mode",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.label_allocation_mode.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.label_allocation_mode.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "label-mode" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.label_allocation_mode.is_set or self.label_allocation_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.label_allocation_mode.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "label-allocation-mode" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "label-allocation-mode"):
                                                self.label_allocation_mode = value
                                                self.label_allocation_mode.value_namespace = name_space
                                                self.label_allocation_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.rnh_install_format.is_set or
                                            self.source_rt_import_policy.is_set or
                                            self.table_policy.is_set or
                                            (self.label_mode is not None and self.label_mode.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.rnh_install_format.yfilter != YFilter.not_set or
                                            self.source_rt_import_policy.yfilter != YFilter.not_set or
                                            self.table_policy.yfilter != YFilter.not_set or
                                            (self.label_mode is not None and self.label_mode.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-all" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.rnh_install_format.is_set or self.rnh_install_format.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rnh_install_format.get_name_leafdata())
                                        if (self.source_rt_import_policy.is_set or self.source_rt_import_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_rt_import_policy.get_name_leafdata())
                                        if (self.table_policy.is_set or self.table_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.table_policy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "label-mode"):
                                            if (self.label_mode is None):
                                                self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode()
                                                self.label_mode.parent = self
                                                self._children_name_map["label_mode"] = "label-mode"
                                            return self.label_mode

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "label-mode" or name == "enable" or name == "rnh-install-format" or name == "source-rt-import-policy" or name == "table-policy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rnh-install-format"):
                                            self.rnh_install_format = value
                                            self.rnh_install_format.value_namespace = name_space
                                            self.rnh_install_format.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-rt-import-policy"):
                                            self.source_rt_import_policy = value
                                            self.source_rt_import_policy.value_namespace = name_space
                                            self.source_rt_import_policy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "table-policy"):
                                            self.table_policy = value
                                            self.table_policy.value_namespace = name_space
                                            self.table_policy.value_namespace_prefix = name_space_prefix


                                class DisableClusterClientToClientRrs(Entity):
                                    """
                                    Disable client\-to\-client reflection for a
                                    cluster
                                    
                                    .. attribute:: disable_cluster_client_to_client_rr
                                    
                                    	Cluster ID for which reflection is to be disbled
                                    	**type**\: list of    :py:class:`DisableClusterClientToClientRr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs, self).__init__()

                                        self.yang_name = "disable-cluster-client-to-client-rrs"
                                        self.yang_parent_name = "global-af"

                                        self.disable_cluster_client_to_client_rr = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs, self).__setattr__(name, value)


                                    class DisableClusterClientToClientRr(Entity):
                                        """
                                        Cluster ID for which reflection is to be
                                        disbled
                                        
                                        .. attribute:: cluster_type  <key>
                                        
                                        	Type of cluster\-id
                                        	**type**\:   :py:class:`BgpClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpClusterId>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	ipv4 address
                                        	**type**\: list of    :py:class:`Ipv4Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address>`
                                        
                                        .. attribute:: number
                                        
                                        	number
                                        	**type**\: list of    :py:class:`Number <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr, self).__init__()

                                            self.yang_name = "disable-cluster-client-to-client-rr"
                                            self.yang_parent_name = "disable-cluster-client-to-client-rrs"

                                            self.cluster_type = YLeaf(YType.enumeration, "cluster-type")

                                            self.ipv4_address = YList(self)
                                            self.number = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cluster_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr, self).__setattr__(name, value)


                                        class Number(Entity):
                                            """
                                            number
                                            
                                            .. attribute:: cluster_id_number  <key>
                                            
                                            	Cluster ID\: if configured as a number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number, self).__init__()

                                                self.yang_name = "number"
                                                self.yang_parent_name = "disable-cluster-client-to-client-rr"

                                                self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cluster_id_number") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.cluster_id_number.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cluster_id_number.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "number" + "[cluster-id-number='" + self.cluster_id_number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cluster_id_number.is_set or self.cluster_id_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cluster_id_number.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cluster-id-number"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cluster-id-number"):
                                                    self.cluster_id_number = value
                                                    self.cluster_id_number.value_namespace = name_space
                                                    self.cluster_id_number.value_namespace_prefix = name_space_prefix


                                        class Ipv4Address(Entity):
                                            """
                                            ipv4 address
                                            
                                            .. attribute:: cluster_id_address  <key>
                                            
                                            	Cluster ID\: if configured as an IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address, self).__init__()

                                                self.yang_name = "ipv4-address"
                                                self.yang_parent_name = "disable-cluster-client-to-client-rr"

                                                self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cluster_id_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.cluster_id_address.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cluster_id_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipv4-address" + "[cluster-id-address='" + self.cluster_id_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cluster_id_address.is_set or self.cluster_id_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cluster_id_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cluster-id-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cluster-id-address"):
                                                    self.cluster_id_address = value
                                                    self.cluster_id_address.value_namespace = name_space
                                                    self.cluster_id_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ipv4_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.number:
                                                if (c.has_data()):
                                                    return True
                                            return self.cluster_type.is_set

                                        def has_operation(self):
                                            for c in self.ipv4_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.number:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cluster_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disable-cluster-client-to-client-rr" + "[cluster-type='" + self.cluster_type.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cluster_type.is_set or self.cluster_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cluster_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ipv4-address"):
                                                for c in self.ipv4_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ipv4_address.append(c)
                                                return c

                                            if (child_yang_name == "number"):
                                                for c in self.number:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.number.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "number" or name == "cluster-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cluster-type"):
                                                self.cluster_type = value
                                                self.cluster_type.value_namespace = name_space
                                                self.cluster_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.disable_cluster_client_to_client_rr:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.disable_cluster_client_to_client_rr:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disable-cluster-client-to-client-rrs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "disable-cluster-client-to-client-rr"):
                                            for c in self.disable_cluster_client_to_client_rr:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.disable_cluster_client_to_client_rr.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "disable-cluster-client-to-client-rr"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LabelDelay(Entity):
                                    """
                                    Delay timer to batch label processing.
                                    
                                    .. attribute:: milliseconds
                                    
                                    	Delay, milliseconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Delay, seconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..10
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay, self).__init__()

                                        self.yang_name = "label-delay"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.milliseconds = YLeaf(YType.uint32, "milliseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("milliseconds",
                                                        "seconds") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.milliseconds.is_set or
                                            self.seconds.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.milliseconds.yfilter != YFilter.not_set or
                                            self.seconds.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "label-delay" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.milliseconds.is_set or self.milliseconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.milliseconds.get_name_leafdata())
                                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.seconds.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "milliseconds" or name == "seconds"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "milliseconds"):
                                            self.milliseconds = value
                                            self.milliseconds.value_namespace = name_space
                                            self.milliseconds.value_namespace_prefix = name_space_prefix
                                        if(value_path == "seconds"):
                                            self.seconds = value
                                            self.seconds.value_namespace = name_space
                                            self.seconds.value_namespace_prefix = name_space_prefix


                                class Ebgp(Entity):
                                    """
                                    Use eBGP multipaths
                                    
                                    .. attribute:: order_by_igp_metric
                                    
                                    	Order candidate multipaths by IGP metric
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: paths_value
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 2..64
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: selective
                                    
                                    	Allow multipaths only from marked neighbors
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	UNUSED
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp, self).__init__()

                                        self.yang_name = "ebgp"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                        self.paths_value = YLeaf(YType.uint32, "paths-value")

                                        self.selective = YLeaf(YType.boolean, "selective")

                                        self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("order_by_igp_metric",
                                                        "paths_value",
                                                        "selective",
                                                        "unequal_cost") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.order_by_igp_metric.is_set or
                                            self.paths_value.is_set or
                                            self.selective.is_set or
                                            self.unequal_cost.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.order_by_igp_metric.yfilter != YFilter.not_set or
                                            self.paths_value.yfilter != YFilter.not_set or
                                            self.selective.yfilter != YFilter.not_set or
                                            self.unequal_cost.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ebgp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.order_by_igp_metric.is_set or self.order_by_igp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.order_by_igp_metric.get_name_leafdata())
                                        if (self.paths_value.is_set or self.paths_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.paths_value.get_name_leafdata())
                                        if (self.selective.is_set or self.selective.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.selective.get_name_leafdata())
                                        if (self.unequal_cost.is_set or self.unequal_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unequal_cost.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "order-by-igp-metric" or name == "paths-value" or name == "selective" or name == "unequal-cost"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "order-by-igp-metric"):
                                            self.order_by_igp_metric = value
                                            self.order_by_igp_metric.value_namespace = name_space
                                            self.order_by_igp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "paths-value"):
                                            self.paths_value = value
                                            self.paths_value.value_namespace = name_space
                                            self.paths_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "selective"):
                                            self.selective = value
                                            self.selective.value_namespace = name_space
                                            self.selective.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unequal-cost"):
                                            self.unequal_cost = value
                                            self.unequal_cost.value_namespace = name_space
                                            self.unequal_cost.value_namespace_prefix = name_space_prefix


                                class Eibgp(Entity):
                                    """
                                    Use eiBGP multipaths
                                    
                                    .. attribute:: order_by_igp_metric
                                    
                                    	Order candidate multipaths by IGP metric
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: paths_value
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 2..64
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: selective
                                    
                                    	Allow multipaths only from marked neighbors
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	UNUSED
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp, self).__init__()

                                        self.yang_name = "eibgp"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                        self.paths_value = YLeaf(YType.uint32, "paths-value")

                                        self.selective = YLeaf(YType.boolean, "selective")

                                        self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("order_by_igp_metric",
                                                        "paths_value",
                                                        "selective",
                                                        "unequal_cost") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.order_by_igp_metric.is_set or
                                            self.paths_value.is_set or
                                            self.selective.is_set or
                                            self.unequal_cost.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.order_by_igp_metric.yfilter != YFilter.not_set or
                                            self.paths_value.yfilter != YFilter.not_set or
                                            self.selective.yfilter != YFilter.not_set or
                                            self.unequal_cost.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "eibgp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.order_by_igp_metric.is_set or self.order_by_igp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.order_by_igp_metric.get_name_leafdata())
                                        if (self.paths_value.is_set or self.paths_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.paths_value.get_name_leafdata())
                                        if (self.selective.is_set or self.selective.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.selective.get_name_leafdata())
                                        if (self.unequal_cost.is_set or self.unequal_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unequal_cost.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "order-by-igp-metric" or name == "paths-value" or name == "selective" or name == "unequal-cost"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "order-by-igp-metric"):
                                            self.order_by_igp_metric = value
                                            self.order_by_igp_metric.value_namespace = name_space
                                            self.order_by_igp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "paths-value"):
                                            self.paths_value = value
                                            self.paths_value.value_namespace = name_space
                                            self.paths_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "selective"):
                                            self.selective = value
                                            self.selective.value_namespace = name_space
                                            self.selective.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unequal-cost"):
                                            self.unequal_cost = value
                                            self.unequal_cost.value_namespace = name_space
                                            self.unequal_cost.value_namespace_prefix = name_space_prefix


                                class RetainRt(Entity):
                                    """
                                    Accept received updates with the
                                    specified attributes
                                    
                                    .. attribute:: all
                                    
                                    	Whether all RTs are to be retained, default is FALSE
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt, self).__init__()

                                        self.yang_name = "retain-rt"
                                        self.yang_parent_name = "global-af"

                                        self.all = YLeaf(YType.boolean, "all")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "retain-rt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all.is_set or self.all.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all"):
                                            self.all = value
                                            self.all.value_namespace = name_space
                                            self.all.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Ibgp(Entity):
                                    """
                                    Use iBGP multipaths
                                    
                                    .. attribute:: order_by_igp_metric
                                    
                                    	Order candidate multipaths by IGP metric
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: paths_value
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 2..64
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: selective
                                    
                                    	Allow multipaths only from marked neighbors
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Allow multipaths to have different IGP metrics
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                        self.paths_value = YLeaf(YType.uint32, "paths-value")

                                        self.selective = YLeaf(YType.boolean, "selective")

                                        self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("order_by_igp_metric",
                                                        "paths_value",
                                                        "selective",
                                                        "unequal_cost") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.order_by_igp_metric.is_set or
                                            self.paths_value.is_set or
                                            self.selective.is_set or
                                            self.unequal_cost.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.order_by_igp_metric.yfilter != YFilter.not_set or
                                            self.paths_value.yfilter != YFilter.not_set or
                                            self.selective.yfilter != YFilter.not_set or
                                            self.unequal_cost.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ibgp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.order_by_igp_metric.is_set or self.order_by_igp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.order_by_igp_metric.get_name_leafdata())
                                        if (self.paths_value.is_set or self.paths_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.paths_value.get_name_leafdata())
                                        if (self.selective.is_set or self.selective.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.selective.get_name_leafdata())
                                        if (self.unequal_cost.is_set or self.unequal_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unequal_cost.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "order-by-igp-metric" or name == "paths-value" or name == "selective" or name == "unequal-cost"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "order-by-igp-metric"):
                                            self.order_by_igp_metric = value
                                            self.order_by_igp_metric.value_namespace = name_space
                                            self.order_by_igp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "paths-value"):
                                            self.paths_value = value
                                            self.paths_value.value_namespace = name_space
                                            self.paths_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "selective"):
                                            self.selective = value
                                            self.selective.value_namespace = name_space
                                            self.selective.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unequal-cost"):
                                            self.unequal_cost = value
                                            self.unequal_cost.value_namespace = name_space
                                            self.unequal_cost.value_namespace_prefix = name_space_prefix


                                class ImportDelay(Entity):
                                    """
                                    Delay timer to batch import processing.
                                    
                                    .. attribute:: milliseconds
                                    
                                    	Delay, milliseconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Delay, seconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..10
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay, self).__init__()

                                        self.yang_name = "import-delay"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.milliseconds = YLeaf(YType.uint32, "milliseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("milliseconds",
                                                        "seconds") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.milliseconds.is_set or
                                            self.seconds.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.milliseconds.yfilter != YFilter.not_set or
                                            self.seconds.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "import-delay" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.milliseconds.is_set or self.milliseconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.milliseconds.get_name_leafdata())
                                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.seconds.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "milliseconds" or name == "seconds"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "milliseconds"):
                                            self.milliseconds = value
                                            self.milliseconds.value_namespace = name_space
                                            self.milliseconds.value_namespace_prefix = name_space_prefix
                                        if(value_path == "seconds"):
                                            self.seconds = value
                                            self.seconds.value_namespace = name_space
                                            self.seconds.value_namespace_prefix = name_space_prefix


                                class AggregateAddresses(Entity):
                                    """
                                    Configure BGP aggregate entries
                                    
                                    .. attribute:: aggregate_address
                                    
                                    	Aggregate address configuration
                                    	**type**\: list of    :py:class:`AggregateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses, self).__init__()

                                        self.yang_name = "aggregate-addresses"
                                        self.yang_parent_name = "global-af"

                                        self.aggregate_address = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses, self).__setattr__(name, value)


                                    class AggregateAddress(Entity):
                                        """
                                        Aggregate address configuration
                                        
                                        .. attribute:: aggregate_addr  <key>
                                        
                                        	Aggregate in prefix/length format (address part)
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: aggregate_prefix  <key>
                                        
                                        	Aggregate in prefix/length format (prefix part)
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: generate_confederation_set_info
                                        
                                        	TRUE to generate AS confederation set path information, FALSE otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: generate_set_info
                                        
                                        	TRUE to generate AS set path information, FALSE otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy on which to condition advertisement, suppression, and attributes
                                        	**type**\:  str
                                        
                                        .. attribute:: summary_only
                                        
                                        	TRUE to filter more specific routes from updates, FALSEotherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress, self).__init__()

                                            self.yang_name = "aggregate-address"
                                            self.yang_parent_name = "aggregate-addresses"

                                            self.aggregate_addr = YLeaf(YType.str, "aggregate-addr")

                                            self.aggregate_prefix = YLeaf(YType.uint16, "aggregate-prefix")

                                            self.generate_confederation_set_info = YLeaf(YType.boolean, "generate-confederation-set-info")

                                            self.generate_set_info = YLeaf(YType.boolean, "generate-set-info")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            self.summary_only = YLeaf(YType.boolean, "summary-only")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("aggregate_addr",
                                                            "aggregate_prefix",
                                                            "generate_confederation_set_info",
                                                            "generate_set_info",
                                                            "route_policy_name",
                                                            "summary_only") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.aggregate_addr.is_set or
                                                self.aggregate_prefix.is_set or
                                                self.generate_confederation_set_info.is_set or
                                                self.generate_set_info.is_set or
                                                self.route_policy_name.is_set or
                                                self.summary_only.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.aggregate_addr.yfilter != YFilter.not_set or
                                                self.aggregate_prefix.yfilter != YFilter.not_set or
                                                self.generate_confederation_set_info.yfilter != YFilter.not_set or
                                                self.generate_set_info.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set or
                                                self.summary_only.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "aggregate-address" + "[aggregate-addr='" + self.aggregate_addr.get() + "']" + "[aggregate-prefix='" + self.aggregate_prefix.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.aggregate_addr.is_set or self.aggregate_addr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aggregate_addr.get_name_leafdata())
                                            if (self.aggregate_prefix.is_set or self.aggregate_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.aggregate_prefix.get_name_leafdata())
                                            if (self.generate_confederation_set_info.is_set or self.generate_confederation_set_info.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.generate_confederation_set_info.get_name_leafdata())
                                            if (self.generate_set_info.is_set or self.generate_set_info.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.generate_set_info.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                            if (self.summary_only.is_set or self.summary_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.summary_only.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "aggregate-addr" or name == "aggregate-prefix" or name == "generate-confederation-set-info" or name == "generate-set-info" or name == "route-policy-name" or name == "summary-only"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "aggregate-addr"):
                                                self.aggregate_addr = value
                                                self.aggregate_addr.value_namespace = name_space
                                                self.aggregate_addr.value_namespace_prefix = name_space_prefix
                                            if(value_path == "aggregate-prefix"):
                                                self.aggregate_prefix = value
                                                self.aggregate_prefix.value_namespace = name_space
                                                self.aggregate_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "generate-confederation-set-info"):
                                                self.generate_confederation_set_info = value
                                                self.generate_confederation_set_info.value_namespace = name_space
                                                self.generate_confederation_set_info.value_namespace_prefix = name_space_prefix
                                            if(value_path == "generate-set-info"):
                                                self.generate_set_info = value
                                                self.generate_set_info.value_namespace = name_space
                                                self.generate_set_info.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "summary-only"):
                                                self.summary_only = value
                                                self.summary_only.value_namespace = name_space
                                                self.summary_only.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.aggregate_address:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.aggregate_address:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "aggregate-addresses" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "aggregate-address"):
                                            for c in self.aggregate_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.aggregate_address.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "aggregate-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: half_life
                                    
                                    	Half\-life time for the penalty (minutes)
                                    	**type**\:  int
                                    
                                    	**range:** 1..45
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: reuse_threshold
                                    
                                    	Value to start reusing a route
                                    	**type**\:  int
                                    
                                    	**range:** 1..20000
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy to specify criteria for dampening. This cannot be specified if any other parameters are specified
                                    	**type**\:  str
                                    
                                    .. attribute:: suppress_threshold
                                    
                                    	Value to start suppressing a route
                                    	**type**\:  int
                                    
                                    	**range:** 1..20000
                                    
                                    .. attribute:: suppress_time
                                    
                                    	Maximum duration to suppress a stable route (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**units**\: second
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.half_life = YLeaf(YType.uint32, "half-life")

                                        self.reuse_threshold = YLeaf(YType.uint32, "reuse-threshold")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.suppress_threshold = YLeaf(YType.uint32, "suppress-threshold")

                                        self.suppress_time = YLeaf(YType.uint32, "suppress-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("half_life",
                                                        "reuse_threshold",
                                                        "route_policy_name",
                                                        "suppress_threshold",
                                                        "suppress_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.half_life.is_set or
                                            self.reuse_threshold.is_set or
                                            self.route_policy_name.is_set or
                                            self.suppress_threshold.is_set or
                                            self.suppress_time.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.half_life.yfilter != YFilter.not_set or
                                            self.reuse_threshold.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set or
                                            self.suppress_threshold.yfilter != YFilter.not_set or
                                            self.suppress_time.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dampening" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.half_life.is_set or self.half_life.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.half_life.get_name_leafdata())
                                        if (self.reuse_threshold.is_set or self.reuse_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reuse_threshold.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                        if (self.suppress_threshold.is_set or self.suppress_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.suppress_threshold.get_name_leafdata())
                                        if (self.suppress_time.is_set or self.suppress_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.suppress_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "half-life" or name == "reuse-threshold" or name == "route-policy-name" or name == "suppress-threshold" or name == "suppress-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "half-life"):
                                            self.half_life = value
                                            self.half_life.value_namespace = name_space
                                            self.half_life.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reuse-threshold"):
                                            self.reuse_threshold = value
                                            self.reuse_threshold.value_namespace = name_space
                                            self.reuse_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "suppress-threshold"):
                                            self.suppress_threshold = value
                                            self.suppress_threshold.value_namespace = name_space
                                            self.suppress_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "suppress-time"):
                                            self.suppress_time = value
                                            self.suppress_time.value_namespace = name_space
                                            self.suppress_time.value_namespace_prefix = name_space_prefix


                                class RipRoutes(Entity):
                                    """
                                    Redistribute RIP routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes, self).__init__()

                                        self.yang_name = "rip-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("default_metric",
                                                        "not_used",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.default_metric.is_set or
                                            self.not_used.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.default_metric.yfilter != YFilter.not_set or
                                            self.not_used.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rip-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_metric.get_name_leafdata())
                                        if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_used.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "default-metric"):
                                            self.default_metric = value
                                            self.default_metric.value_namespace = name_space
                                            self.default_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-used"):
                                            self.not_used = value
                                            self.not_used.value_namespace = name_space
                                            self.not_used.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class LispRoutes(Entity):
                                    """
                                    Redistribute lisp routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes, self).__init__()

                                        self.yang_name = "lisp-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("default_metric",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.default_metric.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.default_metric.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lisp-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_metric.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "default-metric" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "default-metric"):
                                            self.default_metric = value
                                            self.default_metric.value_namespace = name_space
                                            self.default_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class StaticRoutes(Entity):
                                    """
                                    Redistribute static routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes, self).__init__()

                                        self.yang_name = "static-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("default_metric",
                                                        "not_used",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.default_metric.is_set or
                                            self.not_used.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.default_metric.yfilter != YFilter.not_set or
                                            self.not_used.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "static-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_metric.get_name_leafdata())
                                        if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_used.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "default-metric"):
                                            self.default_metric = value
                                            self.default_metric.value_namespace = name_space
                                            self.default_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-used"):
                                            self.not_used = value
                                            self.not_used.value_namespace = name_space
                                            self.not_used.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Distance(Entity):
                                    """
                                    Define an administrative distance
                                    
                                    .. attribute:: external_routes
                                    
                                    	Distance for routes external to the AS
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 20
                                    
                                    .. attribute:: internal_routes
                                    
                                    	Distance for routes internal to the AS
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 200
                                    
                                    .. attribute:: local_routes
                                    
                                    	Distance for local routes
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 200
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "global-af"

                                        self.external_routes = YLeaf(YType.uint32, "external-routes")

                                        self.internal_routes = YLeaf(YType.uint32, "internal-routes")

                                        self.local_routes = YLeaf(YType.uint32, "local-routes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("external_routes",
                                                        "internal_routes",
                                                        "local_routes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.external_routes.is_set or
                                            self.internal_routes.is_set or
                                            self.local_routes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.external_routes.yfilter != YFilter.not_set or
                                            self.internal_routes.yfilter != YFilter.not_set or
                                            self.local_routes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "distance" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.external_routes.is_set or self.external_routes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.external_routes.get_name_leafdata())
                                        if (self.internal_routes.is_set or self.internal_routes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_routes.get_name_leafdata())
                                        if (self.local_routes.is_set or self.local_routes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_routes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "external-routes" or name == "internal-routes" or name == "local-routes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "external-routes"):
                                            self.external_routes = value
                                            self.external_routes.value_namespace = name_space
                                            self.external_routes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "internal-routes"):
                                            self.internal_routes = value
                                            self.internal_routes.value_namespace = name_space
                                            self.internal_routes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-routes"):
                                            self.local_routes = value
                                            self.local_routes.value_namespace = name_space
                                            self.local_routes.value_namespace_prefix = name_space_prefix


                                class ApplicationRoutes(Entity):
                                    """
                                    Redistribute information for Application routes.
                                    
                                    .. attribute:: application_route
                                    
                                    	Redistribute application routes
                                    	**type**\: list of    :py:class:`ApplicationRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes, self).__init__()

                                        self.yang_name = "application-routes"
                                        self.yang_parent_name = "global-af"

                                        self.application_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes, self).__setattr__(name, value)


                                    class ApplicationRoute(Entity):
                                        """
                                        Redistribute application routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	OnePK application name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute, self).__init__()

                                            self.yang_name = "application-route"
                                            self.yang_parent_name = "application-routes"

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("instance_name",
                                                            "default_metric",
                                                            "not_used",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.instance_name.is_set or
                                                self.default_metric.is_set or
                                                self.not_used.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.instance_name.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.not_used.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "application-route" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.instance_name.get_name_leafdata())
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.not_used.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "instance-name" or name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "instance-name"):
                                                self.instance_name = value
                                                self.instance_name.value_namespace = name_space
                                                self.instance_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "not-used"):
                                                self.not_used = value
                                                self.not_used.value_namespace = name_space
                                                self.not_used.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.application_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.application_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "application-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "application-route"):
                                            for c in self.application_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.application_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "application-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LabelMode(Entity):
                                    """
                                    BGP 6PE/MPLS\-VPN label allocation mode
                                    
                                    .. attribute:: label_allocation_mode
                                    
                                    	Label allocation mode\: per\-ce  Set per CE label mode, per\-vrf Set per VRF label mode, per\-prefix Set per Prefix label mode (for MPLS\-VPN only)
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Label mode route policy name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode, self).__init__()

                                        self.yang_name = "label-mode"
                                        self.yang_parent_name = "global-af"

                                        self.label_allocation_mode = YLeaf(YType.str, "label-allocation-mode")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("label_allocation_mode",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.label_allocation_mode.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.label_allocation_mode.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "label-mode" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.label_allocation_mode.is_set or self.label_allocation_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.label_allocation_mode.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "label-allocation-mode" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "label-allocation-mode"):
                                            self.label_allocation_mode = value
                                            self.label_allocation_mode.value_namespace = name_space
                                            self.label_allocation_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class EigrpRoutes(Entity):
                                    """
                                    Redistribute information for EIGRP routes.
                                    
                                    .. attribute:: eigrp_route
                                    
                                    	Redistribute EIGRP routes
                                    	**type**\: list of    :py:class:`EigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes, self).__init__()

                                        self.yang_name = "eigrp-routes"
                                        self.yang_parent_name = "global-af"

                                        self.eigrp_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes, self).__setattr__(name, value)


                                    class EigrpRoute(Entity):
                                        """
                                        Redistribute EIGRP routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	EIGRP router tag
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: redist_type
                                        
                                        	Redistribution type\: 01 for internal routes, 02 for external routes, Logical combinations permitted
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute, self).__init__()

                                            self.yang_name = "eigrp-route"
                                            self.yang_parent_name = "eigrp-routes"

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.redist_type = YLeaf(YType.str, "redist-type")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("instance_name",
                                                            "default_metric",
                                                            "redist_type",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.instance_name.is_set or
                                                self.default_metric.is_set or
                                                self.redist_type.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.instance_name.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.redist_type.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "eigrp-route" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.instance_name.get_name_leafdata())
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.redist_type.is_set or self.redist_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.redist_type.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "instance-name" or name == "default-metric" or name == "redist-type" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "instance-name"):
                                                self.instance_name = value
                                                self.instance_name.value_namespace = name_space
                                                self.instance_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "redist-type"):
                                                self.redist_type = value
                                                self.redist_type.value_namespace = name_space
                                                self.redist_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.eigrp_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.eigrp_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "eigrp-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "eigrp-route"):
                                            for c in self.eigrp_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.eigrp_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "eigrp-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SourcedNetworks(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: sourced_network
                                    
                                    	Sourced network configuration
                                    	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks, self).__init__()

                                        self.yang_name = "sourced-networks"
                                        self.yang_parent_name = "global-af"

                                        self.sourced_network = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks, self).__setattr__(name, value)


                                    class SourcedNetwork(Entity):
                                        """
                                        Sourced network configuration
                                        
                                        .. attribute:: network_addr  <key>
                                        
                                        	Network in prefix/length format (address part)
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network in prefix/length format (prefix part)
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route, default is FALSE
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork, self).__init__()

                                            self.yang_name = "sourced-network"
                                            self.yang_parent_name = "sourced-networks"

                                            self.network_addr = YLeaf(YType.str, "network-addr")

                                            self.network_prefix = YLeaf(YType.uint16, "network-prefix")

                                            self.backdoor = YLeaf(YType.boolean, "backdoor")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("network_addr",
                                                            "network_prefix",
                                                            "backdoor",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.network_addr.is_set or
                                                self.network_prefix.is_set or
                                                self.backdoor.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.network_addr.yfilter != YFilter.not_set or
                                                self.network_prefix.yfilter != YFilter.not_set or
                                                self.backdoor.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sourced-network" + "[network-addr='" + self.network_addr.get() + "']" + "[network-prefix='" + self.network_prefix.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.network_addr.is_set or self.network_addr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.network_addr.get_name_leafdata())
                                            if (self.network_prefix.is_set or self.network_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.network_prefix.get_name_leafdata())
                                            if (self.backdoor.is_set or self.backdoor.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backdoor.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "network-addr" or name == "network-prefix" or name == "backdoor" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "network-addr"):
                                                self.network_addr = value
                                                self.network_addr.value_namespace = name_space
                                                self.network_addr.value_namespace_prefix = name_space_prefix
                                            if(value_path == "network-prefix"):
                                                self.network_prefix = value
                                                self.network_prefix.value_namespace = name_space
                                                self.network_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backdoor"):
                                                self.backdoor = value
                                                self.backdoor.value_namespace = name_space
                                                self.backdoor.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.sourced_network:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.sourced_network:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sourced-networks" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sourced-network"):
                                            for c in self.sourced_network:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.sourced_network.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sourced-network"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class ConnectedRoutes(Entity):
                                    """
                                    Redistribute connected routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes, self).__init__()

                                        self.yang_name = "connected-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("default_metric",
                                                        "not_used",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.default_metric.is_set or
                                            self.not_used.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.default_metric.yfilter != YFilter.not_set or
                                            self.not_used.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_metric.get_name_leafdata())
                                        if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_used.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "default-metric"):
                                            self.default_metric = value
                                            self.default_metric.value_namespace = name_space
                                            self.default_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-used"):
                                            self.not_used = value
                                            self.not_used.value_namespace = name_space
                                            self.not_used.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class AllocateLabel(Entity):
                                    """
                                    Label allocation policy
                                    
                                    .. attribute:: all
                                    
                                    	Whether all nets should be labeled, default is FALSE
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel, self).__init__()

                                        self.yang_name = "allocate-label"
                                        self.yang_parent_name = "global-af"

                                        self.all = YLeaf(YType.boolean, "all")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "allocate-label" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all.is_set or self.all.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all"):
                                            self.all = value
                                            self.all.value_namespace = name_space
                                            self.all.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class AdditionalPathsSelection(Entity):
                                    """
                                    Configure additional paths selection
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy for selection
                                    	**type**\:  str
                                    
                                    .. attribute:: selection
                                    
                                    	Enable/disable selection 
                                    	**type**\:   :py:class:`BgpafAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpafAdditionalPathsCfg>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection, self).__init__()

                                        self.yang_name = "additional-paths-selection"
                                        self.yang_parent_name = "global-af"

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.selection = YLeaf(YType.enumeration, "selection")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_policy_name",
                                                        "selection") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.route_policy_name.is_set or
                                            self.selection.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set or
                                            self.selection.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "additional-paths-selection" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                        if (self.selection.is_set or self.selection.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.selection.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-policy-name" or name == "selection"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "selection"):
                                            self.selection = value
                                            self.selection.value_namespace = name_space
                                            self.selection.value_namespace_prefix = name_space_prefix


                                class OspfRoutes(Entity):
                                    """
                                    Redistribute information for OSPF routes.
                                    
                                    .. attribute:: ospf_route
                                    
                                    	Redistribute OSPF routes
                                    	**type**\: list of    :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes, self).__init__()

                                        self.yang_name = "ospf-routes"
                                        self.yang_parent_name = "global-af"

                                        self.ospf_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes, self).__setattr__(name, value)


                                    class OspfRoute(Entity):
                                        """
                                        Redistribute OSPF routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	OSPF router tag
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: redist_type
                                        
                                        	Redistribution type\: 01 for internal routes, 02 for external routes of type 1, 04 for external routes of type 2, 08 for NSSA external routes of type 1, 10 for NSSA external routes of type 2, 20 for external routes, 40 for NSSA external routes.  Logical combinations permitted
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute, self).__init__()

                                            self.yang_name = "ospf-route"
                                            self.yang_parent_name = "ospf-routes"

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.redist_type = YLeaf(YType.str, "redist-type")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("instance_name",
                                                            "default_metric",
                                                            "redist_type",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.instance_name.is_set or
                                                self.default_metric.is_set or
                                                self.redist_type.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.instance_name.yfilter != YFilter.not_set or
                                                self.default_metric.yfilter != YFilter.not_set or
                                                self.redist_type.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ospf-route" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.instance_name.get_name_leafdata())
                                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                                            if (self.redist_type.is_set or self.redist_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.redist_type.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "instance-name" or name == "default-metric" or name == "redist-type" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "instance-name"):
                                                self.instance_name = value
                                                self.instance_name.value_namespace = name_space
                                                self.instance_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "default-metric"):
                                                self.default_metric = value
                                                self.default_metric.value_namespace = name_space
                                                self.default_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "redist-type"):
                                                self.redist_type = value
                                                self.redist_type.value_namespace = name_space
                                                self.redist_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.ospf_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.ospf_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ospf-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ospf-route"):
                                            for c in self.ospf_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.ospf_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ospf-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class MobileRoutes(Entity):
                                    """
                                    Redistribute mobile routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes, self).__init__()

                                        self.yang_name = "mobile-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("default_metric",
                                                        "not_used",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.default_metric.is_set or
                                            self.not_used.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.default_metric.yfilter != YFilter.not_set or
                                            self.not_used.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mobile-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_metric.get_name_leafdata())
                                        if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_used.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "default-metric"):
                                            self.default_metric = value
                                            self.default_metric.value_namespace = name_space
                                            self.default_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-used"):
                                            self.not_used = value
                                            self.not_used.value_namespace = name_space
                                            self.not_used.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class SubscriberRoutes(Entity):
                                    """
                                    Redistribute subscriber routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes, self).__init__()

                                        self.yang_name = "subscriber-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("default_metric",
                                                        "not_used",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.default_metric.is_set or
                                            self.not_used.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.default_metric.yfilter != YFilter.not_set or
                                            self.not_used.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "subscriber-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_metric.get_name_leafdata())
                                        if (self.not_used.is_set or self.not_used.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_used.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "default-metric" or name == "not-used" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "default-metric"):
                                            self.default_metric = value
                                            self.default_metric.value_namespace = name_space
                                            self.default_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-used"):
                                            self.not_used = value
                                            self.not_used.value_namespace = name_space
                                            self.not_used.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.additional_paths_receive.is_set or
                                        self.additional_paths_send.is_set or
                                        self.advertise_local_labeled_route_safi_unicast.is_set or
                                        self.attribute_download.is_set or
                                        self.best_external.is_set or
                                        self.disable_as_path_loop_check.is_set or
                                        self.disable_client_to_client_rr.is_set or
                                        self.disable_default_martian_check.is_set or
                                        self.dynamic_med_interval.is_set or
                                        self.enable.is_set or
                                        self.global_table_mcast.is_set or
                                        self.inter_as_install.is_set or
                                        self.label_retain.is_set or
                                        self.label_security_rpf.is_set or
                                        self.next_hop_critical_trigger_delay.is_set or
                                        self.next_hop_non_critical_trigger_delay.is_set or
                                        self.next_hop_resolution_prefix_length_minimum.is_set or
                                        self.next_hop_route_policy.is_set or
                                        self.permanent_network.is_set or
                                        self.reset_weight_on_import.is_set or
                                        self.rnh_install_format.is_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                        self.rpki_bestpath_use_origin_as_validity.is_set or
                                        self.rpki_origin_as_validation_disable.is_set or
                                        self.rpki_origin_as_validity_signal_ibgp.is_set or
                                        self.scan_time.is_set or
                                        self.segmented_mcast.is_set or
                                        self.table_policy.is_set or
                                        self.update_limit_address_family.is_set or
                                        self.update_limit_sub_group_ebgp.is_set or
                                        self.update_limit_sub_group_ibgp.is_set or
                                        self.use_igpsr_label.is_set or
                                        self.wait_rib_install.is_set or
                                        (self.additional_paths_selection is not None and self.additional_paths_selection.has_data()) or
                                        (self.aggregate_addresses is not None and self.aggregate_addresses.has_data()) or
                                        (self.allocate_label is not None and self.allocate_label.has_data()) or
                                        (self.application_routes is not None and self.application_routes.has_data()) or
                                        (self.disable_cluster_client_to_client_rrs is not None and self.disable_cluster_client_to_client_rrs.has_data()) or
                                        (self.distance is not None and self.distance.has_data()) or
                                        (self.eigrp_routes is not None and self.eigrp_routes.has_data()) or
                                        (self.isis_routes is not None and self.isis_routes.has_data()) or
                                        (self.label_mode is not None and self.label_mode.has_data()) or
                                        (self.ospf_routes is not None and self.ospf_routes.has_data()) or
                                        (self.retain_rt is not None and self.retain_rt.has_data()) or
                                        (self.sourced_networks is not None and self.sourced_networks.has_data()) or
                                        (self.vrf_all is not None and self.vrf_all.has_data()) or
                                        (self.connected_routes is not None) or
                                        (self.dampening is not None) or
                                        (self.domain_distinguisher is not None) or
                                        (self.ebgp is not None) or
                                        (self.eibgp is not None) or
                                        (self.ibgp is not None) or
                                        (self.import_delay is not None) or
                                        (self.label_delay is not None) or
                                        (self.lisp_routes is not None) or
                                        (self.mobile_routes is not None) or
                                        (self.rip_routes is not None) or
                                        (self.static_routes is not None) or
                                        (self.subscriber_routes is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.additional_paths_receive.yfilter != YFilter.not_set or
                                        self.additional_paths_send.yfilter != YFilter.not_set or
                                        self.advertise_local_labeled_route_safi_unicast.yfilter != YFilter.not_set or
                                        self.attribute_download.yfilter != YFilter.not_set or
                                        self.best_external.yfilter != YFilter.not_set or
                                        self.disable_as_path_loop_check.yfilter != YFilter.not_set or
                                        self.disable_client_to_client_rr.yfilter != YFilter.not_set or
                                        self.disable_default_martian_check.yfilter != YFilter.not_set or
                                        self.dynamic_med_interval.yfilter != YFilter.not_set or
                                        self.enable.yfilter != YFilter.not_set or
                                        self.global_table_mcast.yfilter != YFilter.not_set or
                                        self.inter_as_install.yfilter != YFilter.not_set or
                                        self.label_retain.yfilter != YFilter.not_set or
                                        self.label_security_rpf.yfilter != YFilter.not_set or
                                        self.next_hop_critical_trigger_delay.yfilter != YFilter.not_set or
                                        self.next_hop_non_critical_trigger_delay.yfilter != YFilter.not_set or
                                        self.next_hop_resolution_prefix_length_minimum.yfilter != YFilter.not_set or
                                        self.next_hop_route_policy.yfilter != YFilter.not_set or
                                        self.permanent_network.yfilter != YFilter.not_set or
                                        self.reset_weight_on_import.yfilter != YFilter.not_set or
                                        self.rnh_install_format.yfilter != YFilter.not_set or
                                        self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                        self.rpki_bestpath_use_origin_as_validity.yfilter != YFilter.not_set or
                                        self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                        self.rpki_origin_as_validity_signal_ibgp.yfilter != YFilter.not_set or
                                        self.scan_time.yfilter != YFilter.not_set or
                                        self.segmented_mcast.yfilter != YFilter.not_set or
                                        self.table_policy.yfilter != YFilter.not_set or
                                        self.update_limit_address_family.yfilter != YFilter.not_set or
                                        self.update_limit_sub_group_ebgp.yfilter != YFilter.not_set or
                                        self.update_limit_sub_group_ibgp.yfilter != YFilter.not_set or
                                        self.use_igpsr_label.yfilter != YFilter.not_set or
                                        self.wait_rib_install.yfilter != YFilter.not_set or
                                        (self.additional_paths_selection is not None and self.additional_paths_selection.has_operation()) or
                                        (self.aggregate_addresses is not None and self.aggregate_addresses.has_operation()) or
                                        (self.allocate_label is not None and self.allocate_label.has_operation()) or
                                        (self.application_routes is not None and self.application_routes.has_operation()) or
                                        (self.connected_routes is not None and self.connected_routes.has_operation()) or
                                        (self.dampening is not None and self.dampening.has_operation()) or
                                        (self.disable_cluster_client_to_client_rrs is not None and self.disable_cluster_client_to_client_rrs.has_operation()) or
                                        (self.distance is not None and self.distance.has_operation()) or
                                        (self.domain_distinguisher is not None and self.domain_distinguisher.has_operation()) or
                                        (self.ebgp is not None and self.ebgp.has_operation()) or
                                        (self.eibgp is not None and self.eibgp.has_operation()) or
                                        (self.eigrp_routes is not None and self.eigrp_routes.has_operation()) or
                                        (self.ibgp is not None and self.ibgp.has_operation()) or
                                        (self.import_delay is not None and self.import_delay.has_operation()) or
                                        (self.isis_routes is not None and self.isis_routes.has_operation()) or
                                        (self.label_delay is not None and self.label_delay.has_operation()) or
                                        (self.label_mode is not None and self.label_mode.has_operation()) or
                                        (self.lisp_routes is not None and self.lisp_routes.has_operation()) or
                                        (self.mobile_routes is not None and self.mobile_routes.has_operation()) or
                                        (self.ospf_routes is not None and self.ospf_routes.has_operation()) or
                                        (self.retain_rt is not None and self.retain_rt.has_operation()) or
                                        (self.rip_routes is not None and self.rip_routes.has_operation()) or
                                        (self.sourced_networks is not None and self.sourced_networks.has_operation()) or
                                        (self.static_routes is not None and self.static_routes.has_operation()) or
                                        (self.subscriber_routes is not None and self.subscriber_routes.has_operation()) or
                                        (self.vrf_all is not None and self.vrf_all.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "global-af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.additional_paths_receive.is_set or self.additional_paths_receive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_receive.get_name_leafdata())
                                    if (self.additional_paths_send.is_set or self.additional_paths_send.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.additional_paths_send.get_name_leafdata())
                                    if (self.advertise_local_labeled_route_safi_unicast.is_set or self.advertise_local_labeled_route_safi_unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertise_local_labeled_route_safi_unicast.get_name_leafdata())
                                    if (self.attribute_download.is_set or self.attribute_download.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.attribute_download.get_name_leafdata())
                                    if (self.best_external.is_set or self.best_external.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.best_external.get_name_leafdata())
                                    if (self.disable_as_path_loop_check.is_set or self.disable_as_path_loop_check.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_as_path_loop_check.get_name_leafdata())
                                    if (self.disable_client_to_client_rr.is_set or self.disable_client_to_client_rr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_client_to_client_rr.get_name_leafdata())
                                    if (self.disable_default_martian_check.is_set or self.disable_default_martian_check.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_default_martian_check.get_name_leafdata())
                                    if (self.dynamic_med_interval.is_set or self.dynamic_med_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dynamic_med_interval.get_name_leafdata())
                                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enable.get_name_leafdata())
                                    if (self.global_table_mcast.is_set or self.global_table_mcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.global_table_mcast.get_name_leafdata())
                                    if (self.inter_as_install.is_set or self.inter_as_install.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.inter_as_install.get_name_leafdata())
                                    if (self.label_retain.is_set or self.label_retain.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_retain.get_name_leafdata())
                                    if (self.label_security_rpf.is_set or self.label_security_rpf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_security_rpf.get_name_leafdata())
                                    if (self.next_hop_critical_trigger_delay.is_set or self.next_hop_critical_trigger_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_critical_trigger_delay.get_name_leafdata())
                                    if (self.next_hop_non_critical_trigger_delay.is_set or self.next_hop_non_critical_trigger_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_non_critical_trigger_delay.get_name_leafdata())
                                    if (self.next_hop_resolution_prefix_length_minimum.is_set or self.next_hop_resolution_prefix_length_minimum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_resolution_prefix_length_minimum.get_name_leafdata())
                                    if (self.next_hop_route_policy.is_set or self.next_hop_route_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_route_policy.get_name_leafdata())
                                    if (self.permanent_network.is_set or self.permanent_network.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.permanent_network.get_name_leafdata())
                                    if (self.reset_weight_on_import.is_set or self.reset_weight_on_import.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reset_weight_on_import.get_name_leafdata())
                                    if (self.rnh_install_format.is_set or self.rnh_install_format.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rnh_install_format.get_name_leafdata())
                                    if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                                    if (self.rpki_bestpath_use_origin_as_validity.is_set or self.rpki_bestpath_use_origin_as_validity.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_bestpath_use_origin_as_validity.get_name_leafdata())
                                    if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                                    if (self.rpki_origin_as_validity_signal_ibgp.is_set or self.rpki_origin_as_validity_signal_ibgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpki_origin_as_validity_signal_ibgp.get_name_leafdata())
                                    if (self.scan_time.is_set or self.scan_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.scan_time.get_name_leafdata())
                                    if (self.segmented_mcast.is_set or self.segmented_mcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segmented_mcast.get_name_leafdata())
                                    if (self.table_policy.is_set or self.table_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.table_policy.get_name_leafdata())
                                    if (self.update_limit_address_family.is_set or self.update_limit_address_family.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_limit_address_family.get_name_leafdata())
                                    if (self.update_limit_sub_group_ebgp.is_set or self.update_limit_sub_group_ebgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_limit_sub_group_ebgp.get_name_leafdata())
                                    if (self.update_limit_sub_group_ibgp.is_set or self.update_limit_sub_group_ibgp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.update_limit_sub_group_ibgp.get_name_leafdata())
                                    if (self.use_igpsr_label.is_set or self.use_igpsr_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.use_igpsr_label.get_name_leafdata())
                                    if (self.wait_rib_install.is_set or self.wait_rib_install.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wait_rib_install.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "additional-paths-selection"):
                                        if (self.additional_paths_selection is None):
                                            self.additional_paths_selection = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection()
                                            self.additional_paths_selection.parent = self
                                            self._children_name_map["additional_paths_selection"] = "additional-paths-selection"
                                        return self.additional_paths_selection

                                    if (child_yang_name == "aggregate-addresses"):
                                        if (self.aggregate_addresses is None):
                                            self.aggregate_addresses = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses()
                                            self.aggregate_addresses.parent = self
                                            self._children_name_map["aggregate_addresses"] = "aggregate-addresses"
                                        return self.aggregate_addresses

                                    if (child_yang_name == "allocate-label"):
                                        if (self.allocate_label is None):
                                            self.allocate_label = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel()
                                            self.allocate_label.parent = self
                                            self._children_name_map["allocate_label"] = "allocate-label"
                                        return self.allocate_label

                                    if (child_yang_name == "application-routes"):
                                        if (self.application_routes is None):
                                            self.application_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes()
                                            self.application_routes.parent = self
                                            self._children_name_map["application_routes"] = "application-routes"
                                        return self.application_routes

                                    if (child_yang_name == "connected-routes"):
                                        if (self.connected_routes is None):
                                            self.connected_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes()
                                            self.connected_routes.parent = self
                                            self._children_name_map["connected_routes"] = "connected-routes"
                                        return self.connected_routes

                                    if (child_yang_name == "dampening"):
                                        if (self.dampening is None):
                                            self.dampening = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening()
                                            self.dampening.parent = self
                                            self._children_name_map["dampening"] = "dampening"
                                        return self.dampening

                                    if (child_yang_name == "disable-cluster-client-to-client-rrs"):
                                        if (self.disable_cluster_client_to_client_rrs is None):
                                            self.disable_cluster_client_to_client_rrs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs()
                                            self.disable_cluster_client_to_client_rrs.parent = self
                                            self._children_name_map["disable_cluster_client_to_client_rrs"] = "disable-cluster-client-to-client-rrs"
                                        return self.disable_cluster_client_to_client_rrs

                                    if (child_yang_name == "distance"):
                                        if (self.distance is None):
                                            self.distance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance()
                                            self.distance.parent = self
                                            self._children_name_map["distance"] = "distance"
                                        return self.distance

                                    if (child_yang_name == "domain-distinguisher"):
                                        if (self.domain_distinguisher is None):
                                            self.domain_distinguisher = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher()
                                            self.domain_distinguisher.parent = self
                                            self._children_name_map["domain_distinguisher"] = "domain-distinguisher"
                                        return self.domain_distinguisher

                                    if (child_yang_name == "ebgp"):
                                        if (self.ebgp is None):
                                            self.ebgp = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp()
                                            self.ebgp.parent = self
                                            self._children_name_map["ebgp"] = "ebgp"
                                        return self.ebgp

                                    if (child_yang_name == "eibgp"):
                                        if (self.eibgp is None):
                                            self.eibgp = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp()
                                            self.eibgp.parent = self
                                            self._children_name_map["eibgp"] = "eibgp"
                                        return self.eibgp

                                    if (child_yang_name == "eigrp-routes"):
                                        if (self.eigrp_routes is None):
                                            self.eigrp_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes()
                                            self.eigrp_routes.parent = self
                                            self._children_name_map["eigrp_routes"] = "eigrp-routes"
                                        return self.eigrp_routes

                                    if (child_yang_name == "ibgp"):
                                        if (self.ibgp is None):
                                            self.ibgp = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"
                                        return self.ibgp

                                    if (child_yang_name == "import-delay"):
                                        if (self.import_delay is None):
                                            self.import_delay = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay()
                                            self.import_delay.parent = self
                                            self._children_name_map["import_delay"] = "import-delay"
                                        return self.import_delay

                                    if (child_yang_name == "isis-routes"):
                                        if (self.isis_routes is None):
                                            self.isis_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes()
                                            self.isis_routes.parent = self
                                            self._children_name_map["isis_routes"] = "isis-routes"
                                        return self.isis_routes

                                    if (child_yang_name == "label-delay"):
                                        if (self.label_delay is None):
                                            self.label_delay = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay()
                                            self.label_delay.parent = self
                                            self._children_name_map["label_delay"] = "label-delay"
                                        return self.label_delay

                                    if (child_yang_name == "label-mode"):
                                        if (self.label_mode is None):
                                            self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode()
                                            self.label_mode.parent = self
                                            self._children_name_map["label_mode"] = "label-mode"
                                        return self.label_mode

                                    if (child_yang_name == "lisp-routes"):
                                        if (self.lisp_routes is None):
                                            self.lisp_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes()
                                            self.lisp_routes.parent = self
                                            self._children_name_map["lisp_routes"] = "lisp-routes"
                                        return self.lisp_routes

                                    if (child_yang_name == "mobile-routes"):
                                        if (self.mobile_routes is None):
                                            self.mobile_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes()
                                            self.mobile_routes.parent = self
                                            self._children_name_map["mobile_routes"] = "mobile-routes"
                                        return self.mobile_routes

                                    if (child_yang_name == "ospf-routes"):
                                        if (self.ospf_routes is None):
                                            self.ospf_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes()
                                            self.ospf_routes.parent = self
                                            self._children_name_map["ospf_routes"] = "ospf-routes"
                                        return self.ospf_routes

                                    if (child_yang_name == "retain-rt"):
                                        if (self.retain_rt is None):
                                            self.retain_rt = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt()
                                            self.retain_rt.parent = self
                                            self._children_name_map["retain_rt"] = "retain-rt"
                                        return self.retain_rt

                                    if (child_yang_name == "rip-routes"):
                                        if (self.rip_routes is None):
                                            self.rip_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes()
                                            self.rip_routes.parent = self
                                            self._children_name_map["rip_routes"] = "rip-routes"
                                        return self.rip_routes

                                    if (child_yang_name == "sourced-networks"):
                                        if (self.sourced_networks is None):
                                            self.sourced_networks = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks()
                                            self.sourced_networks.parent = self
                                            self._children_name_map["sourced_networks"] = "sourced-networks"
                                        return self.sourced_networks

                                    if (child_yang_name == "static-routes"):
                                        if (self.static_routes is None):
                                            self.static_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes()
                                            self.static_routes.parent = self
                                            self._children_name_map["static_routes"] = "static-routes"
                                        return self.static_routes

                                    if (child_yang_name == "subscriber-routes"):
                                        if (self.subscriber_routes is None):
                                            self.subscriber_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes()
                                            self.subscriber_routes.parent = self
                                            self._children_name_map["subscriber_routes"] = "subscriber-routes"
                                        return self.subscriber_routes

                                    if (child_yang_name == "vrf-all"):
                                        if (self.vrf_all is None):
                                            self.vrf_all = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll()
                                            self.vrf_all.parent = self
                                            self._children_name_map["vrf_all"] = "vrf-all"
                                        return self.vrf_all

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "additional-paths-selection" or name == "aggregate-addresses" or name == "allocate-label" or name == "application-routes" or name == "connected-routes" or name == "dampening" or name == "disable-cluster-client-to-client-rrs" or name == "distance" or name == "domain-distinguisher" or name == "ebgp" or name == "eibgp" or name == "eigrp-routes" or name == "ibgp" or name == "import-delay" or name == "isis-routes" or name == "label-delay" or name == "label-mode" or name == "lisp-routes" or name == "mobile-routes" or name == "ospf-routes" or name == "retain-rt" or name == "rip-routes" or name == "sourced-networks" or name == "static-routes" or name == "subscriber-routes" or name == "vrf-all" or name == "af-name" or name == "additional-paths-receive" or name == "additional-paths-send" or name == "advertise-local-labeled-route-safi-unicast" or name == "attribute-download" or name == "best-external" or name == "disable-as-path-loop-check" or name == "disable-client-to-client-rr" or name == "disable-default-martian-check" or name == "dynamic-med-interval" or name == "enable" or name == "global-table-mcast" or name == "inter-as-install" or name == "label-retain" or name == "label-security-rpf" or name == "next-hop-critical-trigger-delay" or name == "next-hop-non-critical-trigger-delay" or name == "next-hop-resolution-prefix-length-minimum" or name == "next-hop-route-policy" or name == "permanent-network" or name == "reset-weight-on-import" or name == "rnh-install-format" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-bestpath-use-origin-as-validity" or name == "rpki-origin-as-validation-disable" or name == "rpki-origin-as-validity-signal-ibgp" or name == "scan-time" or name == "segmented-mcast" or name == "table-policy" or name == "update-limit-address-family" or name == "update-limit-sub-group-ebgp" or name == "update-limit-sub-group-ibgp" or name == "use-igpsr-label" or name == "wait-rib-install"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-receive"):
                                        self.additional_paths_receive = value
                                        self.additional_paths_receive.value_namespace = name_space
                                        self.additional_paths_receive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "additional-paths-send"):
                                        self.additional_paths_send = value
                                        self.additional_paths_send.value_namespace = name_space
                                        self.additional_paths_send.value_namespace_prefix = name_space_prefix
                                    if(value_path == "advertise-local-labeled-route-safi-unicast"):
                                        self.advertise_local_labeled_route_safi_unicast = value
                                        self.advertise_local_labeled_route_safi_unicast.value_namespace = name_space
                                        self.advertise_local_labeled_route_safi_unicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "attribute-download"):
                                        self.attribute_download = value
                                        self.attribute_download.value_namespace = name_space
                                        self.attribute_download.value_namespace_prefix = name_space_prefix
                                    if(value_path == "best-external"):
                                        self.best_external = value
                                        self.best_external.value_namespace = name_space
                                        self.best_external.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-as-path-loop-check"):
                                        self.disable_as_path_loop_check = value
                                        self.disable_as_path_loop_check.value_namespace = name_space
                                        self.disable_as_path_loop_check.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-client-to-client-rr"):
                                        self.disable_client_to_client_rr = value
                                        self.disable_client_to_client_rr.value_namespace = name_space
                                        self.disable_client_to_client_rr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-default-martian-check"):
                                        self.disable_default_martian_check = value
                                        self.disable_default_martian_check.value_namespace = name_space
                                        self.disable_default_martian_check.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dynamic-med-interval"):
                                        self.dynamic_med_interval = value
                                        self.dynamic_med_interval.value_namespace = name_space
                                        self.dynamic_med_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enable"):
                                        self.enable = value
                                        self.enable.value_namespace = name_space
                                        self.enable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "global-table-mcast"):
                                        self.global_table_mcast = value
                                        self.global_table_mcast.value_namespace = name_space
                                        self.global_table_mcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "inter-as-install"):
                                        self.inter_as_install = value
                                        self.inter_as_install.value_namespace = name_space
                                        self.inter_as_install.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-retain"):
                                        self.label_retain = value
                                        self.label_retain.value_namespace = name_space
                                        self.label_retain.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-security-rpf"):
                                        self.label_security_rpf = value
                                        self.label_security_rpf.value_namespace = name_space
                                        self.label_security_rpf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-critical-trigger-delay"):
                                        self.next_hop_critical_trigger_delay = value
                                        self.next_hop_critical_trigger_delay.value_namespace = name_space
                                        self.next_hop_critical_trigger_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-non-critical-trigger-delay"):
                                        self.next_hop_non_critical_trigger_delay = value
                                        self.next_hop_non_critical_trigger_delay.value_namespace = name_space
                                        self.next_hop_non_critical_trigger_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-resolution-prefix-length-minimum"):
                                        self.next_hop_resolution_prefix_length_minimum = value
                                        self.next_hop_resolution_prefix_length_minimum.value_namespace = name_space
                                        self.next_hop_resolution_prefix_length_minimum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-route-policy"):
                                        self.next_hop_route_policy = value
                                        self.next_hop_route_policy.value_namespace = name_space
                                        self.next_hop_route_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "permanent-network"):
                                        self.permanent_network = value
                                        self.permanent_network.value_namespace = name_space
                                        self.permanent_network.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reset-weight-on-import"):
                                        self.reset_weight_on_import = value
                                        self.reset_weight_on_import.value_namespace = name_space
                                        self.reset_weight_on_import.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rnh-install-format"):
                                        self.rnh_install_format = value
                                        self.rnh_install_format.value_namespace = name_space
                                        self.rnh_install_format.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                        self.rpki_bestpath_origin_as_allow_invalid = value
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                        self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-bestpath-use-origin-as-validity"):
                                        self.rpki_bestpath_use_origin_as_validity = value
                                        self.rpki_bestpath_use_origin_as_validity.value_namespace = name_space
                                        self.rpki_bestpath_use_origin_as_validity.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-origin-as-validation-disable"):
                                        self.rpki_origin_as_validation_disable = value
                                        self.rpki_origin_as_validation_disable.value_namespace = name_space
                                        self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpki-origin-as-validity-signal-ibgp"):
                                        self.rpki_origin_as_validity_signal_ibgp = value
                                        self.rpki_origin_as_validity_signal_ibgp.value_namespace = name_space
                                        self.rpki_origin_as_validity_signal_ibgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "scan-time"):
                                        self.scan_time = value
                                        self.scan_time.value_namespace = name_space
                                        self.scan_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segmented-mcast"):
                                        self.segmented_mcast = value
                                        self.segmented_mcast.value_namespace = name_space
                                        self.segmented_mcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "table-policy"):
                                        self.table_policy = value
                                        self.table_policy.value_namespace = name_space
                                        self.table_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-limit-address-family"):
                                        self.update_limit_address_family = value
                                        self.update_limit_address_family.value_namespace = name_space
                                        self.update_limit_address_family.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-limit-sub-group-ebgp"):
                                        self.update_limit_sub_group_ebgp = value
                                        self.update_limit_sub_group_ebgp.value_namespace = name_space
                                        self.update_limit_sub_group_ebgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "update-limit-sub-group-ibgp"):
                                        self.update_limit_sub_group_ibgp = value
                                        self.update_limit_sub_group_ibgp.value_namespace = name_space
                                        self.update_limit_sub_group_ibgp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "use-igpsr-label"):
                                        self.use_igpsr_label = value
                                        self.use_igpsr_label.value_namespace = name_space
                                        self.use_igpsr_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wait-rib-install"):
                                        self.wait_rib_install = value
                                        self.wait_rib_install.value_namespace = name_space
                                        self.wait_rib_install.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.global_af:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.global_af:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "global-afs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "global-af"):
                                    for c in self.global_af:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.global_af.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "global-af"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RpkiStaticRoutes(Entity):
                            """
                            RPKI static route configuration
                            
                            .. attribute:: rpki_static_route
                            
                            	RPKI static route
                            	**type**\: list of    :py:class:`RpkiStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes, self).__init__()

                                self.yang_name = "rpki-static-routes"
                                self.yang_parent_name = "global"

                                self.rpki_static_route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes, self).__setattr__(name, value)


                            class RpkiStaticRoute(Entity):
                                """
                                RPKI static route
                                
                                .. attribute:: addrress  <key>
                                
                                	Address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: minimum  <key>
                                
                                	Minimum Prefix Length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: maximum  <key>
                                
                                	Maximum Prefix Length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: as_  <key>
                                
                                	AS Number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute, self).__init__()

                                    self.yang_name = "rpki-static-route"
                                    self.yang_parent_name = "rpki-static-routes"

                                    self.addrress = YLeaf(YType.str, "addrress")

                                    self.minimum = YLeaf(YType.int32, "minimum")

                                    self.maximum = YLeaf(YType.int32, "maximum")

                                    self.as_ = YLeaf(YType.int32, "as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("addrress",
                                                    "minimum",
                                                    "maximum",
                                                    "as_") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.addrress.is_set or
                                        self.minimum.is_set or
                                        self.maximum.is_set or
                                        self.as_.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.addrress.yfilter != YFilter.not_set or
                                        self.minimum.yfilter != YFilter.not_set or
                                        self.maximum.yfilter != YFilter.not_set or
                                        self.as_.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpki-static-route" + "[addrress='" + self.addrress.get() + "']" + "[minimum='" + self.minimum.get() + "']" + "[maximum='" + self.maximum.get() + "']" + "[as='" + self.as_.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.addrress.is_set or self.addrress.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.addrress.get_name_leafdata())
                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "addrress" or name == "minimum" or name == "maximum" or name == "as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "addrress"):
                                        self.addrress = value
                                        self.addrress.value_namespace = name_space
                                        self.addrress.value_namespace_prefix = name_space_prefix
                                    if(value_path == "minimum"):
                                        self.minimum = value
                                        self.minimum.value_namespace = name_space
                                        self.minimum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum"):
                                        self.maximum = value
                                        self.maximum.value_namespace = name_space
                                        self.maximum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as"):
                                        self.as_ = value
                                        self.as_.value_namespace = name_space
                                        self.as_.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpki_static_route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpki_static_route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpki-static-routes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpki-static-route"):
                                    for c in self.rpki_static_route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpki_static_route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpki-static-route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MplsActivatedInterfaces(Entity):
                            """
                            Configure list of MPLS activated interfaces
                            
                            .. attribute:: mpls_activated_interface
                            
                            	Configure a MPLS activated interface
                            	**type**\: list of    :py:class:`MplsActivatedInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces, self).__init__()

                                self.yang_name = "mpls-activated-interfaces"
                                self.yang_parent_name = "global"

                                self.mpls_activated_interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces, self).__setattr__(name, value)


                            class MplsActivatedInterface(Entity):
                                """
                                Configure a MPLS activated interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface, self).__init__()

                                    self.yang_name = "mpls-activated-interface"
                                    self.yang_parent_name = "mpls-activated-interfaces"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.interface_name.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-activated-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mpls_activated_interface:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.mpls_activated_interface:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mpls-activated-interfaces" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mpls-activated-interface"):
                                    for c in self.mpls_activated_interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mpls_activated_interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mpls-activated-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class GlobalTimers(Entity):
                            """
                            Adjust routing timers.
                            
                            .. attribute:: hold_time
                            
                            	Hold time (seconds).  Specify 0 to disable keepalives/hold time
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 180
                            
                            .. attribute:: keepalive
                            
                            	Keepalive interval (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 60
                            
                            .. attribute:: min_accept_hold_time
                            
                            	Minimum acceptable hold time (seconds). Specify 0 to disable keepalives/hold time
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 3
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers, self).__init__()

                                self.yang_name = "global-timers"
                                self.yang_parent_name = "global"

                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                self.keepalive = YLeaf(YType.uint32, "keepalive")

                                self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("hold_time",
                                                "keepalive",
                                                "min_accept_hold_time") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.hold_time.is_set or
                                    self.keepalive.is_set or
                                    self.min_accept_hold_time.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.hold_time.yfilter != YFilter.not_set or
                                    self.keepalive.yfilter != YFilter.not_set or
                                    self.min_accept_hold_time.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "global-timers" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hold_time.get_name_leafdata())
                                if (self.keepalive.is_set or self.keepalive.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.keepalive.get_name_leafdata())
                                if (self.min_accept_hold_time.is_set or self.min_accept_hold_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.min_accept_hold_time.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "hold-time" or name == "keepalive" or name == "min-accept-hold-time"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "hold-time"):
                                    self.hold_time = value
                                    self.hold_time.value_namespace = name_space
                                    self.hold_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "keepalive"):
                                    self.keepalive = value
                                    self.keepalive.value_namespace = name_space
                                    self.keepalive.value_namespace_prefix = name_space_prefix
                                if(value_path == "min-accept-hold-time"):
                                    self.min_accept_hold_time = value
                                    self.min_accept_hold_time.value_namespace = name_space
                                    self.min_accept_hold_time.value_namespace_prefix = name_space_prefix


                        class Bfd(Entity):
                            """
                            BFD configuration
                            
                            .. attribute:: detection_multiplier
                            
                            	Detection multiplier for BFD sessions created by BGP
                            	**type**\:  int
                            
                            	**range:** 2..16
                            
                            .. attribute:: interval
                            
                            	Hello interval for BFD sessions created by BGP
                            	**type**\:  int
                            
                            	**range:** 3..30000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "global"

                                self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                self.interval = YLeaf(YType.uint32, "interval")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("detection_multiplier",
                                                "interval") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.detection_multiplier.is_set or
                                    self.interval.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.detection_multiplier.yfilter != YFilter.not_set or
                                    self.interval.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bfd" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interval.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "detection-multiplier" or name == "interval"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "detection-multiplier"):
                                    self.detection_multiplier = value
                                    self.detection_multiplier.value_namespace = name_space
                                    self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "interval"):
                                    self.interval = value
                                    self.interval.value_namespace = name_space
                                    self.interval.value_namespace_prefix = name_space_prefix


                        class SendSocketBufferSizes(Entity):
                            """
                            set socket parameters
                            
                            .. attribute:: bgp_send_size
                            
                            	BGP Write buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 4096..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 4096
                            
                            .. attribute:: socket_send_size
                            
                            	Send socket buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 4096..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 24576
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes, self).__init__()

                                self.yang_name = "send-socket-buffer-sizes"
                                self.yang_parent_name = "global"

                                self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bgp_send_size",
                                                "socket_send_size") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bgp_send_size.is_set or
                                    self.socket_send_size.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bgp_send_size.yfilter != YFilter.not_set or
                                    self.socket_send_size.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "send-socket-buffer-sizes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bgp_send_size.is_set or self.bgp_send_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_send_size.get_name_leafdata())
                                if (self.socket_send_size.is_set or self.socket_send_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.socket_send_size.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bgp-send-size" or name == "socket-send-size"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bgp-send-size"):
                                    self.bgp_send_size = value
                                    self.bgp_send_size.value_namespace = name_space
                                    self.bgp_send_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "socket-send-size"):
                                    self.socket_send_size = value
                                    self.socket_send_size.value_namespace = name_space
                                    self.socket_send_size.value_namespace_prefix = name_space_prefix


                        class ReceiveSocketBufferSizes(Entity):
                            """
                            Set socket and BGP receive buffer sizes
                            
                            .. attribute:: bgp_receive_size
                            
                            	BGP Read buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 512..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 4096
                            
                            .. attribute:: socket_receive_size
                            
                            	Receive socket buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 512..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 32768
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2015-08-27'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes, self).__init__()

                                self.yang_name = "receive-socket-buffer-sizes"
                                self.yang_parent_name = "global"

                                self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bgp_receive_size",
                                                "socket_receive_size") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bgp_receive_size.is_set or
                                    self.socket_receive_size.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bgp_receive_size.yfilter != YFilter.not_set or
                                    self.socket_receive_size.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "receive-socket-buffer-sizes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bgp_receive_size.is_set or self.bgp_receive_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_receive_size.get_name_leafdata())
                                if (self.socket_receive_size.is_set or self.socket_receive_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.socket_receive_size.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bgp-receive-size" or name == "socket-receive-size"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bgp-receive-size"):
                                    self.bgp_receive_size = value
                                    self.bgp_receive_size.value_namespace = name_space
                                    self.bgp_receive_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "socket-receive-size"):
                                    self.socket_receive_size = value
                                    self.socket_receive_size.value_namespace = name_space
                                    self.socket_receive_size.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.best_path_aigp_ignore.is_set or
                                self.best_path_as_multipath_relax.is_set or
                                self.best_path_as_path_length.is_set or
                                self.best_path_confederation_paths.is_set or
                                self.best_path_cost_community.is_set or
                                self.best_path_med_always.is_set or
                                self.best_path_med_missing.is_set or
                                self.best_path_router_id.is_set or
                                self.default_info_originate.is_set or
                                self.default_metric.is_set or
                                self.disable_auto_soft_reset.is_set or
                                self.disable_enforce_first_as.is_set or
                                self.disable_fast_external_fallover.is_set or
                                self.disable_msg_log.is_set or
                                self.disable_neighbor_logging.is_set or
                                self.enforce_ibgp_out_policy.is_set or
                                self.global_scan_time.is_set or
                                self.graceful_reset.is_set or
                                self.graceful_restart.is_set or
                                self.graceful_restart_purge_time.is_set or
                                self.graceful_restart_stalepath_time.is_set or
                                self.graceful_restart_time.is_set or
                                self.igp_loop_check.is_set or
                                self.igp_redist_internal.is_set or
                                self.install_diversion.is_set or
                                self.local_preference.is_set or
                                self.multi_path_as_path_ignore_onwards.is_set or
                                self.mvpn.is_set or
                                self.neighbor_logging_detail.is_set or
                                self.next_hop_trigger_delay.is_set or
                                self.nsr.is_set or
                                self.read_only.is_set or
                                self.router_id.is_set or
                                self.rpki_bestpath_origin_as_allow_invalid.is_set or
                                self.rpki_bestpath_use_origin_as_validity.is_set or
                                self.rpki_origin_as_validation_disable.is_set or
                                self.rpki_origin_as_validation_time.is_set or
                                self.rpki_origin_as_validity_signal_ibgp.is_set or
                                self.update_error_handling_basic_ebgp_disable.is_set or
                                self.update_error_handling_basic_ibgp_disable.is_set or
                                self.update_error_handling_extended_ebgp.is_set or
                                self.update_error_handling_extended_ibgp.is_set or
                                self.update_limit_process.is_set or
                                self.update_out_logging.is_set or
                                (self.as_league is not None and self.as_league.has_data()) or
                                (self.as_list_groups is not None and self.as_list_groups.has_data()) or
                                (self.attribute_filter_groups is not None and self.attribute_filter_groups.has_data()) or
                                (self.bfd is not None and self.bfd.has_data()) or
                                (self.cluster_id is not None and self.cluster_id.has_data()) or
                                (self.confederation_domain is not None and self.confederation_domain.has_data()) or
                                (self.confederation_peer_ases is not None and self.confederation_peer_ases.has_data()) or
                                (self.global_afs is not None and self.global_afs.has_data()) or
                                (self.global_graceful_maintenance_activate is not None and self.global_graceful_maintenance_activate.has_data()) or
                                (self.global_timers is not None and self.global_timers.has_data()) or
                                (self.limits is not None and self.limits.has_data()) or
                                (self.mpls_activated_interfaces is not None and self.mpls_activated_interfaces.has_data()) or
                                (self.receive_socket_buffer_sizes is not None and self.receive_socket_buffer_sizes.has_data()) or
                                (self.rpki_servers is not None and self.rpki_servers.has_data()) or
                                (self.rpki_static_routes is not None and self.rpki_static_routes.has_data()) or
                                (self.send_socket_buffer_sizes is not None and self.send_socket_buffer_sizes.has_data()) or
                                (self.update_delay is not None and self.update_delay.has_data()) or
                                (self.write_limit is not None and self.write_limit.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.best_path_aigp_ignore.yfilter != YFilter.not_set or
                                self.best_path_as_multipath_relax.yfilter != YFilter.not_set or
                                self.best_path_as_path_length.yfilter != YFilter.not_set or
                                self.best_path_confederation_paths.yfilter != YFilter.not_set or
                                self.best_path_cost_community.yfilter != YFilter.not_set or
                                self.best_path_med_always.yfilter != YFilter.not_set or
                                self.best_path_med_missing.yfilter != YFilter.not_set or
                                self.best_path_router_id.yfilter != YFilter.not_set or
                                self.default_info_originate.yfilter != YFilter.not_set or
                                self.default_metric.yfilter != YFilter.not_set or
                                self.disable_auto_soft_reset.yfilter != YFilter.not_set or
                                self.disable_enforce_first_as.yfilter != YFilter.not_set or
                                self.disable_fast_external_fallover.yfilter != YFilter.not_set or
                                self.disable_msg_log.yfilter != YFilter.not_set or
                                self.disable_neighbor_logging.yfilter != YFilter.not_set or
                                self.enforce_ibgp_out_policy.yfilter != YFilter.not_set or
                                self.global_scan_time.yfilter != YFilter.not_set or
                                self.graceful_reset.yfilter != YFilter.not_set or
                                self.graceful_restart.yfilter != YFilter.not_set or
                                self.graceful_restart_purge_time.yfilter != YFilter.not_set or
                                self.graceful_restart_stalepath_time.yfilter != YFilter.not_set or
                                self.graceful_restart_time.yfilter != YFilter.not_set or
                                self.igp_loop_check.yfilter != YFilter.not_set or
                                self.igp_redist_internal.yfilter != YFilter.not_set or
                                self.install_diversion.yfilter != YFilter.not_set or
                                self.local_preference.yfilter != YFilter.not_set or
                                self.multi_path_as_path_ignore_onwards.yfilter != YFilter.not_set or
                                self.mvpn.yfilter != YFilter.not_set or
                                self.neighbor_logging_detail.yfilter != YFilter.not_set or
                                self.next_hop_trigger_delay.yfilter != YFilter.not_set or
                                self.nsr.yfilter != YFilter.not_set or
                                self.read_only.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set or
                                self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set or
                                self.rpki_bestpath_use_origin_as_validity.yfilter != YFilter.not_set or
                                self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set or
                                self.rpki_origin_as_validation_time.yfilter != YFilter.not_set or
                                self.rpki_origin_as_validity_signal_ibgp.yfilter != YFilter.not_set or
                                self.update_error_handling_basic_ebgp_disable.yfilter != YFilter.not_set or
                                self.update_error_handling_basic_ibgp_disable.yfilter != YFilter.not_set or
                                self.update_error_handling_extended_ebgp.yfilter != YFilter.not_set or
                                self.update_error_handling_extended_ibgp.yfilter != YFilter.not_set or
                                self.update_limit_process.yfilter != YFilter.not_set or
                                self.update_out_logging.yfilter != YFilter.not_set or
                                (self.as_league is not None and self.as_league.has_operation()) or
                                (self.as_list_groups is not None and self.as_list_groups.has_operation()) or
                                (self.attribute_filter_groups is not None and self.attribute_filter_groups.has_operation()) or
                                (self.bfd is not None and self.bfd.has_operation()) or
                                (self.cluster_id is not None and self.cluster_id.has_operation()) or
                                (self.confederation_domain is not None and self.confederation_domain.has_operation()) or
                                (self.confederation_peer_ases is not None and self.confederation_peer_ases.has_operation()) or
                                (self.global_afs is not None and self.global_afs.has_operation()) or
                                (self.global_graceful_maintenance_activate is not None and self.global_graceful_maintenance_activate.has_operation()) or
                                (self.global_timers is not None and self.global_timers.has_operation()) or
                                (self.limits is not None and self.limits.has_operation()) or
                                (self.mpls_activated_interfaces is not None and self.mpls_activated_interfaces.has_operation()) or
                                (self.receive_socket_buffer_sizes is not None and self.receive_socket_buffer_sizes.has_operation()) or
                                (self.rpki_servers is not None and self.rpki_servers.has_operation()) or
                                (self.rpki_static_routes is not None and self.rpki_static_routes.has_operation()) or
                                (self.send_socket_buffer_sizes is not None and self.send_socket_buffer_sizes.has_operation()) or
                                (self.update_delay is not None and self.update_delay.has_operation()) or
                                (self.write_limit is not None and self.write_limit.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "global" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.best_path_aigp_ignore.is_set or self.best_path_aigp_ignore.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_aigp_ignore.get_name_leafdata())
                            if (self.best_path_as_multipath_relax.is_set or self.best_path_as_multipath_relax.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_as_multipath_relax.get_name_leafdata())
                            if (self.best_path_as_path_length.is_set or self.best_path_as_path_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_as_path_length.get_name_leafdata())
                            if (self.best_path_confederation_paths.is_set or self.best_path_confederation_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_confederation_paths.get_name_leafdata())
                            if (self.best_path_cost_community.is_set or self.best_path_cost_community.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_cost_community.get_name_leafdata())
                            if (self.best_path_med_always.is_set or self.best_path_med_always.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_med_always.get_name_leafdata())
                            if (self.best_path_med_missing.is_set or self.best_path_med_missing.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_med_missing.get_name_leafdata())
                            if (self.best_path_router_id.is_set or self.best_path_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.best_path_router_id.get_name_leafdata())
                            if (self.default_info_originate.is_set or self.default_info_originate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_info_originate.get_name_leafdata())
                            if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_metric.get_name_leafdata())
                            if (self.disable_auto_soft_reset.is_set or self.disable_auto_soft_reset.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_auto_soft_reset.get_name_leafdata())
                            if (self.disable_enforce_first_as.is_set or self.disable_enforce_first_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_enforce_first_as.get_name_leafdata())
                            if (self.disable_fast_external_fallover.is_set or self.disable_fast_external_fallover.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_fast_external_fallover.get_name_leafdata())
                            if (self.disable_msg_log.is_set or self.disable_msg_log.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_msg_log.get_name_leafdata())
                            if (self.disable_neighbor_logging.is_set or self.disable_neighbor_logging.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_neighbor_logging.get_name_leafdata())
                            if (self.enforce_ibgp_out_policy.is_set or self.enforce_ibgp_out_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enforce_ibgp_out_policy.get_name_leafdata())
                            if (self.global_scan_time.is_set or self.global_scan_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.global_scan_time.get_name_leafdata())
                            if (self.graceful_reset.is_set or self.graceful_reset.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.graceful_reset.get_name_leafdata())
                            if (self.graceful_restart.is_set or self.graceful_restart.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.graceful_restart.get_name_leafdata())
                            if (self.graceful_restart_purge_time.is_set or self.graceful_restart_purge_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.graceful_restart_purge_time.get_name_leafdata())
                            if (self.graceful_restart_stalepath_time.is_set or self.graceful_restart_stalepath_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.graceful_restart_stalepath_time.get_name_leafdata())
                            if (self.graceful_restart_time.is_set or self.graceful_restart_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.graceful_restart_time.get_name_leafdata())
                            if (self.igp_loop_check.is_set or self.igp_loop_check.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igp_loop_check.get_name_leafdata())
                            if (self.igp_redist_internal.is_set or self.igp_redist_internal.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igp_redist_internal.get_name_leafdata())
                            if (self.install_diversion.is_set or self.install_diversion.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.install_diversion.get_name_leafdata())
                            if (self.local_preference.is_set or self.local_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_preference.get_name_leafdata())
                            if (self.multi_path_as_path_ignore_onwards.is_set or self.multi_path_as_path_ignore_onwards.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multi_path_as_path_ignore_onwards.get_name_leafdata())
                            if (self.mvpn.is_set or self.mvpn.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvpn.get_name_leafdata())
                            if (self.neighbor_logging_detail.is_set or self.neighbor_logging_detail.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_logging_detail.get_name_leafdata())
                            if (self.next_hop_trigger_delay.is_set or self.next_hop_trigger_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_trigger_delay.get_name_leafdata())
                            if (self.nsr.is_set or self.nsr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr.get_name_leafdata())
                            if (self.read_only.is_set or self.read_only.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.read_only.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())
                            if (self.rpki_bestpath_origin_as_allow_invalid.is_set or self.rpki_bestpath_origin_as_allow_invalid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpki_bestpath_origin_as_allow_invalid.get_name_leafdata())
                            if (self.rpki_bestpath_use_origin_as_validity.is_set or self.rpki_bestpath_use_origin_as_validity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpki_bestpath_use_origin_as_validity.get_name_leafdata())
                            if (self.rpki_origin_as_validation_disable.is_set or self.rpki_origin_as_validation_disable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpki_origin_as_validation_disable.get_name_leafdata())
                            if (self.rpki_origin_as_validation_time.is_set or self.rpki_origin_as_validation_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpki_origin_as_validation_time.get_name_leafdata())
                            if (self.rpki_origin_as_validity_signal_ibgp.is_set or self.rpki_origin_as_validity_signal_ibgp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpki_origin_as_validity_signal_ibgp.get_name_leafdata())
                            if (self.update_error_handling_basic_ebgp_disable.is_set or self.update_error_handling_basic_ebgp_disable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_error_handling_basic_ebgp_disable.get_name_leafdata())
                            if (self.update_error_handling_basic_ibgp_disable.is_set or self.update_error_handling_basic_ibgp_disable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_error_handling_basic_ibgp_disable.get_name_leafdata())
                            if (self.update_error_handling_extended_ebgp.is_set or self.update_error_handling_extended_ebgp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_error_handling_extended_ebgp.get_name_leafdata())
                            if (self.update_error_handling_extended_ibgp.is_set or self.update_error_handling_extended_ibgp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_error_handling_extended_ibgp.get_name_leafdata())
                            if (self.update_limit_process.is_set or self.update_limit_process.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_limit_process.get_name_leafdata())
                            if (self.update_out_logging.is_set or self.update_out_logging.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_out_logging.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "as-league"):
                                if (self.as_league is None):
                                    self.as_league = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague()
                                    self.as_league.parent = self
                                    self._children_name_map["as_league"] = "as-league"
                                return self.as_league

                            if (child_yang_name == "as-list-groups"):
                                if (self.as_list_groups is None):
                                    self.as_list_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups()
                                    self.as_list_groups.parent = self
                                    self._children_name_map["as_list_groups"] = "as-list-groups"
                                return self.as_list_groups

                            if (child_yang_name == "attribute-filter-groups"):
                                if (self.attribute_filter_groups is None):
                                    self.attribute_filter_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups()
                                    self.attribute_filter_groups.parent = self
                                    self._children_name_map["attribute_filter_groups"] = "attribute-filter-groups"
                                return self.attribute_filter_groups

                            if (child_yang_name == "bfd"):
                                if (self.bfd is None):
                                    self.bfd = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                return self.bfd

                            if (child_yang_name == "cluster-id"):
                                if (self.cluster_id is None):
                                    self.cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId()
                                    self.cluster_id.parent = self
                                    self._children_name_map["cluster_id"] = "cluster-id"
                                return self.cluster_id

                            if (child_yang_name == "confederation-domain"):
                                if (self.confederation_domain is None):
                                    self.confederation_domain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain()
                                    self.confederation_domain.parent = self
                                    self._children_name_map["confederation_domain"] = "confederation-domain"
                                return self.confederation_domain

                            if (child_yang_name == "confederation-peer-ases"):
                                if (self.confederation_peer_ases is None):
                                    self.confederation_peer_ases = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses()
                                    self.confederation_peer_ases.parent = self
                                    self._children_name_map["confederation_peer_ases"] = "confederation-peer-ases"
                                return self.confederation_peer_ases

                            if (child_yang_name == "global-afs"):
                                if (self.global_afs is None):
                                    self.global_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs()
                                    self.global_afs.parent = self
                                    self._children_name_map["global_afs"] = "global-afs"
                                return self.global_afs

                            if (child_yang_name == "global-graceful-maintenance-activate"):
                                if (self.global_graceful_maintenance_activate is None):
                                    self.global_graceful_maintenance_activate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate()
                                    self.global_graceful_maintenance_activate.parent = self
                                    self._children_name_map["global_graceful_maintenance_activate"] = "global-graceful-maintenance-activate"
                                return self.global_graceful_maintenance_activate

                            if (child_yang_name == "global-timers"):
                                if (self.global_timers is None):
                                    self.global_timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers()
                                    self.global_timers.parent = self
                                    self._children_name_map["global_timers"] = "global-timers"
                                return self.global_timers

                            if (child_yang_name == "limits"):
                                if (self.limits is None):
                                    self.limits = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits()
                                    self.limits.parent = self
                                    self._children_name_map["limits"] = "limits"
                                return self.limits

                            if (child_yang_name == "mpls-activated-interfaces"):
                                if (self.mpls_activated_interfaces is None):
                                    self.mpls_activated_interfaces = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces()
                                    self.mpls_activated_interfaces.parent = self
                                    self._children_name_map["mpls_activated_interfaces"] = "mpls-activated-interfaces"
                                return self.mpls_activated_interfaces

                            if (child_yang_name == "receive-socket-buffer-sizes"):
                                if (self.receive_socket_buffer_sizes is None):
                                    self.receive_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes()
                                    self.receive_socket_buffer_sizes.parent = self
                                    self._children_name_map["receive_socket_buffer_sizes"] = "receive-socket-buffer-sizes"
                                return self.receive_socket_buffer_sizes

                            if (child_yang_name == "rpki-servers"):
                                if (self.rpki_servers is None):
                                    self.rpki_servers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers()
                                    self.rpki_servers.parent = self
                                    self._children_name_map["rpki_servers"] = "rpki-servers"
                                return self.rpki_servers

                            if (child_yang_name == "rpki-static-routes"):
                                if (self.rpki_static_routes is None):
                                    self.rpki_static_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes()
                                    self.rpki_static_routes.parent = self
                                    self._children_name_map["rpki_static_routes"] = "rpki-static-routes"
                                return self.rpki_static_routes

                            if (child_yang_name == "send-socket-buffer-sizes"):
                                if (self.send_socket_buffer_sizes is None):
                                    self.send_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes()
                                    self.send_socket_buffer_sizes.parent = self
                                    self._children_name_map["send_socket_buffer_sizes"] = "send-socket-buffer-sizes"
                                return self.send_socket_buffer_sizes

                            if (child_yang_name == "update-delay"):
                                if (self.update_delay is None):
                                    self.update_delay = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay()
                                    self.update_delay.parent = self
                                    self._children_name_map["update_delay"] = "update-delay"
                                return self.update_delay

                            if (child_yang_name == "write-limit"):
                                if (self.write_limit is None):
                                    self.write_limit = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit()
                                    self.write_limit.parent = self
                                    self._children_name_map["write_limit"] = "write-limit"
                                return self.write_limit

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "as-league" or name == "as-list-groups" or name == "attribute-filter-groups" or name == "bfd" or name == "cluster-id" or name == "confederation-domain" or name == "confederation-peer-ases" or name == "global-afs" or name == "global-graceful-maintenance-activate" or name == "global-timers" or name == "limits" or name == "mpls-activated-interfaces" or name == "receive-socket-buffer-sizes" or name == "rpki-servers" or name == "rpki-static-routes" or name == "send-socket-buffer-sizes" or name == "update-delay" or name == "write-limit" or name == "best-path-aigp-ignore" or name == "best-path-as-multipath-relax" or name == "best-path-as-path-length" or name == "best-path-confederation-paths" or name == "best-path-cost-community" or name == "best-path-med-always" or name == "best-path-med-missing" or name == "best-path-router-id" or name == "default-info-originate" or name == "default-metric" or name == "disable-auto-soft-reset" or name == "disable-enforce-first-as" or name == "disable-fast-external-fallover" or name == "disable-msg-log" or name == "disable-neighbor-logging" or name == "enforce-ibgp-out-policy" or name == "global-scan-time" or name == "graceful-reset" or name == "graceful-restart" or name == "graceful-restart-purge-time" or name == "graceful-restart-stalepath-time" or name == "graceful-restart-time" or name == "igp-loop-check" or name == "igp-redist-internal" or name == "install-diversion" or name == "local-preference" or name == "multi-path-as-path-ignore-onwards" or name == "mvpn" or name == "neighbor-logging-detail" or name == "next-hop-trigger-delay" or name == "nsr" or name == "read-only" or name == "router-id" or name == "rpki-bestpath-origin-as-allow-invalid" or name == "rpki-bestpath-use-origin-as-validity" or name == "rpki-origin-as-validation-disable" or name == "rpki-origin-as-validation-time" or name == "rpki-origin-as-validity-signal-ibgp" or name == "update-error-handling-basic-ebgp-disable" or name == "update-error-handling-basic-ibgp-disable" or name == "update-error-handling-extended-ebgp" or name == "update-error-handling-extended-ibgp" or name == "update-limit-process" or name == "update-out-logging"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "best-path-aigp-ignore"):
                                self.best_path_aigp_ignore = value
                                self.best_path_aigp_ignore.value_namespace = name_space
                                self.best_path_aigp_ignore.value_namespace_prefix = name_space_prefix
                            if(value_path == "best-path-as-multipath-relax"):
                                self.best_path_as_multipath_relax = value
                                self.best_path_as_multipath_relax.value_namespace = name_space
                                self.best_path_as_multipath_relax.value_namespace_prefix = name_space_prefix
                            if(value_path == "best-path-as-path-length"):
                                self.best_path_as_path_length = value
                                self.best_path_as_path_length.value_namespace = name_space
                                self.best_path_as_path_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "best-path-confederation-paths"):
                                self.best_path_confederation_paths = value
                                self.best_path_confederation_paths.value_namespace = name_space
                                self.best_path_confederation_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "best-path-cost-community"):
                                self.best_path_cost_community = value
                                self.best_path_cost_community.value_namespace = name_space
                                self.best_path_cost_community.value_namespace_prefix = name_space_prefix
                            if(value_path == "best-path-med-always"):
                                self.best_path_med_always = value
                                self.best_path_med_always.value_namespace = name_space
                                self.best_path_med_always.value_namespace_prefix = name_space_prefix
                            if(value_path == "best-path-med-missing"):
                                self.best_path_med_missing = value
                                self.best_path_med_missing.value_namespace = name_space
                                self.best_path_med_missing.value_namespace_prefix = name_space_prefix
                            if(value_path == "best-path-router-id"):
                                self.best_path_router_id = value
                                self.best_path_router_id.value_namespace = name_space
                                self.best_path_router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-info-originate"):
                                self.default_info_originate = value
                                self.default_info_originate.value_namespace = name_space
                                self.default_info_originate.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-metric"):
                                self.default_metric = value
                                self.default_metric.value_namespace = name_space
                                self.default_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-auto-soft-reset"):
                                self.disable_auto_soft_reset = value
                                self.disable_auto_soft_reset.value_namespace = name_space
                                self.disable_auto_soft_reset.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-enforce-first-as"):
                                self.disable_enforce_first_as = value
                                self.disable_enforce_first_as.value_namespace = name_space
                                self.disable_enforce_first_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-fast-external-fallover"):
                                self.disable_fast_external_fallover = value
                                self.disable_fast_external_fallover.value_namespace = name_space
                                self.disable_fast_external_fallover.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-msg-log"):
                                self.disable_msg_log = value
                                self.disable_msg_log.value_namespace = name_space
                                self.disable_msg_log.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-neighbor-logging"):
                                self.disable_neighbor_logging = value
                                self.disable_neighbor_logging.value_namespace = name_space
                                self.disable_neighbor_logging.value_namespace_prefix = name_space_prefix
                            if(value_path == "enforce-ibgp-out-policy"):
                                self.enforce_ibgp_out_policy = value
                                self.enforce_ibgp_out_policy.value_namespace = name_space
                                self.enforce_ibgp_out_policy.value_namespace_prefix = name_space_prefix
                            if(value_path == "global-scan-time"):
                                self.global_scan_time = value
                                self.global_scan_time.value_namespace = name_space
                                self.global_scan_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "graceful-reset"):
                                self.graceful_reset = value
                                self.graceful_reset.value_namespace = name_space
                                self.graceful_reset.value_namespace_prefix = name_space_prefix
                            if(value_path == "graceful-restart"):
                                self.graceful_restart = value
                                self.graceful_restart.value_namespace = name_space
                                self.graceful_restart.value_namespace_prefix = name_space_prefix
                            if(value_path == "graceful-restart-purge-time"):
                                self.graceful_restart_purge_time = value
                                self.graceful_restart_purge_time.value_namespace = name_space
                                self.graceful_restart_purge_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "graceful-restart-stalepath-time"):
                                self.graceful_restart_stalepath_time = value
                                self.graceful_restart_stalepath_time.value_namespace = name_space
                                self.graceful_restart_stalepath_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "graceful-restart-time"):
                                self.graceful_restart_time = value
                                self.graceful_restart_time.value_namespace = name_space
                                self.graceful_restart_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "igp-loop-check"):
                                self.igp_loop_check = value
                                self.igp_loop_check.value_namespace = name_space
                                self.igp_loop_check.value_namespace_prefix = name_space_prefix
                            if(value_path == "igp-redist-internal"):
                                self.igp_redist_internal = value
                                self.igp_redist_internal.value_namespace = name_space
                                self.igp_redist_internal.value_namespace_prefix = name_space_prefix
                            if(value_path == "install-diversion"):
                                self.install_diversion = value
                                self.install_diversion.value_namespace = name_space
                                self.install_diversion.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-preference"):
                                self.local_preference = value
                                self.local_preference.value_namespace = name_space
                                self.local_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "multi-path-as-path-ignore-onwards"):
                                self.multi_path_as_path_ignore_onwards = value
                                self.multi_path_as_path_ignore_onwards.value_namespace = name_space
                                self.multi_path_as_path_ignore_onwards.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvpn"):
                                self.mvpn = value
                                self.mvpn.value_namespace = name_space
                                self.mvpn.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-logging-detail"):
                                self.neighbor_logging_detail = value
                                self.neighbor_logging_detail.value_namespace = name_space
                                self.neighbor_logging_detail.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-trigger-delay"):
                                self.next_hop_trigger_delay = value
                                self.next_hop_trigger_delay.value_namespace = name_space
                                self.next_hop_trigger_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr"):
                                self.nsr = value
                                self.nsr.value_namespace = name_space
                                self.nsr.value_namespace_prefix = name_space_prefix
                            if(value_path == "read-only"):
                                self.read_only = value
                                self.read_only.value_namespace = name_space
                                self.read_only.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpki-bestpath-origin-as-allow-invalid"):
                                self.rpki_bestpath_origin_as_allow_invalid = value
                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace = name_space
                                self.rpki_bestpath_origin_as_allow_invalid.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpki-bestpath-use-origin-as-validity"):
                                self.rpki_bestpath_use_origin_as_validity = value
                                self.rpki_bestpath_use_origin_as_validity.value_namespace = name_space
                                self.rpki_bestpath_use_origin_as_validity.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpki-origin-as-validation-disable"):
                                self.rpki_origin_as_validation_disable = value
                                self.rpki_origin_as_validation_disable.value_namespace = name_space
                                self.rpki_origin_as_validation_disable.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpki-origin-as-validation-time"):
                                self.rpki_origin_as_validation_time = value
                                self.rpki_origin_as_validation_time.value_namespace = name_space
                                self.rpki_origin_as_validation_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpki-origin-as-validity-signal-ibgp"):
                                self.rpki_origin_as_validity_signal_ibgp = value
                                self.rpki_origin_as_validity_signal_ibgp.value_namespace = name_space
                                self.rpki_origin_as_validity_signal_ibgp.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-error-handling-basic-ebgp-disable"):
                                self.update_error_handling_basic_ebgp_disable = value
                                self.update_error_handling_basic_ebgp_disable.value_namespace = name_space
                                self.update_error_handling_basic_ebgp_disable.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-error-handling-basic-ibgp-disable"):
                                self.update_error_handling_basic_ibgp_disable = value
                                self.update_error_handling_basic_ibgp_disable.value_namespace = name_space
                                self.update_error_handling_basic_ibgp_disable.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-error-handling-extended-ebgp"):
                                self.update_error_handling_extended_ebgp = value
                                self.update_error_handling_extended_ebgp.value_namespace = name_space
                                self.update_error_handling_extended_ebgp.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-error-handling-extended-ibgp"):
                                self.update_error_handling_extended_ibgp = value
                                self.update_error_handling_extended_ibgp.value_namespace = name_space
                                self.update_error_handling_extended_ibgp.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-limit-process"):
                                self.update_limit_process = value
                                self.update_limit_process.value_namespace = name_space
                                self.update_limit_process.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-out-logging"):
                                self.update_out_logging = value
                                self.update_out_logging.value_namespace = name_space
                                self.update_out_logging.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.bgp_entity is not None and self.bgp_entity.has_data()) or
                            (self.global_ is not None and self.global_.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bgp_entity is not None and self.bgp_entity.has_operation()) or
                            (self.global_ is not None and self.global_.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "default-vrf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bgp-entity"):
                            if (self.bgp_entity is None):
                                self.bgp_entity = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity()
                                self.bgp_entity.parent = self
                                self._children_name_map["bgp_entity"] = "bgp-entity"
                            return self.bgp_entity

                        if (child_yang_name == "global"):
                            if (self.global_ is None):
                                self.global_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"
                            return self.global_

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bgp-entity" or name == "global"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.as_.is_set or
                        self.bgp_running.is_set or
                        (self.default_vrf is not None and self.default_vrf.has_data()) or
                        (self.vrfs is not None and self.vrfs.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.as_.yfilter != YFilter.not_set or
                        self.bgp_running.yfilter != YFilter.not_set or
                        (self.default_vrf is not None and self.default_vrf.has_operation()) or
                        (self.vrfs is not None and self.vrfs.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "four-byte-as" + "[as='" + self.as_.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.as_.get_name_leafdata())
                    if (self.bgp_running.is_set or self.bgp_running.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_running.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "default-vrf"):
                        if (self.default_vrf is None):
                            self.default_vrf = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf()
                            self.default_vrf.parent = self
                            self._children_name_map["default_vrf"] = "default-vrf"
                        return self.default_vrf

                    if (child_yang_name == "vrfs"):
                        if (self.vrfs is None):
                            self.vrfs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs()
                            self.vrfs.parent = self
                            self._children_name_map["vrfs"] = "vrfs"
                        return self.vrfs

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "default-vrf" or name == "vrfs" or name == "as" or name == "bgp-running"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "as"):
                        self.as_ = value
                        self.as_.value_namespace = name_space
                        self.as_.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-running"):
                        self.bgp_running = value
                        self.bgp_running.value_namespace = name_space
                        self.bgp_running.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.four_byte_as:
                    if (c.has_data()):
                        return True
                return self.as_.is_set

            def has_operation(self):
                for c in self.four_byte_as:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.as_.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "instance-as" + "[as='" + self.as_.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.as_.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "four-byte-as"):
                    for c in self.four_byte_as:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Bgp.Instance.InstanceAs.FourByteAs()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.four_byte_as.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "four-byte-as" or name == "as"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "as"):
                    self.as_ = value
                    self.as_.value_namespace = name_space
                    self.as_.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.instance_as:
                if (c.has_data()):
                    return True
            return self.instance_name.is_set

        def has_operation(self):
            for c in self.instance_as:
                if (c.has_operation()):
                    return True
            return (
                self.yfilter != YFilter.not_set or
                self.instance_name.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "instance" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-bgp-cfg:bgp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                leaf_name_data.append(self.instance_name.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "instance-as"):
                for c in self.instance_as:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Bgp.Instance.InstanceAs()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.instance_as.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "instance-as" or name == "instance-name"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "instance-name"):
                self.instance_name = value
                self.instance_name.value_namespace = name_space
                self.instance_name.value_namespace_prefix = name_space_prefix

    def has_data(self):
        for c in self.instance:
            if (c.has_data()):
                return True
        return False

    def has_operation(self):
        for c in self.instance:
            if (c.has_operation()):
                return True
        return self.yfilter != YFilter.not_set

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-bgp-cfg:bgp" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "instance"):
            for c in self.instance:
                segment = c.get_segment_path()
                if (segment_path == segment):
                    return c
            c = Bgp.Instance()
            c.parent = self
            local_reference_key = "ydk::seg::%s" % segment_path
            self._local_refs[local_reference_key] = c
            self.instance.append(c)
            return c

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "instance"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Bgp()
        return self._top_entity

class BmpServerAll(Entity):
    """
    bmp server all
    
    .. attribute:: maximum_buffer_size
    
    	Range in MegaBytes for the maximum buffer size of BMP message queue. The maximum buf\-size is 20% and default buf\-size is 15% of the platform virtual memory max\-limit (aka rlimit). Please run show bgp process performance\-statistics to see the individual values. Unit is in Megabytes
    	**type**\:  int
    
    	**range:** 1..4294967295
    
    	**units**\: megabyte
    
    .. attribute:: route_monitoring
    
    	Enable Route Monitoring capability for the BMP servers. BGP update messages messages will be regenrated with a table walk 
    	**type**\:   :py:class:`RouteMonitoring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServerAll.RouteMonitoring>`
    
    

    """

    _prefix = 'ipv4-bgp-cfg'
    _revision = '2015-08-27'

    def __init__(self):
        super(BmpServerAll, self).__init__()
        self._top_entity = None

        self.yang_name = "bmp-server-all"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-cfg"

        self.maximum_buffer_size = YLeaf(YType.uint32, "maximum-buffer-size")

        self.route_monitoring = BmpServerAll.RouteMonitoring()
        self.route_monitoring.parent = self
        self._children_name_map["route_monitoring"] = "route-monitoring"
        self._children_yang_names.add("route-monitoring")

    def __setattr__(self, name, value):
        self._check_monkey_patching_error(name, value)
        with _handle_type_error():
            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                    "Please use list append or extend method."
                                    .format(value))
            if isinstance(value, Enum.YLeaf):
                value = value.name
            if name in ("maximum_buffer_size") and name in self.__dict__:
                if isinstance(value, YLeaf):
                    self.__dict__[name].set(value.get())
                elif isinstance(value, YLeafList):
                    super(BmpServerAll, self).__setattr__(name, value)
                else:
                    self.__dict__[name].set(value)
            else:
                if hasattr(value, "parent") and name != "parent":
                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                        value.parent = self
                    elif value.parent is None and value.yang_name in self._children_yang_names:
                        value.parent = self
                super(BmpServerAll, self).__setattr__(name, value)


    class RouteMonitoring(Entity):
        """
        Enable Route Monitoring capability for the BMP
        servers.
        BGP update messages messages will be
        regenrated with a table walk
        
        
        .. attribute:: direction
        
        	Specify if the routes should be picked up at inbound or outbound direction
        	**type**\:   :py:class:`BmpRouteDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpRouteDirection>`
        
        .. attribute:: policy
        
        	Specify if the routes packed in update messages should be before or after the application of route\-policy
        	**type**\:   :py:class:`BmpPolicySelect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpPolicySelect>`
        
        

        """

        _prefix = 'ipv4-bgp-cfg'
        _revision = '2015-08-27'

        def __init__(self):
            super(BmpServerAll.RouteMonitoring, self).__init__()

            self.yang_name = "route-monitoring"
            self.yang_parent_name = "bmp-server-all"

            self.direction = YLeaf(YType.enumeration, "direction")

            self.policy = YLeaf(YType.enumeration, "policy")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("direction",
                            "policy") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(BmpServerAll.RouteMonitoring, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(BmpServerAll.RouteMonitoring, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.direction.is_set or
                self.policy.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.direction.yfilter != YFilter.not_set or
                self.policy.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "route-monitoring" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-server-all/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                leaf_name_data.append(self.direction.get_name_leafdata())
            if (self.policy.is_set or self.policy.yfilter != YFilter.not_set):
                leaf_name_data.append(self.policy.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "direction" or name == "policy"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "direction"):
                self.direction = value
                self.direction.value_namespace = name_space
                self.direction.value_namespace_prefix = name_space_prefix
            if(value_path == "policy"):
                self.policy = value
                self.policy.value_namespace = name_space
                self.policy.value_namespace_prefix = name_space_prefix

    def has_data(self):
        return (
            self.maximum_buffer_size.is_set or
            (self.route_monitoring is not None and self.route_monitoring.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            self.maximum_buffer_size.yfilter != YFilter.not_set or
            (self.route_monitoring is not None and self.route_monitoring.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-server-all" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()
        if (self.maximum_buffer_size.is_set or self.maximum_buffer_size.yfilter != YFilter.not_set):
            leaf_name_data.append(self.maximum_buffer_size.get_name_leafdata())

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "route-monitoring"):
            if (self.route_monitoring is None):
                self.route_monitoring = BmpServerAll.RouteMonitoring()
                self.route_monitoring.parent = self
                self._children_name_map["route_monitoring"] = "route-monitoring"
            return self.route_monitoring

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "route-monitoring" or name == "maximum-buffer-size"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        if(value_path == "maximum-buffer-size"):
            self.maximum_buffer_size = value
            self.maximum_buffer_size.value_namespace = name_space
            self.maximum_buffer_size.value_namespace_prefix = name_space_prefix

    def clone_ptr(self):
        self._top_entity = BmpServerAll()
        return self._top_entity

class BmpServers(Entity):
    """
    bmp servers
    
    .. attribute:: bmp_server
    
    	A particular BMP server
    	**type**\: list of    :py:class:`BmpServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer>`
    
    

    """

    _prefix = 'ipv4-bgp-cfg'
    _revision = '2015-08-27'

    def __init__(self):
        super(BmpServers, self).__init__()
        self._top_entity = None

        self.yang_name = "bmp-servers"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-cfg"

        self.bmp_server = YList(self)

    def __setattr__(self, name, value):
        self._check_monkey_patching_error(name, value)
        with _handle_type_error():
            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                    "Please use list append or extend method."
                                    .format(value))
            if isinstance(value, Enum.YLeaf):
                value = value.name
            if name in () and name in self.__dict__:
                if isinstance(value, YLeaf):
                    self.__dict__[name].set(value.get())
                elif isinstance(value, YLeafList):
                    super(BmpServers, self).__setattr__(name, value)
                else:
                    self.__dict__[name].set(value)
            else:
                if hasattr(value, "parent") and name != "parent":
                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                        value.parent = self
                    elif value.parent is None and value.yang_name in self._children_yang_names:
                        value.parent = self
                super(BmpServers, self).__setattr__(name, value)


    class BmpServer(Entity):
        """
        A particular BMP server
        
        .. attribute:: server_id  <key>
        
        	BMP Server ID
        	**type**\:  int
        
        	**range:** 1..8
        
        .. attribute:: bmptcp_keep_alive
        
        	configure TCP keep alives to be exchanged between client and server. Default=1000
        	**type**\:  int
        
        	**range:** 0..7200
        
        	**units**\: second
        
        .. attribute:: bmptcp_maximum_segment_size
        
        	configure TCP maximum segment size. Default=16384
        	**type**\:  int
        
        	**range:** 68..10000
        
        	**units**\: byte
        
        .. attribute:: create
        
        	BMP Server Creation
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: description
        
        	String to describe the BMP server
        	**type**\:  str
        
        .. attribute:: flapping_delay
        
        	Delay in connecting to BMP Server after a flap had been detected
        	**type**\:  int
        
        	**range:** 60..3600
        
        	**units**\: second
        
        .. attribute:: host_port
        
        	Configure Host Name/Address and Port for BMP Server
        	**type**\:   :py:class:`HostPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer.HostPort>`
        
        .. attribute:: initial_delay
        
        	Initial connect delay in seconds in sending updates
        	**type**\:  int
        
        	**range:** 1..3600
        
        	**units**\: second
        
        .. attribute:: initial_refresh_delay
        
        	Initial refresh to generate BGP updates
        	**type**\:   :py:class:`InitialRefreshDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer.InitialRefreshDelay>`
        
        .. attribute:: maximum_buffer_size
        
        	Range in MegaBytes for the maximum buffer size of BMP message queue. The maximum buf\-size is 20% and default buf\-size is 15% of the platform virtual memory max\-limit (aka rlimit) . Please run show bgp process performance\-statistics to see the individual values. Unit is in Megabytes
        	**type**\:  int
        
        	**range:** 1..4294967295
        
        	**units**\: megabyte
        
        .. attribute:: shutdown
        
        	TRUE to shutdown the BMP Server ConnectionFALSE to bring back the BMP Server Connection
        	**type**\:  bool
        
        .. attribute:: status_report_interval
        
        	Stats reporting period for BMP server
        	**type**\:  int
        
        	**range:** 1..3600
        
        	**units**\: second
        
        .. attribute:: tos
        
        	TOS (Type Of Service)
        	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer.Tos>`
        
        .. attribute:: update_source_interface
        
        	Select an interface to configure
        	**type**\:  str
        
        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
        
        .. attribute:: vrf
        
        	VRF for BMP Server
        	**type**\:  str
        
        

        """

        _prefix = 'ipv4-bgp-cfg'
        _revision = '2015-08-27'

        def __init__(self):
            super(BmpServers.BmpServer, self).__init__()

            self.yang_name = "bmp-server"
            self.yang_parent_name = "bmp-servers"

            self.server_id = YLeaf(YType.uint32, "server-id")

            self.bmptcp_keep_alive = YLeaf(YType.uint32, "bmptcp-keep-alive")

            self.bmptcp_maximum_segment_size = YLeaf(YType.uint32, "bmptcp-maximum-segment-size")

            self.create = YLeaf(YType.empty, "create")

            self.description = YLeaf(YType.str, "description")

            self.flapping_delay = YLeaf(YType.uint32, "flapping-delay")

            self.initial_delay = YLeaf(YType.uint32, "initial-delay")

            self.maximum_buffer_size = YLeaf(YType.uint32, "maximum-buffer-size")

            self.shutdown = YLeaf(YType.boolean, "shutdown")

            self.status_report_interval = YLeaf(YType.uint32, "status-report-interval")

            self.update_source_interface = YLeaf(YType.str, "update-source-interface")

            self.vrf = YLeaf(YType.str, "vrf")

            self.host_port = BmpServers.BmpServer.HostPort()
            self.host_port.parent = self
            self._children_name_map["host_port"] = "host-port"
            self._children_yang_names.add("host-port")

            self.initial_refresh_delay = BmpServers.BmpServer.InitialRefreshDelay()
            self.initial_refresh_delay.parent = self
            self._children_name_map["initial_refresh_delay"] = "initial-refresh-delay"
            self._children_yang_names.add("initial-refresh-delay")

            self.tos = BmpServers.BmpServer.Tos()
            self.tos.parent = self
            self._children_name_map["tos"] = "tos"
            self._children_yang_names.add("tos")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("server_id",
                            "bmptcp_keep_alive",
                            "bmptcp_maximum_segment_size",
                            "create",
                            "description",
                            "flapping_delay",
                            "initial_delay",
                            "maximum_buffer_size",
                            "shutdown",
                            "status_report_interval",
                            "update_source_interface",
                            "vrf") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(BmpServers.BmpServer, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(BmpServers.BmpServer, self).__setattr__(name, value)


        class InitialRefreshDelay(Entity):
            """
            Initial refresh to generate BGP updates
            
            .. attribute:: delay
            
            	Delay in seconds before sending Refresh request to Peers
            	**type**\:  int
            
            	**range:** 0..3600
            
            	**units**\: second
            
            .. attribute:: spread
            
            	Spread over which to send initial Refresh request to Peers
            	**type**\:  int
            
            	**range:** 0..3600
            
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2015-08-27'

            def __init__(self):
                super(BmpServers.BmpServer.InitialRefreshDelay, self).__init__()

                self.yang_name = "initial-refresh-delay"
                self.yang_parent_name = "bmp-server"

                self.delay = YLeaf(YType.uint32, "delay")

                self.spread = YLeaf(YType.uint32, "spread")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("delay",
                                "spread") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BmpServers.BmpServer.InitialRefreshDelay, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BmpServers.BmpServer.InitialRefreshDelay, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.delay.is_set or
                    self.spread.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.delay.yfilter != YFilter.not_set or
                    self.spread.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "initial-refresh-delay" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.delay.is_set or self.delay.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.delay.get_name_leafdata())
                if (self.spread.is_set or self.spread.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.spread.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "delay" or name == "spread"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "delay"):
                    self.delay = value
                    self.delay.value_namespace = name_space
                    self.delay.value_namespace_prefix = name_space_prefix
                if(value_path == "spread"):
                    self.spread = value
                    self.spread.value_namespace = name_space
                    self.spread.value_namespace_prefix = name_space_prefix


        class HostPort(Entity):
            """
            Configure Host Name/Address and Port for BMP
            Server
            
            .. attribute:: host
            
            	Name of the BMP server(accepts IPv4/IPv6 Address format too)
            	**type**\:  str
            
            .. attribute:: port
            
            	Port Number of listening BMP server
            	**type**\:  int
            
            	**range:** 1..65535
            
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2015-08-27'

            def __init__(self):
                super(BmpServers.BmpServer.HostPort, self).__init__()

                self.yang_name = "host-port"
                self.yang_parent_name = "bmp-server"

                self.host = YLeaf(YType.str, "host")

                self.port = YLeaf(YType.uint16, "port")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("host",
                                "port") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BmpServers.BmpServer.HostPort, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BmpServers.BmpServer.HostPort, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.host.is_set or
                    self.port.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.host.yfilter != YFilter.not_set or
                    self.port.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "host-port" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.host.is_set or self.host.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.host.get_name_leafdata())
                if (self.port.is_set or self.port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.port.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "host" or name == "port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "host"):
                    self.host = value
                    self.host.value_namespace = name_space
                    self.host.value_namespace_prefix = name_space_prefix
                if(value_path == "port"):
                    self.port = value
                    self.port.value_namespace = name_space
                    self.port.value_namespace_prefix = name_space_prefix


        class Tos(Entity):
            """
            TOS (Type Of Service)
            
            .. attribute:: type
            
            	Set type of service
            	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
            
            .. attribute:: value
            
            	TOS value to set
            	**type**\: one of the below types:
            
            	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
            
            
            ----
            	**type**\:  int
            
            	**range:** 0..63
            
            
            ----
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2015-08-27'

            def __init__(self):
                super(BmpServers.BmpServer.Tos, self).__init__()

                self.yang_name = "tos"
                self.yang_parent_name = "bmp-server"

                self.type = YLeaf(YType.enumeration, "type")

                self.value = YLeaf(YType.str, "value")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("type",
                                "value") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BmpServers.BmpServer.Tos, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BmpServers.BmpServer.Tos, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.type.is_set or
                    self.value.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.type.yfilter != YFilter.not_set or
                    self.value.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "tos" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.type.get_name_leafdata())
                if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.value.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "type" or name == "value"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "type"):
                    self.type = value
                    self.type.value_namespace = name_space
                    self.type.value_namespace_prefix = name_space_prefix
                if(value_path == "value"):
                    self.value = value
                    self.value.value_namespace = name_space
                    self.value.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                self.server_id.is_set or
                self.bmptcp_keep_alive.is_set or
                self.bmptcp_maximum_segment_size.is_set or
                self.create.is_set or
                self.description.is_set or
                self.flapping_delay.is_set or
                self.initial_delay.is_set or
                self.maximum_buffer_size.is_set or
                self.shutdown.is_set or
                self.status_report_interval.is_set or
                self.update_source_interface.is_set or
                self.vrf.is_set or
                (self.host_port is not None and self.host_port.has_data()) or
                (self.initial_refresh_delay is not None and self.initial_refresh_delay.has_data()) or
                (self.tos is not None and self.tos.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.server_id.yfilter != YFilter.not_set or
                self.bmptcp_keep_alive.yfilter != YFilter.not_set or
                self.bmptcp_maximum_segment_size.yfilter != YFilter.not_set or
                self.create.yfilter != YFilter.not_set or
                self.description.yfilter != YFilter.not_set or
                self.flapping_delay.yfilter != YFilter.not_set or
                self.initial_delay.yfilter != YFilter.not_set or
                self.maximum_buffer_size.yfilter != YFilter.not_set or
                self.shutdown.yfilter != YFilter.not_set or
                self.status_report_interval.yfilter != YFilter.not_set or
                self.update_source_interface.yfilter != YFilter.not_set or
                self.vrf.yfilter != YFilter.not_set or
                (self.host_port is not None and self.host_port.has_operation()) or
                (self.initial_refresh_delay is not None and self.initial_refresh_delay.has_operation()) or
                (self.tos is not None and self.tos.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bmp-server" + "[server-id='" + self.server_id.get() + "']" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-servers/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.server_id.is_set or self.server_id.yfilter != YFilter.not_set):
                leaf_name_data.append(self.server_id.get_name_leafdata())
            if (self.bmptcp_keep_alive.is_set or self.bmptcp_keep_alive.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bmptcp_keep_alive.get_name_leafdata())
            if (self.bmptcp_maximum_segment_size.is_set or self.bmptcp_maximum_segment_size.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bmptcp_maximum_segment_size.get_name_leafdata())
            if (self.create.is_set or self.create.yfilter != YFilter.not_set):
                leaf_name_data.append(self.create.get_name_leafdata())
            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                leaf_name_data.append(self.description.get_name_leafdata())
            if (self.flapping_delay.is_set or self.flapping_delay.yfilter != YFilter.not_set):
                leaf_name_data.append(self.flapping_delay.get_name_leafdata())
            if (self.initial_delay.is_set or self.initial_delay.yfilter != YFilter.not_set):
                leaf_name_data.append(self.initial_delay.get_name_leafdata())
            if (self.maximum_buffer_size.is_set or self.maximum_buffer_size.yfilter != YFilter.not_set):
                leaf_name_data.append(self.maximum_buffer_size.get_name_leafdata())
            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                leaf_name_data.append(self.shutdown.get_name_leafdata())
            if (self.status_report_interval.is_set or self.status_report_interval.yfilter != YFilter.not_set):
                leaf_name_data.append(self.status_report_interval.get_name_leafdata())
            if (self.update_source_interface.is_set or self.update_source_interface.yfilter != YFilter.not_set):
                leaf_name_data.append(self.update_source_interface.get_name_leafdata())
            if (self.vrf.is_set or self.vrf.yfilter != YFilter.not_set):
                leaf_name_data.append(self.vrf.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "host-port"):
                if (self.host_port is None):
                    self.host_port = BmpServers.BmpServer.HostPort()
                    self.host_port.parent = self
                    self._children_name_map["host_port"] = "host-port"
                return self.host_port

            if (child_yang_name == "initial-refresh-delay"):
                if (self.initial_refresh_delay is None):
                    self.initial_refresh_delay = BmpServers.BmpServer.InitialRefreshDelay()
                    self.initial_refresh_delay.parent = self
                    self._children_name_map["initial_refresh_delay"] = "initial-refresh-delay"
                return self.initial_refresh_delay

            if (child_yang_name == "tos"):
                if (self.tos is None):
                    self.tos = BmpServers.BmpServer.Tos()
                    self.tos.parent = self
                    self._children_name_map["tos"] = "tos"
                return self.tos

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "host-port" or name == "initial-refresh-delay" or name == "tos" or name == "server-id" or name == "bmptcp-keep-alive" or name == "bmptcp-maximum-segment-size" or name == "create" or name == "description" or name == "flapping-delay" or name == "initial-delay" or name == "maximum-buffer-size" or name == "shutdown" or name == "status-report-interval" or name == "update-source-interface" or name == "vrf"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "server-id"):
                self.server_id = value
                self.server_id.value_namespace = name_space
                self.server_id.value_namespace_prefix = name_space_prefix
            if(value_path == "bmptcp-keep-alive"):
                self.bmptcp_keep_alive = value
                self.bmptcp_keep_alive.value_namespace = name_space
                self.bmptcp_keep_alive.value_namespace_prefix = name_space_prefix
            if(value_path == "bmptcp-maximum-segment-size"):
                self.bmptcp_maximum_segment_size = value
                self.bmptcp_maximum_segment_size.value_namespace = name_space
                self.bmptcp_maximum_segment_size.value_namespace_prefix = name_space_prefix
            if(value_path == "create"):
                self.create = value
                self.create.value_namespace = name_space
                self.create.value_namespace_prefix = name_space_prefix
            if(value_path == "description"):
                self.description = value
                self.description.value_namespace = name_space
                self.description.value_namespace_prefix = name_space_prefix
            if(value_path == "flapping-delay"):
                self.flapping_delay = value
                self.flapping_delay.value_namespace = name_space
                self.flapping_delay.value_namespace_prefix = name_space_prefix
            if(value_path == "initial-delay"):
                self.initial_delay = value
                self.initial_delay.value_namespace = name_space
                self.initial_delay.value_namespace_prefix = name_space_prefix
            if(value_path == "maximum-buffer-size"):
                self.maximum_buffer_size = value
                self.maximum_buffer_size.value_namespace = name_space
                self.maximum_buffer_size.value_namespace_prefix = name_space_prefix
            if(value_path == "shutdown"):
                self.shutdown = value
                self.shutdown.value_namespace = name_space
                self.shutdown.value_namespace_prefix = name_space_prefix
            if(value_path == "status-report-interval"):
                self.status_report_interval = value
                self.status_report_interval.value_namespace = name_space
                self.status_report_interval.value_namespace_prefix = name_space_prefix
            if(value_path == "update-source-interface"):
                self.update_source_interface = value
                self.update_source_interface.value_namespace = name_space
                self.update_source_interface.value_namespace_prefix = name_space_prefix
            if(value_path == "vrf"):
                self.vrf = value
                self.vrf.value_namespace = name_space
                self.vrf.value_namespace_prefix = name_space_prefix

    def has_data(self):
        for c in self.bmp_server:
            if (c.has_data()):
                return True
        return False

    def has_operation(self):
        for c in self.bmp_server:
            if (c.has_operation()):
                return True
        return self.yfilter != YFilter.not_set

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-servers" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "bmp-server"):
            for c in self.bmp_server:
                segment = c.get_segment_path()
                if (segment_path == segment):
                    return c
            c = BmpServers.BmpServer()
            c.parent = self
            local_reference_key = "ydk::seg::%s" % segment_path
            self._local_refs[local_reference_key] = c
            self.bmp_server.append(c)
            return c

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "bmp-server"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = BmpServers()
        return self._top_entity

